/********************************************************************************
** Form generated from reading UI file 'flattencolumnswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FLATTENCOLUMNSWIDGET_H
#define UI_FLATTENCOLUMNSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FlattenColumnsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *FlattenColumnsWidget)
    {
        if (FlattenColumnsWidget->objectName().isEmpty())
            FlattenColumnsWidget->setObjectName("FlattenColumnsWidget");
        FlattenColumnsWidget->resize(472, 269);
        verticalLayout = new QVBoxLayout(FlattenColumnsWidget);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(FlattenColumnsWidget);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        verticalLayout->addWidget(label);

        scrollArea = new QScrollArea(FlattenColumnsWidget);
        scrollArea->setObjectName("scrollArea");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(scrollArea->sizePolicy().hasHeightForWidth());
        scrollArea->setSizePolicy(sizePolicy);
        scrollArea->setFrameShape(QFrame::NoFrame);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 460, 83));
        gridLayout = new QGridLayout(scrollAreaWidgetContents);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout->addWidget(scrollArea);

        verticalSpacer = new QSpacerItem(20, 37, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(FlattenColumnsWidget);

        QMetaObject::connectSlotsByName(FlattenColumnsWidget);
    } // setupUi

    void retranslateUi(QWidget *FlattenColumnsWidget)
    {
        FlattenColumnsWidget->setWindowTitle(tr2i18n("Form", nullptr));
        label->setText(tr2i18n("Flatten selected columns relative to:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FlattenColumnsWidget: public Ui_FlattenColumnsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FLATTENCOLUMNSWIDGET_H

