/********************************************************************************
** Form generated from reading UI file 'aspectdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ASPECTDOCK_H
#define UI_ASPECTDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_AspectDock
{
public:
    QGridLayout *gridLayout;
    QLabel *lName;
    TimedLineEdit *leName;
    ResizableTextEdit *teComment;
    QLabel *lComment;
    QSpacerItem *verticalSpacer;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *AspectDock)
    {
        if (AspectDock->objectName().isEmpty())
            AspectDock->setObjectName("AspectDock");
        AspectDock->resize(357, 410);
        gridLayout = new QGridLayout(AspectDock);
        gridLayout->setObjectName("gridLayout");
        lName = new QLabel(AspectDock);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        leName = new TimedLineEdit(AspectDock);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        teComment = new ResizableTextEdit(AspectDock);
        teComment->setObjectName("teComment");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(teComment->sizePolicy().hasHeightForWidth());
        teComment->setSizePolicy(sizePolicy);
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        lComment = new QLabel(AspectDock);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 2, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 1, 1, 1);


        retranslateUi(AspectDock);

        QMetaObject::connectSlotsByName(AspectDock);
    } // setupUi

    void retranslateUi(QWidget *AspectDock)
    {
        lName->setText(tr2i18n("Name:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        (void)AspectDock;
    } // retranslateUi

};

namespace Ui {
    class AspectDock: public Ui_AspectDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ASPECTDOCK_H

