/********************************************************************************
** Form generated from reading UI file 'hdf5optionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HDF5OPTIONSWIDGET_H
#define UI_HDF5OPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_HDF5OptionsWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QGridLayout *gridLayout_2;
    QPushButton *bRefreshPreview;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QSpinBox *sbPreviewLines;
    QHBoxLayout *horizontalLayout_3;
    QSplitter *splitter;
    QTreeWidget *twContent;
    QTableWidget *twPreview;

    void setupUi(QWidget *HDF5OptionsWidget)
    {
        if (HDF5OptionsWidget->objectName().isEmpty())
            HDF5OptionsWidget->setObjectName("HDF5OptionsWidget");
        HDF5OptionsWidget->resize(500, 250);
        gridLayout = new QGridLayout(HDF5OptionsWidget);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        bRefreshPreview = new QPushButton(HDF5OptionsWidget);
        bRefreshPreview->setObjectName("bRefreshPreview");

        gridLayout_2->addWidget(bRefreshPreview, 0, 4, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 2, 1, 1);

        label = new QLabel(HDF5OptionsWidget);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        sbPreviewLines = new QSpinBox(HDF5OptionsWidget);
        sbPreviewLines->setObjectName("sbPreviewLines");
        sbPreviewLines->setMinimum(1);
        sbPreviewLines->setMaximum(10000);
        sbPreviewLines->setValue(100);

        gridLayout_2->addWidget(sbPreviewLines, 0, 1, 1, 1);


        horizontalLayout->addLayout(gridLayout_2);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        splitter = new QSplitter(HDF5OptionsWidget);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        twContent = new QTreeWidget(splitter);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        twContent->setHeaderItem(__qtreewidgetitem);
        twContent->setObjectName("twContent");
        splitter->addWidget(twContent);
        twContent->header()->setStretchLastSection(false);
        twPreview = new QTableWidget(splitter);
        twPreview->setObjectName("twPreview");
        splitter->addWidget(twPreview);
        twPreview->horizontalHeader()->setVisible(false);
        twPreview->verticalHeader()->setVisible(false);

        horizontalLayout_3->addWidget(splitter);


        gridLayout->addLayout(horizontalLayout_3, 1, 0, 1, 1);


        retranslateUi(HDF5OptionsWidget);

        QMetaObject::connectSlotsByName(HDF5OptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *HDF5OptionsWidget)
    {
        bRefreshPreview->setText(tr2i18n("Refresh", nullptr));
        label->setText(tr2i18n("Number of rows to preview:", nullptr));
#if QT_CONFIG(tooltip)
        twContent->setToolTip(tr2i18n("Shows the content of the selected HDF5 file", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)HDF5OptionsWidget;
    } // retranslateUi

};

namespace Ui {
    class HDF5OptionsWidget: public Ui_HDF5OptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // HDF5OPTIONSWIDGET_H

