/********************************************************************************
** Form generated from reading UI file 'fitsheadereditnewkeywordwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FITSHEADEREDITNEWKEYWORDWIDGET_H
#define UI_FITSHEADEREDITNEWKEYWORDWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FITSHeaderEditNewKeywordDialog
{
public:
    QGridLayout *gridLayout;
    QLineEdit *leKey;
    QLabel *lComment;
    QLineEdit *leComment;
    QLineEdit *leValue;
    QLabel *lValue;
    QLabel *lKey;

    void setupUi(QWidget *FITSHeaderEditNewKeywordDialog)
    {
        if (FITSHeaderEditNewKeywordDialog->objectName().isEmpty())
            FITSHeaderEditNewKeywordDialog->setObjectName("FITSHeaderEditNewKeywordDialog");
        FITSHeaderEditNewKeywordDialog->resize(454, 159);
        gridLayout = new QGridLayout(FITSHeaderEditNewKeywordDialog);
        gridLayout->setObjectName("gridLayout");
        leKey = new QLineEdit(FITSHeaderEditNewKeywordDialog);
        leKey->setObjectName("leKey");
        leKey->setClearButtonEnabled(true);

        gridLayout->addWidget(leKey, 0, 2, 1, 1);

        lComment = new QLabel(FITSHeaderEditNewKeywordDialog);
        lComment->setObjectName("lComment");

        gridLayout->addWidget(lComment, 2, 0, 1, 2);

        leComment = new QLineEdit(FITSHeaderEditNewKeywordDialog);
        leComment->setObjectName("leComment");
        leComment->setClearButtonEnabled(true);

        gridLayout->addWidget(leComment, 2, 2, 1, 1);

        leValue = new QLineEdit(FITSHeaderEditNewKeywordDialog);
        leValue->setObjectName("leValue");
        leValue->setClearButtonEnabled(true);

        gridLayout->addWidget(leValue, 1, 2, 1, 1);

        lValue = new QLabel(FITSHeaderEditNewKeywordDialog);
        lValue->setObjectName("lValue");

        gridLayout->addWidget(lValue, 1, 0, 1, 2);

        lKey = new QLabel(FITSHeaderEditNewKeywordDialog);
        lKey->setObjectName("lKey");

        gridLayout->addWidget(lKey, 0, 0, 1, 2);

        QWidget::setTabOrder(leKey, leValue);
        QWidget::setTabOrder(leValue, leComment);

        retranslateUi(FITSHeaderEditNewKeywordDialog);

        QMetaObject::connectSlotsByName(FITSHeaderEditNewKeywordDialog);
    } // setupUi

    void retranslateUi(QWidget *FITSHeaderEditNewKeywordDialog)
    {
        leKey->setPlaceholderText(tr2i18n("Enter search term here", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        leComment->setPlaceholderText(tr2i18n("Enter search term here", nullptr));
        leValue->setPlaceholderText(tr2i18n("Enter search term here", nullptr));
        lValue->setText(tr2i18n("Value:", nullptr));
        lKey->setText(tr2i18n("Key:", nullptr));
        (void)FITSHeaderEditNewKeywordDialog;
    } // retranslateUi

};

namespace Ui {
    class FITSHeaderEditNewKeywordDialog: public Ui_FITSHeaderEditNewKeywordDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FITSHEADEREDITNEWKEYWORDWIDGET_H

