/********************************************************************************
** Form generated from reading UI file 'asciioptionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ASCIIOPTIONSWIDGET_H
#define UI_ASCIIOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_AsciiOptionsWidget
{
public:
    QGridLayout *gridLayout_2;
    QCheckBox *chbSkipEmptyParts;
    QComboBox *cbDecimalSeparator;
    QLabel *lColumnMode;
    QLineEdit *kleColumnMode;
    QCheckBox *chbSimplifyWhitespaces;
    QLabel *lSeparatingCharacter;
    QLineEdit *kleVectorNames;
    QCheckBox *chbCreateTimestamp;
    QLabel *lDecimalSeparator;
    QCheckBox *chbIntAsDouble;
    QSpinBox *sbYearBase;
    QLabel *lVectorNames;
    QCheckBox *chbRemoveQuotes;
    QLabel *label;
    QLabel *label_7;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *horizontalSpacer;
    KComboBox *cbSeparatingCharacter;
    QCheckBox *chbConvertNaNToZero;
    QCheckBox *chbCreateIndex;
    QSpacerItem *verticalSpacer_4;
    KComboBox *cbCommentCharacter;
    KComboBox *cbDateTimeFormat;
    QLabel *lDateTimeFormat;
    QCheckBox *chbHeader;
    QSpinBox *sbHeaderLine;

    void setupUi(QWidget *AsciiOptionsWidget)
    {
        if (AsciiOptionsWidget->objectName().isEmpty())
            AsciiOptionsWidget->setObjectName("AsciiOptionsWidget");
        AsciiOptionsWidget->resize(744, 278);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(AsciiOptionsWidget->sizePolicy().hasHeightForWidth());
        AsciiOptionsWidget->setSizePolicy(sizePolicy);
        gridLayout_2 = new QGridLayout(AsciiOptionsWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        chbSkipEmptyParts = new QCheckBox(AsciiOptionsWidget);
        chbSkipEmptyParts->setObjectName("chbSkipEmptyParts");

        gridLayout_2->addWidget(chbSkipEmptyParts, 2, 4, 1, 2);

        cbDecimalSeparator = new QComboBox(AsciiOptionsWidget);
        cbDecimalSeparator->setObjectName("cbDecimalSeparator");

        gridLayout_2->addWidget(cbDecimalSeparator, 2, 2, 1, 1);

        lColumnMode = new QLabel(AsciiOptionsWidget);
        lColumnMode->setObjectName("lColumnMode");

        gridLayout_2->addWidget(lColumnMode, 9, 0, 1, 1);

        kleColumnMode = new QLineEdit(AsciiOptionsWidget);
        kleColumnMode->setObjectName("kleColumnMode");

        gridLayout_2->addWidget(kleColumnMode, 9, 2, 1, 5);

        chbSimplifyWhitespaces = new QCheckBox(AsciiOptionsWidget);
        chbSimplifyWhitespaces->setObjectName("chbSimplifyWhitespaces");
        chbSimplifyWhitespaces->setChecked(false);

        gridLayout_2->addWidget(chbSimplifyWhitespaces, 1, 6, 1, 1);

        lSeparatingCharacter = new QLabel(AsciiOptionsWidget);
        lSeparatingCharacter->setObjectName("lSeparatingCharacter");

        gridLayout_2->addWidget(lSeparatingCharacter, 1, 0, 1, 2);

        kleVectorNames = new QLineEdit(AsciiOptionsWidget);
        kleVectorNames->setObjectName("kleVectorNames");
        kleVectorNames->setEnabled(true);
        kleVectorNames->setProperty("showClearButton", QVariant(true));

        gridLayout_2->addWidget(kleVectorNames, 8, 2, 1, 5);

        chbCreateTimestamp = new QCheckBox(AsciiOptionsWidget);
        chbCreateTimestamp->setObjectName("chbCreateTimestamp");

        gridLayout_2->addWidget(chbCreateTimestamp, 0, 6, 1, 1);

        lDecimalSeparator = new QLabel(AsciiOptionsWidget);
        lDecimalSeparator->setObjectName("lDecimalSeparator");

        gridLayout_2->addWidget(lDecimalSeparator, 2, 0, 1, 2);

        chbIntAsDouble = new QCheckBox(AsciiOptionsWidget);
        chbIntAsDouble->setObjectName("chbIntAsDouble");
        chbIntAsDouble->setChecked(true);

        gridLayout_2->addWidget(chbIntAsDouble, 3, 4, 1, 1);

        sbYearBase = new QSpinBox(AsciiOptionsWidget);
        sbYearBase->setObjectName("sbYearBase");
        sbYearBase->setMinimum(-1000000);
        sbYearBase->setMaximum(1000000);
        sbYearBase->setSingleStep(100);
        sbYearBase->setValue(1900);

        gridLayout_2->addWidget(sbYearBase, 4, 6, 1, 1);

        lVectorNames = new QLabel(AsciiOptionsWidget);
        lVectorNames->setObjectName("lVectorNames");

        gridLayout_2->addWidget(lVectorNames, 8, 0, 1, 2);

        chbRemoveQuotes = new QCheckBox(AsciiOptionsWidget);
        chbRemoveQuotes->setObjectName("chbRemoveQuotes");

        gridLayout_2->addWidget(chbRemoveQuotes, 2, 6, 1, 1);

        label = new QLabel(AsciiOptionsWidget);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 4, 4, 1, 2);

        label_7 = new QLabel(AsciiOptionsWidget);
        label_7->setObjectName("label_7");

        gridLayout_2->addWidget(label_7, 0, 0, 1, 2);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_3, 0, 3, 1, 1);

        horizontalSpacer = new QSpacerItem(91, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 7, 1, 1);

        cbSeparatingCharacter = new KComboBox(AsciiOptionsWidget);
        cbSeparatingCharacter->setObjectName("cbSeparatingCharacter");
        cbSeparatingCharacter->setEditable(true);

        gridLayout_2->addWidget(cbSeparatingCharacter, 1, 2, 1, 1);

        chbConvertNaNToZero = new QCheckBox(AsciiOptionsWidget);
        chbConvertNaNToZero->setObjectName("chbConvertNaNToZero");
        chbConvertNaNToZero->setChecked(false);

        gridLayout_2->addWidget(chbConvertNaNToZero, 1, 4, 1, 2);

        chbCreateIndex = new QCheckBox(AsciiOptionsWidget);
        chbCreateIndex->setObjectName("chbCreateIndex");

        gridLayout_2->addWidget(chbCreateIndex, 0, 4, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 44, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_4, 10, 0, 1, 1);

        cbCommentCharacter = new KComboBox(AsciiOptionsWidget);
        cbCommentCharacter->setObjectName("cbCommentCharacter");
        sizePolicy.setHeightForWidth(cbCommentCharacter->sizePolicy().hasHeightForWidth());
        cbCommentCharacter->setSizePolicy(sizePolicy);
        cbCommentCharacter->setEditable(true);

        gridLayout_2->addWidget(cbCommentCharacter, 0, 2, 1, 1);

        cbDateTimeFormat = new KComboBox(AsciiOptionsWidget);
        cbDateTimeFormat->setObjectName("cbDateTimeFormat");
        sizePolicy.setHeightForWidth(cbDateTimeFormat->sizePolicy().hasHeightForWidth());
        cbDateTimeFormat->setSizePolicy(sizePolicy);
        cbDateTimeFormat->setEditable(true);

        gridLayout_2->addWidget(cbDateTimeFormat, 3, 2, 1, 1);

        lDateTimeFormat = new QLabel(AsciiOptionsWidget);
        lDateTimeFormat->setObjectName("lDateTimeFormat");

        gridLayout_2->addWidget(lDateTimeFormat, 3, 0, 1, 1);

        chbHeader = new QCheckBox(AsciiOptionsWidget);
        chbHeader->setObjectName("chbHeader");

        gridLayout_2->addWidget(chbHeader, 4, 0, 1, 1);

        sbHeaderLine = new QSpinBox(AsciiOptionsWidget);
        sbHeaderLine->setObjectName("sbHeaderLine");
        sbHeaderLine->setMinimum(1);
        sbHeaderLine->setMaximum(999);

        gridLayout_2->addWidget(sbHeaderLine, 4, 2, 1, 1);


        retranslateUi(AsciiOptionsWidget);

        QMetaObject::connectSlotsByName(AsciiOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *AsciiOptionsWidget)
    {
        chbSkipEmptyParts->setText(tr2i18n("Skip empty Parts", nullptr));
        lColumnMode->setText(tr2i18n("Column Data Types:", nullptr));
#if QT_CONFIG(tooltip)
        chbSimplifyWhitespaces->setToolTip(tr2i18n("Removes the whitespaces from the start and the end, and replaces each sequence of internal whitespaces with a single space.", nullptr));
#endif // QT_CONFIG(tooltip)
        chbSimplifyWhitespaces->setText(tr2i18n("Simplify Whitespaces", nullptr));
        lSeparatingCharacter->setText(tr2i18n("Column Separator:", nullptr));
        chbCreateTimestamp->setText(tr2i18n("Create Timestamp ", nullptr));
        lDecimalSeparator->setText(tr2i18n("Decimal Separator:", nullptr));
        chbIntAsDouble->setText(tr2i18n("Import Integer as Double", nullptr));
#if QT_CONFIG(tooltip)
        sbYearBase->setToolTip(tr2i18n("Base year when only 2 digits are provided for the year", nullptr));
#endif // QT_CONFIG(tooltip)
        lVectorNames->setText(tr2i18n("Column Names:", nullptr));
        chbRemoveQuotes->setText(tr2i18n("Remove Quotes", nullptr));
        label->setText(tr2i18n("Year Base:", nullptr));
        label_7->setText(tr2i18n("Comment Character:", nullptr));
        chbConvertNaNToZero->setText(tr2i18n("Convert NaN to 0", nullptr));
        chbCreateIndex->setText(tr2i18n("Create Index", nullptr));
        lDateTimeFormat->setText(tr2i18n("DateTime Format:", nullptr));
        chbHeader->setText(tr2i18n("Names at Line:", nullptr));
        (void)AsciiOptionsWidget;
    } // retranslateUi

};

namespace Ui {
    class AsciiOptionsWidget: public Ui_AsciiOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ASCIIOPTIONSWIDGET_H

