/****************************************************************************
** Meta object code from reading C++ file 'LiveDataDock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/dockwidgets/LiveDataDock.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'LiveDataDock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12LiveDataDockE_t {};
} // unnamed namespace

template <> constexpr inline auto LiveDataDock::qt_create_metaobjectdata<qt_meta_tag_ZN12LiveDataDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LiveDataDock",
        "newTopic",
        "",
        "MQTTClearTopics",
        "updateSubscriptionTree",
        "updateTypeChanged",
        "readingTypeChanged",
        "sampleSizeChanged",
        "updateIntervalChanged",
        "keepNValuesChanged",
        "updateNow",
        "pauseContinueReading",
        "useWillMessage",
        "use",
        "willQoSChanged",
        "willRetainChanged",
        "willTopicChanged",
        "willMessageTypeChanged",
        "MQTTClient::WillMessageType",
        "willOwnMessageChanged",
        "willUpdateTypeChanged",
        "willUpdateNow",
        "willUpdateIntervalChanged",
        "statisticsChanged",
        "MQTTClient::WillStatisticsType",
        "onMQTTConnect",
        "mqttMessageReceived",
        "QMqttTopicName",
        "mqttMessageReceivedInBackground",
        "removeClient",
        "showWillSettings",
        "enableWill",
        "enable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newTopic'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'MQTTClearTopics'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateSubscriptionTree'
        QtMocHelpers::SignalData<void(const QVector<QString> &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
        // Slot 'updateTypeChanged'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'readingTypeChanged'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'sampleSizeChanged'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'updateIntervalChanged'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'keepNValuesChanged'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'updateNow'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pauseContinueReading'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'useWillMessage'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'willQoSChanged'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'willRetainChanged'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'willTopicChanged'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'willMessageTypeChanged'
        QtMocHelpers::SlotData<void(MQTTClient::WillMessageType)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Slot 'willOwnMessageChanged'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'willUpdateTypeChanged'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'willUpdateNow'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'willUpdateIntervalChanged'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'statisticsChanged'
        QtMocHelpers::SlotData<void(MQTTClient::WillStatisticsType)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 2 },
        }}),
        // Slot 'onMQTTConnect'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'mqttMessageReceived'
        QtMocHelpers::SlotData<void(const QByteArray &, const QMqttTopicName &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 2 }, { 0x80000000 | 27, 2 },
        }}),
        // Slot 'mqttMessageReceivedInBackground'
        QtMocHelpers::SlotData<void(const QByteArray &, const QMqttTopicName &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 2 }, { 0x80000000 | 27, 2 },
        }}),
        // Slot 'removeClient'
        QtMocHelpers::SlotData<void(const QString &, quint16)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::UShort, 2 },
        }}),
        // Slot 'showWillSettings'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableWill'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LiveDataDock, qt_meta_tag_ZN12LiveDataDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LiveDataDock::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseDock::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12LiveDataDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12LiveDataDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12LiveDataDockE_t>.metaTypes,
    nullptr
} };

void LiveDataDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LiveDataDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newTopic((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->MQTTClearTopics(); break;
        case 2: _t->updateSubscriptionTree((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1]))); break;
        case 3: _t->updateTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->readingTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->sampleSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->updateIntervalChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->keepNValuesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->updateNow(); break;
        case 9: _t->pauseContinueReading(); break;
        case 10: _t->useWillMessage((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->willQoSChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->willRetainChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->willTopicChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->willMessageTypeChanged((*reinterpret_cast<std::add_pointer_t<MQTTClient::WillMessageType>>(_a[1]))); break;
        case 15: _t->willOwnMessageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->willUpdateTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->willUpdateNow(); break;
        case 18: _t->willUpdateIntervalChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->statisticsChanged((*reinterpret_cast<std::add_pointer_t<MQTTClient::WillStatisticsType>>(_a[1]))); break;
        case 20: _t->onMQTTConnect(); break;
        case 21: _t->mqttMessageReceived((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMqttTopicName>>(_a[2]))); break;
        case 22: _t->mqttMessageReceivedInBackground((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMqttTopicName>>(_a[2]))); break;
        case 23: _t->removeClient((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint16>>(_a[2]))); break;
        case 24: _t->showWillSettings(); break;
        case 25: _t->enableWill((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMqttTopicName >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMqttTopicName >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LiveDataDock::*)(const QString & )>(_a, &LiveDataDock::newTopic, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LiveDataDock::*)()>(_a, &LiveDataDock::MQTTClearTopics, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LiveDataDock::*)(const QVector<QString> & )>(_a, &LiveDataDock::updateSubscriptionTree, 2))
            return;
    }
}

const QMetaObject *LiveDataDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LiveDataDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12LiveDataDockE_t>.strings))
        return static_cast<void*>(this);
    return BaseDock::qt_metacast(_clname);
}

int LiveDataDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseDock::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void LiveDataDock::newTopic(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void LiveDataDock::MQTTClearTopics()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LiveDataDock::updateSubscriptionTree(const QVector<QString> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
