/********************************************************************************
** Form generated from reading UI file 'cartesianplotlegenddock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CARTESIANPLOTLEGENDDOCK_H
#define UI_CARTESIANPLOTLEGENDDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcolorbutton.h"
#include "kcombobox.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_CartesianPlotLegendDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer_5;
    QSpacerItem *verticalSpacer;
    QSpinBox *sbRotation;
    QLabel *label_2;
    QLabel *lPositionXLogical;
    KFontRequester *kfrLabelFont;
    NumberSpinBox *sbPositionX;
    QLabel *lFont;
    QLabel *lPositionXLogicalDateTime;
    ResizableTextEdit *teComment;
    QSpacerItem *verticalSpacer_3;
    NumberSpinBox *sbPositionY;
    QLabel *lFormat;
    QSpinBox *sbLayoutColumnCount;
    QLabel *lPosition;
    QLabel *lPositionYLogical;
    NumberSpinBox *sbPositionXLogical;
    NumberSpinBox *sbPositionYLogical;
    QLabel *lBindLogicalPos;
    TimedLineEdit *leName;
    QLabel *lComment;
    QComboBox *cbVerticalAlignment;
    QCheckBox *chkVisible;
    QLabel *lFontColor;
    QLabel *lLineSymbolWidth;
    KComboBox *cbPositionY;
    QCheckBox *chbBindLogicalPos;
    KComboBox *cbOrder;
    KColorButton *kcbLabelColor;
    QLabel *lPositionY;
    QComboBox *cbHorizontalAlignment;
    QLabel *lOrder;
    QLabel *lRotation;
    QCheckBox *chbLock;
    QSpacerItem *verticalSpacer_9;
    NumberSpinBox *sbLineSymbolWidth;
    UTCDateTimeEdit *dtePositionXLogical;
    QLabel *label;
    KComboBox *cbPositionX;
    QLabel *lColumnCount;
    QSpacerItem *verticalSpacer_8;
    QLabel *lName;
    QLabel *lPositionX;
    QLabel *lUsePlotColor;
    QCheckBox *chkUsePlotColor;
    QWidget *tabTitle;
    QWidget *tabBackground;
    QGridLayout *gridLayout_2;
    QLabel *lBackground;
    NumberSpinBox *sbBorderCornerRadius;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer_7;
    QLabel *lBorderCornerRadius;
    QSpacerItem *verticalSpacer_5;
    QSpacerItem *horizontalSpacer_3;
    QLabel *lBorder;
    QSpacerItem *verticalSpacer_10;
    QWidget *tabLayout;
    QGridLayout *gridLayout_3;
    QSpacerItem *verticalSpacer_6;
    QLabel *lMargin;
    QLabel *lSpacing;
    QLabel *lTopMargin;
    NumberSpinBox *sbLayoutBottomMargin;
    NumberSpinBox *sbLayoutRightMargin;
    QLabel *lLeftMargin;
    QLabel *lVerticalSpacing;
    NumberSpinBox *sbLayoutLeftMargin;
    QSpacerItem *horizontalSpacer_4;
    QLabel *lHorizontalSpacing;
    QLabel *lRightMargin;
    NumberSpinBox *sbLayoutHorizontalSpacing;
    NumberSpinBox *sbLayoutTopMargin;
    QSpacerItem *verticalSpacer_4;
    QLabel *lBottomMargin;
    NumberSpinBox *sbLayoutVerticalSpacing;

    void setupUi(QWidget *CartesianPlotLegendDock)
    {
        if (CartesianPlotLegendDock->objectName().isEmpty())
            CartesianPlotLegendDock->setObjectName("CartesianPlotLegendDock");
        CartesianPlotLegendDock->resize(419, 897);
        verticalLayout = new QVBoxLayout(CartesianPlotLegendDock);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(CartesianPlotLegendDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        verticalSpacer = new QSpacerItem(24, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 23, 0, 1, 1);

        sbRotation = new QSpinBox(tabGeneral);
        sbRotation->setObjectName("sbRotation");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(sbRotation->sizePolicy().hasHeightForWidth());
        sbRotation->setSizePolicy(sizePolicy);
        sbRotation->setMinimum(-360);
        sbRotation->setMaximum(360);
        sbRotation->setSingleStep(10);
        sbRotation->setValue(0);

        gridLayout->addWidget(sbRotation, 20, 2, 1, 3);

        label_2 = new QLabel(tabGeneral);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 22, 0, 1, 1);

        lPositionXLogical = new QLabel(tabGeneral);
        lPositionXLogical->setObjectName("lPositionXLogical");

        gridLayout->addWidget(lPositionXLogical, 16, 0, 1, 1);

        kfrLabelFont = new KFontRequester(tabGeneral);
        kfrLabelFont->setObjectName("kfrLabelFont");

        gridLayout->addWidget(kfrLabelFont, 4, 2, 1, 3);

        sbPositionX = new NumberSpinBox(tabGeneral);
        sbPositionX->setObjectName("sbPositionX");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sbPositionX->sizePolicy().hasHeightForWidth());
        sbPositionX->setSizePolicy(sizePolicy1);
        sbPositionX->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionX, 14, 3, 1, 1);

        lFont = new QLabel(tabGeneral);
        lFont->setObjectName("lFont");

        gridLayout->addWidget(lFont, 4, 0, 1, 1);

        lPositionXLogicalDateTime = new QLabel(tabGeneral);
        lPositionXLogicalDateTime->setObjectName("lPositionXLogicalDateTime");

        gridLayout->addWidget(lPositionXLogicalDateTime, 18, 0, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(teComment->sizePolicy().hasHeightForWidth());
        teComment->setSizePolicy(sizePolicy2);
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 3);

        verticalSpacer_3 = new QSpacerItem(58, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 11, 0, 1, 1);

        sbPositionY = new NumberSpinBox(tabGeneral);
        sbPositionY->setObjectName("sbPositionY");
        sizePolicy1.setHeightForWidth(sbPositionY->sizePolicy().hasHeightForWidth());
        sbPositionY->setSizePolicy(sizePolicy1);
        sbPositionY->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionY, 15, 3, 1, 1);

        lFormat = new QLabel(tabGeneral);
        lFormat->setObjectName("lFormat");
        QFont font;
        font.setBold(true);
        lFormat->setFont(font);

        gridLayout->addWidget(lFormat, 3, 0, 1, 1);

        sbLayoutColumnCount = new QSpinBox(tabGeneral);
        sbLayoutColumnCount->setObjectName("sbLayoutColumnCount");
        sbLayoutColumnCount->setMinimum(1);

        gridLayout->addWidget(sbLayoutColumnCount, 8, 2, 1, 3);

        lPosition = new QLabel(tabGeneral);
        lPosition->setObjectName("lPosition");
        lPosition->setFont(font);

        gridLayout->addWidget(lPosition, 12, 0, 1, 1);

        lPositionYLogical = new QLabel(tabGeneral);
        lPositionYLogical->setObjectName("lPositionYLogical");

        gridLayout->addWidget(lPositionYLogical, 17, 0, 1, 1);

        sbPositionXLogical = new NumberSpinBox(tabGeneral);
        sbPositionXLogical->setObjectName("sbPositionXLogical");
        sizePolicy1.setHeightForWidth(sbPositionXLogical->sizePolicy().hasHeightForWidth());
        sbPositionXLogical->setSizePolicy(sizePolicy1);
        sbPositionXLogical->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionXLogical, 16, 2, 1, 2);

        sbPositionYLogical = new NumberSpinBox(tabGeneral);
        sbPositionYLogical->setObjectName("sbPositionYLogical");
        sizePolicy1.setHeightForWidth(sbPositionYLogical->sizePolicy().hasHeightForWidth());
        sbPositionYLogical->setSizePolicy(sizePolicy1);
        sbPositionYLogical->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionYLogical, 17, 2, 1, 2);

        lBindLogicalPos = new QLabel(tabGeneral);
        lBindLogicalPos->setObjectName("lBindLogicalPos");

        gridLayout->addWidget(lBindLogicalPos, 13, 0, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 3);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(lComment->sizePolicy().hasHeightForWidth());
        lComment->setSizePolicy(sizePolicy3);
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        cbVerticalAlignment = new QComboBox(tabGeneral);
        cbVerticalAlignment->setObjectName("cbVerticalAlignment");

        gridLayout->addWidget(cbVerticalAlignment, 22, 2, 1, 3);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout->addWidget(chkVisible, 25, 0, 1, 1);

        lFontColor = new QLabel(tabGeneral);
        lFontColor->setObjectName("lFontColor");

        gridLayout->addWidget(lFontColor, 6, 0, 1, 1);

        lLineSymbolWidth = new QLabel(tabGeneral);
        lLineSymbolWidth->setObjectName("lLineSymbolWidth");

        gridLayout->addWidget(lLineSymbolWidth, 10, 0, 1, 1);

        cbPositionY = new KComboBox(tabGeneral);
        cbPositionY->setObjectName("cbPositionY");

        gridLayout->addWidget(cbPositionY, 15, 2, 1, 1);

        chbBindLogicalPos = new QCheckBox(tabGeneral);
        chbBindLogicalPos->setObjectName("chbBindLogicalPos");

        gridLayout->addWidget(chbBindLogicalPos, 13, 2, 1, 1);

        cbOrder = new KComboBox(tabGeneral);
        cbOrder->setObjectName("cbOrder");

        gridLayout->addWidget(cbOrder, 9, 2, 1, 3);

        kcbLabelColor = new KColorButton(tabGeneral);
        kcbLabelColor->setObjectName("kcbLabelColor");
        sizePolicy.setHeightForWidth(kcbLabelColor->sizePolicy().hasHeightForWidth());
        kcbLabelColor->setSizePolicy(sizePolicy);

        gridLayout->addWidget(kcbLabelColor, 6, 2, 1, 3);

        lPositionY = new QLabel(tabGeneral);
        lPositionY->setObjectName("lPositionY");

        gridLayout->addWidget(lPositionY, 15, 0, 1, 1);

        cbHorizontalAlignment = new QComboBox(tabGeneral);
        cbHorizontalAlignment->setObjectName("cbHorizontalAlignment");

        gridLayout->addWidget(cbHorizontalAlignment, 21, 2, 1, 3);

        lOrder = new QLabel(tabGeneral);
        lOrder->setObjectName("lOrder");

        gridLayout->addWidget(lOrder, 9, 0, 1, 1);

        lRotation = new QLabel(tabGeneral);
        lRotation->setObjectName("lRotation");

        gridLayout->addWidget(lRotation, 20, 0, 1, 1);

        chbLock = new QCheckBox(tabGeneral);
        chbLock->setObjectName("chbLock");

        gridLayout->addWidget(chbLock, 24, 0, 1, 1);

        verticalSpacer_9 = new QSpacerItem(28, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_9, 7, 0, 1, 1);

        sbLineSymbolWidth = new NumberSpinBox(tabGeneral);
        sbLineSymbolWidth->setObjectName("sbLineSymbolWidth");
        sbLineSymbolWidth->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbLineSymbolWidth, 10, 2, 1, 2);

        dtePositionXLogical = new UTCDateTimeEdit(tabGeneral);
        dtePositionXLogical->setObjectName("dtePositionXLogical");

        gridLayout->addWidget(dtePositionXLogical, 18, 2, 1, 3);

        label = new QLabel(tabGeneral);
        label->setObjectName("label");

        gridLayout->addWidget(label, 21, 0, 1, 1);

        cbPositionX = new KComboBox(tabGeneral);
        cbPositionX->setObjectName("cbPositionX");
        sizePolicy1.setHeightForWidth(cbPositionX->sizePolicy().hasHeightForWidth());
        cbPositionX->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbPositionX, 14, 2, 1, 1);

        lColumnCount = new QLabel(tabGeneral);
        lColumnCount->setObjectName("lColumnCount");

        gridLayout->addWidget(lColumnCount, 8, 0, 1, 1);

        verticalSpacer_8 = new QSpacerItem(58, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_8, 2, 0, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");
        sizePolicy3.setHeightForWidth(lName->sizePolicy().hasHeightForWidth());
        lName->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        lPositionX = new QLabel(tabGeneral);
        lPositionX->setObjectName("lPositionX");

        gridLayout->addWidget(lPositionX, 14, 0, 1, 1);

        lUsePlotColor = new QLabel(tabGeneral);
        lUsePlotColor->setObjectName("lUsePlotColor");

        gridLayout->addWidget(lUsePlotColor, 5, 0, 1, 1);

        chkUsePlotColor = new QCheckBox(tabGeneral);
        chkUsePlotColor->setObjectName("chkUsePlotColor");

        gridLayout->addWidget(chkUsePlotColor, 5, 2, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabTitle = new QWidget();
        tabTitle->setObjectName("tabTitle");
        tabWidget->addTab(tabTitle, QString());
        tabBackground = new QWidget();
        tabBackground->setObjectName("tabBackground");
        gridLayout_2 = new QGridLayout(tabBackground);
        gridLayout_2->setObjectName("gridLayout_2");
        lBackground = new QLabel(tabBackground);
        lBackground->setObjectName("lBackground");
        lBackground->setFont(font);

        gridLayout_2->addWidget(lBackground, 0, 0, 1, 1);

        sbBorderCornerRadius = new NumberSpinBox(tabBackground);
        sbBorderCornerRadius->setObjectName("sbBorderCornerRadius");
        sizePolicy1.setHeightForWidth(sbBorderCornerRadius->sizePolicy().hasHeightForWidth());
        sbBorderCornerRadius->setSizePolicy(sizePolicy1);
        sbBorderCornerRadius->setProperty("feedback", QVariant(true));

        gridLayout_2->addWidget(sbBorderCornerRadius, 5, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(24, 238, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 6, 0, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_7, 4, 0, 1, 1);

        lBorderCornerRadius = new QLabel(tabBackground);
        lBorderCornerRadius->setObjectName("lBorderCornerRadius");

        gridLayout_2->addWidget(lBorderCornerRadius, 5, 0, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_5, 1, 0, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_3, 5, 1, 1, 1);

        lBorder = new QLabel(tabBackground);
        lBorder->setObjectName("lBorder");
        lBorder->setFont(font);

        gridLayout_2->addWidget(lBorder, 3, 0, 1, 1);

        verticalSpacer_10 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_10, 2, 0, 1, 1);

        tabWidget->addTab(tabBackground, QString());
        tabLayout = new QWidget();
        tabLayout->setObjectName("tabLayout");
        gridLayout_3 = new QGridLayout(tabLayout);
        gridLayout_3->setObjectName("gridLayout_3");
        verticalSpacer_6 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_6, 5, 0, 1, 1);

        lMargin = new QLabel(tabLayout);
        lMargin->setObjectName("lMargin");
        lMargin->setFont(font);

        gridLayout_3->addWidget(lMargin, 0, 0, 1, 1);

        lSpacing = new QLabel(tabLayout);
        lSpacing->setObjectName("lSpacing");
        lSpacing->setFont(font);

        gridLayout_3->addWidget(lSpacing, 6, 0, 1, 1);

        lTopMargin = new QLabel(tabLayout);
        lTopMargin->setObjectName("lTopMargin");

        gridLayout_3->addWidget(lTopMargin, 1, 0, 1, 1);

        sbLayoutBottomMargin = new NumberSpinBox(tabLayout);
        sbLayoutBottomMargin->setObjectName("sbLayoutBottomMargin");
        sizePolicy1.setHeightForWidth(sbLayoutBottomMargin->sizePolicy().hasHeightForWidth());
        sbLayoutBottomMargin->setSizePolicy(sizePolicy1);
        sbLayoutBottomMargin->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbLayoutBottomMargin, 2, 3, 1, 1);

        sbLayoutRightMargin = new NumberSpinBox(tabLayout);
        sbLayoutRightMargin->setObjectName("sbLayoutRightMargin");
        sizePolicy1.setHeightForWidth(sbLayoutRightMargin->sizePolicy().hasHeightForWidth());
        sbLayoutRightMargin->setSizePolicy(sizePolicy1);
        sbLayoutRightMargin->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbLayoutRightMargin, 4, 3, 1, 1);

        lLeftMargin = new QLabel(tabLayout);
        lLeftMargin->setObjectName("lLeftMargin");

        gridLayout_3->addWidget(lLeftMargin, 3, 0, 1, 1);

        lVerticalSpacing = new QLabel(tabLayout);
        lVerticalSpacing->setObjectName("lVerticalSpacing");

        gridLayout_3->addWidget(lVerticalSpacing, 8, 0, 1, 1);

        sbLayoutLeftMargin = new NumberSpinBox(tabLayout);
        sbLayoutLeftMargin->setObjectName("sbLayoutLeftMargin");
        sizePolicy1.setHeightForWidth(sbLayoutLeftMargin->sizePolicy().hasHeightForWidth());
        sbLayoutLeftMargin->setSizePolicy(sizePolicy1);
        sbLayoutLeftMargin->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbLayoutLeftMargin, 3, 3, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_4, 1, 2, 1, 1);

        lHorizontalSpacing = new QLabel(tabLayout);
        lHorizontalSpacing->setObjectName("lHorizontalSpacing");

        gridLayout_3->addWidget(lHorizontalSpacing, 7, 0, 1, 1);

        lRightMargin = new QLabel(tabLayout);
        lRightMargin->setObjectName("lRightMargin");

        gridLayout_3->addWidget(lRightMargin, 4, 0, 1, 1);

        sbLayoutHorizontalSpacing = new NumberSpinBox(tabLayout);
        sbLayoutHorizontalSpacing->setObjectName("sbLayoutHorizontalSpacing");
        sizePolicy1.setHeightForWidth(sbLayoutHorizontalSpacing->sizePolicy().hasHeightForWidth());
        sbLayoutHorizontalSpacing->setSizePolicy(sizePolicy1);
        sbLayoutHorizontalSpacing->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbLayoutHorizontalSpacing, 7, 3, 1, 1);

        sbLayoutTopMargin = new NumberSpinBox(tabLayout);
        sbLayoutTopMargin->setObjectName("sbLayoutTopMargin");
        sizePolicy1.setHeightForWidth(sbLayoutTopMargin->sizePolicy().hasHeightForWidth());
        sbLayoutTopMargin->setSizePolicy(sizePolicy1);
        sbLayoutTopMargin->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbLayoutTopMargin, 1, 3, 1, 1);

        verticalSpacer_4 = new QSpacerItem(24, 284, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_4, 9, 0, 1, 1);

        lBottomMargin = new QLabel(tabLayout);
        lBottomMargin->setObjectName("lBottomMargin");

        gridLayout_3->addWidget(lBottomMargin, 2, 0, 1, 1);

        sbLayoutVerticalSpacing = new NumberSpinBox(tabLayout);
        sbLayoutVerticalSpacing->setObjectName("sbLayoutVerticalSpacing");
        sizePolicy1.setHeightForWidth(sbLayoutVerticalSpacing->sizePolicy().hasHeightForWidth());
        sbLayoutVerticalSpacing->setSizePolicy(sizePolicy1);
        sbLayoutVerticalSpacing->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbLayoutVerticalSpacing, 8, 3, 1, 1);

        tabWidget->addTab(tabLayout, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, kfrLabelFont);
        QWidget::setTabOrder(kfrLabelFont, chkUsePlotColor);
        QWidget::setTabOrder(chkUsePlotColor, kcbLabelColor);
        QWidget::setTabOrder(kcbLabelColor, sbLayoutColumnCount);
        QWidget::setTabOrder(sbLayoutColumnCount, cbOrder);
        QWidget::setTabOrder(cbOrder, sbLineSymbolWidth);
        QWidget::setTabOrder(sbLineSymbolWidth, chbBindLogicalPos);
        QWidget::setTabOrder(chbBindLogicalPos, cbPositionX);
        QWidget::setTabOrder(cbPositionX, sbPositionX);
        QWidget::setTabOrder(sbPositionX, cbPositionY);
        QWidget::setTabOrder(cbPositionY, sbPositionY);
        QWidget::setTabOrder(sbPositionY, sbPositionXLogical);
        QWidget::setTabOrder(sbPositionXLogical, sbPositionYLogical);
        QWidget::setTabOrder(sbPositionYLogical, dtePositionXLogical);
        QWidget::setTabOrder(dtePositionXLogical, sbRotation);
        QWidget::setTabOrder(sbRotation, cbHorizontalAlignment);
        QWidget::setTabOrder(cbHorizontalAlignment, cbVerticalAlignment);
        QWidget::setTabOrder(cbVerticalAlignment, chbLock);
        QWidget::setTabOrder(chbLock, chkVisible);
        QWidget::setTabOrder(chkVisible, sbBorderCornerRadius);
        QWidget::setTabOrder(sbBorderCornerRadius, sbLayoutBottomMargin);
        QWidget::setTabOrder(sbLayoutBottomMargin, sbLayoutRightMargin);
        QWidget::setTabOrder(sbLayoutRightMargin, sbLayoutLeftMargin);
        QWidget::setTabOrder(sbLayoutLeftMargin, sbLayoutHorizontalSpacing);
        QWidget::setTabOrder(sbLayoutHorizontalSpacing, sbLayoutTopMargin);
        QWidget::setTabOrder(sbLayoutTopMargin, sbLayoutVerticalSpacing);

        retranslateUi(CartesianPlotLegendDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(CartesianPlotLegendDock);
    } // setupUi

    void retranslateUi(QWidget *CartesianPlotLegendDock)
    {
#if QT_CONFIG(tooltip)
        sbRotation->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        sbRotation->setSuffix(tr2i18n("\302\260", nullptr));
        label_2->setText(tr2i18n("Ver. align.:", nullptr));
        lPositionXLogical->setText(tr2i18n("x:", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionX->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionX->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbPositionX->setSuffix(tr2i18n(" cm", nullptr));
        lFont->setText(tr2i18n("Font:", nullptr));
        lPositionXLogicalDateTime->setText(tr2i18n("x:", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionY->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionY->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbPositionY->setSuffix(tr2i18n(" cm", nullptr));
        lFormat->setText(tr2i18n("Format", nullptr));
        lPosition->setText(tr2i18n("Geometry", nullptr));
        lPositionYLogical->setText(tr2i18n("y:", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionXLogical->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionXLogical->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        sbPositionYLogical->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionYLogical->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lBindLogicalPos->setText(tr2i18n("Logical coordinates", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lFontColor->setText(tr2i18n("Color:", nullptr));
        lLineSymbolWidth->setText(tr2i18n("Line+Symbol Width:", nullptr));
        chbBindLogicalPos->setText(QString());
        lPositionY->setText(tr2i18n("y:", nullptr));
        lOrder->setText(tr2i18n("Order:", nullptr));
        lRotation->setText(tr2i18n("Rotation:", nullptr));
        chbLock->setText(tr2i18n("Locked", nullptr));
#if QT_CONFIG(tooltip)
        sbLineSymbolWidth->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLineSymbolWidth->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLineSymbolWidth->setSuffix(tr2i18n(" cm", nullptr));
        label->setText(tr2i18n("Hor. align.:", nullptr));
        lColumnCount->setText(tr2i18n("Columns:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lPositionX->setText(tr2i18n("x:", nullptr));
        lUsePlotColor->setText(tr2i18n("Plot's Color:", nullptr));
        chkUsePlotColor->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabTitle), tr2i18n("Title", nullptr));
        lBackground->setText(tr2i18n("Background", nullptr));
#if QT_CONFIG(tooltip)
        sbBorderCornerRadius->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbBorderCornerRadius->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbBorderCornerRadius->setSuffix(tr2i18n(" cm", nullptr));
        lBorderCornerRadius->setText(tr2i18n("Corner radius:", nullptr));
        lBorder->setText(tr2i18n("Border", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabBackground), tr2i18n("Background", nullptr));
        lMargin->setText(tr2i18n("Margins", nullptr));
        lSpacing->setText(tr2i18n("Spacing", nullptr));
        lTopMargin->setText(tr2i18n("Top:", nullptr));
#if QT_CONFIG(tooltip)
        sbLayoutBottomMargin->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLayoutBottomMargin->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLayoutBottomMargin->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        sbLayoutRightMargin->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLayoutRightMargin->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLayoutRightMargin->setSuffix(tr2i18n(" cm", nullptr));
        lLeftMargin->setText(tr2i18n("Left:", nullptr));
        lVerticalSpacing->setText(tr2i18n("Vertical:", nullptr));
#if QT_CONFIG(tooltip)
        sbLayoutLeftMargin->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLayoutLeftMargin->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLayoutLeftMargin->setSuffix(tr2i18n(" cm", nullptr));
        lHorizontalSpacing->setText(tr2i18n("Horizontal:", nullptr));
        lRightMargin->setText(tr2i18n("Right:", nullptr));
#if QT_CONFIG(tooltip)
        sbLayoutHorizontalSpacing->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLayoutHorizontalSpacing->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLayoutHorizontalSpacing->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        sbLayoutTopMargin->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLayoutTopMargin->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLayoutTopMargin->setSuffix(tr2i18n(" cm", nullptr));
        lBottomMargin->setText(tr2i18n("Bottom:", nullptr));
#if QT_CONFIG(tooltip)
        sbLayoutVerticalSpacing->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLayoutVerticalSpacing->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLayoutVerticalSpacing->setSuffix(tr2i18n(" cm", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabLayout), tr2i18n("Layout", nullptr));
        (void)CartesianPlotLegendDock;
    } // retranslateUi

};

namespace Ui {
    class CartesianPlotLegendDock: public Ui_CartesianPlotLegendDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CARTESIANPLOTLEGENDDOCK_H

