/********************************************************************************
** Form generated from reading UI file 'functionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FUNCTIONSWIDGET_H
#define UI_FUNCTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FunctionsWidget
{
public:
    QGridLayout *gridLayout;
    QLineEdit *leFilter;
    QFrame *line;
    QComboBox *cbGroup;
    QListWidget *lwFunctions;
    QSpacerItem *horizontalSpacer;
    QPushButton *bInsert;
    QPushButton *bCancel;

    void setupUi(QWidget *FunctionsWidget)
    {
        if (FunctionsWidget->objectName().isEmpty())
            FunctionsWidget->setObjectName("FunctionsWidget");
        FunctionsWidget->resize(293, 251);
        gridLayout = new QGridLayout(FunctionsWidget);
        gridLayout->setObjectName("gridLayout");
        leFilter = new QLineEdit(FunctionsWidget);
        leFilter->setObjectName("leFilter");
        leFilter->setClearButtonEnabled(true);
        leFilter->setProperty("showClearButton", QVariant(false));

        gridLayout->addWidget(leFilter, 0, 0, 1, 3);

        line = new QFrame(FunctionsWidget);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 1, 0, 1, 3);

        cbGroup = new QComboBox(FunctionsWidget);
        cbGroup->setObjectName("cbGroup");

        gridLayout->addWidget(cbGroup, 2, 0, 1, 3);

        lwFunctions = new QListWidget(FunctionsWidget);
        lwFunctions->setObjectName("lwFunctions");

        gridLayout->addWidget(lwFunctions, 3, 0, 1, 3);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 4, 0, 1, 1);

        bInsert = new QPushButton(FunctionsWidget);
        bInsert->setObjectName("bInsert");

        gridLayout->addWidget(bInsert, 4, 1, 1, 1);

        bCancel = new QPushButton(FunctionsWidget);
        bCancel->setObjectName("bCancel");

        gridLayout->addWidget(bCancel, 4, 2, 1, 1);


        retranslateUi(FunctionsWidget);

        QMetaObject::connectSlotsByName(FunctionsWidget);
    } // setupUi

    void retranslateUi(QWidget *FunctionsWidget)
    {
        leFilter->setPlaceholderText(tr2i18n("Enter search term here", nullptr));
        bInsert->setText(tr2i18n("Insert", nullptr));
        bCancel->setText(tr2i18n("Cancel", nullptr));
        (void)FunctionsWidget;
    } // retranslateUi

};

namespace Ui {
    class FunctionsWidget: public Ui_FunctionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FUNCTIONSWIDGET_H

