/********************************************************************************
** Form generated from reading UI file 'mqttconnectionmanagerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MQTTCONNECTIONMANAGERWIDGET_H
#define UI_MQTTCONNECTIONMANAGERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MQTTConnectionManagerWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *gbConnection;
    QGridLayout *gridLayout_2;
    QLabel *lPassword;
    QSpacerItem *verticalSpacer;
    QLineEdit *lePort;
    QLineEdit *leID;
    QLabel *lHost;
    QLabel *lID;
    QLabel *lPort;
    QLineEdit *lePassword;
    QLineEdit *leUserName;
    QLineEdit *leHost;
    QLabel *lUsername;
    QCheckBox *chbID;
    QCheckBox *chbAuthentication;
    QCheckBox *chbRetain;
    QLabel *lName;
    QLineEdit *leName;
    QListWidget *lwConnections;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QPushButton *bAdd;
    QPushButton *bRemove;
    QSpacerItem *horizontalSpacer;
    QPushButton *bTest;

    void setupUi(QWidget *MQTTConnectionManagerWidget)
    {
        if (MQTTConnectionManagerWidget->objectName().isEmpty())
            MQTTConnectionManagerWidget->setObjectName("MQTTConnectionManagerWidget");
        MQTTConnectionManagerWidget->resize(572, 453);
        gridLayout = new QGridLayout(MQTTConnectionManagerWidget);
        gridLayout->setObjectName("gridLayout");
        gbConnection = new QGroupBox(MQTTConnectionManagerWidget);
        gbConnection->setObjectName("gbConnection");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(gbConnection->sizePolicy().hasHeightForWidth());
        gbConnection->setSizePolicy(sizePolicy);
        gridLayout_2 = new QGridLayout(gbConnection);
        gridLayout_2->setObjectName("gridLayout_2");
        lPassword = new QLabel(gbConnection);
        lPassword->setObjectName("lPassword");

        gridLayout_2->addWidget(lPassword, 5, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 9, 1, 1, 1);

        lePort = new QLineEdit(gbConnection);
        lePort->setObjectName("lePort");
        lePort->setClearButtonEnabled(true);

        gridLayout_2->addWidget(lePort, 2, 1, 1, 1);

        leID = new QLineEdit(gbConnection);
        leID->setObjectName("leID");
        leID->setClearButtonEnabled(true);

        gridLayout_2->addWidget(leID, 7, 1, 1, 1);

        lHost = new QLabel(gbConnection);
        lHost->setObjectName("lHost");

        gridLayout_2->addWidget(lHost, 1, 0, 1, 1);

        lID = new QLabel(gbConnection);
        lID->setObjectName("lID");

        gridLayout_2->addWidget(lID, 7, 0, 1, 1);

        lPort = new QLabel(gbConnection);
        lPort->setObjectName("lPort");

        gridLayout_2->addWidget(lPort, 2, 0, 1, 1);

        lePassword = new QLineEdit(gbConnection);
        lePassword->setObjectName("lePassword");
        lePassword->setClearButtonEnabled(true);

        gridLayout_2->addWidget(lePassword, 5, 1, 1, 1);

        leUserName = new QLineEdit(gbConnection);
        leUserName->setObjectName("leUserName");
        leUserName->setClearButtonEnabled(true);

        gridLayout_2->addWidget(leUserName, 4, 1, 1, 1);

        leHost = new QLineEdit(gbConnection);
        leHost->setObjectName("leHost");
        leHost->setClearButtonEnabled(true);

        gridLayout_2->addWidget(leHost, 1, 1, 1, 1);

        lUsername = new QLabel(gbConnection);
        lUsername->setObjectName("lUsername");

        gridLayout_2->addWidget(lUsername, 4, 0, 1, 1);

        chbID = new QCheckBox(gbConnection);
        chbID->setObjectName("chbID");

        gridLayout_2->addWidget(chbID, 6, 0, 1, 2);

        chbAuthentication = new QCheckBox(gbConnection);
        chbAuthentication->setObjectName("chbAuthentication");

        gridLayout_2->addWidget(chbAuthentication, 3, 0, 1, 2);

        chbRetain = new QCheckBox(gbConnection);
        chbRetain->setObjectName("chbRetain");

        gridLayout_2->addWidget(chbRetain, 8, 0, 1, 2);

        lName = new QLabel(gbConnection);
        lName->setObjectName("lName");

        gridLayout_2->addWidget(lName, 0, 0, 1, 1);

        leName = new QLineEdit(gbConnection);
        leName->setObjectName("leName");
        leName->setClearButtonEnabled(true);

        gridLayout_2->addWidget(leName, 0, 1, 1, 1);


        gridLayout->addWidget(gbConnection, 0, 1, 1, 1);

        lwConnections = new QListWidget(MQTTConnectionManagerWidget);
        lwConnections->setObjectName("lwConnections");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lwConnections->sizePolicy().hasHeightForWidth());
        lwConnections->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(lwConnections, 0, 0, 1, 1);

        frame = new QFrame(MQTTConnectionManagerWidget);
        frame->setObjectName("frame");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy2);
        frame->setFrameShape(QFrame::Shape::StyledPanel);
        frame->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setObjectName("horizontalLayout");
        bAdd = new QPushButton(frame);
        bAdd->setObjectName("bAdd");

        horizontalLayout->addWidget(bAdd);

        bRemove = new QPushButton(frame);
        bRemove->setObjectName("bRemove");

        horizontalLayout->addWidget(bRemove);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        bTest = new QPushButton(frame);
        bTest->setObjectName("bTest");

        horizontalLayout->addWidget(bTest);


        gridLayout->addWidget(frame, 1, 0, 1, 1);

        QWidget::setTabOrder(lwConnections, leName);
        QWidget::setTabOrder(leName, leHost);
        QWidget::setTabOrder(leHost, lePort);
        QWidget::setTabOrder(lePort, chbAuthentication);
        QWidget::setTabOrder(chbAuthentication, leUserName);
        QWidget::setTabOrder(leUserName, lePassword);
        QWidget::setTabOrder(lePassword, chbID);
        QWidget::setTabOrder(chbID, leID);
        QWidget::setTabOrder(leID, chbRetain);
        QWidget::setTabOrder(chbRetain, bAdd);
        QWidget::setTabOrder(bAdd, bRemove);
        QWidget::setTabOrder(bRemove, bTest);

        retranslateUi(MQTTConnectionManagerWidget);

        QMetaObject::connectSlotsByName(MQTTConnectionManagerWidget);
    } // setupUi

    void retranslateUi(QWidget *MQTTConnectionManagerWidget)
    {
        gbConnection->setTitle(tr2i18n("Manage connections:", nullptr));
        lPassword->setText(tr2i18n("Password:", nullptr));
        lHost->setText(tr2i18n("Host:", nullptr));
        lID->setText(tr2i18n("Client ID:", nullptr));
        lPort->setText(tr2i18n("Port:", nullptr));
        lUsername->setText(tr2i18n("Username:", nullptr));
        chbID->setText(tr2i18n("Set client ID", nullptr));
        chbAuthentication->setText(tr2i18n("Use authentication", nullptr));
        chbRetain->setText(tr2i18n("Interpret retain messages", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        bAdd->setText(QString());
        bRemove->setText(QString());
        bTest->setText(tr2i18n("Test", nullptr));
        (void)MQTTConnectionManagerWidget;
    } // retranslateUi

};

namespace Ui {
    class MQTTConnectionManagerWidget: public Ui_MQTTConnectionManagerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MQTTCONNECTIONMANAGERWIDGET_H

