/********************************************************************************
** Form generated from reading UI file 'errorbarwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ERRORBARWIDGET_H
#define UI_ERRORBARWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ErrorBarWidget
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer_11;
    QSpacerItem *horizontalSpacer_7;
    KComboBox *cbType;
    QLabel *lXError;
    QLabel *lYErrorType;
    QLabel *lXDataPlus;
    QSpacerItem *verticalSpacer_2;
    QLabel *lXDataMinus;
    QLabel *lYDataPlus;
    QLabel *lFormat;
    QLabel *lCapSize;
    KComboBox *cbYErrorType;
    QSpacerItem *verticalSpacer_5;
    QLabel *lYDataMinus;
    NumberSpinBox *sbCapSize;
    QLabel *lYError;
    QLabel *lXErrorType;
    KComboBox *cbXErrorType;
    QLabel *lType;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ErrorBarWidget)
    {
        if (ErrorBarWidget->objectName().isEmpty())
            ErrorBarWidget->setObjectName("ErrorBarWidget");
        ErrorBarWidget->resize(340, 392);
        gridLayout = new QGridLayout(ErrorBarWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(0);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        verticalSpacer_11 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_11, 9, 0, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(13, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_7, 6, 1, 1, 1);

        cbType = new KComboBox(ErrorBarWidget);
        cbType->setObjectName("cbType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbType->sizePolicy().hasHeightForWidth());
        cbType->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbType, 11, 2, 1, 1);

        lXError = new QLabel(ErrorBarWidget);
        lXError->setObjectName("lXError");
        QFont font;
        font.setBold(true);
        lXError->setFont(font);

        gridLayout->addWidget(lXError, 0, 0, 1, 1);

        lYErrorType = new QLabel(ErrorBarWidget);
        lYErrorType->setObjectName("lYErrorType");

        gridLayout->addWidget(lYErrorType, 6, 0, 1, 1);

        lXDataPlus = new QLabel(ErrorBarWidget);
        lXDataPlus->setObjectName("lXDataPlus");

        gridLayout->addWidget(lXDataPlus, 2, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 14, 0, 1, 1);

        lXDataMinus = new QLabel(ErrorBarWidget);
        lXDataMinus->setObjectName("lXDataMinus");

        gridLayout->addWidget(lXDataMinus, 3, 0, 1, 1);

        lYDataPlus = new QLabel(ErrorBarWidget);
        lYDataPlus->setObjectName("lYDataPlus");

        gridLayout->addWidget(lYDataPlus, 7, 0, 1, 1);

        lFormat = new QLabel(ErrorBarWidget);
        lFormat->setObjectName("lFormat");
        lFormat->setFont(font);

        gridLayout->addWidget(lFormat, 10, 0, 1, 1);

        lCapSize = new QLabel(ErrorBarWidget);
        lCapSize->setObjectName("lCapSize");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lCapSize->sizePolicy().hasHeightForWidth());
        lCapSize->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(lCapSize, 12, 0, 1, 1);

        cbYErrorType = new KComboBox(ErrorBarWidget);
        cbYErrorType->setObjectName("cbYErrorType");
        sizePolicy.setHeightForWidth(cbYErrorType->sizePolicy().hasHeightForWidth());
        cbYErrorType->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbYErrorType, 6, 2, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_5, 13, 0, 1, 1);

        lYDataMinus = new QLabel(ErrorBarWidget);
        lYDataMinus->setObjectName("lYDataMinus");

        gridLayout->addWidget(lYDataMinus, 8, 0, 1, 1);

        sbCapSize = new NumberSpinBox(ErrorBarWidget);
        sbCapSize->setObjectName("sbCapSize");
        sizePolicy.setHeightForWidth(sbCapSize->sizePolicy().hasHeightForWidth());
        sbCapSize->setSizePolicy(sizePolicy);
        sbCapSize->setMinimum(0.000000000000000);
        sbCapSize->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbCapSize, 12, 2, 1, 1);

        lYError = new QLabel(ErrorBarWidget);
        lYError->setObjectName("lYError");
        lYError->setFont(font);

        gridLayout->addWidget(lYError, 5, 0, 1, 1);

        lXErrorType = new QLabel(ErrorBarWidget);
        lXErrorType->setObjectName("lXErrorType");

        gridLayout->addWidget(lXErrorType, 1, 0, 1, 1);

        cbXErrorType = new KComboBox(ErrorBarWidget);
        cbXErrorType->setObjectName("cbXErrorType");
        sizePolicy.setHeightForWidth(cbXErrorType->sizePolicy().hasHeightForWidth());
        cbXErrorType->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbXErrorType, 1, 2, 1, 1);

        lType = new QLabel(ErrorBarWidget);
        lType->setObjectName("lType");

        gridLayout->addWidget(lType, 11, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 4, 0, 1, 1);

        QWidget::setTabOrder(cbXErrorType, cbYErrorType);
        QWidget::setTabOrder(cbYErrorType, cbType);
        QWidget::setTabOrder(cbType, sbCapSize);

        retranslateUi(ErrorBarWidget);

        QMetaObject::connectSlotsByName(ErrorBarWidget);
    } // setupUi

    void retranslateUi(QWidget *ErrorBarWidget)
    {
        ErrorBarWidget->setWindowTitle(tr2i18n("Form", nullptr));
        lXError->setText(tr2i18n("X Error", nullptr));
        lYErrorType->setText(tr2i18n("Type:", nullptr));
        lXDataPlus->setText(tr2i18n("Data, +:", nullptr));
        lXDataMinus->setText(tr2i18n("Data, -:", nullptr));
        lYDataPlus->setText(tr2i18n("Data, +:", nullptr));
        lFormat->setText(tr2i18n("Format", nullptr));
        lCapSize->setText(tr2i18n("Cap size:", nullptr));
        lYDataMinus->setText(tr2i18n("Data, -:", nullptr));
#if QT_CONFIG(tooltip)
        sbCapSize->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbCapSize->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbCapSize->setSuffix(tr2i18n(" pt", nullptr));
        lYError->setText(tr2i18n("Y Error", nullptr));
        lXErrorType->setText(tr2i18n("Type:", nullptr));
        lType->setText(tr2i18n("Type:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ErrorBarWidget: public Ui_ErrorBarWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ERRORBARWIDGET_H

