/********************************************************************************
** Form generated from reading UI file 'plotdatawidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLOTDATAWIDGET_H
#define UI_PLOTDATAWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PlotDataWidget
{
public:
    QGridLayout *gridLayout_2;
    QGroupBox *gbData;
    QGridLayout *gridLayout_3;
    QScrollArea *scrollAreaColumns;
    QWidget *scrollAreaWidgetContents;
    QGridLayout *gridLayout;
    QLabel *lXColumn;
    QSpacerItem *horizontalSpacer_5;
    QComboBox *cbXColumn;
    QFrame *line;
    QLabel *lYColumn;
    QSpacerItem *horizontalSpacer_6;
    QComboBox *cbYColumn;
    QGroupBox *gbCurvePlacement;
    QVBoxLayout *verticalLayout;
    QRadioButton *rbCurvePlacementAllInOnePlotArea;
    QRadioButton *rbCurvePlacementAllInOwnPlotArea;
    QGroupBox *gbPlotPlacement;
    QGridLayout *gridLayout_4;
    QRadioButton *rbPlotPlacementExistingPlotArea;
    QRadioButton *rbPlotPlacementExistingWorksheet;
    QRadioButton *rbPlotPlacementNewWorksheet;
    QSpacerItem *spacer;
    QCheckBox *chkCreateDataCurve;

    void setupUi(QWidget *PlotDataWidget)
    {
        if (PlotDataWidget->objectName().isEmpty())
            PlotDataWidget->setObjectName("PlotDataWidget");
        PlotDataWidget->resize(470, 469);
        gridLayout_2 = new QGridLayout(PlotDataWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        gbData = new QGroupBox(PlotDataWidget);
        gbData->setObjectName("gbData");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(gbData->sizePolicy().hasHeightForWidth());
        gbData->setSizePolicy(sizePolicy);
        gridLayout_3 = new QGridLayout(gbData);
        gridLayout_3->setObjectName("gridLayout_3");
        scrollAreaColumns = new QScrollArea(gbData);
        scrollAreaColumns->setObjectName("scrollAreaColumns");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(scrollAreaColumns->sizePolicy().hasHeightForWidth());
        scrollAreaColumns->setSizePolicy(sizePolicy1);
        scrollAreaColumns->setFrameShape(QFrame::NoFrame);
        scrollAreaColumns->setFrameShadow(QFrame::Plain);
        scrollAreaColumns->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 414, 73));
        gridLayout = new QGridLayout(scrollAreaWidgetContents);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(0);
        gridLayout->setVerticalSpacing(6);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        lXColumn = new QLabel(scrollAreaWidgetContents);
        lXColumn->setObjectName("lXColumn");

        gridLayout->addWidget(lXColumn, 0, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        cbXColumn = new QComboBox(scrollAreaWidgetContents);
        cbXColumn->setObjectName("cbXColumn");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cbXColumn->sizePolicy().hasHeightForWidth());
        cbXColumn->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(cbXColumn, 0, 2, 1, 1);

        line = new QFrame(scrollAreaWidgetContents);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 1, 0, 1, 3);

        lYColumn = new QLabel(scrollAreaWidgetContents);
        lYColumn->setObjectName("lYColumn");

        gridLayout->addWidget(lYColumn, 2, 0, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_6, 2, 1, 1, 1);

        cbYColumn = new QComboBox(scrollAreaWidgetContents);
        cbYColumn->setObjectName("cbYColumn");
        sizePolicy2.setHeightForWidth(cbYColumn->sizePolicy().hasHeightForWidth());
        cbYColumn->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(cbYColumn, 2, 2, 1, 1);

        scrollAreaColumns->setWidget(scrollAreaWidgetContents);

        gridLayout_3->addWidget(scrollAreaColumns, 0, 0, 1, 2);


        gridLayout_2->addWidget(gbData, 0, 0, 1, 1);

        gbCurvePlacement = new QGroupBox(PlotDataWidget);
        gbCurvePlacement->setObjectName("gbCurvePlacement");
        verticalLayout = new QVBoxLayout(gbCurvePlacement);
        verticalLayout->setObjectName("verticalLayout");
        rbCurvePlacementAllInOnePlotArea = new QRadioButton(gbCurvePlacement);
        rbCurvePlacementAllInOnePlotArea->setObjectName("rbCurvePlacementAllInOnePlotArea");
        rbCurvePlacementAllInOnePlotArea->setChecked(true);

        verticalLayout->addWidget(rbCurvePlacementAllInOnePlotArea);

        rbCurvePlacementAllInOwnPlotArea = new QRadioButton(gbCurvePlacement);
        rbCurvePlacementAllInOwnPlotArea->setObjectName("rbCurvePlacementAllInOwnPlotArea");

        verticalLayout->addWidget(rbCurvePlacementAllInOwnPlotArea);


        gridLayout_2->addWidget(gbCurvePlacement, 1, 0, 1, 1);

        gbPlotPlacement = new QGroupBox(PlotDataWidget);
        gbPlotPlacement->setObjectName("gbPlotPlacement");
        gridLayout_4 = new QGridLayout(gbPlotPlacement);
        gridLayout_4->setObjectName("gridLayout_4");
        rbPlotPlacementExistingPlotArea = new QRadioButton(gbPlotPlacement);
        rbPlotPlacementExistingPlotArea->setObjectName("rbPlotPlacementExistingPlotArea");
        rbPlotPlacementExistingPlotArea->setChecked(true);

        gridLayout_4->addWidget(rbPlotPlacementExistingPlotArea, 0, 0, 1, 1);

        rbPlotPlacementExistingWorksheet = new QRadioButton(gbPlotPlacement);
        rbPlotPlacementExistingWorksheet->setObjectName("rbPlotPlacementExistingWorksheet");

        gridLayout_4->addWidget(rbPlotPlacementExistingWorksheet, 1, 0, 1, 1);

        rbPlotPlacementNewWorksheet = new QRadioButton(gbPlotPlacement);
        rbPlotPlacementNewWorksheet->setObjectName("rbPlotPlacementNewWorksheet");

        gridLayout_4->addWidget(rbPlotPlacementNewWorksheet, 2, 0, 1, 1);

        spacer = new QSpacerItem(20, 38, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(spacer, 3, 0, 1, 1);

        chkCreateDataCurve = new QCheckBox(gbPlotPlacement);
        chkCreateDataCurve->setObjectName("chkCreateDataCurve");
        chkCreateDataCurve->setChecked(true);

        gridLayout_4->addWidget(chkCreateDataCurve, 4, 0, 1, 1);


        gridLayout_2->addWidget(gbPlotPlacement, 2, 0, 1, 1);


        retranslateUi(PlotDataWidget);

        QMetaObject::connectSlotsByName(PlotDataWidget);
    } // setupUi

    void retranslateUi(QWidget *PlotDataWidget)
    {
        gbData->setTitle(tr2i18n("Data", nullptr));
        lXColumn->setText(tr2i18n("X-Data:", nullptr));
        lYColumn->setText(tr2i18n("Y-Data:", nullptr));
        gbCurvePlacement->setTitle(tr2i18n("Placement", nullptr));
        rbCurvePlacementAllInOnePlotArea->setText(tr2i18n("All Plots in one Plot Area", nullptr));
        rbCurvePlacementAllInOwnPlotArea->setText(tr2i18n("One Plot Area per Plot", nullptr));
        gbPlotPlacement->setTitle(tr2i18n("Add Plots to", nullptr));
        rbPlotPlacementExistingPlotArea->setText(tr2i18n("Existing Plot Area", nullptr));
        rbPlotPlacementExistingWorksheet->setText(tr2i18n("&New Plot Area in an existing Worksheet", nullptr));
        rbPlotPlacementNewWorksheet->setText(tr2i18n("New Plot Area in a new Worksheet", nullptr));
        chkCreateDataCurve->setText(tr2i18n("Create Plot for original Data", nullptr));
        (void)PlotDataWidget;
    } // retranslateUi

};

namespace Ui {
    class PlotDataWidget: public Ui_PlotDataWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PLOTDATAWIDGET_H

