/****************************************************************************
** Meta object code from reading C++ file 'DatapickerImage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/datapicker/DatapickerImage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DatapickerImage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15DatapickerImageE_t {};
} // unnamed namespace

template <> constexpr inline auto DatapickerImage::qt_create_metaobjectdata<qt_meta_tag_ZN15DatapickerImageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DatapickerImage",
        "requestProjectContextMenu",
        "",
        "QMenu*",
        "requestUpdate",
        "requestUpdateActions",
        "relativeFilePathChanged",
        "fileNameChanged",
        "embeddedChanged",
        "rotationAngleChanged",
        "axisPointsChanged",
        "DatapickerImage::ReferencePoints",
        "axisPointsRemoved",
        "settingsChanged",
        "DatapickerImage::EditorSettings",
        "minSegmentLengthChanged",
        "pointStyleChanged",
        "Symbol::Style",
        "pointSizeChanged",
        "pointRotationAngleChanged",
        "pointOpacityChanged",
        "pointBrushChanged",
        "QBrush",
        "pointPenChanged",
        "QPen",
        "pointVisibilityChanged",
        "referencePointSelected",
        "index",
        "const DatapickerPoint*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestProjectContextMenu'
        QtMocHelpers::SignalData<void(QMenu *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'requestUpdate'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestUpdateActions'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'relativeFilePathChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'fileNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'embeddedChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'rotationAngleChanged'
        QtMocHelpers::SignalData<void(float)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'axisPointsChanged'
        QtMocHelpers::SignalData<void(const DatapickerImage::ReferencePoints &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Signal 'axisPointsRemoved'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'settingsChanged'
        QtMocHelpers::SignalData<void(const DatapickerImage::EditorSettings &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Signal 'minSegmentLengthChanged'
        QtMocHelpers::SignalData<void(const int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'pointStyleChanged'
        QtMocHelpers::SignalData<void(Symbol::Style)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Signal 'pointSizeChanged'
        QtMocHelpers::SignalData<void(qreal)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'pointRotationAngleChanged'
        QtMocHelpers::SignalData<void(qreal)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'pointOpacityChanged'
        QtMocHelpers::SignalData<void(qreal)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'pointBrushChanged'
        QtMocHelpers::SignalData<void(QBrush)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Signal 'pointPenChanged'
        QtMocHelpers::SignalData<void(const QPen &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 2 },
        }}),
        // Signal 'pointVisibilityChanged'
        QtMocHelpers::SignalData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'referencePointSelected'
        QtMocHelpers::SignalData<void(int)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'referencePointSelected'
        QtMocHelpers::SlotData<void(const DatapickerPoint *)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DatapickerImage, qt_meta_tag_ZN15DatapickerImageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DatapickerImage::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractPart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DatapickerImageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DatapickerImageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DatapickerImageE_t>.metaTypes,
    nullptr
} };

void DatapickerImage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DatapickerImage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestProjectContextMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 1: _t->requestUpdate(); break;
        case 2: _t->requestUpdateActions(); break;
        case 3: _t->relativeFilePathChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->fileNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->embeddedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->rotationAngleChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 7: _t->axisPointsChanged((*reinterpret_cast<std::add_pointer_t<DatapickerImage::ReferencePoints>>(_a[1]))); break;
        case 8: _t->axisPointsRemoved(); break;
        case 9: _t->settingsChanged((*reinterpret_cast<std::add_pointer_t<DatapickerImage::EditorSettings>>(_a[1]))); break;
        case 10: _t->minSegmentLengthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->pointStyleChanged((*reinterpret_cast<std::add_pointer_t<Symbol::Style>>(_a[1]))); break;
        case 12: _t->pointSizeChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 13: _t->pointRotationAngleChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 14: _t->pointOpacityChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 15: _t->pointBrushChanged((*reinterpret_cast<std::add_pointer_t<QBrush>>(_a[1]))); break;
        case 16: _t->pointPenChanged((*reinterpret_cast<std::add_pointer_t<QPen>>(_a[1]))); break;
        case 17: _t->pointVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->referencePointSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->referencePointSelected((*reinterpret_cast<std::add_pointer_t<const DatapickerPoint*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(QMenu * )>(_a, &DatapickerImage::requestProjectContextMenu, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)()>(_a, &DatapickerImage::requestUpdate, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)()>(_a, &DatapickerImage::requestUpdateActions, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(bool )>(_a, &DatapickerImage::relativeFilePathChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(const QString & )>(_a, &DatapickerImage::fileNameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(bool )>(_a, &DatapickerImage::embeddedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(float )>(_a, &DatapickerImage::rotationAngleChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(const DatapickerImage::ReferencePoints & )>(_a, &DatapickerImage::axisPointsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)()>(_a, &DatapickerImage::axisPointsRemoved, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(const DatapickerImage::EditorSettings & )>(_a, &DatapickerImage::settingsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(const int )>(_a, &DatapickerImage::minSegmentLengthChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(Symbol::Style )>(_a, &DatapickerImage::pointStyleChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(qreal )>(_a, &DatapickerImage::pointSizeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(qreal )>(_a, &DatapickerImage::pointRotationAngleChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(qreal )>(_a, &DatapickerImage::pointOpacityChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(QBrush )>(_a, &DatapickerImage::pointBrushChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(const QPen & )>(_a, &DatapickerImage::pointPenChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(bool )>(_a, &DatapickerImage::pointVisibilityChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerImage::*)(int )>(_a, &DatapickerImage::referencePointSelected, 18))
            return;
    }
}

const QMetaObject *DatapickerImage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DatapickerImage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DatapickerImageE_t>.strings))
        return static_cast<void*>(this);
    return AbstractPart::qt_metacast(_clname);
}

int DatapickerImage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractPart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void DatapickerImage::requestProjectContextMenu(QMenu * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DatapickerImage::requestUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DatapickerImage::requestUpdateActions()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DatapickerImage::relativeFilePathChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DatapickerImage::fileNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DatapickerImage::embeddedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DatapickerImage::rotationAngleChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DatapickerImage::axisPointsChanged(const DatapickerImage::ReferencePoints & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DatapickerImage::axisPointsRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DatapickerImage::settingsChanged(const DatapickerImage::EditorSettings & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DatapickerImage::minSegmentLengthChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DatapickerImage::pointStyleChanged(Symbol::Style _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DatapickerImage::pointSizeChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DatapickerImage::pointRotationAngleChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void DatapickerImage::pointOpacityChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DatapickerImage::pointBrushChanged(QBrush _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DatapickerImage::pointPenChanged(const QPen & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void DatapickerImage::pointVisibilityChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void DatapickerImage::referencePointSelected(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}
QT_WARNING_POP
