/********************************************************************************
** Form generated from reading UI file 'labelwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LABELWIDGET_H
#define UI_LABELWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcolorbutton.h"
#include "kcombobox.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_LabelWidget
{
public:
    QGridLayout *gridLayout_2;
    KColorButton *kcbFontColor;
    KColorButton *kcbBackgroundColor;
    QSpacerItem *verticalSpacer_3;
    KComboBox *cbVerticalAlignment;
    QLabel *lFontColor;
    QLabel *lBorderShape;
    QLabel *lPositionX;
    QCheckBox *chbLock;
    QLabel *lPositionXLogicalDateTime;
    KFontRequester *kfontRequester;
    UTCDateTimeEdit *dtePositionXLogical;
    QLabel *lBackgroundColor;
    NumberSpinBox *sbOffsetX;
    KComboBox *cbHorizontalAlignment;
    QLabel *lGeometry;
    QHBoxLayout *horizontalLayout;
    KComboBox *cbPositionX;
    NumberSpinBox *sbPositionX;
    QSpacerItem *horizontalSpacer_8;
    NumberSpinBox *sbPositionYLogical;
    QLabel *lName;
    QLabel *lVerticalAlignment;
    QLabel *lOffsetX;
    QLabel *label;
    ResizableTextEdit *teLabel;
    QSpacerItem *verticalSpacer;
    QLabel *lBorder;
    QSpacerItem *verticalSpacer_2;
    QLabel *lComment;
    TimedLineEdit *leName;
    QLabel *lFontSize;
    QComboBox *cbMode;
    NumberSpinBox *sbOffsetY;
    QSpinBox *sbFontSize;
    QLabel *lFontTeX;
    QHBoxLayout *horizontalLayout_2;
    KComboBox *cbPositionY;
    NumberSpinBox *sbPositionY;
    QCheckBox *chbShowPlaceholderText;
    QFrame *frameTextBox;
    QGridLayout *gridLayout;
    QSpacerItem *spacer;
    QToolButton *tbSymbols;
    QToolButton *tbFontItalic;
    QToolButton *tbFontUnderline;
    QToolButton *tbFontStrikeOut;
    QToolButton *tbFontSubScript;
    QToolButton *tbFontSuperScript;
    QToolButton *tbAlignCenter;
    QToolButton *tbFontBold;
    QToolButton *tbAlignRight;
    QToolButton *tbAlignLeft;
    QToolButton *tbDateTime;
    QToolButton *tbAlignJustify;
    QSpacerItem *verticalSpacer_4;
    QLabel *lText;
    QSpinBox *sbRotation;
    QLabel *lPositionY;
    QLabel *lFont;
    QSpacerItem *horizontalSpacer;
    ResizableTextEdit *teComment;
    QLabel *lRotation;
    NumberSpinBox *sbPositionXLogical;
    QLabel *lPositionYLogical;
    QLabel *lHorizontalAlignment;
    QComboBox *cbBorderShape;
    QCheckBox *chbBindLogicalPos;
    QLabel *lPositionXLogical;
    QLabel *lOffsetY;
    QCheckBox *chbVisible;
    KFontRequester *kfontRequesterTeX;

    void setupUi(QWidget *LabelWidget)
    {
        if (LabelWidget->objectName().isEmpty())
            LabelWidget->setObjectName("LabelWidget");
        LabelWidget->resize(532, 1180);
        gridLayout_2 = new QGridLayout(LabelWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        kcbFontColor = new KColorButton(LabelWidget);
        kcbFontColor->setObjectName("kcbFontColor");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcbFontColor->sizePolicy().hasHeightForWidth());
        kcbFontColor->setSizePolicy(sizePolicy);
        kcbFontColor->setIconSize(QSize(20, 20));

        gridLayout_2->addWidget(kcbFontColor, 10, 3, 1, 1);

        kcbBackgroundColor = new KColorButton(LabelWidget);
        kcbBackgroundColor->setObjectName("kcbBackgroundColor");
        sizePolicy.setHeightForWidth(kcbBackgroundColor->sizePolicy().hasHeightForWidth());
        kcbBackgroundColor->setSizePolicy(sizePolicy);
        kcbBackgroundColor->setIconSize(QSize(20, 20));

        gridLayout_2->addWidget(kcbBackgroundColor, 11, 3, 1, 1);

        verticalSpacer_3 = new QSpacerItem(58, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_3, 12, 0, 1, 2);

        cbVerticalAlignment = new KComboBox(LabelWidget);
        cbVerticalAlignment->setObjectName("cbVerticalAlignment");

        gridLayout_2->addWidget(cbVerticalAlignment, 27, 3, 1, 1);

        lFontColor = new QLabel(LabelWidget);
        lFontColor->setObjectName("lFontColor");

        gridLayout_2->addWidget(lFontColor, 10, 0, 1, 2);

        lBorderShape = new QLabel(LabelWidget);
        lBorderShape->setObjectName("lBorderShape");

        gridLayout_2->addWidget(lBorderShape, 30, 0, 1, 2);

        lPositionX = new QLabel(LabelWidget);
        lPositionX->setObjectName("lPositionX");

        gridLayout_2->addWidget(lPositionX, 16, 0, 1, 2);

        chbLock = new QCheckBox(LabelWidget);
        chbLock->setObjectName("chbLock");

        gridLayout_2->addWidget(chbLock, 33, 0, 1, 2);

        lPositionXLogicalDateTime = new QLabel(LabelWidget);
        lPositionXLogicalDateTime->setObjectName("lPositionXLogicalDateTime");

        gridLayout_2->addWidget(lPositionXLogicalDateTime, 21, 0, 1, 2);

        kfontRequester = new KFontRequester(LabelWidget);
        kfontRequester->setObjectName("kfontRequester");

        gridLayout_2->addWidget(kfontRequester, 7, 3, 1, 1);

        dtePositionXLogical = new UTCDateTimeEdit(LabelWidget);
        dtePositionXLogical->setObjectName("dtePositionXLogical");
        dtePositionXLogical->setCalendarPopup(true);

        gridLayout_2->addWidget(dtePositionXLogical, 21, 3, 1, 1);

        lBackgroundColor = new QLabel(LabelWidget);
        lBackgroundColor->setObjectName("lBackgroundColor");

        gridLayout_2->addWidget(lBackgroundColor, 11, 0, 1, 2);

        sbOffsetX = new NumberSpinBox(LabelWidget);
        sbOffsetX->setObjectName("sbOffsetX");
        sbOffsetX->setProperty("feedback", QVariant(true));

        gridLayout_2->addWidget(sbOffsetX, 23, 3, 1, 1);

        cbHorizontalAlignment = new KComboBox(LabelWidget);
        cbHorizontalAlignment->setObjectName("cbHorizontalAlignment");

        gridLayout_2->addWidget(cbHorizontalAlignment, 26, 3, 1, 1);

        lGeometry = new QLabel(LabelWidget);
        lGeometry->setObjectName("lGeometry");
        QFont font;
        font.setBold(true);
        lGeometry->setFont(font);
        lGeometry->setFrameShape(QFrame::Shape::NoFrame);

        gridLayout_2->addWidget(lGeometry, 13, 0, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        cbPositionX = new KComboBox(LabelWidget);
        cbPositionX->setObjectName("cbPositionX");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbPositionX->sizePolicy().hasHeightForWidth());
        cbPositionX->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(cbPositionX);

        sbPositionX = new NumberSpinBox(LabelWidget);
        sbPositionX->setObjectName("sbPositionX");
        sizePolicy1.setHeightForWidth(sbPositionX->sizePolicy().hasHeightForWidth());
        sbPositionX->setSizePolicy(sizePolicy1);
        sbPositionX->setProperty("feedback", QVariant(true));

        horizontalLayout->addWidget(sbPositionX);


        gridLayout_2->addLayout(horizontalLayout, 16, 3, 1, 1);

        horizontalSpacer_8 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_8, 0, 2, 1, 1);

        sbPositionYLogical = new NumberSpinBox(LabelWidget);
        sbPositionYLogical->setObjectName("sbPositionYLogical");
        sbPositionYLogical->setProperty("feedback", QVariant(true));

        gridLayout_2->addWidget(sbPositionYLogical, 22, 3, 1, 1);

        lName = new QLabel(LabelWidget);
        lName->setObjectName("lName");

        gridLayout_2->addWidget(lName, 0, 0, 1, 2);

        lVerticalAlignment = new QLabel(LabelWidget);
        lVerticalAlignment->setObjectName("lVerticalAlignment");

        gridLayout_2->addWidget(lVerticalAlignment, 27, 0, 1, 2);

        lOffsetX = new QLabel(LabelWidget);
        lOffsetX->setObjectName("lOffsetX");

        gridLayout_2->addWidget(lOffsetX, 23, 0, 1, 2);

        label = new QLabel(LabelWidget);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 3, 0, 1, 2);

        teLabel = new ResizableTextEdit(LabelWidget);
        teLabel->setObjectName("teLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(teLabel->sizePolicy().hasHeightForWidth());
        teLabel->setSizePolicy(sizePolicy2);
        teLabel->setMaximumSize(QSize(16777215, 16777215));
        QFont font1;
        teLabel->setFont(font1);

        gridLayout_2->addWidget(teLabel, 5, 3, 1, 1);

        verticalSpacer = new QSpacerItem(20, 37, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 32, 0, 1, 2);

        lBorder = new QLabel(LabelWidget);
        lBorder->setObjectName("lBorder");
        lBorder->setFont(font);
        lBorder->setFrameShape(QFrame::Shape::NoFrame);

        gridLayout_2->addWidget(lBorder, 29, 0, 1, 2);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_2, 31, 0, 1, 2);

        lComment = new QLabel(LabelWidget);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(lComment, 1, 0, 1, 2);

        leName = new TimedLineEdit(LabelWidget);
        leName->setObjectName("leName");

        gridLayout_2->addWidget(leName, 0, 3, 1, 1);

        lFontSize = new QLabel(LabelWidget);
        lFontSize->setObjectName("lFontSize");

        gridLayout_2->addWidget(lFontSize, 9, 0, 1, 2);

        cbMode = new QComboBox(LabelWidget);
        cbMode->setObjectName("cbMode");

        gridLayout_2->addWidget(cbMode, 3, 3, 1, 1);

        sbOffsetY = new NumberSpinBox(LabelWidget);
        sbOffsetY->setObjectName("sbOffsetY");
        sbOffsetY->setProperty("feedback", QVariant(true));

        gridLayout_2->addWidget(sbOffsetY, 24, 3, 1, 1);

        sbFontSize = new QSpinBox(LabelWidget);
        sbFontSize->setObjectName("sbFontSize");

        gridLayout_2->addWidget(sbFontSize, 9, 3, 1, 1);

        lFontTeX = new QLabel(LabelWidget);
        lFontTeX->setObjectName("lFontTeX");

        gridLayout_2->addWidget(lFontTeX, 8, 0, 1, 2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        cbPositionY = new KComboBox(LabelWidget);
        cbPositionY->setObjectName("cbPositionY");
        sizePolicy1.setHeightForWidth(cbPositionY->sizePolicy().hasHeightForWidth());
        cbPositionY->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(cbPositionY);

        sbPositionY = new NumberSpinBox(LabelWidget);
        sbPositionY->setObjectName("sbPositionY");
        sizePolicy1.setHeightForWidth(sbPositionY->sizePolicy().hasHeightForWidth());
        sbPositionY->setSizePolicy(sizePolicy1);
        sbPositionY->setProperty("feedback", QVariant(true));

        horizontalLayout_2->addWidget(sbPositionY);


        gridLayout_2->addLayout(horizontalLayout_2, 19, 3, 1, 1);

        chbShowPlaceholderText = new QCheckBox(LabelWidget);
        chbShowPlaceholderText->setObjectName("chbShowPlaceholderText");

        gridLayout_2->addWidget(chbShowPlaceholderText, 6, 3, 1, 1);

        frameTextBox = new QFrame(LabelWidget);
        frameTextBox->setObjectName("frameTextBox");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(frameTextBox->sizePolicy().hasHeightForWidth());
        frameTextBox->setSizePolicy(sizePolicy3);
        frameTextBox->setFrameShape(QFrame::Shape::NoFrame);
        frameTextBox->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout = new QGridLayout(frameTextBox);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        spacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer, 0, 12, 1, 1);

        tbSymbols = new QToolButton(frameTextBox);
        tbSymbols->setObjectName("tbSymbols");

        gridLayout->addWidget(tbSymbols, 0, 13, 1, 1);

        tbFontItalic = new QToolButton(frameTextBox);
        tbFontItalic->setObjectName("tbFontItalic");
        tbFontItalic->setCheckable(true);

        gridLayout->addWidget(tbFontItalic, 0, 2, 1, 1);

        tbFontUnderline = new QToolButton(frameTextBox);
        tbFontUnderline->setObjectName("tbFontUnderline");
        tbFontUnderline->setCheckable(true);

        gridLayout->addWidget(tbFontUnderline, 0, 3, 1, 1);

        tbFontStrikeOut = new QToolButton(frameTextBox);
        tbFontStrikeOut->setObjectName("tbFontStrikeOut");
        tbFontStrikeOut->setCheckable(true);

        gridLayout->addWidget(tbFontStrikeOut, 0, 4, 1, 1);

        tbFontSubScript = new QToolButton(frameTextBox);
        tbFontSubScript->setObjectName("tbFontSubScript");
        tbFontSubScript->setCheckable(true);

        gridLayout->addWidget(tbFontSubScript, 0, 6, 1, 1);

        tbFontSuperScript = new QToolButton(frameTextBox);
        tbFontSuperScript->setObjectName("tbFontSuperScript");
        tbFontSuperScript->setCheckable(true);

        gridLayout->addWidget(tbFontSuperScript, 0, 5, 1, 1);

        tbAlignCenter = new QToolButton(frameTextBox);
        tbAlignCenter->setObjectName("tbAlignCenter");

        gridLayout->addWidget(tbAlignCenter, 0, 9, 1, 1);

        tbFontBold = new QToolButton(frameTextBox);
        tbFontBold->setObjectName("tbFontBold");
        tbFontBold->setCheckable(true);

        gridLayout->addWidget(tbFontBold, 0, 1, 1, 1);

        tbAlignRight = new QToolButton(frameTextBox);
        tbAlignRight->setObjectName("tbAlignRight");

        gridLayout->addWidget(tbAlignRight, 0, 10, 1, 1);

        tbAlignLeft = new QToolButton(frameTextBox);
        tbAlignLeft->setObjectName("tbAlignLeft");

        gridLayout->addWidget(tbAlignLeft, 0, 7, 1, 1);

        tbDateTime = new QToolButton(frameTextBox);
        tbDateTime->setObjectName("tbDateTime");

        gridLayout->addWidget(tbDateTime, 0, 14, 1, 1);

        tbAlignJustify = new QToolButton(frameTextBox);
        tbAlignJustify->setObjectName("tbAlignJustify");

        gridLayout->addWidget(tbAlignJustify, 0, 11, 1, 1);


        gridLayout_2->addWidget(frameTextBox, 4, 3, 1, 1);

        verticalSpacer_4 = new QSpacerItem(58, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_4, 28, 0, 1, 2);

        lText = new QLabel(LabelWidget);
        lText->setObjectName("lText");
        lText->setFont(font);
        lText->setFrameShape(QFrame::Shape::NoFrame);
        lText->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout_2->addWidget(lText, 2, 0, 1, 2);

        sbRotation = new QSpinBox(LabelWidget);
        sbRotation->setObjectName("sbRotation");
        sbRotation->setMinimum(-360);
        sbRotation->setMaximum(360);
        sbRotation->setSingleStep(5);

        gridLayout_2->addWidget(sbRotation, 25, 3, 1, 1);

        lPositionY = new QLabel(LabelWidget);
        lPositionY->setObjectName("lPositionY");

        gridLayout_2->addWidget(lPositionY, 19, 0, 1, 2);

        lFont = new QLabel(LabelWidget);
        lFont->setObjectName("lFont");

        gridLayout_2->addWidget(lFont, 7, 0, 1, 2);

        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 3, 2, 1, 1);

        teComment = new ResizableTextEdit(LabelWidget);
        teComment->setObjectName("teComment");

        gridLayout_2->addWidget(teComment, 1, 3, 1, 1);

        lRotation = new QLabel(LabelWidget);
        lRotation->setObjectName("lRotation");

        gridLayout_2->addWidget(lRotation, 25, 0, 1, 2);

        sbPositionXLogical = new NumberSpinBox(LabelWidget);
        sbPositionXLogical->setObjectName("sbPositionXLogical");
        sbPositionXLogical->setProperty("feedback", QVariant(true));

        gridLayout_2->addWidget(sbPositionXLogical, 20, 3, 1, 1);

        lPositionYLogical = new QLabel(LabelWidget);
        lPositionYLogical->setObjectName("lPositionYLogical");

        gridLayout_2->addWidget(lPositionYLogical, 22, 0, 1, 2);

        lHorizontalAlignment = new QLabel(LabelWidget);
        lHorizontalAlignment->setObjectName("lHorizontalAlignment");

        gridLayout_2->addWidget(lHorizontalAlignment, 26, 0, 1, 2);

        cbBorderShape = new QComboBox(LabelWidget);
        cbBorderShape->setObjectName("cbBorderShape");

        gridLayout_2->addWidget(cbBorderShape, 30, 3, 1, 1);

        chbBindLogicalPos = new QCheckBox(LabelWidget);
        chbBindLogicalPos->setObjectName("chbBindLogicalPos");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(chbBindLogicalPos->sizePolicy().hasHeightForWidth());
        chbBindLogicalPos->setSizePolicy(sizePolicy4);

        gridLayout_2->addWidget(chbBindLogicalPos, 14, 3, 1, 1);

        lPositionXLogical = new QLabel(LabelWidget);
        lPositionXLogical->setObjectName("lPositionXLogical");

        gridLayout_2->addWidget(lPositionXLogical, 20, 0, 1, 2);

        lOffsetY = new QLabel(LabelWidget);
        lOffsetY->setObjectName("lOffsetY");

        gridLayout_2->addWidget(lOffsetY, 24, 0, 1, 2);

        chbVisible = new QCheckBox(LabelWidget);
        chbVisible->setObjectName("chbVisible");

        gridLayout_2->addWidget(chbVisible, 34, 0, 1, 2);

        kfontRequesterTeX = new KFontRequester(LabelWidget);
        kfontRequesterTeX->setObjectName("kfontRequesterTeX");

        gridLayout_2->addWidget(kfontRequesterTeX, 8, 3, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbMode);
        QWidget::setTabOrder(cbMode, tbFontBold);
        QWidget::setTabOrder(tbFontBold, tbFontItalic);
        QWidget::setTabOrder(tbFontItalic, tbFontUnderline);
        QWidget::setTabOrder(tbFontUnderline, tbFontStrikeOut);
        QWidget::setTabOrder(tbFontStrikeOut, tbFontSuperScript);
        QWidget::setTabOrder(tbFontSuperScript, tbFontSubScript);
        QWidget::setTabOrder(tbFontSubScript, tbAlignLeft);
        QWidget::setTabOrder(tbAlignLeft, tbAlignCenter);
        QWidget::setTabOrder(tbAlignCenter, tbAlignRight);
        QWidget::setTabOrder(tbAlignRight, tbAlignJustify);
        QWidget::setTabOrder(tbAlignJustify, tbSymbols);
        QWidget::setTabOrder(tbSymbols, tbDateTime);
        QWidget::setTabOrder(tbDateTime, teLabel);
        QWidget::setTabOrder(teLabel, chbShowPlaceholderText);
        QWidget::setTabOrder(chbShowPlaceholderText, kfontRequester);
        QWidget::setTabOrder(kfontRequester, kfontRequesterTeX);
        QWidget::setTabOrder(kfontRequesterTeX, sbFontSize);
        QWidget::setTabOrder(sbFontSize, kcbFontColor);
        QWidget::setTabOrder(kcbFontColor, kcbBackgroundColor);
        QWidget::setTabOrder(kcbBackgroundColor, chbBindLogicalPos);
        QWidget::setTabOrder(chbBindLogicalPos, cbPositionX);
        QWidget::setTabOrder(cbPositionX, sbPositionX);
        QWidget::setTabOrder(sbPositionX, cbPositionY);
        QWidget::setTabOrder(cbPositionY, sbPositionY);
        QWidget::setTabOrder(sbPositionY, sbPositionXLogical);
        QWidget::setTabOrder(sbPositionXLogical, dtePositionXLogical);
        QWidget::setTabOrder(dtePositionXLogical, sbPositionYLogical);
        QWidget::setTabOrder(sbPositionYLogical, sbOffsetX);
        QWidget::setTabOrder(sbOffsetX, sbOffsetY);
        QWidget::setTabOrder(sbOffsetY, sbRotation);
        QWidget::setTabOrder(sbRotation, cbHorizontalAlignment);
        QWidget::setTabOrder(cbHorizontalAlignment, cbVerticalAlignment);
        QWidget::setTabOrder(cbVerticalAlignment, cbBorderShape);
        QWidget::setTabOrder(cbBorderShape, chbLock);
        QWidget::setTabOrder(chbLock, chbVisible);

        retranslateUi(LabelWidget);

        QMetaObject::connectSlotsByName(LabelWidget);
    } // setupUi

    void retranslateUi(QWidget *LabelWidget)
    {
        lFontColor->setText(tr2i18n("Font Color:", nullptr));
        lBorderShape->setText(tr2i18n("Shape:", nullptr));
#if QT_CONFIG(tooltip)
        lPositionX->setToolTip(tr2i18n("Horizontal position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
        lPositionX->setText(tr2i18n("x:", nullptr));
        chbLock->setText(tr2i18n("Locked", nullptr));
        lPositionXLogicalDateTime->setText(tr2i18n("x:", nullptr));
        lBackgroundColor->setText(tr2i18n("Background Color:", nullptr));
#if QT_CONFIG(tooltip)
        sbOffsetX->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbOffsetX->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbOffsetX->setSuffix(tr2i18n(" pt", nullptr));
        lGeometry->setText(tr2i18n("Geometry", nullptr));
#if QT_CONFIG(tooltip)
        cbPositionX->setToolTip(tr2i18n("Horizontal position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        sbPositionX->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionX->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        sbPositionYLogical->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionYLogical->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lName->setText(tr2i18n("Name:", nullptr));
        lVerticalAlignment->setText(tr2i18n("Vert. Alignment:", nullptr));
#if QT_CONFIG(tooltip)
        lOffsetX->setToolTip(tr2i18n("Distance to the axis tick labels", nullptr));
#endif // QT_CONFIG(tooltip)
        lOffsetX->setText(tr2i18n("Offset X:", nullptr));
        label->setText(tr2i18n("Mode:", nullptr));
        teLabel->setHtml(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><meta charset=\"utf-8\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"hr { height: 1px; border-width: 0; }\n"
"li.unchecked::marker { content: \"\\2610\"; }\n"
"li.checked::marker { content: \"\\2612\"; }\n"
"</style></head><body style=\" font-family:'Noto Sans'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p></body></html>", nullptr));
        lBorder->setText(tr2i18n("Border", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lFontSize->setText(tr2i18n("Size:", nullptr));
#if QT_CONFIG(tooltip)
        sbOffsetY->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbOffsetY->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbOffsetY->setSuffix(tr2i18n(" pt", nullptr));
        lFontTeX->setText(tr2i18n("Main font:", nullptr));
#if QT_CONFIG(tooltip)
        cbPositionY->setToolTip(tr2i18n("Vertical position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        sbPositionY->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionY->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chbShowPlaceholderText->setText(tr2i18n("Show Placeholder Text (editable)", nullptr));
        tbSymbols->setText(QString());
        tbFontItalic->setText(QString());
        tbFontUnderline->setText(QString());
        tbFontStrikeOut->setText(QString());
        tbFontSubScript->setText(QString());
        tbFontSuperScript->setText(QString());
        tbAlignCenter->setText(QString());
        tbFontBold->setText(QString());
        tbAlignRight->setText(QString());
        tbAlignLeft->setText(QString());
        tbDateTime->setText(QString());
        tbAlignJustify->setText(QString());
        lText->setText(tr2i18n("Text:", nullptr));
        sbRotation->setSuffix(tr2i18n("\302\260", nullptr));
#if QT_CONFIG(tooltip)
        lPositionY->setToolTip(tr2i18n("Vertical position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
        lPositionY->setText(tr2i18n("y:", nullptr));
        lFont->setText(tr2i18n("Font:", nullptr));
        lRotation->setText(tr2i18n("Rotation:", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionXLogical->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionXLogical->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lPositionYLogical->setText(tr2i18n("Y:", nullptr));
        lHorizontalAlignment->setText(tr2i18n("Hor. Alignment:", nullptr));
        chbBindLogicalPos->setText(tr2i18n("Logical Coordinates", nullptr));
        lPositionXLogical->setText(tr2i18n("X:", nullptr));
#if QT_CONFIG(tooltip)
        lOffsetY->setToolTip(tr2i18n("Distance to the axis tick labels", nullptr));
#endif // QT_CONFIG(tooltip)
        lOffsetY->setText(tr2i18n("Offset Y:", nullptr));
        chbVisible->setText(tr2i18n("Visible", nullptr));
        (void)LabelWidget;
    } // retranslateUi

};

namespace Ui {
    class LabelWidget: public Ui_LabelWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LABELWIDGET_H

