/****************************************************************************
** Meta object code from reading C++ file 'ImportFileWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/datasources/ImportFileWidget.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ImportFileWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16ImportFileWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto ImportFileWidget::qt_create_metaobjectdata<qt_meta_tag_ZN16ImportFileWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImportFileWidget",
        "enableImportToMatrix",
        "",
        "enable",
        "fileNameChanged",
        "sourceTypeChanged",
        "hostChanged",
        "portChanged",
        "error",
        "previewReady",
        "newTopic",
        "subscriptionsChanged",
        "checkFileType",
        "updateSubscriptionTree",
        "MQTTClearTopics",
        "dataContainerChanged",
        "AbstractAspect*",
        "fileTypeChanged",
        "updateTypeChanged",
        "readingTypeChanged",
        "firstRowAsColNamesChanged",
        "checked",
        "hidePropertyWidgets",
        "filterChanged",
        "selectFile",
        "selectDBCFile",
        "showFileInfo",
        "refreshPreview",
        "updateStartRow",
        "enableDataPortionSelection",
        "changeMcapTopic",
        "loadConfigFromTemplate",
        "KConfig&",
        "saveConfigAsTemplate",
        "mqttConnectionChanged",
        "onMqttConnect",
        "subscribeTopic",
        "unsubscribeTopic",
        "QList<QTreeWidgetItem*>",
        "mqttMessageReceived",
        "QMqttTopicName",
        "mqttSubscriptionMessageReceived",
        "QMqttMessage",
        "onMqttDisconnect",
        "mqttErrorChanged",
        "QMqttClient::ClientError",
        "mqttConnectTimeout",
        "showMQTTConnectionManager",
        "readMQTTConnections",
        "showWillSettings",
        "enableWill"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enableImportToMatrix'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'fileNameChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceTypeChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hostChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'portChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'previewReady'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newTopic'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'subscriptionsChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'checkFileType'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateSubscriptionTree'
        QtMocHelpers::SignalData<void(const QVector<QString> &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
        // Signal 'MQTTClearTopics'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'dataContainerChanged'
        QtMocHelpers::SlotData<void(AbstractAspect *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'fileNameChanged'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'fileTypeChanged'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'fileTypeChanged'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'sourceTypeChanged'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'updateTypeChanged'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'readingTypeChanged'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'firstRowAsColNamesChanged'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'hidePropertyWidgets'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'filterChanged'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'selectFile'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectDBCFile'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showFileInfo'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshPreview'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateStartRow'
        QtMocHelpers::SlotData<void(int)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'enableDataPortionSelection'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'changeMcapTopic'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadConfigFromTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 2 },
        }}),
        // Slot 'saveConfigAsTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 2 },
        }}),
        // Slot 'mqttConnectionChanged'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMqttConnect'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'subscribeTopic'
        QtMocHelpers::SlotData<void(const QString &, uint)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::UInt, 2 },
        }}),
        // Slot 'unsubscribeTopic'
        QtMocHelpers::SlotData<void(const QString &, QVector<QTreeWidgetItem*>)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 38, 2 },
        }}),
        // Slot 'mqttMessageReceived'
        QtMocHelpers::SlotData<void(const QByteArray &, const QMqttTopicName &)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 2 }, { 0x80000000 | 40, 2 },
        }}),
        // Slot 'mqttSubscriptionMessageReceived'
        QtMocHelpers::SlotData<void(const QMqttMessage &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 2 },
        }}),
        // Slot 'onMqttDisconnect'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'mqttErrorChanged'
        QtMocHelpers::SlotData<void(QMqttClient::ClientError)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 45, 2 },
        }}),
        // Slot 'mqttConnectTimeout'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showMQTTConnectionManager'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'readMQTTConnections'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showWillSettings'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableWill'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImportFileWidget, qt_meta_tag_ZN16ImportFileWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ImportFileWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ImportFileWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ImportFileWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ImportFileWidgetE_t>.metaTypes,
    nullptr
} };

void ImportFileWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImportFileWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enableImportToMatrix((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->fileNameChanged(); break;
        case 2: _t->sourceTypeChanged(); break;
        case 3: _t->hostChanged(); break;
        case 4: _t->portChanged(); break;
        case 5: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->previewReady(); break;
        case 7: _t->newTopic((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->subscriptionsChanged(); break;
        case 9: _t->checkFileType(); break;
        case 10: _t->updateSubscriptionTree((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1]))); break;
        case 11: _t->MQTTClearTopics(); break;
        case 12: _t->dataContainerChanged((*reinterpret_cast<std::add_pointer_t<AbstractAspect*>>(_a[1]))); break;
        case 13: _t->fileNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->fileTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->fileTypeChanged(); break;
        case 16: _t->sourceTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->updateTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->readingTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->firstRowAsColNamesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->hidePropertyWidgets(); break;
        case 21: _t->filterChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->selectFile(); break;
        case 23: _t->selectDBCFile(); break;
        case 24: _t->showFileInfo(); break;
        case 25: _t->refreshPreview(); break;
        case 26: _t->updateStartRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->enableDataPortionSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->changeMcapTopic(); break;
        case 29: _t->loadConfigFromTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        case 30: _t->saveConfigAsTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        case 31: _t->mqttConnectionChanged(); break;
        case 32: _t->onMqttConnect(); break;
        case 33: _t->subscribeTopic((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 34: _t->unsubscribeTopic((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QTreeWidgetItem*>>>(_a[2]))); break;
        case 35: _t->mqttMessageReceived((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMqttTopicName>>(_a[2]))); break;
        case 36: _t->mqttSubscriptionMessageReceived((*reinterpret_cast<std::add_pointer_t<QMqttMessage>>(_a[1]))); break;
        case 37: _t->onMqttDisconnect(); break;
        case 38: _t->mqttErrorChanged((*reinterpret_cast<std::add_pointer_t<QMqttClient::ClientError>>(_a[1]))); break;
        case 39: _t->mqttConnectTimeout(); break;
        case 40: _t->showMQTTConnectionManager(); break;
        case 41: _t->readMQTTConnections(); break;
        case 42: _t->showWillSettings(); break;
        case 43: _t->enableWill((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAspect* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMqttTopicName >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMqttMessage >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMqttClient::ClientError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ImportFileWidget::*)(bool )>(_a, &ImportFileWidget::enableImportToMatrix, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportFileWidget::*)()>(_a, &ImportFileWidget::fileNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportFileWidget::*)()>(_a, &ImportFileWidget::sourceTypeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportFileWidget::*)()>(_a, &ImportFileWidget::hostChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportFileWidget::*)()>(_a, &ImportFileWidget::portChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportFileWidget::*)(const QString & )>(_a, &ImportFileWidget::error, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportFileWidget::*)()>(_a, &ImportFileWidget::previewReady, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportFileWidget::*)(const QString & )>(_a, &ImportFileWidget::newTopic, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportFileWidget::*)()>(_a, &ImportFileWidget::subscriptionsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportFileWidget::*)()>(_a, &ImportFileWidget::checkFileType, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportFileWidget::*)(const QVector<QString> & )>(_a, &ImportFileWidget::updateSubscriptionTree, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportFileWidget::*)()>(_a, &ImportFileWidget::MQTTClearTopics, 11))
            return;
    }
}

const QMetaObject *ImportFileWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImportFileWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ImportFileWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ImportFileWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void ImportFileWidget::enableImportToMatrix(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ImportFileWidget::fileNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ImportFileWidget::sourceTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ImportFileWidget::hostChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ImportFileWidget::portChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ImportFileWidget::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ImportFileWidget::previewReady()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ImportFileWidget::newTopic(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ImportFileWidget::subscriptionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ImportFileWidget::checkFileType()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ImportFileWidget::updateSubscriptionTree(const QVector<QString> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void ImportFileWidget::MQTTClearTopics()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
