/********************************************************************************
** Form generated from reading UI file 'importsqldatabasewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTSQLDATABASEWIDGET_H
#define UI_IMPORTSQLDATABASEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ImportSQLDatabaseWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *lConnection;
    QComboBox *cbConnection;
    QPushButton *bDatabaseManager;
    QLabel *lImportFrom;
    QComboBox *cbImportFrom;
    QSpacerItem *verticalSpacer_2;
    QLabel *lDecimalSeparator;
    QLabel *lDateTimeFormat;
    QComboBox *cbDecimalSeparator;
    KComboBox *cbDateTimeFormat;
    QSplitter *splitterMain;
    QGroupBox *gbQuery;
    QHBoxLayout *horizontalLayout_6;
    QTextEdit *teQuery;
    QTabWidget *tabWidget;
    QWidget *tabDataPreview;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QSpinBox *sbPreviewLines;
    QPushButton *bRefreshPreview;
    QHBoxLayout *horizontalLayout_2;
    QSplitter *splitterPreview;
    QListWidget *lwTables;
    QTableWidget *twPreview;
    QWidget *tabDataPortion;
    QGridLayout *gridLayout_3;
    QLabel *lStartRow;
    QSpinBox *sbStartRow;
    QSpacerItem *horizontalSpacer_1;
    QLabel *lEndRow;
    QSpinBox *sbEndRow;
    QSpacerItem *horizontalSpacer_2;
    QLabel *lStartColumn;
    QSpinBox *sbStartColumn;
    QSpacerItem *horizontalSpacer_3;
    QLabel *lEndColumn;
    QSpinBox *sbEndColumn;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ImportSQLDatabaseWidget)
    {
        if (ImportSQLDatabaseWidget->objectName().isEmpty())
            ImportSQLDatabaseWidget->setObjectName("ImportSQLDatabaseWidget");
        ImportSQLDatabaseWidget->resize(675, 634);
        verticalLayout = new QVBoxLayout(ImportSQLDatabaseWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(ImportSQLDatabaseWidget);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        lConnection = new QLabel(groupBox);
        lConnection->setObjectName("lConnection");

        gridLayout->addWidget(lConnection, 0, 0, 1, 1);

        cbConnection = new QComboBox(groupBox);
        cbConnection->setObjectName("cbConnection");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbConnection->sizePolicy().hasHeightForWidth());
        cbConnection->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbConnection, 0, 1, 1, 1);

        bDatabaseManager = new QPushButton(groupBox);
        bDatabaseManager->setObjectName("bDatabaseManager");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(bDatabaseManager->sizePolicy().hasHeightForWidth());
        bDatabaseManager->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(bDatabaseManager, 0, 2, 1, 1);

        lImportFrom = new QLabel(groupBox);
        lImportFrom->setObjectName("lImportFrom");

        gridLayout->addWidget(lImportFrom, 1, 0, 1, 1);

        cbImportFrom = new QComboBox(groupBox);
        cbImportFrom->setObjectName("cbImportFrom");

        gridLayout->addWidget(cbImportFrom, 1, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 2, 0, 1, 1);

        lDecimalSeparator = new QLabel(groupBox);
        lDecimalSeparator->setObjectName("lDecimalSeparator");

        gridLayout->addWidget(lDecimalSeparator, 3, 0, 1, 1);

        lDateTimeFormat = new QLabel(groupBox);
        lDateTimeFormat->setObjectName("lDateTimeFormat");

        gridLayout->addWidget(lDateTimeFormat, 4, 0, 1, 1);

        cbDecimalSeparator = new QComboBox(groupBox);
        cbDecimalSeparator->setObjectName("cbDecimalSeparator");

        gridLayout->addWidget(cbDecimalSeparator, 3, 1, 1, 1);

        cbDateTimeFormat = new KComboBox(groupBox);
        cbDateTimeFormat->setObjectName("cbDateTimeFormat");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cbDateTimeFormat->sizePolicy().hasHeightForWidth());
        cbDateTimeFormat->setSizePolicy(sizePolicy2);
        cbDateTimeFormat->setEditable(true);

        gridLayout->addWidget(cbDateTimeFormat, 4, 1, 1, 1);


        verticalLayout->addWidget(groupBox);

        splitterMain = new QSplitter(ImportSQLDatabaseWidget);
        splitterMain->setObjectName("splitterMain");
        splitterMain->setOrientation(Qt::Vertical);
        splitterMain->setChildrenCollapsible(false);
        gbQuery = new QGroupBox(splitterMain);
        gbQuery->setObjectName("gbQuery");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(gbQuery->sizePolicy().hasHeightForWidth());
        gbQuery->setSizePolicy(sizePolicy3);
        horizontalLayout_6 = new QHBoxLayout(gbQuery);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        teQuery = new QTextEdit(gbQuery);
        teQuery->setObjectName("teQuery");
        teQuery->setMinimumSize(QSize(0, 100));

        horizontalLayout_6->addWidget(teQuery);

        splitterMain->addWidget(gbQuery);
        tabWidget = new QTabWidget(splitterMain);
        tabWidget->setObjectName("tabWidget");
        tabDataPreview = new QWidget();
        tabDataPreview->setObjectName("tabDataPreview");
        verticalLayout_3 = new QVBoxLayout(tabDataPreview);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        label = new QLabel(tabDataPreview);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        sbPreviewLines = new QSpinBox(tabDataPreview);
        sbPreviewLines->setObjectName("sbPreviewLines");
        sbPreviewLines->setMinimum(1);
        sbPreviewLines->setMaximum(10000);
        sbPreviewLines->setValue(100);

        horizontalLayout->addWidget(sbPreviewLines);

        bRefreshPreview = new QPushButton(tabDataPreview);
        bRefreshPreview->setObjectName("bRefreshPreview");

        horizontalLayout->addWidget(bRefreshPreview);


        verticalLayout_3->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        splitterPreview = new QSplitter(tabDataPreview);
        splitterPreview->setObjectName("splitterPreview");
        splitterPreview->setOrientation(Qt::Horizontal);
        splitterPreview->setChildrenCollapsible(false);
        lwTables = new QListWidget(splitterPreview);
        lwTables->setObjectName("lwTables");
        lwTables->setMinimumSize(QSize(300, 0));
        lwTables->setAlternatingRowColors(true);
        splitterPreview->addWidget(lwTables);
        twPreview = new QTableWidget(splitterPreview);
        twPreview->setObjectName("twPreview");
        twPreview->setAlternatingRowColors(true);
        splitterPreview->addWidget(twPreview);

        horizontalLayout_2->addWidget(splitterPreview);


        verticalLayout_3->addLayout(horizontalLayout_2);

        tabWidget->addTab(tabDataPreview, QString());
        tabDataPortion = new QWidget();
        tabDataPortion->setObjectName("tabDataPortion");
        gridLayout_3 = new QGridLayout(tabDataPortion);
        gridLayout_3->setObjectName("gridLayout_3");
        lStartRow = new QLabel(tabDataPortion);
        lStartRow->setObjectName("lStartRow");

        gridLayout_3->addWidget(lStartRow, 0, 0, 1, 1);

        sbStartRow = new QSpinBox(tabDataPortion);
        sbStartRow->setObjectName("sbStartRow");
        sbStartRow->setMinimum(1);
        sbStartRow->setMaximum(2147483647);
        sbStartRow->setValue(1);

        gridLayout_3->addWidget(sbStartRow, 0, 1, 1, 1);

        horizontalSpacer_1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_1, 0, 2, 1, 1);

        lEndRow = new QLabel(tabDataPortion);
        lEndRow->setObjectName("lEndRow");

        gridLayout_3->addWidget(lEndRow, 0, 3, 1, 1);

        sbEndRow = new QSpinBox(tabDataPortion);
        sbEndRow->setObjectName("sbEndRow");
        sbEndRow->setMinimum(-1);
        sbEndRow->setMaximum(2147483647);
        sbEndRow->setValue(-1);

        gridLayout_3->addWidget(sbEndRow, 0, 4, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(523, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 0, 5, 1, 1);

        lStartColumn = new QLabel(tabDataPortion);
        lStartColumn->setObjectName("lStartColumn");

        gridLayout_3->addWidget(lStartColumn, 1, 0, 1, 1);

        sbStartColumn = new QSpinBox(tabDataPortion);
        sbStartColumn->setObjectName("sbStartColumn");
        sbStartColumn->setMinimum(1);
        sbStartColumn->setMaximum(2147483647);

        gridLayout_3->addWidget(sbStartColumn, 1, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_3, 1, 2, 1, 1);

        lEndColumn = new QLabel(tabDataPortion);
        lEndColumn->setObjectName("lEndColumn");

        gridLayout_3->addWidget(lEndColumn, 1, 3, 1, 1);

        sbEndColumn = new QSpinBox(tabDataPortion);
        sbEndColumn->setObjectName("sbEndColumn");
        sbEndColumn->setMinimum(-1);
        sbEndColumn->setMaximum(2147483647);
        sbEndColumn->setValue(-1);

        gridLayout_3->addWidget(sbEndColumn, 1, 4, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(523, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_4, 1, 5, 1, 1);

        verticalSpacer = new QSpacerItem(20, 139, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer, 2, 0, 1, 1);

        tabWidget->addTab(tabDataPortion, QString());
        splitterMain->addWidget(tabWidget);

        verticalLayout->addWidget(splitterMain);


        retranslateUi(ImportSQLDatabaseWidget);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ImportSQLDatabaseWidget);
    } // setupUi

    void retranslateUi(QWidget *ImportSQLDatabaseWidget)
    {
        groupBox->setTitle(tr2i18n("Database", nullptr));
        lConnection->setText(tr2i18n("Connection:", nullptr));
        bDatabaseManager->setText(QString());
        lImportFrom->setText(tr2i18n("Import from:", nullptr));
        lDecimalSeparator->setText(tr2i18n("Decimal separator:", nullptr));
        lDateTimeFormat->setText(tr2i18n("DateTime format:", nullptr));
        gbQuery->setTitle(tr2i18n("Query", nullptr));
        label->setText(tr2i18n("Number of rows to preview:", nullptr));
        bRefreshPreview->setText(tr2i18n("Refresh", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDataPreview), tr2i18n("Preview", nullptr));
        lStartRow->setText(tr2i18n("Start row:", nullptr));
#if QT_CONFIG(tooltip)
        sbStartRow->setToolTip(tr2i18n("Specify the start row for import", nullptr));
#endif // QT_CONFIG(tooltip)
        lEndRow->setText(tr2i18n("End row:", nullptr));
#if QT_CONFIG(tooltip)
        sbEndRow->setToolTip(tr2i18n("Specify the end row to import; -1 stands for the last row", nullptr));
#endif // QT_CONFIG(tooltip)
        lStartColumn->setText(tr2i18n("Start column:", nullptr));
#if QT_CONFIG(tooltip)
        sbStartColumn->setToolTip(tr2i18n("Specify the start column for import", nullptr));
#endif // QT_CONFIG(tooltip)
        lEndColumn->setText(tr2i18n("End column:", nullptr));
#if QT_CONFIG(tooltip)
        sbEndColumn->setToolTip(tr2i18n("Specify the end column to import; -1 stands for the last column", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(tabDataPortion), tr2i18n("Data Portion to Read", nullptr));
        (void)ImportSQLDatabaseWidget;
    } // retranslateUi

};

namespace Ui {
    class ImportSQLDatabaseWidget: public Ui_ImportSQLDatabaseWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTSQLDATABASEWIDGET_H

