/********************************************************************************
** Form generated from reading UI file 'formattingheatmapwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FORMATTINGHEATMAPWIDGET_H
#define UI_FORMATTINGHEATMAPWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FormattingHeatmapWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *lMaximum;
    QPushButton *bColorMap;
    QLabel *lHightlight;
    QLabel *lColorMap;
    QComboBox *cbHightlight;
    QCheckBox *chkAutoRange;
    QSpacerItem *verticalSpacer_2;
    QLabel *lLevelsTop;
    QLabel *lMinimum;
    QLabel *lAutoScale;
    QLineEdit *leMinimum;
    QLabel *lColors;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QLabel *lColorMapPreview;
    QLineEdit *leMaximum;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *FormattingHeatmapWidget)
    {
        if (FormattingHeatmapWidget->objectName().isEmpty())
            FormattingHeatmapWidget->setObjectName("FormattingHeatmapWidget");
        FormattingHeatmapWidget->resize(352, 298);
        gridLayout = new QGridLayout(FormattingHeatmapWidget);
        gridLayout->setObjectName("gridLayout");
        lMaximum = new QLabel(FormattingHeatmapWidget);
        lMaximum->setObjectName("lMaximum");

        gridLayout->addWidget(lMaximum, 3, 0, 1, 1);

        bColorMap = new QPushButton(FormattingHeatmapWidget);
        bColorMap->setObjectName("bColorMap");

        gridLayout->addWidget(bColorMap, 6, 2, 1, 1);

        lHightlight = new QLabel(FormattingHeatmapWidget);
        lHightlight->setObjectName("lHightlight");

        gridLayout->addWidget(lHightlight, 7, 0, 1, 1);

        lColorMap = new QLabel(FormattingHeatmapWidget);
        lColorMap->setObjectName("lColorMap");

        gridLayout->addWidget(lColorMap, 6, 0, 1, 1);

        cbHightlight = new QComboBox(FormattingHeatmapWidget);
        cbHightlight->setObjectName("cbHightlight");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbHightlight->sizePolicy().hasHeightForWidth());
        cbHightlight->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbHightlight, 7, 1, 1, 2);

        chkAutoRange = new QCheckBox(FormattingHeatmapWidget);
        chkAutoRange->setObjectName("chkAutoRange");
        sizePolicy.setHeightForWidth(chkAutoRange->sizePolicy().hasHeightForWidth());
        chkAutoRange->setSizePolicy(sizePolicy);

        gridLayout->addWidget(chkAutoRange, 1, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 45, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 8, 0, 1, 1);

        lLevelsTop = new QLabel(FormattingHeatmapWidget);
        lLevelsTop->setObjectName("lLevelsTop");
        QFont font;
        font.setBold(true);
        lLevelsTop->setFont(font);

        gridLayout->addWidget(lLevelsTop, 0, 0, 1, 1);

        lMinimum = new QLabel(FormattingHeatmapWidget);
        lMinimum->setObjectName("lMinimum");

        gridLayout->addWidget(lMinimum, 2, 0, 1, 1);

        lAutoScale = new QLabel(FormattingHeatmapWidget);
        lAutoScale->setObjectName("lAutoScale");

        gridLayout->addWidget(lAutoScale, 1, 0, 1, 1);

        leMinimum = new QLineEdit(FormattingHeatmapWidget);
        leMinimum->setObjectName("leMinimum");

        gridLayout->addWidget(leMinimum, 2, 1, 1, 2);

        lColors = new QLabel(FormattingHeatmapWidget);
        lColors->setObjectName("lColors");
        lColors->setFont(font);

        gridLayout->addWidget(lColors, 5, 0, 1, 1);

        frame = new QFrame(FormattingHeatmapWidget);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        lColorMapPreview = new QLabel(frame);
        lColorMapPreview->setObjectName("lColorMapPreview");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lColorMapPreview->sizePolicy().hasHeightForWidth());
        lColorMapPreview->setSizePolicy(sizePolicy1);
        lColorMapPreview->setScaledContents(true);

        horizontalLayout->addWidget(lColorMapPreview);


        gridLayout->addWidget(frame, 6, 1, 1, 1);

        leMaximum = new QLineEdit(FormattingHeatmapWidget);
        leMaximum->setObjectName("leMaximum");

        gridLayout->addWidget(leMaximum, 3, 1, 1, 2);

        verticalSpacer = new QSpacerItem(28, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 4, 0, 1, 1);


        retranslateUi(FormattingHeatmapWidget);

        QMetaObject::connectSlotsByName(FormattingHeatmapWidget);
    } // setupUi

    void retranslateUi(QWidget *FormattingHeatmapWidget)
    {
        lMaximum->setText(tr2i18n("Maximum:", nullptr));
        bColorMap->setText(QString());
        lHightlight->setText(tr2i18n("Highlight:", nullptr));
        lColorMap->setText(tr2i18n("Color Map:", nullptr));
        chkAutoRange->setText(tr2i18n("Auto", nullptr));
        lLevelsTop->setText(tr2i18n("Levels", nullptr));
        lMinimum->setText(tr2i18n("Minimum:", nullptr));
        lAutoScale->setText(tr2i18n("Range:", nullptr));
        lColors->setText(tr2i18n("Colors", nullptr));
        lColorMapPreview->setText(QString());
        (void)FormattingHeatmapWidget;
    } // retranslateUi

};

namespace Ui {
    class FormattingHeatmapWidget: public Ui_FormattingHeatmapWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FORMATTINGHEATMAPWIDGET_H

