/****************************************************************************
** Meta object code from reading C++ file 'XYAnalysisCurve.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/plots/cartesian/XYAnalysisCurve.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'XYAnalysisCurve.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15XYAnalysisCurveE_t {};
} // unnamed namespace

template <> constexpr inline auto XYAnalysisCurve::qt_create_metaobjectdata<qt_meta_tag_ZN15XYAnalysisCurveE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XYAnalysisCurve",
        "sourceDataChanged",
        "",
        "dataSourceTypeChanged",
        "XYAnalysisCurve::DataSourceType",
        "dataSourceCurveChanged",
        "const XYCurve*",
        "xDataColumnChanged",
        "const AbstractColumn*",
        "yDataColumnChanged",
        "y2DataColumnChanged",
        "handleSourceDataChanged",
        "createDataSpreadsheet",
        "xDataColumnAboutToBeRemoved",
        "const AbstractAspect*",
        "yDataColumnAboutToBeRemoved",
        "y2DataColumnAboutToBeRemoved",
        "xDataColumnNameChanged",
        "yDataColumnNameChanged",
        "y2DataColumnNameChanged",
        "dataSourceCurveAboutToBeRemoved",
        "dataSourceCurveNameChanged",
        "DataSourceType",
        "Spreadsheet",
        "Curve",
        "Histogram",
        "AnalysisAction",
        "DataReduction",
        "Differentiation",
        "Integration",
        "Interpolation",
        "Smoothing",
        "FitLinear",
        "FitPower",
        "FitExp1",
        "FitExp2",
        "FitInvExp",
        "FitGauss",
        "FitCauchyLorentz",
        "FitTan",
        "FitTanh",
        "FitErrFunc",
        "FitCustom",
        "FourierFilter"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceDataChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataSourceTypeChanged'
        QtMocHelpers::SignalData<void(XYAnalysisCurve::DataSourceType)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'dataSourceCurveChanged'
        QtMocHelpers::SignalData<void(const XYCurve *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'xDataColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'yDataColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'y2DataColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'handleSourceDataChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createDataSpreadsheet'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'xDataColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'yDataColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'y2DataColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'xDataColumnNameChanged'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'yDataColumnNameChanged'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'y2DataColumnNameChanged'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'dataSourceCurveAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'dataSourceCurveNameChanged'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DataSourceType'
        QtMocHelpers::EnumData<enum DataSourceType>(22, 22, QMC::EnumIsScoped).add({
            {   23, DataSourceType::Spreadsheet },
            {   24, DataSourceType::Curve },
            {   25, DataSourceType::Histogram },
        }),
        // enum 'AnalysisAction'
        QtMocHelpers::EnumData<enum AnalysisAction>(26, 26, QMC::EnumIsScoped).add({
            {   27, AnalysisAction::DataReduction },
            {   28, AnalysisAction::Differentiation },
            {   29, AnalysisAction::Integration },
            {   30, AnalysisAction::Interpolation },
            {   31, AnalysisAction::Smoothing },
            {   32, AnalysisAction::FitLinear },
            {   33, AnalysisAction::FitPower },
            {   34, AnalysisAction::FitExp1 },
            {   35, AnalysisAction::FitExp2 },
            {   36, AnalysisAction::FitInvExp },
            {   37, AnalysisAction::FitGauss },
            {   38, AnalysisAction::FitCauchyLorentz },
            {   39, AnalysisAction::FitTan },
            {   40, AnalysisAction::FitTanh },
            {   41, AnalysisAction::FitErrFunc },
            {   42, AnalysisAction::FitCustom },
            {   43, AnalysisAction::FourierFilter },
        }),
    };
    return QtMocHelpers::metaObjectData<XYAnalysisCurve, qt_meta_tag_ZN15XYAnalysisCurveE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XYAnalysisCurve::staticMetaObject = { {
    QMetaObject::SuperData::link<XYCurve::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15XYAnalysisCurveE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15XYAnalysisCurveE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15XYAnalysisCurveE_t>.metaTypes,
    nullptr
} };

void XYAnalysisCurve::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XYAnalysisCurve *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceDataChanged(); break;
        case 1: _t->dataSourceTypeChanged((*reinterpret_cast<std::add_pointer_t<XYAnalysisCurve::DataSourceType>>(_a[1]))); break;
        case 2: _t->dataSourceCurveChanged((*reinterpret_cast<std::add_pointer_t<const XYCurve*>>(_a[1]))); break;
        case 3: _t->xDataColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 4: _t->yDataColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 5: _t->y2DataColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 6: _t->handleSourceDataChanged(); break;
        case 7: _t->createDataSpreadsheet(); break;
        case 8: _t->xDataColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 9: _t->yDataColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 10: _t->y2DataColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 11: _t->xDataColumnNameChanged(); break;
        case 12: _t->yDataColumnNameChanged(); break;
        case 13: _t->y2DataColumnNameChanged(); break;
        case 14: _t->dataSourceCurveAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 15: _t->dataSourceCurveNameChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (XYAnalysisCurve::*)()>(_a, &XYAnalysisCurve::sourceDataChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYAnalysisCurve::*)(XYAnalysisCurve::DataSourceType )>(_a, &XYAnalysisCurve::dataSourceTypeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYAnalysisCurve::*)(const XYCurve * )>(_a, &XYAnalysisCurve::dataSourceCurveChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYAnalysisCurve::*)(const AbstractColumn * )>(_a, &XYAnalysisCurve::xDataColumnChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYAnalysisCurve::*)(const AbstractColumn * )>(_a, &XYAnalysisCurve::yDataColumnChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYAnalysisCurve::*)(const AbstractColumn * )>(_a, &XYAnalysisCurve::y2DataColumnChanged, 5))
            return;
    }
}

const QMetaObject *XYAnalysisCurve::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XYAnalysisCurve::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15XYAnalysisCurveE_t>.strings))
        return static_cast<void*>(this);
    return XYCurve::qt_metacast(_clname);
}

int XYAnalysisCurve::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XYCurve::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void XYAnalysisCurve::sourceDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void XYAnalysisCurve::dataSourceTypeChanged(XYAnalysisCurve::DataSourceType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void XYAnalysisCurve::dataSourceCurveChanged(const XYCurve * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void XYAnalysisCurve::xDataColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void XYAnalysisCurve::yDataColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void XYAnalysisCurve::y2DataColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
