/********************************************************************************
** Form generated from reading UI file 'columndock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLUMNDOCK_H
#define UI_COLUMNDOCK_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ColumnDock
{
public:
    QGridLayout *gridLayout;
    QLabel *lComment;
    TimedLineEdit *leName;
    QLabel *lDateTimeFormat;
    ResizableTextEdit *teComment;
    KComboBox *cbType;
    QLabel *lName;
    QFrame *frameLabels;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *bAddLabel;
    QPushButton *bRemoveLabel;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *bBatchEditLabels;
    QSpinBox *sbPrecision;
    QLabel *lLabels;
    QTableWidget *twLabels;
    QLabel *lFormat_2;
    QLabel *lPrecision;
    KComboBox *cbNumericFormat;
    QLabel *lNumericFormat;
    QComboBox *cbDateTimeFormat;
    QSpacerItem *verticalSpacer;
    QLabel *lType;
    QSpacerItem *verticalSpacer_4;
    KComboBox *cbPlotDesignation;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *horizontalSpacer_3;
    QLabel *lPlotDesignation;

    void setupUi(QWidget *ColumnDock)
    {
        if (ColumnDock->objectName().isEmpty())
            ColumnDock->setObjectName("ColumnDock");
        ColumnDock->resize(308, 711);
        gridLayout = new QGridLayout(ColumnDock);
        gridLayout->setObjectName("gridLayout");
        lComment = new QLabel(ColumnDock);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        leName = new TimedLineEdit(ColumnDock);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        lDateTimeFormat = new QLabel(ColumnDock);
        lDateTimeFormat->setObjectName("lDateTimeFormat");

        gridLayout->addWidget(lDateTimeFormat, 7, 0, 1, 1);

        teComment = new ResizableTextEdit(ColumnDock);
        teComment->setObjectName("teComment");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(teComment->sizePolicy().hasHeightForWidth());
        teComment->setSizePolicy(sizePolicy);
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        cbType = new KComboBox(ColumnDock);
        cbType->setObjectName("cbType");

        gridLayout->addWidget(cbType, 4, 2, 1, 1);

        lName = new QLabel(ColumnDock);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        frameLabels = new QFrame(ColumnDock);
        frameLabels->setObjectName("frameLabels");
        frameLabels->setFrameShape(QFrame::Shape::NoFrame);
        frameLabels->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout = new QHBoxLayout(frameLabels);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalSpacer = new QSpacerItem(95, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        bAddLabel = new QPushButton(frameLabels);
        bAddLabel->setObjectName("bAddLabel");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        bAddLabel->setIcon(icon);

        horizontalLayout->addWidget(bAddLabel);

        bRemoveLabel = new QPushButton(frameLabels);
        bRemoveLabel->setObjectName("bRemoveLabel");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        bRemoveLabel->setIcon(icon1);

        horizontalLayout->addWidget(bRemoveLabel);

        horizontalSpacer_2 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        bBatchEditLabels = new QPushButton(frameLabels);
        bBatchEditLabels->setObjectName("bBatchEditLabels");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("format-list-unordered")));
        bBatchEditLabels->setIcon(icon2);

        horizontalLayout->addWidget(bBatchEditLabels);


        gridLayout->addWidget(frameLabels, 12, 2, 1, 1);

        sbPrecision = new QSpinBox(ColumnDock);
        sbPrecision->setObjectName("sbPrecision");
        sbPrecision->setMaximum(16);

        gridLayout->addWidget(sbPrecision, 6, 2, 1, 1);

        lLabels = new QLabel(ColumnDock);
        lLabels->setObjectName("lLabels");
        lLabels->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout->addWidget(lLabels, 11, 0, 1, 1);

        twLabels = new QTableWidget(ColumnDock);
        if (twLabels->columnCount() < 2)
            twLabels->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        twLabels->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        twLabels->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        twLabels->setObjectName("twLabels");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(twLabels->sizePolicy().hasHeightForWidth());
        twLabels->setSizePolicy(sizePolicy1);
        twLabels->setAlternatingRowColors(true);
        twLabels->setSelectionMode(QAbstractItemView::SelectionMode::SingleSelection);
        twLabels->setSelectionBehavior(QAbstractItemView::SelectionBehavior::SelectRows);
        twLabels->verticalHeader()->setVisible(false);

        gridLayout->addWidget(twLabels, 11, 2, 1, 1);

        lFormat_2 = new QLabel(ColumnDock);
        lFormat_2->setObjectName("lFormat_2");
        QFont font;
        font.setBold(true);
        lFormat_2->setFont(font);

        gridLayout->addWidget(lFormat_2, 3, 0, 1, 1);

        lPrecision = new QLabel(ColumnDock);
        lPrecision->setObjectName("lPrecision");

        gridLayout->addWidget(lPrecision, 6, 0, 1, 1);

        cbNumericFormat = new KComboBox(ColumnDock);
        cbNumericFormat->setObjectName("cbNumericFormat");

        gridLayout->addWidget(cbNumericFormat, 5, 2, 1, 1);

        lNumericFormat = new QLabel(ColumnDock);
        lNumericFormat->setObjectName("lNumericFormat");

        gridLayout->addWidget(lNumericFormat, 5, 0, 1, 1);

        cbDateTimeFormat = new QComboBox(ColumnDock);
        cbDateTimeFormat->setObjectName("cbDateTimeFormat");

        gridLayout->addWidget(cbDateTimeFormat, 7, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 2, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 13, 1, 1, 1);

        lType = new QLabel(ColumnDock);
        lType->setObjectName("lType");

        gridLayout->addWidget(lType, 4, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 10, 0, 1, 1);

        cbPlotDesignation = new KComboBox(ColumnDock);
        cbPlotDesignation->setObjectName("cbPlotDesignation");

        gridLayout->addWidget(cbPlotDesignation, 9, 2, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 2, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 8, 0, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 0, 1, 1, 1);

        lPlotDesignation = new QLabel(ColumnDock);
        lPlotDesignation->setObjectName("lPlotDesignation");

        gridLayout->addWidget(lPlotDesignation, 9, 0, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbType);
        QWidget::setTabOrder(cbType, cbNumericFormat);
        QWidget::setTabOrder(cbNumericFormat, sbPrecision);
        QWidget::setTabOrder(sbPrecision, cbDateTimeFormat);
        QWidget::setTabOrder(cbDateTimeFormat, cbPlotDesignation);
        QWidget::setTabOrder(cbPlotDesignation, twLabels);
        QWidget::setTabOrder(twLabels, bAddLabel);
        QWidget::setTabOrder(bAddLabel, bRemoveLabel);
        QWidget::setTabOrder(bRemoveLabel, bBatchEditLabels);

        retranslateUi(ColumnDock);

        QMetaObject::connectSlotsByName(ColumnDock);
    } // setupUi

    void retranslateUi(QWidget *ColumnDock)
    {
        lComment->setText(tr2i18n("Comment:", nullptr));
        lDateTimeFormat->setText(tr2i18n("Format:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        bAddLabel->setText(QString());
        bRemoveLabel->setText(QString());
        bBatchEditLabels->setText(QString());
        lLabels->setText(tr2i18n("Labels:", nullptr));
        QTableWidgetItem *___qtablewidgetitem = twLabels->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Value", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = twLabels->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Label", nullptr));
        lFormat_2->setText(tr2i18n("Data", nullptr));
        lPrecision->setText(tr2i18n("Precision:", nullptr));
        lNumericFormat->setText(tr2i18n("Format:", nullptr));
        lType->setText(tr2i18n("Type:", nullptr));
        lPlotDesignation->setText(tr2i18n("Plot Designation:", nullptr));
        (void)ColumnDock;
    } // retranslateUi

};

namespace Ui {
    class ColumnDock: public Ui_ColumnDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COLUMNDOCK_H

