/********************************************************************************
** Form generated from reading UI file 'xyhilberttransformcurvedockgeneraltab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XYHILBERTTRANSFORMCURVEDOCKGENERALTAB_H
#define UI_XYHILBERTTRANSFORMCURVEDOCKGENERALTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_XYHilbertTransformCurveDockGeneralTab
{
public:
    QGridLayout *gridLayout;
    QLabel *lYColumn;
    QHBoxLayout *horizontalLayout_3;
    QLabel *lMax;
    QLineEdit *leMax;
    QCheckBox *cbAutoRange;
    QLabel *lData;
    QLabel *lName;
    QLabel *lPlotRange;
    ResizableTextEdit *teComment;
    QLabel *lXColumn;
    QComboBox *cbPlotRanges;
    QSpacerItem *verticalSpacer_5;
    KComboBox *cbType;
    QSpacerItem *verticalSpacer_4;
    QCheckBox *chkVisible;
    QLabel *lType;
    QTextEdit *teResult;
    QSpacerItem *verticalSpacerGeneral;
    QHBoxLayout *horizontalLayout_2;
    QLabel *lMin;
    QLineEdit *leMin;
    QLabel *label;
    QLabel *lOptions;
    TimedLineEdit *leName;
    QLabel *lXRange;
    QSpacerItem *horizontalSpacer_2;
    QFrame *line_2;
    QSpacerItem *verticalSpacer_3;
    QPushButton *pbRecalculate;
    QLabel *lComment;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *chkLegendVisible;

    void setupUi(QWidget *XYHilbertTransformCurveDockGeneralTab)
    {
        if (XYHilbertTransformCurveDockGeneralTab->objectName().isEmpty())
            XYHilbertTransformCurveDockGeneralTab->setObjectName("XYHilbertTransformCurveDockGeneralTab");
        XYHilbertTransformCurveDockGeneralTab->resize(311, 693);
        gridLayout = new QGridLayout(XYHilbertTransformCurveDockGeneralTab);
        gridLayout->setObjectName("gridLayout");
        lYColumn = new QLabel(XYHilbertTransformCurveDockGeneralTab);
        lYColumn->setObjectName("lYColumn");

        gridLayout->addWidget(lYColumn, 6, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        lMax = new QLabel(XYHilbertTransformCurveDockGeneralTab);
        lMax->setObjectName("lMax");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lMax->sizePolicy().hasHeightForWidth());
        lMax->setSizePolicy(sizePolicy);
        lMax->setMinimumSize(QSize(50, 0));

        horizontalLayout_3->addWidget(lMax);

        leMax = new QLineEdit(XYHilbertTransformCurveDockGeneralTab);
        leMax->setObjectName("leMax");

        horizontalLayout_3->addWidget(leMax);


        gridLayout->addLayout(horizontalLayout_3, 9, 2, 1, 2);

        cbAutoRange = new QCheckBox(XYHilbertTransformCurveDockGeneralTab);
        cbAutoRange->setObjectName("cbAutoRange");
        cbAutoRange->setChecked(true);

        gridLayout->addWidget(cbAutoRange, 7, 2, 1, 2);

        lData = new QLabel(XYHilbertTransformCurveDockGeneralTab);
        lData->setObjectName("lData");
        QFont font;
        font.setBold(true);
        lData->setFont(font);

        gridLayout->addWidget(lData, 4, 0, 1, 1);

        lName = new QLabel(XYHilbertTransformCurveDockGeneralTab);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        lPlotRange = new QLabel(XYHilbertTransformCurveDockGeneralTab);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout->addWidget(lPlotRange, 21, 0, 1, 2);

        teComment = new ResizableTextEdit(XYHilbertTransformCurveDockGeneralTab);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 2);

        lXColumn = new QLabel(XYHilbertTransformCurveDockGeneralTab);
        lXColumn->setObjectName("lXColumn");

        gridLayout->addWidget(lXColumn, 5, 0, 1, 1);

        cbPlotRanges = new QComboBox(XYHilbertTransformCurveDockGeneralTab);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout->addWidget(cbPlotRanges, 21, 2, 1, 2);

        verticalSpacer_5 = new QSpacerItem(38, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_5, 17, 2, 1, 2);

        cbType = new KComboBox(XYHilbertTransformCurveDockGeneralTab);
        cbType->setObjectName("cbType");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbType->sizePolicy().hasHeightForWidth());
        cbType->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbType, 14, 2, 1, 2);

        verticalSpacer_4 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 10, 2, 1, 2);

        chkVisible = new QCheckBox(XYHilbertTransformCurveDockGeneralTab);
        chkVisible->setObjectName("chkVisible");

        gridLayout->addWidget(chkVisible, 26, 0, 1, 1);

        lType = new QLabel(XYHilbertTransformCurveDockGeneralTab);
        lType->setObjectName("lType");

        gridLayout->addWidget(lType, 14, 0, 1, 1);

        teResult = new QTextEdit(XYHilbertTransformCurveDockGeneralTab);
        teResult->setObjectName("teResult");
        teResult->setReadOnly(true);

        gridLayout->addWidget(teResult, 18, 2, 1, 2);

        verticalSpacerGeneral = new QSpacerItem(24, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacerGeneral, 24, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        lMin = new QLabel(XYHilbertTransformCurveDockGeneralTab);
        lMin->setObjectName("lMin");
        sizePolicy.setHeightForWidth(lMin->sizePolicy().hasHeightForWidth());
        lMin->setSizePolicy(sizePolicy);
        lMin->setMinimumSize(QSize(50, 0));

        horizontalLayout_2->addWidget(lMin);

        leMin = new QLineEdit(XYHilbertTransformCurveDockGeneralTab);
        leMin->setObjectName("leMin");

        horizontalLayout_2->addWidget(leMin);


        gridLayout->addLayout(horizontalLayout_2, 8, 2, 1, 2);

        label = new QLabel(XYHilbertTransformCurveDockGeneralTab);
        label->setObjectName("label");
        label->setFont(font);
        label->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout->addWidget(label, 18, 0, 1, 1);

        lOptions = new QLabel(XYHilbertTransformCurveDockGeneralTab);
        lOptions->setObjectName("lOptions");
        lOptions->setFont(font);

        gridLayout->addWidget(lOptions, 13, 0, 1, 1);

        leName = new TimedLineEdit(XYHilbertTransformCurveDockGeneralTab);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 2);

        lXRange = new QLabel(XYHilbertTransformCurveDockGeneralTab);
        lXRange->setObjectName("lXRange");

        gridLayout->addWidget(lXRange, 7, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(312, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 20, 2, 1, 1);

        line_2 = new QFrame(XYHilbertTransformCurveDockGeneralTab);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 19, 0, 1, 4);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 2, 2, 1, 2);

        pbRecalculate = new QPushButton(XYHilbertTransformCurveDockGeneralTab);
        pbRecalculate->setObjectName("pbRecalculate");

        gridLayout->addWidget(pbRecalculate, 20, 3, 1, 1);

        lComment = new QLabel(XYHilbertTransformCurveDockGeneralTab);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        chkLegendVisible = new QCheckBox(XYHilbertTransformCurveDockGeneralTab);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout->addWidget(chkLegendVisible, 25, 0, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbAutoRange);
        QWidget::setTabOrder(cbAutoRange, leMin);
        QWidget::setTabOrder(leMin, leMax);
        QWidget::setTabOrder(leMax, cbType);
        QWidget::setTabOrder(cbType, teResult);
        QWidget::setTabOrder(teResult, pbRecalculate);
        QWidget::setTabOrder(pbRecalculate, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);

        retranslateUi(XYHilbertTransformCurveDockGeneralTab);

        QMetaObject::connectSlotsByName(XYHilbertTransformCurveDockGeneralTab);
    } // setupUi

    void retranslateUi(QWidget *XYHilbertTransformCurveDockGeneralTab)
    {
        lYColumn->setText(tr2i18n("Y-Data:", nullptr));
        lMax->setText(tr2i18n("Maximum:", nullptr));
        cbAutoRange->setText(tr2i18n("Auto", nullptr));
        lData->setText(tr2i18n("Data", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        lXColumn->setText(tr2i18n("X-Data:", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lType->setText(tr2i18n("Output:", nullptr));
        lMin->setText(tr2i18n("Minimum:", nullptr));
        label->setText(tr2i18n("Results:", nullptr));
        lOptions->setText(tr2i18n("Options", nullptr));
        lXRange->setText(tr2i18n("X-Range:", nullptr));
        pbRecalculate->setText(tr2i18n("Recalculate", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        (void)XYHilbertTransformCurveDockGeneralTab;
    } // retranslateUi

};

namespace Ui {
    class XYHilbertTransformCurveDockGeneralTab: public Ui_XYHilbertTransformCurveDockGeneralTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // XYHILBERTTRANSFORMCURVEDOCKGENERALTAB_H

