/********************************************************************************
** Form generated from reading UI file 'xycurvedockgeneraltab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XYCURVEDOCKGENERALTAB_H
#define UI_XYCURVEDOCKGENERALTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_XYCurveDockGeneralTab
{
public:
    QGridLayout *gridLayout;
    QLabel *lName;
    QSpacerItem *verticalSpacer;
    QLabel *label;
    QCheckBox *chkVisible;
    QLabel *lXColumn;
    QSpacerItem *verticalSpacerGeneral;
    QComboBox *cbPlotRanges;
    TimedLineEdit *leName;
    ResizableTextEdit *teComment;
    QLabel *lYColumn;
    QLabel *lPlotRange;
    QLabel *lComment;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *chkLegendVisible;

    void setupUi(QWidget *XYCurveDockGeneralTab)
    {
        if (XYCurveDockGeneralTab->objectName().isEmpty())
            XYCurveDockGeneralTab->setObjectName("XYCurveDockGeneralTab");
        XYCurveDockGeneralTab->resize(367, 327);
        gridLayout = new QGridLayout(XYCurveDockGeneralTab);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(2, 2, 2, 2);
        lName = new QLabel(XYCurveDockGeneralTab);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        label = new QLabel(XYCurveDockGeneralTab);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        gridLayout->addWidget(label, 3, 0, 1, 1);

        chkVisible = new QCheckBox(XYCurveDockGeneralTab);
        chkVisible->setObjectName("chkVisible");

        gridLayout->addWidget(chkVisible, 9, 0, 1, 1);

        lXColumn = new QLabel(XYCurveDockGeneralTab);
        lXColumn->setObjectName("lXColumn");

        gridLayout->addWidget(lXColumn, 4, 0, 1, 1);

        verticalSpacerGeneral = new QSpacerItem(24, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout->addItem(verticalSpacerGeneral, 7, 0, 1, 1);

        cbPlotRanges = new QComboBox(XYCurveDockGeneralTab);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout->addWidget(cbPlotRanges, 6, 2, 1, 1);

        leName = new TimedLineEdit(XYCurveDockGeneralTab);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        teComment = new ResizableTextEdit(XYCurveDockGeneralTab);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        lYColumn = new QLabel(XYCurveDockGeneralTab);
        lYColumn->setObjectName("lYColumn");

        gridLayout->addWidget(lYColumn, 5, 0, 1, 1);

        lPlotRange = new QLabel(XYCurveDockGeneralTab);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout->addWidget(lPlotRange, 6, 0, 1, 1);

        lComment = new QLabel(XYCurveDockGeneralTab);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        chkLegendVisible = new QCheckBox(XYCurveDockGeneralTab);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout->addWidget(chkLegendVisible, 8, 0, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);

        retranslateUi(XYCurveDockGeneralTab);

        QMetaObject::connectSlotsByName(XYCurveDockGeneralTab);
    } // setupUi

    void retranslateUi(QWidget *XYCurveDockGeneralTab)
    {
        lName->setText(tr2i18n("Name:", nullptr));
        label->setText(tr2i18n("Data", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lXColumn->setText(tr2i18n("X-Data:", nullptr));
        lYColumn->setText(tr2i18n("Y-Data:", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        (void)XYCurveDockGeneralTab;
    } // retranslateUi

};

namespace Ui {
    class XYCurveDockGeneralTab: public Ui_XYCurveDockGeneralTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // XYCURVEDOCKGENERALTAB_H

