/********************************************************************************
** Form generated from reading UI file 'livedatadock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LIVEDATADOCK_H
#define UI_LIVEDATADOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_LiveDataDock
{
public:
    QGridLayout *gridLayout;
    QComboBox *cbUpdateType;
    QSpacerItem *verticalSpacer;
    QLabel *lSourceInfo;
    QPushButton *bLWT;
    QPushButton *bUpdateNow;
    QLabel *lTopics;
    QSpinBox *sbUpdateInterval;
    QLineEdit *leSourceInfo;
    QLabel *lUpdateInterval;
    QLabel *lKeepNvalues;
    QLabel *lSampleSize;
    QLabel *lUpdate;
    QLabel *lName;
    QLabel *lUpdateType;
    QLabel *lReadingType;
    QStackedWidget *swSubscriptions;
    QWidget *page;
    QWidget *page_2;
    QSpinBox *sbKeepNValues;
    QSpacerItem *horizontalSpacer_2;
    TimedLineEdit *leName;
    QSpinBox *sbSampleSize;
    QPushButton *bPausePlayReading;
    QSpacerItem *verticalSpacer_4;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_6;
    QPushButton *bWillUpdateNow;
    QLabel *lData;
    QSpacerItem *verticalSpacer_2;
    QLabel *lLWT;
    QComboBox *cbReadingType;
    QLabel *lComment;
    ResizableTextEdit *teComment;

    void setupUi(QWidget *LiveDataDock)
    {
        if (LiveDataDock->objectName().isEmpty())
            LiveDataDock->setObjectName("LiveDataDock");
        LiveDataDock->resize(371, 818);
        gridLayout = new QGridLayout(LiveDataDock);
        gridLayout->setObjectName("gridLayout");
        cbUpdateType = new QComboBox(LiveDataDock);
        cbUpdateType->addItem(QString());
        cbUpdateType->addItem(QString());
        cbUpdateType->setObjectName("cbUpdateType");

        gridLayout->addWidget(cbUpdateType, 10, 2, 1, 2);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        lSourceInfo = new QLabel(LiveDataDock);
        lSourceInfo->setObjectName("lSourceInfo");

        gridLayout->addWidget(lSourceInfo, 4, 0, 1, 1);

        bLWT = new QPushButton(LiveDataDock);
        bLWT->setObjectName("bLWT");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(bLWT->sizePolicy().hasHeightForWidth());
        bLWT->setSizePolicy(sizePolicy);

        gridLayout->addWidget(bLWT, 15, 2, 1, 1);

        bUpdateNow = new QPushButton(LiveDataDock);
        bUpdateNow->setObjectName("bUpdateNow");

        gridLayout->addWidget(bUpdateNow, 12, 2, 1, 2);

        lTopics = new QLabel(LiveDataDock);
        lTopics->setObjectName("lTopics");
        QFont font;
        font.setBold(true);
        lTopics->setFont(font);
        lTopics->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout->addWidget(lTopics, 14, 0, 1, 1);

        sbUpdateInterval = new QSpinBox(LiveDataDock);
        sbUpdateInterval->setObjectName("sbUpdateInterval");
        sbUpdateInterval->setMinimum(20);
        sbUpdateInterval->setMaximum(3600000);
        sbUpdateInterval->setValue(1000);

        gridLayout->addWidget(sbUpdateInterval, 11, 2, 1, 2);

        leSourceInfo = new QLineEdit(LiveDataDock);
        leSourceInfo->setObjectName("leSourceInfo");
        leSourceInfo->setReadOnly(true);

        gridLayout->addWidget(leSourceInfo, 4, 2, 1, 2);

        lUpdateInterval = new QLabel(LiveDataDock);
        lUpdateInterval->setObjectName("lUpdateInterval");

        gridLayout->addWidget(lUpdateInterval, 11, 0, 1, 1);

        lKeepNvalues = new QLabel(LiveDataDock);
        lKeepNvalues->setObjectName("lKeepNvalues");

        gridLayout->addWidget(lKeepNvalues, 7, 0, 1, 1);

        lSampleSize = new QLabel(LiveDataDock);
        lSampleSize->setObjectName("lSampleSize");

        gridLayout->addWidget(lSampleSize, 6, 0, 1, 1);

        lUpdate = new QLabel(LiveDataDock);
        lUpdate->setObjectName("lUpdate");
        lUpdate->setFont(font);

        gridLayout->addWidget(lUpdate, 9, 0, 1, 1);

        lName = new QLabel(LiveDataDock);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        lUpdateType = new QLabel(LiveDataDock);
        lUpdateType->setObjectName("lUpdateType");

        gridLayout->addWidget(lUpdateType, 10, 0, 1, 1);

        lReadingType = new QLabel(LiveDataDock);
        lReadingType->setObjectName("lReadingType");

        gridLayout->addWidget(lReadingType, 5, 0, 1, 1);

        swSubscriptions = new QStackedWidget(LiveDataDock);
        swSubscriptions->setObjectName("swSubscriptions");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(swSubscriptions->sizePolicy().hasHeightForWidth());
        swSubscriptions->setSizePolicy(sizePolicy1);
        page = new QWidget();
        page->setObjectName("page");
        swSubscriptions->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        swSubscriptions->addWidget(page_2);

        gridLayout->addWidget(swSubscriptions, 14, 2, 1, 2);

        sbKeepNValues = new QSpinBox(LiveDataDock);
        sbKeepNValues->setObjectName("sbKeepNValues");
        sbKeepNValues->setEnabled(false);
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(sbKeepNValues->sizePolicy().hasHeightForWidth());
        sbKeepNValues->setSizePolicy(sizePolicy2);
        sbKeepNValues->setMaximum(999999);

        gridLayout->addWidget(sbKeepNValues, 7, 2, 1, 2);

        horizontalSpacer_2 = new QSpacerItem(318, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 15, 3, 1, 1);

        leName = new TimedLineEdit(LiveDataDock);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 2);

        sbSampleSize = new QSpinBox(LiveDataDock);
        sbSampleSize->setObjectName("sbSampleSize");
        sizePolicy2.setHeightForWidth(sbSampleSize->sizePolicy().hasHeightForWidth());
        sbSampleSize->setSizePolicy(sizePolicy2);
        sbSampleSize->setMinimum(1);
        sbSampleSize->setMaximum(1000000);
        sbSampleSize->setValue(1);

        gridLayout->addWidget(sbSampleSize, 6, 2, 1, 2);

        bPausePlayReading = new QPushButton(LiveDataDock);
        bPausePlayReading->setObjectName("bPausePlayReading");
        sizePolicy2.setHeightForWidth(bPausePlayReading->sizePolicy().hasHeightForWidth());
        bPausePlayReading->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(bPausePlayReading, 18, 0, 1, 4);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 13, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 1, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_6, 17, 0, 1, 1);

        bWillUpdateNow = new QPushButton(LiveDataDock);
        bWillUpdateNow->setObjectName("bWillUpdateNow");
        sizePolicy2.setHeightForWidth(bWillUpdateNow->sizePolicy().hasHeightForWidth());
        bWillUpdateNow->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(bWillUpdateNow, 16, 2, 1, 2);

        lData = new QLabel(LiveDataDock);
        lData->setObjectName("lData");
        lData->setFont(font);

        gridLayout->addWidget(lData, 3, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 8, 0, 1, 1);

        lLWT = new QLabel(LiveDataDock);
        lLWT->setObjectName("lLWT");

        gridLayout->addWidget(lLWT, 15, 0, 1, 1);

        cbReadingType = new QComboBox(LiveDataDock);
        cbReadingType->addItem(QString());
        cbReadingType->addItem(QString());
        cbReadingType->addItem(QString());
        cbReadingType->addItem(QString());
        cbReadingType->setObjectName("cbReadingType");
        sizePolicy2.setHeightForWidth(cbReadingType->sizePolicy().hasHeightForWidth());
        cbReadingType->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(cbReadingType, 5, 2, 1, 2);

        lComment = new QLabel(LiveDataDock);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        teComment = new ResizableTextEdit(LiveDataDock);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 2);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, leSourceInfo);
        QWidget::setTabOrder(leSourceInfo, cbReadingType);
        QWidget::setTabOrder(cbReadingType, sbSampleSize);
        QWidget::setTabOrder(sbSampleSize, sbKeepNValues);
        QWidget::setTabOrder(sbKeepNValues, cbUpdateType);
        QWidget::setTabOrder(cbUpdateType, sbUpdateInterval);
        QWidget::setTabOrder(sbUpdateInterval, bUpdateNow);
        QWidget::setTabOrder(bUpdateNow, bLWT);
        QWidget::setTabOrder(bLWT, bWillUpdateNow);
        QWidget::setTabOrder(bWillUpdateNow, bPausePlayReading);

        retranslateUi(LiveDataDock);

        QMetaObject::connectSlotsByName(LiveDataDock);
    } // setupUi

    void retranslateUi(QWidget *LiveDataDock)
    {
        cbUpdateType->setItemText(0, tr2i18n("Periodically", nullptr));
        cbUpdateType->setItemText(1, tr2i18n("On New Data", nullptr));

        lSourceInfo->setText(tr2i18n("Source:", nullptr));
        bLWT->setText(QString());
        bUpdateNow->setText(tr2i18n("Update Now", nullptr));
        lTopics->setText(tr2i18n("Topics", nullptr));
        sbUpdateInterval->setSuffix(tr2i18n(" ms", nullptr));
        lUpdateInterval->setText(tr2i18n("Interval:", nullptr));
        lKeepNvalues->setText(tr2i18n("Keep last values:", nullptr));
        lSampleSize->setText(tr2i18n("Sample size:", nullptr));
        lUpdate->setText(tr2i18n("Update", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lUpdateType->setText(tr2i18n("Type:", nullptr));
        lReadingType->setText(tr2i18n("Read:", nullptr));
        sbKeepNValues->setSpecialValueText(tr2i18n("All", nullptr));
        bPausePlayReading->setText(tr2i18n("Pause Reading", nullptr));
        bWillUpdateNow->setText(tr2i18n("Update Will Message", nullptr));
        lData->setText(tr2i18n("Data", nullptr));
        lLWT->setText(tr2i18n("LWT:", nullptr));
        cbReadingType->setItemText(0, tr2i18n("Continuously Fixed", nullptr));
        cbReadingType->setItemText(1, tr2i18n("From End", nullptr));
        cbReadingType->setItemText(2, tr2i18n("Till the End", nullptr));
        cbReadingType->setItemText(3, tr2i18n("Read Whole File", nullptr));

        lComment->setText(tr2i18n("Comment:", nullptr));
        (void)LiveDataDock;
    } // retranslateUi

};

namespace Ui {
    class LiveDataDock: public Ui_LiveDataDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LIVEDATADOCK_H

