/********************************************************************************
** Form generated from reading UI file 'mqtterrorwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MQTTERRORWIDGET_H
#define UI_MQTTERRORWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MQTTErrorWidget
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;
    QLabel *lUserName;
    QLabel *lPassword;
    QLineEdit *lePassword;
    QLineEdit *leUserName;
    QPushButton *bChange;
    QLabel *lErrorType;
    QLabel *lId;
    QLineEdit *leId;

    void setupUi(QWidget *MQTTErrorWidget)
    {
        if (MQTTErrorWidget->objectName().isEmpty())
            MQTTErrorWidget->setObjectName("MQTTErrorWidget");
        MQTTErrorWidget->resize(462, 182);
        gridLayout = new QGridLayout(MQTTErrorWidget);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 5, 0, 1, 1);

        lUserName = new QLabel(MQTTErrorWidget);
        lUserName->setObjectName("lUserName");

        gridLayout->addWidget(lUserName, 1, 0, 1, 1);

        lPassword = new QLabel(MQTTErrorWidget);
        lPassword->setObjectName("lPassword");

        gridLayout->addWidget(lPassword, 2, 0, 1, 1);

        lePassword = new QLineEdit(MQTTErrorWidget);
        lePassword->setObjectName("lePassword");

        gridLayout->addWidget(lePassword, 2, 1, 1, 1);

        leUserName = new QLineEdit(MQTTErrorWidget);
        leUserName->setObjectName("leUserName");

        gridLayout->addWidget(leUserName, 1, 1, 1, 1);

        bChange = new QPushButton(MQTTErrorWidget);
        bChange->setObjectName("bChange");

        gridLayout->addWidget(bChange, 4, 0, 1, 2);

        lErrorType = new QLabel(MQTTErrorWidget);
        lErrorType->setObjectName("lErrorType");

        gridLayout->addWidget(lErrorType, 0, 0, 1, 2);

        lId = new QLabel(MQTTErrorWidget);
        lId->setObjectName("lId");

        gridLayout->addWidget(lId, 3, 0, 1, 1);

        leId = new QLineEdit(MQTTErrorWidget);
        leId->setObjectName("leId");

        gridLayout->addWidget(leId, 3, 1, 1, 1);


        retranslateUi(MQTTErrorWidget);

        QMetaObject::connectSlotsByName(MQTTErrorWidget);
    } // setupUi

    void retranslateUi(QWidget *MQTTErrorWidget)
    {
        MQTTErrorWidget->setWindowTitle(tr2i18n("MQTT Error Widget", nullptr));
        lUserName->setText(tr2i18n("User name:", nullptr));
        lPassword->setText(tr2i18n("Password:", nullptr));
        bChange->setText(tr2i18n("Make Changes", nullptr));
        lErrorType->setText(QString());
        lId->setText(tr2i18n("Client ID:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MQTTErrorWidget: public Ui_MQTTErrorWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MQTTERRORWIDGET_H

