/********************************************************************************
** Form generated from reading UI file 'datapickercurvewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DATAPICKERCURVEWIDGET_H
#define UI_DATAPICKERCURVEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcolorbutton.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_DatapickerCurveWidget
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout_2;
    QLabel *lYErrorType;
    ResizableTextEdit *teComment;
    QLabel *lComment;
    QSpacerItem *verticalSpacer;
    KComboBox *cbYErrorType;
    QLabel *lName;
    QLabel *label;
    QLabel *lXErrorType;
    QSpacerItem *horizontalSpacer;
    KComboBox *cbXErrorType;
    QSpacerItem *verticalSpacer_3;
    TimedLineEdit *leName;
    QCheckBox *chkVisible;
    QWidget *tabSymbol;
    QWidget *tabErrorBars_2;
    QGridLayout *gridLayout_4;
    KComboBox *cbErrorBarFillingStyle;
    QLabel *lErrorBarFillingStyle;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_2;
    QLabel *lErrorBarFillingColor;
    KColorButton *kcbErrorBarFillingColor;
    QLabel *lErrorBarSize;
    NumberSpinBox *sbErrorBarSize;

    void setupUi(QWidget *DatapickerCurveWidget)
    {
        if (DatapickerCurveWidget->objectName().isEmpty())
            DatapickerCurveWidget->setObjectName("DatapickerCurveWidget");
        DatapickerCurveWidget->resize(290, 503);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DatapickerCurveWidget->sizePolicy().hasHeightForWidth());
        DatapickerCurveWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(DatapickerCurveWidget);
        gridLayout->setObjectName("gridLayout");
        tabWidget = new QTabWidget(DatapickerCurveWidget);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout_2 = new QGridLayout(tabGeneral);
        gridLayout_2->setObjectName("gridLayout_2");
        lYErrorType = new QLabel(tabGeneral);
        lYErrorType->setObjectName("lYErrorType");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lYErrorType->sizePolicy().hasHeightForWidth());
        lYErrorType->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(lYErrorType, 5, 0, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");

        gridLayout_2->addWidget(teComment, 1, 2, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(lComment, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 145, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 6, 0, 1, 1);

        cbYErrorType = new KComboBox(tabGeneral);
        cbYErrorType->setObjectName("cbYErrorType");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cbYErrorType->sizePolicy().hasHeightForWidth());
        cbYErrorType->setSizePolicy(sizePolicy2);
        cbYErrorType->setMouseTracking(true);

        gridLayout_2->addWidget(cbYErrorType, 5, 2, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout_2->addWidget(lName, 0, 0, 1, 1);

        label = new QLabel(tabGeneral);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        gridLayout_2->addWidget(label, 3, 0, 1, 1);

        lXErrorType = new QLabel(tabGeneral);
        lXErrorType->setObjectName("lXErrorType");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(lXErrorType->sizePolicy().hasHeightForWidth());
        lXErrorType->setSizePolicy(sizePolicy3);

        gridLayout_2->addWidget(lXErrorType, 4, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 1, 1, 1);

        cbXErrorType = new KComboBox(tabGeneral);
        cbXErrorType->setObjectName("cbXErrorType");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(cbXErrorType->sizePolicy().hasHeightForWidth());
        cbXErrorType->setSizePolicy(sizePolicy4);

        gridLayout_2->addWidget(cbXErrorType, 4, 2, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_3, 2, 0, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(leName->sizePolicy().hasHeightForWidth());
        leName->setSizePolicy(sizePolicy5);
        leName->setClearButtonEnabled(true);

        gridLayout_2->addWidget(leName, 0, 2, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout_2->addWidget(chkVisible, 7, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabSymbol = new QWidget();
        tabSymbol->setObjectName("tabSymbol");
        tabWidget->addTab(tabSymbol, QString());
        tabErrorBars_2 = new QWidget();
        tabErrorBars_2->setObjectName("tabErrorBars_2");
        gridLayout_4 = new QGridLayout(tabErrorBars_2);
        gridLayout_4->setObjectName("gridLayout_4");
        cbErrorBarFillingStyle = new KComboBox(tabErrorBars_2);
        cbErrorBarFillingStyle->setObjectName("cbErrorBarFillingStyle");

        gridLayout_4->addWidget(cbErrorBarFillingStyle, 1, 3, 1, 1);

        lErrorBarFillingStyle = new QLabel(tabErrorBars_2);
        lErrorBarFillingStyle->setObjectName("lErrorBarFillingStyle");

        gridLayout_4->addWidget(lErrorBarFillingStyle, 1, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_2, 0, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 542, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer_2, 3, 0, 1, 1);

        lErrorBarFillingColor = new QLabel(tabErrorBars_2);
        lErrorBarFillingColor->setObjectName("lErrorBarFillingColor");

        gridLayout_4->addWidget(lErrorBarFillingColor, 2, 0, 1, 1);

        kcbErrorBarFillingColor = new KColorButton(tabErrorBars_2);
        kcbErrorBarFillingColor->setObjectName("kcbErrorBarFillingColor");
        sizePolicy2.setHeightForWidth(kcbErrorBarFillingColor->sizePolicy().hasHeightForWidth());
        kcbErrorBarFillingColor->setSizePolicy(sizePolicy2);

        gridLayout_4->addWidget(kcbErrorBarFillingColor, 2, 3, 1, 1);

        lErrorBarSize = new QLabel(tabErrorBars_2);
        lErrorBarSize->setObjectName("lErrorBarSize");

        gridLayout_4->addWidget(lErrorBarSize, 0, 0, 1, 1);

        sbErrorBarSize = new NumberSpinBox(tabErrorBars_2);
        sbErrorBarSize->setObjectName("sbErrorBarSize");
        sizePolicy4.setHeightForWidth(sbErrorBarSize->sizePolicy().hasHeightForWidth());
        sbErrorBarSize->setSizePolicy(sizePolicy4);
        sbErrorBarSize->setProperty("feedback", QVariant(true));

        gridLayout_4->addWidget(sbErrorBarSize, 0, 3, 1, 1);

        tabWidget->addTab(tabErrorBars_2, QString());

        gridLayout->addWidget(tabWidget, 0, 0, 1, 1);


        retranslateUi(DatapickerCurveWidget);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DatapickerCurveWidget);
    } // setupUi

    void retranslateUi(QWidget *DatapickerCurveWidget)
    {
        lYErrorType->setText(tr2i18n("Y-error type:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
#if QT_CONFIG(tooltip)
        cbYErrorType->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        lName->setText(tr2i18n("Name:", nullptr));
        label->setText(tr2i18n("Error Type", nullptr));
        lXErrorType->setText(tr2i18n("X-error type:", nullptr));
#if QT_CONFIG(tooltip)
        cbXErrorType->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        chkVisible->setText(tr2i18n("Visible", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabSymbol), tr2i18n("Symbols", nullptr));
        lErrorBarFillingStyle->setText(tr2i18n("Style:", nullptr));
        lErrorBarFillingColor->setText(tr2i18n("Color:", nullptr));
        lErrorBarSize->setText(tr2i18n("Size:", nullptr));
#if QT_CONFIG(tooltip)
        sbErrorBarSize->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbErrorBarSize->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbErrorBarSize->setSuffix(tr2i18n(" pt", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabErrorBars_2), tr2i18n("Error Bars", nullptr));
        (void)DatapickerCurveWidget;
    } // retranslateUi

};

namespace Ui {
    class DatapickerCurveWidget: public Ui_DatapickerCurveWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DATAPICKERCURVEWIDGET_H

