/********************************************************************************
** Form generated from reading UI file 'cursordock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CURSORDOCK_H
#define UI_CURSORDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CursorDock
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *cbCursor0en;
    QSpacerItem *horizontalSpacer;
    QCheckBox *cbCursor1en;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *bCollapseAll;
    QPushButton *bExpandAll;
    QTreeView *tvCursorData;

    void setupUi(QWidget *CursorDock)
    {
        if (CursorDock->objectName().isEmpty())
            CursorDock->setObjectName("CursorDock");
        CursorDock->resize(374, 378);
        verticalLayout_2 = new QVBoxLayout(CursorDock);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        cbCursor0en = new QCheckBox(CursorDock);
        cbCursor0en->setObjectName("cbCursor0en");

        horizontalLayout_2->addWidget(cbCursor0en);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        cbCursor1en = new QCheckBox(CursorDock);
        cbCursor1en->setObjectName("cbCursor1en");

        horizontalLayout_2->addWidget(cbCursor1en);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        bCollapseAll = new QPushButton(CursorDock);
        bCollapseAll->setObjectName("bCollapseAll");

        horizontalLayout_2->addWidget(bCollapseAll);

        bExpandAll = new QPushButton(CursorDock);
        bExpandAll->setObjectName("bExpandAll");

        horizontalLayout_2->addWidget(bExpandAll);


        verticalLayout_2->addLayout(horizontalLayout_2);

        tvCursorData = new QTreeView(CursorDock);
        tvCursorData->setObjectName("tvCursorData");
        tvCursorData->setEditTriggers(QAbstractItemView::EditTrigger::NoEditTriggers);

        verticalLayout_2->addWidget(tvCursorData);

        QWidget::setTabOrder(cbCursor0en, cbCursor1en);
        QWidget::setTabOrder(cbCursor1en, bCollapseAll);
        QWidget::setTabOrder(bCollapseAll, bExpandAll);
        QWidget::setTabOrder(bExpandAll, tvCursorData);

        retranslateUi(CursorDock);

        QMetaObject::connectSlotsByName(CursorDock);
    } // setupUi

    void retranslateUi(QWidget *CursorDock)
    {
        cbCursor0en->setText(tr2i18n("Cursor 1", nullptr));
        cbCursor1en->setText(tr2i18n("Cursor 2", nullptr));
        bCollapseAll->setText(QString());
        bExpandAll->setText(QString());
        (void)CursorDock;
    } // retranslateUi

};

namespace Ui {
    class CursorDock: public Ui_CursorDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CURSORDOCK_H

