/********************************************************************************
** Form generated from reading UI file 'settingsdatasetspage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSDATASETSPAGE_H
#define UI_SETTINGSDATASETSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SettingsDatasetsPage
{
public:
    QGridLayout *gridLayout;
    QLineEdit *leKagglePath;
    QLabel *lCache;
    QLabel *lKaggle;
    QLabel *lKagglePath;
    QSpacerItem *verticalSpacer;
    QLabel *lSize;
    QLabel *lFiles;
    QSpacerItem *horizontalSpacer;
    QPushButton *bClearCache;
    QSpacerItem *verticalSpacer_2;
    QLabel *lKaggleUrl;

    void setupUi(QWidget *SettingsDatasetsPage)
    {
        if (SettingsDatasetsPage->objectName().isEmpty())
            SettingsDatasetsPage->setObjectName("SettingsDatasetsPage");
        SettingsDatasetsPage->resize(801, 279);
        gridLayout = new QGridLayout(SettingsDatasetsPage);
        gridLayout->setObjectName("gridLayout");
        leKagglePath = new QLineEdit(SettingsDatasetsPage);
        leKagglePath->setObjectName("leKagglePath");

        gridLayout->addWidget(leKagglePath, 5, 1, 1, 2);

        lCache = new QLabel(SettingsDatasetsPage);
        lCache->setObjectName("lCache");
        QFont font;
        font.setBold(true);
        lCache->setFont(font);

        gridLayout->addWidget(lCache, 0, 0, 1, 1);

        lKaggle = new QLabel(SettingsDatasetsPage);
        lKaggle->setObjectName("lKaggle");
        lKaggle->setFont(font);

        gridLayout->addWidget(lKaggle, 4, 0, 1, 1);

        lKagglePath = new QLabel(SettingsDatasetsPage);
        lKagglePath->setObjectName("lKagglePath");

        gridLayout->addWidget(lKagglePath, 5, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 137, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 6, 0, 1, 1);

        lSize = new QLabel(SettingsDatasetsPage);
        lSize->setObjectName("lSize");

        gridLayout->addWidget(lSize, 2, 0, 1, 1);

        lFiles = new QLabel(SettingsDatasetsPage);
        lFiles->setObjectName("lFiles");

        gridLayout->addWidget(lFiles, 1, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(576, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 2, 1, 1, 1);

        bClearCache = new QPushButton(SettingsDatasetsPage);
        bClearCache->setObjectName("bClearCache");

        gridLayout->addWidget(bClearCache, 2, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 3, 0, 1, 1);

        lKaggleUrl = new QLabel(SettingsDatasetsPage);
        lKaggleUrl->setObjectName("lKaggleUrl");

        gridLayout->addWidget(lKaggleUrl, 4, 1, 1, 2);


        retranslateUi(SettingsDatasetsPage);

        QMetaObject::connectSlotsByName(SettingsDatasetsPage);
    } // setupUi

    void retranslateUi(QWidget *SettingsDatasetsPage)
    {
        lCache->setText(tr2i18n("Cache:", nullptr));
        lKaggle->setText(tr2i18n("Kaggle", nullptr));
        lKagglePath->setText(tr2i18n("CLI Path:", nullptr));
        lSize->setText(tr2i18n("Total size - ", nullptr));
        lFiles->setText(tr2i18n("Files - ", nullptr));
        bClearCache->setText(tr2i18n("Clear", nullptr));
        lKaggleUrl->setText(QString());
        (void)SettingsDatasetsPage;
    } // retranslateUi

};

namespace Ui {
    class SettingsDatasetsPage: public Ui_SettingsDatasetsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGSDATASETSPAGE_H

