/****************************************************************************
** Meta object code from reading C++ file 'BoxPlot.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/plots/cartesian/BoxPlot.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'BoxPlot.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BoxPlotE_t {};
} // unnamed namespace

template <> constexpr inline auto BoxPlot::qt_create_metaobjectdata<qt_meta_tag_ZN7BoxPlotE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BoxPlot",
        "dataColumnsChanged",
        "",
        "QList<const AbstractColumn*>",
        "dataDataChanged",
        "orderingChanged",
        "BoxPlot::Ordering",
        "orientationChanged",
        "BoxPlot::Orientation",
        "variableWidthChanged",
        "widthFactorChanged",
        "notchesEnabledChanged",
        "jitteringEnabledChanged",
        "whiskersTypeChanged",
        "BoxPlot::WhiskersType",
        "whiskersRangeParameterChanged",
        "whiskersCapSizeChanged",
        "rugEnabledChanged",
        "rugLengthChanged",
        "rugWidthChanged",
        "rugOffsetChanged",
        "createDataSpreadsheet",
        "orientationChangedSlot",
        "QAction*",
        "dataColumnAboutToBeRemoved",
        "const AbstractAspect*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataColumnsChanged'
        QtMocHelpers::SignalData<void(const QVector<const AbstractColumn*> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'dataDataChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'orderingChanged'
        QtMocHelpers::SignalData<void(BoxPlot::Ordering)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'orientationChanged'
        QtMocHelpers::SignalData<void(BoxPlot::Orientation)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'variableWidthChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'widthFactorChanged'
        QtMocHelpers::SignalData<void(double)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'notchesEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'jitteringEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'whiskersTypeChanged'
        QtMocHelpers::SignalData<void(BoxPlot::WhiskersType)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Signal 'whiskersRangeParameterChanged'
        QtMocHelpers::SignalData<void(double)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'whiskersCapSizeChanged'
        QtMocHelpers::SignalData<void(double)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'rugEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'rugLengthChanged'
        QtMocHelpers::SignalData<void(double)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'rugWidthChanged'
        QtMocHelpers::SignalData<void(double)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'rugOffsetChanged'
        QtMocHelpers::SignalData<void(double)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'createDataSpreadsheet'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'orientationChangedSlot'
        QtMocHelpers::SlotData<void(QAction *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 2 },
        }}),
        // Slot 'dataColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BoxPlot, qt_meta_tag_ZN7BoxPlotE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BoxPlot::staticMetaObject = { {
    QMetaObject::SuperData::link<Plot::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BoxPlotE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BoxPlotE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BoxPlotE_t>.metaTypes,
    nullptr
} };

void BoxPlot::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BoxPlot *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataColumnsChanged((*reinterpret_cast<std::add_pointer_t<QList<const AbstractColumn*>>>(_a[1]))); break;
        case 1: _t->dataDataChanged(); break;
        case 2: _t->orderingChanged((*reinterpret_cast<std::add_pointer_t<BoxPlot::Ordering>>(_a[1]))); break;
        case 3: _t->orientationChanged((*reinterpret_cast<std::add_pointer_t<BoxPlot::Orientation>>(_a[1]))); break;
        case 4: _t->variableWidthChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->widthFactorChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->notchesEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->jitteringEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->whiskersTypeChanged((*reinterpret_cast<std::add_pointer_t<BoxPlot::WhiskersType>>(_a[1]))); break;
        case 9: _t->whiskersRangeParameterChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->whiskersCapSizeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 11: _t->rugEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->rugLengthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 13: _t->rugWidthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 14: _t->rugOffsetChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: _t->createDataSpreadsheet(); break;
        case 16: _t->orientationChangedSlot((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 17: _t->dataColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(const QVector<const AbstractColumn*> & )>(_a, &BoxPlot::dataColumnsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)()>(_a, &BoxPlot::dataDataChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(BoxPlot::Ordering )>(_a, &BoxPlot::orderingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(BoxPlot::Orientation )>(_a, &BoxPlot::orientationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(bool )>(_a, &BoxPlot::variableWidthChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(double )>(_a, &BoxPlot::widthFactorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(bool )>(_a, &BoxPlot::notchesEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(bool )>(_a, &BoxPlot::jitteringEnabledChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(BoxPlot::WhiskersType )>(_a, &BoxPlot::whiskersTypeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(double )>(_a, &BoxPlot::whiskersRangeParameterChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(double )>(_a, &BoxPlot::whiskersCapSizeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(bool )>(_a, &BoxPlot::rugEnabledChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(double )>(_a, &BoxPlot::rugLengthChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(double )>(_a, &BoxPlot::rugWidthChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (BoxPlot::*)(double )>(_a, &BoxPlot::rugOffsetChanged, 14))
            return;
    }
}

const QMetaObject *BoxPlot::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BoxPlot::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BoxPlotE_t>.strings))
        return static_cast<void*>(this);
    return Plot::qt_metacast(_clname);
}

int BoxPlot::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Plot::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void BoxPlot::dataColumnsChanged(const QVector<const AbstractColumn*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BoxPlot::dataDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void BoxPlot::orderingChanged(BoxPlot::Ordering _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BoxPlot::orientationChanged(BoxPlot::Orientation _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BoxPlot::variableWidthChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BoxPlot::widthFactorChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BoxPlot::notchesEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void BoxPlot::jitteringEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void BoxPlot::whiskersTypeChanged(BoxPlot::WhiskersType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void BoxPlot::whiskersRangeParameterChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void BoxPlot::whiskersCapSizeChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void BoxPlot::rugEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void BoxPlot::rugLengthChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void BoxPlot::rugWidthChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void BoxPlot::rugOffsetChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}
QT_WARNING_POP
