/****************************************************************************
** Meta object code from reading C++ file 'Spreadsheet.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/spreadsheet/Spreadsheet.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Spreadsheet.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11SpreadsheetE_t {};
} // unnamed namespace

template <> constexpr inline auto Spreadsheet::qt_create_metaobjectdata<qt_meta_tag_ZN11SpreadsheetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Spreadsheet",
        "requestProjectContextMenu",
        "",
        "QMenu*",
        "columnSelected",
        "columnDeselected",
        "rowCountChanged",
        "columnCountChanged",
        "aboutToResize",
        "resizeFinished",
        "aspectsAboutToBeInserted",
        "first",
        "last",
        "aspectsInserted",
        "aspectsAboutToBeRemoved",
        "aspectsRemoved",
        "manyAspectsAboutToBeInserted",
        "rowsAboutToBeInserted",
        "before",
        "rowsInserted",
        "newRowCount",
        "rowsAboutToBeRemoved",
        "count",
        "rowsRemoved",
        "showCommentsChanged",
        "showSparklinesChanged",
        "linkingChanged",
        "linkedSpreadsheetChanged",
        "const Spreadsheet*",
        "appendRows",
        "appendRow",
        "removeEmptyRows",
        "maskEmptyRows",
        "appendColumns",
        "appendColumn",
        "prependColumns",
        "setColumnCount",
        "setRowCount",
        "linkedSpreadsheet",
        "setLinkedSpreadsheet",
        "skipUndo",
        "linkedSpreadsheetPath",
        "clear",
        "QList<Column*>",
        "clearMasks",
        "moveColumn",
        "from",
        "to",
        "sortColumns",
        "Column*",
        "leading",
        "ascending",
        "toggleStatisticsSpreadsheet",
        "childSelected",
        "const AbstractAspect*",
        "childDeselected",
        "initConnectionsRowCountChanges",
        "linkedSpreadsheetDeleted",
        "linkedSpreadsheetNewRowCount",
        "handleAspectUpdated",
        "aspectPath"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestProjectContextMenu'
        QtMocHelpers::SignalData<void(QMenu *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'columnSelected'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'columnDeselected'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'rowCountChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'columnCountChanged'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'aboutToResize'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resizeFinished'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aspectsAboutToBeInserted'
        QtMocHelpers::SignalData<void(int, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'aspectsInserted'
        QtMocHelpers::SignalData<void(int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'aspectsAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'aspectsRemoved'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'manyAspectsAboutToBeInserted'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rowsAboutToBeInserted'
        QtMocHelpers::SignalData<void(int, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'rowsInserted'
        QtMocHelpers::SignalData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Signal 'rowsAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::Int, 22 },
        }}),
        // Signal 'rowsRemoved'
        QtMocHelpers::SignalData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Signal 'showCommentsChanged'
        QtMocHelpers::SignalData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'showSparklinesChanged'
        QtMocHelpers::SignalData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'linkingChanged'
        QtMocHelpers::SignalData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'linkedSpreadsheetChanged'
        QtMocHelpers::SignalData<void(const Spreadsheet *)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 2 },
        }}),
        // Slot 'appendRows'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'appendRow'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeEmptyRows'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'maskEmptyRows'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'appendColumns'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'appendColumn'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'prependColumns'
        QtMocHelpers::SlotData<void(int)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'setColumnCount'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'setRowCount'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'linkedSpreadsheet'
        QtMocHelpers::SlotData<const Spreadsheet *() const>(38, 2, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'setLinkedSpreadsheet'
        QtMocHelpers::SlotData<void(const Spreadsheet *, bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 2 }, { QMetaType::Bool, 40 },
        }}),
        // Slot 'setLinkedSpreadsheet'
        QtMocHelpers::SlotData<void(const Spreadsheet *)>(39, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 28, 2 },
        }}),
        // Slot 'linkedSpreadsheetPath'
        QtMocHelpers::SlotData<QString() const>(41, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void(const QVector<Column*> &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 2 },
        }}),
        // Slot 'clearMasks'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveColumn'
        QtMocHelpers::SlotData<void(int, int)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 46 }, { QMetaType::Int, 47 },
        }}),
        // Slot 'sortColumns'
        QtMocHelpers::SlotData<void(Column *, const QVector<Column*> &, bool)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 49, 50 }, { 0x80000000 | 43, 2 }, { QMetaType::Bool, 51 },
        }}),
        // Slot 'toggleStatisticsSpreadsheet'
        QtMocHelpers::SlotData<void(bool)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'childSelected'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 54, 2 },
        }}),
        // Slot 'childDeselected'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 54, 2 },
        }}),
        // Slot 'initConnectionsRowCountChanges'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'linkedSpreadsheetDeleted'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'linkedSpreadsheetNewRowCount'
        QtMocHelpers::SlotData<void(int)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'handleAspectUpdated'
        QtMocHelpers::SlotData<void(const QString &, const AbstractAspect *)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 60 }, { 0x80000000 | 54, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Spreadsheet, qt_meta_tag_ZN11SpreadsheetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Spreadsheet::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SpreadsheetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SpreadsheetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11SpreadsheetE_t>.metaTypes,
    nullptr
} };

void Spreadsheet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Spreadsheet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestProjectContextMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 1: _t->columnSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->columnDeselected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->rowCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->columnCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->aboutToResize(); break;
        case 6: _t->resizeFinished(); break;
        case 7: _t->aspectsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->aspectsInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->aspectsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->aspectsRemoved(); break;
        case 11: _t->manyAspectsAboutToBeInserted(); break;
        case 12: _t->rowsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 13: _t->rowsInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->rowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->rowsRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->showCommentsChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->showSparklinesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->linkingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->linkedSpreadsheetChanged((*reinterpret_cast<std::add_pointer_t<const Spreadsheet*>>(_a[1]))); break;
        case 20: _t->appendRows((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->appendRow(); break;
        case 22: _t->removeEmptyRows(); break;
        case 23: _t->maskEmptyRows(); break;
        case 24: _t->appendColumns((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->appendColumn(); break;
        case 26: _t->prependColumns((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->setColumnCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->setRowCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: { const Spreadsheet* _r = _t->linkedSpreadsheet();
            if (_a[0]) *reinterpret_cast<const Spreadsheet**>(_a[0]) = std::move(_r); }  break;
        case 30: _t->setLinkedSpreadsheet((*reinterpret_cast<std::add_pointer_t<const Spreadsheet*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 31: _t->setLinkedSpreadsheet((*reinterpret_cast<std::add_pointer_t<const Spreadsheet*>>(_a[1]))); break;
        case 32: { QString _r = _t->linkedSpreadsheetPath();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 33: _t->clear(); break;
        case 34: _t->clear((*reinterpret_cast<std::add_pointer_t<QList<Column*>>>(_a[1]))); break;
        case 35: _t->clearMasks(); break;
        case 36: _t->moveColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 37: _t->sortColumns((*reinterpret_cast<std::add_pointer_t<Column*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<Column*>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 38: _t->toggleStatisticsSpreadsheet((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->childSelected((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 40: _t->childDeselected((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 41: _t->initConnectionsRowCountChanges(); break;
        case 42: _t->linkedSpreadsheetDeleted(); break;
        case 43: _t->linkedSpreadsheetNewRowCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 44: _t->handleAspectUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Column*> >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Column* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Column*> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(QMenu * )>(_a, &Spreadsheet::requestProjectContextMenu, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(int )>(_a, &Spreadsheet::columnSelected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(int )>(_a, &Spreadsheet::columnDeselected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(int )>(_a, &Spreadsheet::rowCountChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(int )>(_a, &Spreadsheet::columnCountChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)()>(_a, &Spreadsheet::aboutToResize, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)()>(_a, &Spreadsheet::resizeFinished, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(int , int )>(_a, &Spreadsheet::aspectsAboutToBeInserted, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(int , int )>(_a, &Spreadsheet::aspectsInserted, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(int , int )>(_a, &Spreadsheet::aspectsAboutToBeRemoved, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)()>(_a, &Spreadsheet::aspectsRemoved, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)()>(_a, &Spreadsheet::manyAspectsAboutToBeInserted, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(int , int )>(_a, &Spreadsheet::rowsAboutToBeInserted, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(int )>(_a, &Spreadsheet::rowsInserted, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(int , int )>(_a, &Spreadsheet::rowsAboutToBeRemoved, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(int )>(_a, &Spreadsheet::rowsRemoved, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(bool )>(_a, &Spreadsheet::showCommentsChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(bool )>(_a, &Spreadsheet::showSparklinesChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(bool )>(_a, &Spreadsheet::linkingChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Spreadsheet::*)(const Spreadsheet * )>(_a, &Spreadsheet::linkedSpreadsheetChanged, 19))
            return;
    }
}

const QMetaObject *Spreadsheet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Spreadsheet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SpreadsheetE_t>.strings))
        return static_cast<void*>(this);
    return AbstractDataSource::qt_metacast(_clname);
}

int Spreadsheet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractDataSource::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    return _id;
}

// SIGNAL 0
void Spreadsheet::requestProjectContextMenu(QMenu * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Spreadsheet::columnSelected(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Spreadsheet::columnDeselected(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Spreadsheet::rowCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Spreadsheet::columnCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Spreadsheet::aboutToResize()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Spreadsheet::resizeFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Spreadsheet::aspectsAboutToBeInserted(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Spreadsheet::aspectsInserted(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void Spreadsheet::aspectsAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void Spreadsheet::aspectsRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Spreadsheet::manyAspectsAboutToBeInserted()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Spreadsheet::rowsAboutToBeInserted(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void Spreadsheet::rowsInserted(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Spreadsheet::rowsAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void Spreadsheet::rowsRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Spreadsheet::showCommentsChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Spreadsheet::showSparklinesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Spreadsheet::linkingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Spreadsheet::linkedSpreadsheetChanged(const Spreadsheet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}
QT_WARNING_POP
