/****************************************************************************
** Meta object code from reading C++ file 'CartesianPlotDock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/dockwidgets/CartesianPlotDock.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CartesianPlotDock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17CartesianPlotDockE_t {};
} // unnamed namespace

template <> constexpr inline auto CartesianPlotDock::qt_create_metaobjectdata<qt_meta_tag_ZN17CartesianPlotDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CartesianPlotDock",
        "info",
        "",
        "init",
        "rangeTypeChanged",
        "niceExtendChanged",
        "checked",
        "rangePointsChanged",
        "autoScaleChanged",
        "Dimension",
        "rangeIndex",
        "minDateTimeChanged",
        "const QObject*",
        "sender",
        "value",
        "maxDateTimeChanged",
        "rangeFormatChanged",
        "index",
        "scaleChanged",
        "addXRange",
        "addYRange",
        "removeRange",
        "dim",
        "removeXRange",
        "removeYRange",
        "addPlotRange",
        "removePlotRange",
        "PlotRangeChanged",
        "cSystemIndex",
        "PlotRangeXChanged",
        "PlotRangeYChanged",
        "minChanged",
        "min",
        "maxChanged",
        "max",
        "geometryChanged",
        "layoutChanged",
        "Worksheet::Layout",
        "symmetricPaddingChanged",
        "horizontalPaddingChanged",
        "rightPaddingChanged",
        "verticalPaddingChanged",
        "bottomPaddingChanged",
        "toggleXBreak",
        "addXBreak",
        "removeXBreak",
        "currentXBreakChanged",
        "xBreakStartChanged",
        "xBreakEndChanged",
        "xBreakPositionChanged",
        "xBreakStyleChanged",
        "toggleYBreak",
        "addYBreak",
        "removeYBreak",
        "currentYBreakChanged",
        "yBreakStartChanged",
        "yBreakEndChanged",
        "yBreakPositionChanged",
        "yBreakStyleChanged",
        "borderTypeChanged",
        "borderCornerRadiusChanged",
        "exportPlotTemplate",
        "plotRangeTypeChanged",
        "CartesianPlot::RangeType",
        "plotRangeFirstValuesChanged",
        "plotRangeLastValuesChanged",
        "plotAutoScaleChanged",
        "plotMinChanged",
        "plotMaxChanged",
        "plotRangeChanged",
        "Range<double>",
        "plotRangeFormatChanged",
        "RangeT::Format",
        "format",
        "plotScaleChanged",
        "RangeT::Scale",
        "defaultPlotRangeChanged",
        "plotRectChanged",
        "QRectF&",
        "plotHorizontalPaddingChanged",
        "plotVerticalPaddingChanged",
        "plotRightPaddingChanged",
        "plotBottomPaddingChanged",
        "plotSymmetricPaddingChanged",
        "plotXRangeBreakingEnabledChanged",
        "plotXRangeBreaksChanged",
        "CartesianPlot::RangeBreaks",
        "plotYRangeBreakingEnabledChanged",
        "plotYRangeBreaksChanged",
        "plotBorderTypeChanged",
        "PlotArea::BorderType",
        "plotBorderCornerRadiusChanged",
        "loadConfigFromTemplate",
        "KConfig&",
        "saveConfigAsTemplate",
        "loadTheme",
        "saveTheme"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'info'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'init'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'rangeTypeChanged'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'niceExtendChanged'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'rangePointsChanged'
        QtMocHelpers::SlotData<void(const QString &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'autoScaleChanged'
        QtMocHelpers::SlotData<void(const Dimension, const int, bool)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { QMetaType::Int, 10 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'minDateTimeChanged'
        QtMocHelpers::SlotData<void(const QObject *, const Dimension, qint64)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 9, 2 }, { QMetaType::LongLong, 14 },
        }}),
        // Slot 'maxDateTimeChanged'
        QtMocHelpers::SlotData<void(const QObject *, const Dimension, qint64)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 9, 2 }, { QMetaType::LongLong, 2 },
        }}),
        // Slot 'rangeFormatChanged'
        QtMocHelpers::SlotData<void(const QObject *, const Dimension, int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 9, 2 }, { QMetaType::Int, 17 },
        }}),
        // Slot 'scaleChanged'
        QtMocHelpers::SlotData<void(const QObject *, const Dimension, int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 9, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'addXRange'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addYRange'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeRange'
        QtMocHelpers::SlotData<void(const Dimension)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 22 },
        }}),
        // Slot 'removeXRange'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeYRange'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addPlotRange'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removePlotRange'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'PlotRangeChanged'
        QtMocHelpers::SlotData<void(const int, const Dimension, const int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { 0x80000000 | 9, 2 }, { QMetaType::Int, 17 },
        }}),
        // Slot 'PlotRangeXChanged'
        QtMocHelpers::SlotData<void(const int)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'PlotRangeYChanged'
        QtMocHelpers::SlotData<void(const int)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'minChanged'
        QtMocHelpers::SlotData<void(const Dimension, const int, double)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 22 }, { QMetaType::Int, 17 }, { QMetaType::Double, 32 },
        }}),
        // Slot 'maxChanged'
        QtMocHelpers::SlotData<void(const Dimension, const int, double)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 22 }, { QMetaType::Int, 17 }, { QMetaType::Double, 34 },
        }}),
        // Slot 'geometryChanged'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'layoutChanged'
        QtMocHelpers::SlotData<void(Worksheet::Layout)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 2 },
        }}),
        // Slot 'symmetricPaddingChanged'
        QtMocHelpers::SlotData<void(bool)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'horizontalPaddingChanged'
        QtMocHelpers::SlotData<void(double)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'rightPaddingChanged'
        QtMocHelpers::SlotData<void(double)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'verticalPaddingChanged'
        QtMocHelpers::SlotData<void(double)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'bottomPaddingChanged'
        QtMocHelpers::SlotData<void(double)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'toggleXBreak'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'addXBreak'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeXBreak'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'currentXBreakChanged'
        QtMocHelpers::SlotData<void(int)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'xBreakStartChanged'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'xBreakEndChanged'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'xBreakPositionChanged'
        QtMocHelpers::SlotData<void(int)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'xBreakStyleChanged'
        QtMocHelpers::SlotData<void(int)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'toggleYBreak'
        QtMocHelpers::SlotData<void(bool)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'addYBreak'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeYBreak'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'currentYBreakChanged'
        QtMocHelpers::SlotData<void(int)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'yBreakStartChanged'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'yBreakEndChanged'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'yBreakPositionChanged'
        QtMocHelpers::SlotData<void(int)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'yBreakStyleChanged'
        QtMocHelpers::SlotData<void(int)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'borderTypeChanged'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'borderCornerRadiusChanged'
        QtMocHelpers::SlotData<void(double)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'exportPlotTemplate'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'plotRangeTypeChanged'
        QtMocHelpers::SlotData<void(CartesianPlot::RangeType)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 63, 2 },
        }}),
        // Slot 'plotRangeFirstValuesChanged'
        QtMocHelpers::SlotData<void(int)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'plotRangeLastValuesChanged'
        QtMocHelpers::SlotData<void(int)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'plotAutoScaleChanged'
        QtMocHelpers::SlotData<void(const Dimension, int, bool)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { QMetaType::Int, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'plotMinChanged'
        QtMocHelpers::SlotData<void(const Dimension, int, double)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { QMetaType::Int, 10 }, { QMetaType::Double, 2 },
        }}),
        // Slot 'plotMaxChanged'
        QtMocHelpers::SlotData<void(const Dimension, int, double)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { QMetaType::Int, 10 }, { QMetaType::Double, 2 },
        }}),
        // Slot 'plotRangeChanged'
        QtMocHelpers::SlotData<void(const Dimension, int, Range<double>)>(69, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { QMetaType::Int, 2 }, { 0x80000000 | 70, 2 },
        }}),
        // Slot 'plotRangeFormatChanged'
        QtMocHelpers::SlotData<void(const Dimension, int, RangeT::Format)>(71, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { QMetaType::Int, 10 }, { 0x80000000 | 72, 73 },
        }}),
        // Slot 'plotScaleChanged'
        QtMocHelpers::SlotData<void(const Dimension, int, RangeT::Scale)>(74, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { QMetaType::Int, 10 }, { 0x80000000 | 75, 2 },
        }}),
        // Slot 'defaultPlotRangeChanged'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'plotRectChanged'
        QtMocHelpers::SlotData<void(QRectF &)>(77, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 78, 2 },
        }}),
        // Slot 'plotHorizontalPaddingChanged'
        QtMocHelpers::SlotData<void(double)>(79, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'plotVerticalPaddingChanged'
        QtMocHelpers::SlotData<void(double)>(80, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'plotRightPaddingChanged'
        QtMocHelpers::SlotData<void(double)>(81, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'plotBottomPaddingChanged'
        QtMocHelpers::SlotData<void(double)>(82, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'plotSymmetricPaddingChanged'
        QtMocHelpers::SlotData<void(bool)>(83, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'plotXRangeBreakingEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(84, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'plotXRangeBreaksChanged'
        QtMocHelpers::SlotData<void(const CartesianPlot::RangeBreaks &)>(85, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 86, 2 },
        }}),
        // Slot 'plotYRangeBreakingEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(87, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'plotYRangeBreaksChanged'
        QtMocHelpers::SlotData<void(const CartesianPlot::RangeBreaks &)>(88, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 86, 2 },
        }}),
        // Slot 'plotBorderTypeChanged'
        QtMocHelpers::SlotData<void(PlotArea::BorderType)>(89, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 90, 2 },
        }}),
        // Slot 'plotBorderCornerRadiusChanged'
        QtMocHelpers::SlotData<void(double)>(91, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'loadConfigFromTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(92, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 93, 2 },
        }}),
        // Slot 'saveConfigAsTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(94, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 93, 2 },
        }}),
        // Slot 'loadTheme'
        QtMocHelpers::SlotData<void(const QString &)>(95, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'saveTheme'
        QtMocHelpers::SlotData<void(KConfig &) const>(96, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 93, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CartesianPlotDock, qt_meta_tag_ZN17CartesianPlotDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CartesianPlotDock::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseDock::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CartesianPlotDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CartesianPlotDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17CartesianPlotDockE_t>.metaTypes,
    nullptr
} };

void CartesianPlotDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CartesianPlotDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->init(); break;
        case 2: _t->rangeTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->niceExtendChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->rangePointsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->autoScaleChanged((*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 6: _t->minDateTimeChanged((*reinterpret_cast<std::add_pointer_t<const QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 7: _t->maxDateTimeChanged((*reinterpret_cast<std::add_pointer_t<const QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 8: _t->rangeFormatChanged((*reinterpret_cast<std::add_pointer_t<const QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 9: _t->scaleChanged((*reinterpret_cast<std::add_pointer_t<const QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 10: _t->addXRange(); break;
        case 11: _t->addYRange(); break;
        case 12: _t->removeRange((*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[1]))); break;
        case 13: _t->removeXRange(); break;
        case 14: _t->removeYRange(); break;
        case 15: _t->addPlotRange(); break;
        case 16: _t->removePlotRange(); break;
        case 17: _t->PlotRangeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 18: _t->PlotRangeXChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->PlotRangeYChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->minChanged((*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 21: _t->maxChanged((*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 22: _t->geometryChanged(); break;
        case 23: _t->layoutChanged((*reinterpret_cast<std::add_pointer_t<Worksheet::Layout>>(_a[1]))); break;
        case 24: _t->symmetricPaddingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->horizontalPaddingChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 26: _t->rightPaddingChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 27: _t->verticalPaddingChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 28: _t->bottomPaddingChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 29: _t->toggleXBreak((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->addXBreak(); break;
        case 31: _t->removeXBreak(); break;
        case 32: _t->currentXBreakChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->xBreakStartChanged(); break;
        case 34: _t->xBreakEndChanged(); break;
        case 35: _t->xBreakPositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->xBreakStyleChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 37: _t->toggleYBreak((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->addYBreak(); break;
        case 39: _t->removeYBreak(); break;
        case 40: _t->currentYBreakChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 41: _t->yBreakStartChanged(); break;
        case 42: _t->yBreakEndChanged(); break;
        case 43: _t->yBreakPositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 44: _t->yBreakStyleChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 45: _t->borderTypeChanged(); break;
        case 46: _t->borderCornerRadiusChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 47: _t->exportPlotTemplate(); break;
        case 48: _t->plotRangeTypeChanged((*reinterpret_cast<std::add_pointer_t<CartesianPlot::RangeType>>(_a[1]))); break;
        case 49: _t->plotRangeFirstValuesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 50: _t->plotRangeLastValuesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 51: _t->plotAutoScaleChanged((*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 52: _t->plotMinChanged((*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 53: _t->plotMaxChanged((*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 54: _t->plotRangeChanged((*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Range<double>>>(_a[3]))); break;
        case 55: _t->plotRangeFormatChanged((*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<RangeT::Format>>(_a[3]))); break;
        case 56: _t->plotScaleChanged((*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<RangeT::Scale>>(_a[3]))); break;
        case 57: _t->defaultPlotRangeChanged(); break;
        case 58: _t->plotRectChanged((*reinterpret_cast<std::add_pointer_t<QRectF&>>(_a[1]))); break;
        case 59: _t->plotHorizontalPaddingChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 60: _t->plotVerticalPaddingChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 61: _t->plotRightPaddingChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 62: _t->plotBottomPaddingChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 63: _t->plotSymmetricPaddingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 64: _t->plotXRangeBreakingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 65: _t->plotXRangeBreaksChanged((*reinterpret_cast<std::add_pointer_t<CartesianPlot::RangeBreaks>>(_a[1]))); break;
        case 66: _t->plotYRangeBreakingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 67: _t->plotYRangeBreaksChanged((*reinterpret_cast<std::add_pointer_t<CartesianPlot::RangeBreaks>>(_a[1]))); break;
        case 68: _t->plotBorderTypeChanged((*reinterpret_cast<std::add_pointer_t<PlotArea::BorderType>>(_a[1]))); break;
        case 69: _t->plotBorderCornerRadiusChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 70: _t->loadConfigFromTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        case 71: _t->saveConfigAsTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        case 72: _t->loadTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 73: _t->saveTheme((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotDock::*)(const QString & )>(_a, &CartesianPlotDock::info, 0))
            return;
    }
}

const QMetaObject *CartesianPlotDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CartesianPlotDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CartesianPlotDockE_t>.strings))
        return static_cast<void*>(this);
    return BaseDock::qt_metacast(_clname);
}

int CartesianPlotDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseDock::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 74)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 74;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 74)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 74;
    }
    return _id;
}

// SIGNAL 0
void CartesianPlotDock::info(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
