/****************************************************************************
** Meta object code from reading C++ file 'AxisDock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/dockwidgets/AxisDock.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AxisDock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8AxisDockE_t {};
} // unnamed namespace

template <> constexpr inline auto AxisDock::qt_create_metaobjectdata<qt_meta_tag_ZN8AxisDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AxisDock",
        "info",
        "",
        "colorChanged",
        "QColor",
        "orientationChanged",
        "positionChanged",
        "value",
        "logicalPositionChanged",
        "scaleChanged",
        "rangeScaleChanged",
        "rangeTypeChanged",
        "startChanged",
        "endChanged",
        "startDateTimeChanged",
        "endDateTimeChanged",
        "zeroOffsetChanged",
        "scalingFactorChanged",
        "showScaleOffsetChanged",
        "setLeftOffset",
        "setCenterOffset",
        "setRightOffset",
        "setUnityScale",
        "setUnityRange",
        "setAxisColor",
        "updateArrowLineColor",
        "arrowPositionChanged",
        "arrowTypeChanged",
        "arrowSizeChanged",
        "majorTicksDirectionChanged",
        "majorTicksTypeChanged",
        "majorTicksAutoNumberChanged",
        "state",
        "majorTicksNumberChanged",
        "majorTicksSpacingChanged",
        "majorTicksColumnChanged",
        "QModelIndex",
        "majorTicksStartTypeChanged",
        "majorTicksDateTimeStartOffsetChanged",
        "majorTicksStartOffsetChanged",
        "majorTicksStartValueChanged",
        "majorTicksStartDateTimeChanged",
        "setTickOffsetData",
        "nice",
        "setTickOffsetAuto",
        "majorTicksLengthChanged",
        "minorTicksDirectionChanged",
        "minorTicksTypeChanged",
        "minorTicksAutoNumberChanged",
        "minorTicksNumberChanged",
        "minorTicksSpacingChanged",
        "minorTicksColumnChanged",
        "minorTicksLengthChanged",
        "labelsFormatChanged",
        "labelsFormatAutoChanged",
        "labelsPrecisionChanged",
        "labelsAutoPrecisionChanged",
        "labelsDateTimeFormatChanged",
        "labelsPositionChanged",
        "labelsOffsetChanged",
        "labelsRotationChanged",
        "labelsTextTypeChanged",
        "labelsTextColumnChanged",
        "labelsFontChanged",
        "QFont",
        "labelsFontColorChanged",
        "labelsBackgroundTypeChanged",
        "labelsBackgroundColorChanged",
        "labelsPrefixChanged",
        "labelsSuffixChanged",
        "labelsOpacityChanged",
        "axisOrientationChanged",
        "Axis::Orientation",
        "axisPositionChanged",
        "Axis::Position",
        "axisLogicalPositionChanged",
        "axisScaleChanged",
        "RangeT::Scale",
        "axisRangeScaleChanged",
        "axisRangeTypeChanged",
        "Axis::RangeType",
        "axisStartChanged",
        "axisEndChanged",
        "axisScalingFactorChanged",
        "axisZeroOffsetChanged",
        "axisShowScaleOffsetChanged",
        "axisArrowTypeChanged",
        "Axis::ArrowType",
        "axisArrowPositionChanged",
        "Axis::ArrowPosition",
        "axisArrowSizeChanged",
        "axisMajorTicksDirectionChanged",
        "Axis::TicksDirection",
        "axisMajorTicksTypeChanged",
        "Axis::TicksType",
        "axisMajorTicksAutoNumberChanged",
        "axisMajorTicksNumberChanged",
        "axisMajorTicksSpacingChanged",
        "axisMajorTicksStartTypeChanged",
        "Axis::TicksStartType",
        "axisMajorTicksStartOffsetChanged",
        "axisMajorTicksStartValueChanged",
        "axisMajorTicksColumnChanged",
        "const AbstractColumn*",
        "axisMajorTicksLengthChanged",
        "axisMinorTicksDirectionChanged",
        "axisMinorTicksTypeChanged",
        "axisMinorTicksAutoNumberChanged",
        "axisMinorTicksNumberChanged",
        "axisMinorTicksSpacingChanged",
        "axisMinorTicksColumnChanged",
        "axisMinorTicksLengthChanged",
        "axisLabelsFormatChanged",
        "Axis::LabelsFormat",
        "axisLabelsFormatAutoChanged",
        "axisLabelsAutoPrecisionChanged",
        "axisLabelsPrecisionChanged",
        "axisLabelsDateTimeFormatChanged",
        "axisLabelsPositionChanged",
        "Axis::LabelsPosition",
        "axisLabelsOffsetChanged",
        "axisLabelsRotationAngleChanged",
        "axisLabelsTextTypeChanged",
        "Axis::LabelsTextType",
        "axisLabelsTextColumnChanged",
        "axisLabelsFontChanged",
        "axisLabelsFontColorChanged",
        "axisLabelsBackgroundTypeChanged",
        "Axis::LabelsBackgroundType",
        "axisLabelsBackgroundColorChanged",
        "axisLabelsPrefixChanged",
        "axisLabelsSuffixChanged",
        "axisLabelsOpacityChanged",
        "loadConfigFromTemplate",
        "KConfig&",
        "saveConfigAsTemplate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'info'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'colorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'orientationChanged'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'positionChanged'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'positionChanged'
        QtMocHelpers::SlotData<void(double)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Slot 'logicalPositionChanged'
        QtMocHelpers::SlotData<void(double)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Slot 'scaleChanged'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'rangeScaleChanged'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'rangeTypeChanged'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'startChanged'
        QtMocHelpers::SlotData<void(double)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'endChanged'
        QtMocHelpers::SlotData<void(double)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'startDateTimeChanged'
        QtMocHelpers::SlotData<void(qint64)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 2 },
        }}),
        // Slot 'endDateTimeChanged'
        QtMocHelpers::SlotData<void(qint64)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 2 },
        }}),
        // Slot 'zeroOffsetChanged'
        QtMocHelpers::SlotData<void(double)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'scalingFactorChanged'
        QtMocHelpers::SlotData<void(double)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'showScaleOffsetChanged'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setLeftOffset'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setCenterOffset'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setRightOffset'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setUnityScale'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setUnityRange'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setAxisColor'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateArrowLineColor'
        QtMocHelpers::SlotData<void(const QColor &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'arrowPositionChanged'
        QtMocHelpers::SlotData<void(int)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'arrowTypeChanged'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'arrowSizeChanged'
        QtMocHelpers::SlotData<void(int)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'majorTicksDirectionChanged'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'majorTicksTypeChanged'
        QtMocHelpers::SlotData<void(int)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'majorTicksAutoNumberChanged'
        QtMocHelpers::SlotData<void(int)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 32 },
        }}),
        // Slot 'majorTicksNumberChanged'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'majorTicksSpacingChanged'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'majorTicksColumnChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'majorTicksStartTypeChanged'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 32 },
        }}),
        // Slot 'majorTicksDateTimeStartOffsetChanged'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'majorTicksStartOffsetChanged'
        QtMocHelpers::SlotData<void(double)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'majorTicksStartValueChanged'
        QtMocHelpers::SlotData<void(double)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'majorTicksStartDateTimeChanged'
        QtMocHelpers::SlotData<void(qint64)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Slot 'setTickOffsetData'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 43 },
        }}),
        // Slot 'setTickOffsetData'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setTickOffsetAuto'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'majorTicksLengthChanged'
        QtMocHelpers::SlotData<void(double)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'minorTicksDirectionChanged'
        QtMocHelpers::SlotData<void(int)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'minorTicksTypeChanged'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'minorTicksAutoNumberChanged'
        QtMocHelpers::SlotData<void(int)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 32 },
        }}),
        // Slot 'minorTicksNumberChanged'
        QtMocHelpers::SlotData<void(int)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'minorTicksSpacingChanged'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'minorTicksColumnChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'minorTicksLengthChanged'
        QtMocHelpers::SlotData<void(double)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'labelsFormatChanged'
        QtMocHelpers::SlotData<void(int)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'labelsFormatAutoChanged'
        QtMocHelpers::SlotData<void(bool)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'labelsPrecisionChanged'
        QtMocHelpers::SlotData<void(int)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'labelsAutoPrecisionChanged'
        QtMocHelpers::SlotData<void(bool)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'labelsDateTimeFormatChanged'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'labelsPositionChanged'
        QtMocHelpers::SlotData<void(int)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'labelsOffsetChanged'
        QtMocHelpers::SlotData<void(double)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'labelsRotationChanged'
        QtMocHelpers::SlotData<void(int)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'labelsTextTypeChanged'
        QtMocHelpers::SlotData<void(int)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'labelsTextColumnChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'labelsFontChanged'
        QtMocHelpers::SlotData<void(const QFont &)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 64, 2 },
        }}),
        // Slot 'labelsFontColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'labelsBackgroundTypeChanged'
        QtMocHelpers::SlotData<void(int)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'labelsBackgroundColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'labelsPrefixChanged'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'labelsSuffixChanged'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'labelsOpacityChanged'
        QtMocHelpers::SlotData<void(int)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'axisOrientationChanged'
        QtMocHelpers::SlotData<void(Axis::Orientation)>(71, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 72, 2 },
        }}),
        // Slot 'axisPositionChanged'
        QtMocHelpers::SlotData<void(Axis::Position)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 74, 2 },
        }}),
        // Slot 'axisPositionChanged'
        QtMocHelpers::SlotData<void(double)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'axisLogicalPositionChanged'
        QtMocHelpers::SlotData<void(double)>(75, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'axisScaleChanged'
        QtMocHelpers::SlotData<void(RangeT::Scale)>(76, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 77, 2 },
        }}),
        // Slot 'axisRangeScaleChanged'
        QtMocHelpers::SlotData<void(bool)>(78, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'axisRangeTypeChanged'
        QtMocHelpers::SlotData<void(Axis::RangeType)>(79, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 80, 2 },
        }}),
        // Slot 'axisStartChanged'
        QtMocHelpers::SlotData<void(double)>(81, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'axisEndChanged'
        QtMocHelpers::SlotData<void(double)>(82, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'axisScalingFactorChanged'
        QtMocHelpers::SlotData<void(qreal)>(83, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'axisZeroOffsetChanged'
        QtMocHelpers::SlotData<void(qreal)>(84, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'axisShowScaleOffsetChanged'
        QtMocHelpers::SlotData<void(bool)>(85, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'axisArrowTypeChanged'
        QtMocHelpers::SlotData<void(Axis::ArrowType)>(86, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 87, 2 },
        }}),
        // Slot 'axisArrowPositionChanged'
        QtMocHelpers::SlotData<void(Axis::ArrowPosition)>(88, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 89, 2 },
        }}),
        // Slot 'axisArrowSizeChanged'
        QtMocHelpers::SlotData<void(qreal)>(90, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'axisMajorTicksDirectionChanged'
        QtMocHelpers::SlotData<void(Axis::TicksDirection)>(91, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 92, 2 },
        }}),
        // Slot 'axisMajorTicksTypeChanged'
        QtMocHelpers::SlotData<void(Axis::TicksType)>(93, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 94, 2 },
        }}),
        // Slot 'axisMajorTicksAutoNumberChanged'
        QtMocHelpers::SlotData<void(bool)>(95, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'axisMajorTicksNumberChanged'
        QtMocHelpers::SlotData<void(int)>(96, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'axisMajorTicksSpacingChanged'
        QtMocHelpers::SlotData<void(qreal)>(97, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'axisMajorTicksStartTypeChanged'
        QtMocHelpers::SlotData<void(Axis::TicksStartType)>(98, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 99, 2 },
        }}),
        // Slot 'axisMajorTicksStartOffsetChanged'
        QtMocHelpers::SlotData<void(qreal)>(100, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'axisMajorTicksStartValueChanged'
        QtMocHelpers::SlotData<void(qreal)>(101, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'axisMajorTicksColumnChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(102, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 103, 2 },
        }}),
        // Slot 'axisMajorTicksLengthChanged'
        QtMocHelpers::SlotData<void(qreal)>(104, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'axisMinorTicksDirectionChanged'
        QtMocHelpers::SlotData<void(Axis::TicksDirection)>(105, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 92, 2 },
        }}),
        // Slot 'axisMinorTicksTypeChanged'
        QtMocHelpers::SlotData<void(Axis::TicksType)>(106, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 94, 2 },
        }}),
        // Slot 'axisMinorTicksAutoNumberChanged'
        QtMocHelpers::SlotData<void(bool)>(107, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'axisMinorTicksNumberChanged'
        QtMocHelpers::SlotData<void(int)>(108, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'axisMinorTicksSpacingChanged'
        QtMocHelpers::SlotData<void(qreal)>(109, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'axisMinorTicksColumnChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(110, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 103, 2 },
        }}),
        // Slot 'axisMinorTicksLengthChanged'
        QtMocHelpers::SlotData<void(qreal)>(111, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'axisLabelsFormatChanged'
        QtMocHelpers::SlotData<void(Axis::LabelsFormat)>(112, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 113, 2 },
        }}),
        // Slot 'axisLabelsFormatAutoChanged'
        QtMocHelpers::SlotData<void(bool)>(114, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'axisLabelsAutoPrecisionChanged'
        QtMocHelpers::SlotData<void(bool)>(115, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'axisLabelsPrecisionChanged'
        QtMocHelpers::SlotData<void(int)>(116, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'axisLabelsDateTimeFormatChanged'
        QtMocHelpers::SlotData<void(const QString &)>(117, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'axisLabelsPositionChanged'
        QtMocHelpers::SlotData<void(Axis::LabelsPosition)>(118, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 119, 2 },
        }}),
        // Slot 'axisLabelsOffsetChanged'
        QtMocHelpers::SlotData<void(double)>(120, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'axisLabelsRotationAngleChanged'
        QtMocHelpers::SlotData<void(qreal)>(121, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'axisLabelsTextTypeChanged'
        QtMocHelpers::SlotData<void(Axis::LabelsTextType)>(122, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 123, 2 },
        }}),
        // Slot 'axisLabelsTextColumnChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(124, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 103, 2 },
        }}),
        // Slot 'axisLabelsFontChanged'
        QtMocHelpers::SlotData<void(const QFont &)>(125, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 64, 2 },
        }}),
        // Slot 'axisLabelsFontColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(126, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'axisLabelsBackgroundTypeChanged'
        QtMocHelpers::SlotData<void(Axis::LabelsBackgroundType)>(127, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 128, 2 },
        }}),
        // Slot 'axisLabelsBackgroundColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(129, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'axisLabelsPrefixChanged'
        QtMocHelpers::SlotData<void(const QString &)>(130, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'axisLabelsSuffixChanged'
        QtMocHelpers::SlotData<void(const QString &)>(131, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'axisLabelsOpacityChanged'
        QtMocHelpers::SlotData<void(qreal)>(132, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'loadConfigFromTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(133, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 134, 2 },
        }}),
        // Slot 'saveConfigAsTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(135, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 134, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AxisDock, qt_meta_tag_ZN8AxisDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AxisDock::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseDock::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8AxisDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8AxisDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8AxisDockE_t>.metaTypes,
    nullptr
} };

void AxisDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AxisDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->colorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 2: _t->orientationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->logicalPositionChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->scaleChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->rangeScaleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->rangeTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->startChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->endChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 11: _t->startDateTimeChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 12: _t->endDateTimeChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 13: _t->zeroOffsetChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 14: _t->scalingFactorChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: _t->showScaleOffsetChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->setLeftOffset(); break;
        case 17: _t->setCenterOffset(); break;
        case 18: _t->setRightOffset(); break;
        case 19: _t->setUnityScale(); break;
        case 20: _t->setUnityRange(); break;
        case 21: _t->setAxisColor(); break;
        case 22: _t->updateArrowLineColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 23: _t->arrowPositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->arrowTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->arrowSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->majorTicksDirectionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->majorTicksTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->majorTicksAutoNumberChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->majorTicksNumberChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->majorTicksSpacingChanged(); break;
        case 31: _t->majorTicksColumnChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 32: _t->majorTicksStartTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->majorTicksDateTimeStartOffsetChanged(); break;
        case 34: _t->majorTicksStartOffsetChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 35: _t->majorTicksStartValueChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 36: _t->majorTicksStartDateTimeChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 37: _t->setTickOffsetData((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->setTickOffsetData(); break;
        case 39: _t->setTickOffsetAuto(); break;
        case 40: _t->majorTicksLengthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 41: _t->minorTicksDirectionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 42: _t->minorTicksTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 43: _t->minorTicksAutoNumberChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 44: _t->minorTicksNumberChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 45: _t->minorTicksSpacingChanged(); break;
        case 46: _t->minorTicksColumnChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 47: _t->minorTicksLengthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 48: _t->labelsFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 49: _t->labelsFormatAutoChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 50: _t->labelsPrecisionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 51: _t->labelsAutoPrecisionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 52: _t->labelsDateTimeFormatChanged(); break;
        case 53: _t->labelsPositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 54: _t->labelsOffsetChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 55: _t->labelsRotationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 56: _t->labelsTextTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 57: _t->labelsTextColumnChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 58: _t->labelsFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 59: _t->labelsFontColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 60: _t->labelsBackgroundTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 61: _t->labelsBackgroundColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 62: _t->labelsPrefixChanged(); break;
        case 63: _t->labelsSuffixChanged(); break;
        case 64: _t->labelsOpacityChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 65: _t->axisOrientationChanged((*reinterpret_cast<std::add_pointer_t<Axis::Orientation>>(_a[1]))); break;
        case 66: _t->axisPositionChanged((*reinterpret_cast<std::add_pointer_t<Axis::Position>>(_a[1]))); break;
        case 67: _t->axisPositionChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 68: _t->axisLogicalPositionChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 69: _t->axisScaleChanged((*reinterpret_cast<std::add_pointer_t<RangeT::Scale>>(_a[1]))); break;
        case 70: _t->axisRangeScaleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 71: _t->axisRangeTypeChanged((*reinterpret_cast<std::add_pointer_t<Axis::RangeType>>(_a[1]))); break;
        case 72: _t->axisStartChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 73: _t->axisEndChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 74: _t->axisScalingFactorChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 75: _t->axisZeroOffsetChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 76: _t->axisShowScaleOffsetChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 77: _t->axisArrowTypeChanged((*reinterpret_cast<std::add_pointer_t<Axis::ArrowType>>(_a[1]))); break;
        case 78: _t->axisArrowPositionChanged((*reinterpret_cast<std::add_pointer_t<Axis::ArrowPosition>>(_a[1]))); break;
        case 79: _t->axisArrowSizeChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 80: _t->axisMajorTicksDirectionChanged((*reinterpret_cast<std::add_pointer_t<Axis::TicksDirection>>(_a[1]))); break;
        case 81: _t->axisMajorTicksTypeChanged((*reinterpret_cast<std::add_pointer_t<Axis::TicksType>>(_a[1]))); break;
        case 82: _t->axisMajorTicksAutoNumberChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 83: _t->axisMajorTicksNumberChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 84: _t->axisMajorTicksSpacingChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 85: _t->axisMajorTicksStartTypeChanged((*reinterpret_cast<std::add_pointer_t<Axis::TicksStartType>>(_a[1]))); break;
        case 86: _t->axisMajorTicksStartOffsetChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 87: _t->axisMajorTicksStartValueChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 88: _t->axisMajorTicksColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 89: _t->axisMajorTicksLengthChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 90: _t->axisMinorTicksDirectionChanged((*reinterpret_cast<std::add_pointer_t<Axis::TicksDirection>>(_a[1]))); break;
        case 91: _t->axisMinorTicksTypeChanged((*reinterpret_cast<std::add_pointer_t<Axis::TicksType>>(_a[1]))); break;
        case 92: _t->axisMinorTicksAutoNumberChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 93: _t->axisMinorTicksNumberChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 94: _t->axisMinorTicksSpacingChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 95: _t->axisMinorTicksColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 96: _t->axisMinorTicksLengthChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 97: _t->axisLabelsFormatChanged((*reinterpret_cast<std::add_pointer_t<Axis::LabelsFormat>>(_a[1]))); break;
        case 98: _t->axisLabelsFormatAutoChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 99: _t->axisLabelsAutoPrecisionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 100: _t->axisLabelsPrecisionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 101: _t->axisLabelsDateTimeFormatChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 102: _t->axisLabelsPositionChanged((*reinterpret_cast<std::add_pointer_t<Axis::LabelsPosition>>(_a[1]))); break;
        case 103: _t->axisLabelsOffsetChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 104: _t->axisLabelsRotationAngleChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 105: _t->axisLabelsTextTypeChanged((*reinterpret_cast<std::add_pointer_t<Axis::LabelsTextType>>(_a[1]))); break;
        case 106: _t->axisLabelsTextColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 107: _t->axisLabelsFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 108: _t->axisLabelsFontColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 109: _t->axisLabelsBackgroundTypeChanged((*reinterpret_cast<std::add_pointer_t<Axis::LabelsBackgroundType>>(_a[1]))); break;
        case 110: _t->axisLabelsBackgroundColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 111: _t->axisLabelsPrefixChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 112: _t->axisLabelsSuffixChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 113: _t->axisLabelsOpacityChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 114: _t->loadConfigFromTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        case 115: _t->saveConfigAsTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AxisDock::*)(const QString & )>(_a, &AxisDock::info, 0))
            return;
    }
}

const QMetaObject *AxisDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AxisDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8AxisDockE_t>.strings))
        return static_cast<void*>(this);
    return BaseDock::qt_metacast(_clname);
}

int AxisDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseDock::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 116)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 116;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 116)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 116;
    }
    return _id;
}

// SIGNAL 0
void AxisDock::info(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
