/********************************************************************************
** Form generated from reading UI file 'databasemanagerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DATABASEMANAGERWIDGET_H
#define UI_DATABASEMANAGERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DatabaseManagerWidget
{
public:
    QGridLayout *gridLayout_3;
    QListWidget *lwConnections;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QCheckBox *chkCustomConnection;
    QLabel *lCustomConnection;
    QLabel *lName;
    QLineEdit *leName;
    QLabel *lDriver;
    QComboBox *cbDriver;
    QLabel *lHost;
    QLineEdit *leHost;
    QLabel *lPort;
    QSpinBox *sbPort;
    QLabel *lDatabase;
    QLineEdit *leDatabase;
    QPushButton *bOpen;
    QSpacerItem *verticalSpacer_2;
    QPlainTextEdit *teCustomConnection;
    QGroupBox *gbAuthentication;
    QGridLayout *gridLayout_2;
    QLabel *lUserName;
    QLineEdit *leUserName;
    QLabel *lPassword;
    QLineEdit *lePassword;
    QSpacerItem *verticalSpacer;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QToolButton *tbAdd;
    QToolButton *tbDelete;
    QSpacerItem *horizontalSpacer;
    QPushButton *bTestConnection;

    void setupUi(QWidget *DatabaseManagerWidget)
    {
        if (DatabaseManagerWidget->objectName().isEmpty())
            DatabaseManagerWidget->setObjectName("DatabaseManagerWidget");
        DatabaseManagerWidget->resize(849, 750);
        gridLayout_3 = new QGridLayout(DatabaseManagerWidget);
        gridLayout_3->setObjectName("gridLayout_3");
        lwConnections = new QListWidget(DatabaseManagerWidget);
        lwConnections->setObjectName("lwConnections");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lwConnections->sizePolicy().hasHeightForWidth());
        lwConnections->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(lwConnections, 0, 0, 2, 1);

        groupBox = new QGroupBox(DatabaseManagerWidget);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy1);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        chkCustomConnection = new QCheckBox(groupBox);
        chkCustomConnection->setObjectName("chkCustomConnection");

        gridLayout->addWidget(chkCustomConnection, 5, 1, 1, 1);

        lCustomConnection = new QLabel(groupBox);
        lCustomConnection->setObjectName("lCustomConnection");
        lCustomConnection->setWordWrap(false);

        gridLayout->addWidget(lCustomConnection, 5, 0, 1, 1);

        lName = new QLabel(groupBox);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        leName = new QLineEdit(groupBox);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 1, 1, 1);

        lDriver = new QLabel(groupBox);
        lDriver->setObjectName("lDriver");

        gridLayout->addWidget(lDriver, 1, 0, 1, 1);

        cbDriver = new QComboBox(groupBox);
        cbDriver->setObjectName("cbDriver");

        gridLayout->addWidget(cbDriver, 1, 1, 1, 1);

        lHost = new QLabel(groupBox);
        lHost->setObjectName("lHost");

        gridLayout->addWidget(lHost, 2, 0, 1, 1);

        leHost = new QLineEdit(groupBox);
        leHost->setObjectName("leHost");
        leHost->setClearButtonEnabled(true);

        gridLayout->addWidget(leHost, 2, 1, 1, 1);

        lPort = new QLabel(groupBox);
        lPort->setObjectName("lPort");

        gridLayout->addWidget(lPort, 3, 0, 1, 1);

        sbPort = new QSpinBox(groupBox);
        sbPort->setObjectName("sbPort");
        sbPort->setButtonSymbols(QAbstractSpinBox::NoButtons);
        sbPort->setMaximum(60000);

        gridLayout->addWidget(sbPort, 3, 1, 1, 1);

        lDatabase = new QLabel(groupBox);
        lDatabase->setObjectName("lDatabase");

        gridLayout->addWidget(lDatabase, 4, 0, 1, 1);

        leDatabase = new QLineEdit(groupBox);
        leDatabase->setObjectName("leDatabase");
        leDatabase->setClearButtonEnabled(true);

        gridLayout->addWidget(leDatabase, 4, 1, 1, 1);

        bOpen = new QPushButton(groupBox);
        bOpen->setObjectName("bOpen");

        gridLayout->addWidget(bOpen, 4, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 7, 1, 1, 1);

        teCustomConnection = new QPlainTextEdit(groupBox);
        teCustomConnection->setObjectName("teCustomConnection");

        gridLayout->addWidget(teCustomConnection, 6, 1, 1, 1);


        gridLayout_3->addWidget(groupBox, 0, 1, 1, 1);

        gbAuthentication = new QGroupBox(DatabaseManagerWidget);
        gbAuthentication->setObjectName("gbAuthentication");
        sizePolicy1.setHeightForWidth(gbAuthentication->sizePolicy().hasHeightForWidth());
        gbAuthentication->setSizePolicy(sizePolicy1);
        gridLayout_2 = new QGridLayout(gbAuthentication);
        gridLayout_2->setObjectName("gridLayout_2");
        lUserName = new QLabel(gbAuthentication);
        lUserName->setObjectName("lUserName");

        gridLayout_2->addWidget(lUserName, 0, 0, 1, 1);

        leUserName = new QLineEdit(gbAuthentication);
        leUserName->setObjectName("leUserName");
        leUserName->setClearButtonEnabled(true);

        gridLayout_2->addWidget(leUserName, 0, 1, 1, 1);

        lPassword = new QLabel(gbAuthentication);
        lPassword->setObjectName("lPassword");

        gridLayout_2->addWidget(lPassword, 1, 0, 1, 1);

        lePassword = new QLineEdit(gbAuthentication);
        lePassword->setObjectName("lePassword");
        lePassword->setClearButtonEnabled(true);

        gridLayout_2->addWidget(lePassword, 1, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 38, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 2, 1, 1, 1);


        gridLayout_3->addWidget(gbAuthentication, 1, 1, 1, 1);

        frame = new QFrame(DatabaseManagerWidget);
        frame->setObjectName("frame");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy2);
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        tbAdd = new QToolButton(frame);
        tbAdd->setObjectName("tbAdd");

        horizontalLayout->addWidget(tbAdd);

        tbDelete = new QToolButton(frame);
        tbDelete->setObjectName("tbDelete");

        horizontalLayout->addWidget(tbDelete);

        horizontalSpacer = new QSpacerItem(69, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        bTestConnection = new QPushButton(frame);
        bTestConnection->setObjectName("bTestConnection");

        horizontalLayout->addWidget(bTestConnection);


        gridLayout_3->addWidget(frame, 2, 0, 1, 1);


        retranslateUi(DatabaseManagerWidget);

        QMetaObject::connectSlotsByName(DatabaseManagerWidget);
    } // setupUi

    void retranslateUi(QWidget *DatabaseManagerWidget)
    {
        groupBox->setTitle(tr2i18n("Database", nullptr));
        chkCustomConnection->setText(tr2i18n("enable", nullptr));
        lCustomConnection->setText(tr2i18n("Connection String:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lDriver->setText(tr2i18n("Driver:", nullptr));
        lHost->setText(tr2i18n("Host:", nullptr));
        lPort->setText(tr2i18n("Port:", nullptr));
        sbPort->setSuffix(QString());
        lDatabase->setText(tr2i18n("Database:", nullptr));
        bOpen->setText(QString());
        gbAuthentication->setTitle(tr2i18n("Authentication", nullptr));
        lUserName->setText(tr2i18n("User:", nullptr));
        lPassword->setText(tr2i18n("Password:", nullptr));
        lePassword->setText(QString());
        tbAdd->setText(QString());
        tbDelete->setText(QString());
        bTestConnection->setText(tr2i18n("Test", nullptr));
        (void)DatabaseManagerWidget;
    } // retranslateUi

};

namespace Ui {
    class DatabaseManagerWidget: public Ui_DatabaseManagerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DATABASEMANAGERWIDGET_H

