/********************************************************************************
** Form generated from reading UI file 'matiooptionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MATIOOPTIONSWIDGET_H
#define UI_MATIOOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MatioOptionsWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_3;
    QSplitter *splitter;
    QTableWidget *twContent;
    QTableWidget *twPreview;
    QHBoxLayout *horizontalLayout;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QSpinBox *sbPreviewLines;
    QPushButton *bRefreshPreview;

    void setupUi(QWidget *MatioOptionsWidget)
    {
        if (MatioOptionsWidget->objectName().isEmpty())
            MatioOptionsWidget->setObjectName("MatioOptionsWidget");
        MatioOptionsWidget->resize(686, 267);
        gridLayout = new QGridLayout(MatioOptionsWidget);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        splitter = new QSplitter(MatioOptionsWidget);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        twContent = new QTableWidget(splitter);
        if (twContent->columnCount() < 7)
            twContent->setColumnCount(7);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        twContent->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        twContent->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        twContent->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        twContent->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        twContent->setHorizontalHeaderItem(4, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        twContent->setHorizontalHeaderItem(5, __qtablewidgetitem5);
        QTableWidgetItem *__qtablewidgetitem6 = new QTableWidgetItem();
        twContent->setHorizontalHeaderItem(6, __qtablewidgetitem6);
        twContent->setObjectName("twContent");
        splitter->addWidget(twContent);
        twPreview = new QTableWidget(splitter);
        twPreview->setObjectName("twPreview");
        splitter->addWidget(twPreview);
        twPreview->horizontalHeader()->setVisible(false);
        twPreview->verticalHeader()->setVisible(false);

        horizontalLayout_3->addWidget(splitter);


        gridLayout->addLayout(horizontalLayout_3, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(MatioOptionsWidget);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 2, 1, 1);

        sbPreviewLines = new QSpinBox(MatioOptionsWidget);
        sbPreviewLines->setObjectName("sbPreviewLines");
        sbPreviewLines->setMinimum(1);
        sbPreviewLines->setMaximum(10000);
        sbPreviewLines->setValue(100);

        gridLayout_2->addWidget(sbPreviewLines, 0, 1, 1, 1);


        horizontalLayout->addLayout(gridLayout_2);

        bRefreshPreview = new QPushButton(MatioOptionsWidget);
        bRefreshPreview->setObjectName("bRefreshPreview");

        horizontalLayout->addWidget(bRefreshPreview);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);


        retranslateUi(MatioOptionsWidget);

        QMetaObject::connectSlotsByName(MatioOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *MatioOptionsWidget)
    {
        QTableWidgetItem *___qtablewidgetitem = twContent->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Variable", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = twContent->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Rank", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = twContent->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Dims", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = twContent->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("Class", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = twContent->horizontalHeaderItem(4);
        ___qtablewidgetitem4->setText(tr2i18n("Type", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = twContent->horizontalHeaderItem(5);
        ___qtablewidgetitem5->setText(tr2i18n("Complex", nullptr));
        QTableWidgetItem *___qtablewidgetitem6 = twContent->horizontalHeaderItem(6);
        ___qtablewidgetitem6->setText(tr2i18n("Logical", nullptr));
#if QT_CONFIG(tooltip)
        twContent->setToolTip(tr2i18n("Shows the content of the selected NetCDF file", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Number of rows to preview:", nullptr));
        bRefreshPreview->setText(tr2i18n("Refresh", nullptr));
        (void)MatioOptionsWidget;
    } // retranslateUi

};

namespace Ui {
    class MatioOptionsWidget: public Ui_MatioOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MATIOOPTIONSWIDGET_H

