/****************************************************************************
** Meta object code from reading C++ file 'DatapickerPoint.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/datapicker/DatapickerPoint.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DatapickerPoint.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ErrorBarItemE_t {};
} // unnamed namespace

template <> constexpr inline auto ErrorBarItem::qt_create_metaobjectdata<qt_meta_tag_ZN12ErrorBarItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ErrorBarItem",
        "setPosition",
        "",
        "QPointF"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setPosition'
        QtMocHelpers::SlotData<void(QPointF)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ErrorBarItem, qt_meta_tag_ZN12ErrorBarItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ErrorBarItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ErrorBarItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ErrorBarItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ErrorBarItemE_t>.metaTypes,
    nullptr
} };

void ErrorBarItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ErrorBarItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setPosition((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *ErrorBarItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ErrorBarItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ErrorBarItemE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QGraphicsRectItem"))
        return static_cast< QGraphicsRectItem*>(this);
    return QObject::qt_metacast(_clname);
}

int ErrorBarItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN15DatapickerPointE_t {};
} // unnamed namespace

template <> constexpr inline auto DatapickerPoint::qt_create_metaobjectdata<qt_meta_tag_ZN15DatapickerPointE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DatapickerPoint",
        "dataChanged",
        "",
        "const DatapickerPoint*",
        "positionChanged",
        "QPointF",
        "plusDeltaXPosChanged",
        "minusDeltaXPosChanged",
        "plusDeltaYPosChanged",
        "minusDeltaYPosChanged",
        "pointSelected",
        "retransform"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void(const DatapickerPoint *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(QPointF)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'plusDeltaXPosChanged'
        QtMocHelpers::SignalData<void(QPointF)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'minusDeltaXPosChanged'
        QtMocHelpers::SignalData<void(QPointF)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'plusDeltaYPosChanged'
        QtMocHelpers::SignalData<void(QPointF)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'minusDeltaYPosChanged'
        QtMocHelpers::SignalData<void(QPointF)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'pointSelected'
        QtMocHelpers::SignalData<void(const DatapickerPoint *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'retransform'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DatapickerPoint, qt_meta_tag_ZN15DatapickerPointE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DatapickerPoint::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractAspect::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DatapickerPointE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DatapickerPointE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DatapickerPointE_t>.metaTypes,
    nullptr
} };

void DatapickerPoint::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DatapickerPoint *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataChanged((*reinterpret_cast<std::add_pointer_t<const DatapickerPoint*>>(_a[1]))); break;
        case 1: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 2: _t->plusDeltaXPosChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 3: _t->minusDeltaXPosChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 4: _t->plusDeltaYPosChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 5: _t->minusDeltaYPosChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 6: _t->pointSelected((*reinterpret_cast<std::add_pointer_t<const DatapickerPoint*>>(_a[1]))); break;
        case 7: _t->retransform(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DatapickerPoint::*)(const DatapickerPoint * )>(_a, &DatapickerPoint::dataChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerPoint::*)(QPointF )>(_a, &DatapickerPoint::positionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerPoint::*)(QPointF )>(_a, &DatapickerPoint::plusDeltaXPosChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerPoint::*)(QPointF )>(_a, &DatapickerPoint::minusDeltaXPosChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerPoint::*)(QPointF )>(_a, &DatapickerPoint::plusDeltaYPosChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerPoint::*)(QPointF )>(_a, &DatapickerPoint::minusDeltaYPosChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerPoint::*)(const DatapickerPoint * )>(_a, &DatapickerPoint::pointSelected, 6))
            return;
    }
}

const QMetaObject *DatapickerPoint::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DatapickerPoint::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DatapickerPointE_t>.strings))
        return static_cast<void*>(this);
    return AbstractAspect::qt_metacast(_clname);
}

int DatapickerPoint::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractAspect::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void DatapickerPoint::dataChanged(const DatapickerPoint * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DatapickerPoint::positionChanged(QPointF _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DatapickerPoint::plusDeltaXPosChanged(QPointF _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DatapickerPoint::minusDeltaXPosChanged(QPointF _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DatapickerPoint::plusDeltaYPosChanged(QPointF _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DatapickerPoint::minusDeltaYPosChanged(QPointF _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DatapickerPoint::pointSelected(const DatapickerPoint * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
