/********************************************************************************
** Form generated from reading UI file 'randomvalueswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RANDOMVALUESWIDGET_H
#define UI_RANDOMVALUESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RandomValuesWidget
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer_2;
    QLineEdit *leParameter2;
    QLabel *lParameter2;
    QLabel *lFunc;
    QLineEdit *leParameter1;
    QLabel *lFuncPic;
    QLabel *lParameter1;
    QLabel *lDistribution;
    QLabel *lParameter3;
    QLineEdit *leParameter3;
    QSpacerItem *verticalSpacer;
    QComboBox *cbDistribution;
    QLabel *lSeed;
    QLineEdit *leSeed;

    void setupUi(QWidget *RandomValuesWidget)
    {
        if (RandomValuesWidget->objectName().isEmpty())
            RandomValuesWidget->setObjectName("RandomValuesWidget");
        RandomValuesWidget->resize(469, 301);
        gridLayout = new QGridLayout(RandomValuesWidget);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer_2 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 5, 0, 1, 1);

        leParameter2 = new QLineEdit(RandomValuesWidget);
        leParameter2->setObjectName("leParameter2");

        gridLayout->addWidget(leParameter2, 3, 1, 1, 1);

        lParameter2 = new QLabel(RandomValuesWidget);
        lParameter2->setObjectName("lParameter2");
        QFont font;
        font.setBold(true);
        lParameter2->setFont(font);
        lParameter2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lParameter2, 3, 0, 1, 1);

        lFunc = new QLabel(RandomValuesWidget);
        lFunc->setObjectName("lFunc");
        lFunc->setFont(font);
        lFunc->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lFunc, 1, 0, 1, 1);

        leParameter1 = new QLineEdit(RandomValuesWidget);
        leParameter1->setObjectName("leParameter1");

        gridLayout->addWidget(leParameter1, 2, 1, 1, 1);

        lFuncPic = new QLabel(RandomValuesWidget);
        lFuncPic->setObjectName("lFuncPic");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lFuncPic->sizePolicy().hasHeightForWidth());
        lFuncPic->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lFuncPic, 1, 1, 1, 1);

        lParameter1 = new QLabel(RandomValuesWidget);
        lParameter1->setObjectName("lParameter1");
        lParameter1->setFont(font);
        lParameter1->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lParameter1, 2, 0, 1, 1);

        lDistribution = new QLabel(RandomValuesWidget);
        lDistribution->setObjectName("lDistribution");

        gridLayout->addWidget(lDistribution, 0, 0, 1, 1);

        lParameter3 = new QLabel(RandomValuesWidget);
        lParameter3->setObjectName("lParameter3");
        lParameter3->setFont(font);
        lParameter3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lParameter3, 4, 0, 1, 1);

        leParameter3 = new QLineEdit(RandomValuesWidget);
        leParameter3->setObjectName("leParameter3");

        gridLayout->addWidget(leParameter3, 4, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 45, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 7, 0, 1, 1);

        cbDistribution = new QComboBox(RandomValuesWidget);
        cbDistribution->setObjectName("cbDistribution");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbDistribution->sizePolicy().hasHeightForWidth());
        cbDistribution->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbDistribution, 0, 1, 1, 1);

        lSeed = new QLabel(RandomValuesWidget);
        lSeed->setObjectName("lSeed");

        gridLayout->addWidget(lSeed, 6, 0, 1, 1);

        leSeed = new QLineEdit(RandomValuesWidget);
        leSeed->setObjectName("leSeed");

        gridLayout->addWidget(leSeed, 6, 1, 1, 1);

        QWidget::setTabOrder(cbDistribution, leParameter1);
        QWidget::setTabOrder(leParameter1, leParameter2);
        QWidget::setTabOrder(leParameter2, leParameter3);
        QWidget::setTabOrder(leParameter3, leSeed);

        retranslateUi(RandomValuesWidget);

        QMetaObject::connectSlotsByName(RandomValuesWidget);
    } // setupUi

    void retranslateUi(QWidget *RandomValuesWidget)
    {
        lParameter2->setText(tr2i18n("2:", nullptr));
        lFunc->setText(tr2i18n("p(x)", nullptr));
        lFuncPic->setText(QString());
        lParameter1->setText(tr2i18n("1:", nullptr));
        lDistribution->setText(tr2i18n("Distribution:", nullptr));
        lParameter3->setText(tr2i18n("3:", nullptr));
        leParameter3->setText(QString());
#if QT_CONFIG(tooltip)
        cbDistribution->setToolTip(tr2i18n("<html><head/><body><p>Random number distributions as defined in <a href=\"https://www.gnu.org/software/gsl/doc/html/randist.html\"><span style=\" text-decoration: underline; color:#2980b9;\">GSL documentation</span></a></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        lSeed->setText(tr2i18n("Seed:", nullptr));
        (void)RandomValuesWidget;
    } // retranslateUi

};

namespace Ui {
    class RandomValuesWidget: public Ui_RandomValuesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RANDOMVALUESWIDGET_H

