/********************************************************************************
** Form generated from reading UI file 'rootoptionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ROOTOPTIONSWIDGET_H
#define UI_ROOTOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ROOTOptionsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QSplitter *splitter;
    QTreeWidget *twContent;
    QWidget *vlSelectiontWidget;
    QVBoxLayout *vlSelection;
    QTreeWidget *twColumns;
    QHBoxLayout *horizontalLayout;
    QLabel *labelFirst;
    QSpinBox *sbFirst;
    QLabel *labelLast;
    QSpinBox *sbLast;
    QWidget *vlPreviewWidget;
    QVBoxLayout *vlPreview;
    QHBoxLayout *hlPreviewSetup;
    QLabel *labelPreview;
    QSpinBox *sbPreviewLines;
    QSpacerItem *horizontalSpacer;
    QPushButton *bRefreshPreview;
    QTableWidget *twPreview;
    QHBoxLayout *hlPreview;

    void setupUi(QWidget *ROOTOptionsWidget)
    {
        if (ROOTOptionsWidget->objectName().isEmpty())
            ROOTOptionsWidget->setObjectName("ROOTOptionsWidget");
        ROOTOptionsWidget->resize(913, 242);
        verticalLayout = new QVBoxLayout(ROOTOptionsWidget);
        verticalLayout->setObjectName("verticalLayout");
        splitter = new QSplitter(ROOTOptionsWidget);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        splitter->setChildrenCollapsible(false);
        twContent = new QTreeWidget(splitter);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        twContent->setHeaderItem(__qtreewidgetitem);
        twContent->setObjectName("twContent");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(twContent->sizePolicy().hasHeightForWidth());
        twContent->setSizePolicy(sizePolicy);
        twContent->setSelectionMode(QAbstractItemView::SingleSelection);
        splitter->addWidget(twContent);
        twContent->header()->setVisible(false);
        vlSelectiontWidget = new QWidget(splitter);
        vlSelectiontWidget->setObjectName("vlSelectiontWidget");
        vlSelection = new QVBoxLayout(vlSelectiontWidget);
        vlSelection->setObjectName("vlSelection");
        vlSelection->setContentsMargins(0, 0, 0, 0);
        twColumns = new QTreeWidget(vlSelectiontWidget);
        QTreeWidgetItem *__qtreewidgetitem1 = new QTreeWidgetItem();
        __qtreewidgetitem1->setText(0, QString::fromUtf8("1"));
        twColumns->setHeaderItem(__qtreewidgetitem1);
        twColumns->setObjectName("twColumns");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(twColumns->sizePolicy().hasHeightForWidth());
        twColumns->setSizePolicy(sizePolicy1);
        twColumns->setSelectionMode(QAbstractItemView::MultiSelection);
        twColumns->header()->setVisible(false);

        vlSelection->addWidget(twColumns);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        labelFirst = new QLabel(vlSelectiontWidget);
        labelFirst->setObjectName("labelFirst");

        horizontalLayout->addWidget(labelFirst);

        sbFirst = new QSpinBox(vlSelectiontWidget);
        sbFirst->setObjectName("sbFirst");
        sbFirst->setMaximum(100);
        sbFirst->setValue(1);

        horizontalLayout->addWidget(sbFirst);

        labelLast = new QLabel(vlSelectiontWidget);
        labelLast->setObjectName("labelLast");

        horizontalLayout->addWidget(labelLast);

        sbLast = new QSpinBox(vlSelectiontWidget);
        sbLast->setObjectName("sbLast");
        sbLast->setMaximum(100);
        sbLast->setValue(99);

        horizontalLayout->addWidget(sbLast);


        vlSelection->addLayout(horizontalLayout);

        splitter->addWidget(vlSelectiontWidget);
        vlPreviewWidget = new QWidget(splitter);
        vlPreviewWidget->setObjectName("vlPreviewWidget");
        vlPreview = new QVBoxLayout(vlPreviewWidget);
        vlPreview->setObjectName("vlPreview");
        vlPreview->setContentsMargins(0, 0, 0, 0);
        hlPreviewSetup = new QHBoxLayout();
        hlPreviewSetup->setObjectName("hlPreviewSetup");
        labelPreview = new QLabel(vlPreviewWidget);
        labelPreview->setObjectName("labelPreview");

        hlPreviewSetup->addWidget(labelPreview);

        sbPreviewLines = new QSpinBox(vlPreviewWidget);
        sbPreviewLines->setObjectName("sbPreviewLines");
        sbPreviewLines->setMinimum(1);
        sbPreviewLines->setMaximum(10000);
        sbPreviewLines->setValue(100);

        hlPreviewSetup->addWidget(sbPreviewLines);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hlPreviewSetup->addItem(horizontalSpacer);

        bRefreshPreview = new QPushButton(vlPreviewWidget);
        bRefreshPreview->setObjectName("bRefreshPreview");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("view-refresh");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        bRefreshPreview->setIcon(icon);

        hlPreviewSetup->addWidget(bRefreshPreview);


        vlPreview->addLayout(hlPreviewSetup);

        twPreview = new QTableWidget(vlPreviewWidget);
        twPreview->setObjectName("twPreview");
        sizePolicy1.setHeightForWidth(twPreview->sizePolicy().hasHeightForWidth());
        twPreview->setSizePolicy(sizePolicy1);
        twPreview->setEditTriggers(QAbstractItemView::NoEditTriggers);
        twPreview->horizontalHeader()->setVisible(true);
        twPreview->verticalHeader()->setVisible(false);

        vlPreview->addWidget(twPreview);

        vlPreview->setStretch(0, 5);
        splitter->addWidget(vlPreviewWidget);

        verticalLayout->addWidget(splitter);

        hlPreview = new QHBoxLayout();
        hlPreview->setObjectName("hlPreview");

        verticalLayout->addLayout(hlPreview);


        retranslateUi(ROOTOptionsWidget);

        QMetaObject::connectSlotsByName(ROOTOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *ROOTOptionsWidget)
    {
#if QT_CONFIG(tooltip)
        twContent->setToolTip(tr2i18n("Shows the content of the selected ROOT file", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFirst->setText(tr2i18n("First row:", nullptr));
        labelLast->setText(tr2i18n("Last row:", nullptr));
        labelPreview->setText(tr2i18n("Number of rows to preview:", nullptr));
        bRefreshPreview->setText(tr2i18n("Refresh", nullptr));
        (void)ROOTOptionsWidget;
    } // retranslateUi

};

namespace Ui {
    class ROOTOptionsWidget: public Ui_ROOTOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ROOTOPTIONSWIDGET_H

