/********************************************************************************
** Form generated from reading UI file 'imageoptionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMAGEOPTIONSWIDGET_H
#define UI_IMAGEOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ImageOptionsWidget
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;
    QLabel *lImportFormat;
    QSpacerItem *horizontalSpacer;
    QComboBox *cbImportFormat;

    void setupUi(QWidget *ImageOptionsWidget)
    {
        if (ImageOptionsWidget->objectName().isEmpty())
            ImageOptionsWidget->setObjectName("ImageOptionsWidget");
        ImageOptionsWidget->resize(289, 177);
        gridLayout = new QGridLayout(ImageOptionsWidget);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer = new QSpacerItem(20, 74, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);

        lImportFormat = new QLabel(ImageOptionsWidget);
        lImportFormat->setObjectName("lImportFormat");

        gridLayout->addWidget(lImportFormat, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(80, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        cbImportFormat = new QComboBox(ImageOptionsWidget);
        cbImportFormat->setObjectName("cbImportFormat");

        gridLayout->addWidget(cbImportFormat, 0, 1, 1, 1);


        retranslateUi(ImageOptionsWidget);

        QMetaObject::connectSlotsByName(ImageOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *ImageOptionsWidget)
    {
        lImportFormat->setText(tr2i18n("Import as:", nullptr));
#if QT_CONFIG(tooltip)
        cbImportFormat->setToolTip(tr2i18n("Choose how to import the image", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)ImageOptionsWidget;
    } // retranslateUi

};

namespace Ui {
    class ImageOptionsWidget: public Ui_ImageOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMAGEOPTIONSWIDGET_H

