/****************************************************************************
** Meta object code from reading C++ file 'AbstractAspect.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/core/AbstractAspect.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbstractAspect.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14AbstractAspectE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractAspect::qt_create_metaobjectdata<qt_meta_tag_ZN14AbstractAspectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractAspect",
        "aspectDescriptionAboutToChange",
        "",
        "const AbstractAspect*",
        "aspectDescriptionChanged",
        "childAspectAboutToBeAdded",
        "parent",
        "index",
        "child",
        "before",
        "childAspectAdded",
        "childAspectAboutToBeRemoved",
        "childAspectRemoved",
        "aspectAboutToBeRemoved",
        "childAspectAboutToBeMoved",
        "destinationRow",
        "childAspectMoved",
        "aspectHiddenAboutToChange",
        "aspectHiddenChanged",
        "statusInfo",
        "renameRequested",
        "contextMenuRequested",
        "AspectType",
        "QMenu*",
        "selected",
        "deselected",
        "childAspectSelectedInView",
        "childAspectDeselectedInView",
        "retransformCalledSignal",
        "sender",
        "suppressed",
        "setName",
        "NameHandling",
        "handling",
        "QUndoCommand*",
        "setComment",
        "remove",
        "copy",
        "duplicate",
        "paste",
        "moveUp",
        "moveDown",
        "childSelected",
        "childDeselected"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'aspectDescriptionAboutToChange'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'aspectDescriptionChanged'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'childAspectAboutToBeAdded'
        QtMocHelpers::SignalData<void(const AbstractAspect *, int, const AbstractAspect *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 6 }, { QMetaType::Int, 7 }, { 0x80000000 | 3, 8 },
        }}),
        // Signal 'childAspectAboutToBeAdded'
        QtMocHelpers::SignalData<void(const AbstractAspect *, const AbstractAspect *, const AbstractAspect *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 6 }, { 0x80000000 | 3, 9 }, { 0x80000000 | 3, 8 },
        }}),
        // Signal 'childAspectAdded'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'childAspectAboutToBeRemoved'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 8 },
        }}),
        // Signal 'childAspectRemoved'
        QtMocHelpers::SignalData<void(const AbstractAspect *, const AbstractAspect *, const AbstractAspect *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 6 }, { 0x80000000 | 3, 9 }, { 0x80000000 | 3, 8 },
        }}),
        // Signal 'aspectAboutToBeRemoved'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'childAspectAboutToBeMoved'
        QtMocHelpers::SignalData<void(const AbstractAspect *, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Int, 15 },
        }}),
        // Signal 'childAspectMoved'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aspectHiddenAboutToChange'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'aspectHiddenChanged'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'statusInfo'
        QtMocHelpers::SignalData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'renameRequested'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contextMenuRequested'
        QtMocHelpers::SignalData<void(AspectType, QMenu *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 2 }, { 0x80000000 | 23, 2 },
        }}),
        // Signal 'selected'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'deselected'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'childAspectSelectedInView'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'childAspectDeselectedInView'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'retransformCalledSignal'
        QtMocHelpers::SignalData<void(const AbstractAspect *, bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 29 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'setName'
        QtMocHelpers::SlotData<bool(const QString &, enum NameHandling, QUndoCommand *)>(31, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 32, 33 }, { 0x80000000 | 34, 6 },
        }}),
        // Slot 'setName'
        QtMocHelpers::SlotData<bool(const QString &, enum NameHandling)>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 32, 33 },
        }}),
        // Slot 'setName'
        QtMocHelpers::SlotData<bool(const QString &)>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'setComment'
        QtMocHelpers::SlotData<void(const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'duplicate'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paste'
        QtMocHelpers::SlotData<void(bool, int)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'paste'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'paste'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'moveUp'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveDown'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'childSelected'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(42, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'childDeselected'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(43, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractAspect, qt_meta_tag_ZN14AbstractAspectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractAspect::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AbstractAspectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AbstractAspectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AbstractAspectE_t>.metaTypes,
    nullptr
} };

void AbstractAspect::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractAspect *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->aspectDescriptionAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 1: _t->aspectDescriptionChanged((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 2: _t->childAspectAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[3]))); break;
        case 3: _t->childAspectAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[3]))); break;
        case 4: _t->childAspectAdded((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 5: _t->childAspectAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 6: _t->childAspectRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[3]))); break;
        case 7: _t->aspectAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 8: _t->childAspectAboutToBeMoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->childAspectMoved(); break;
        case 10: _t->aspectHiddenAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 11: _t->aspectHiddenChanged((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 12: _t->statusInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->renameRequested(); break;
        case 14: _t->contextMenuRequested((*reinterpret_cast<std::add_pointer_t<AspectType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2]))); break;
        case 15: _t->selected((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 16: _t->deselected((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 17: _t->childAspectSelectedInView((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 18: _t->childAspectDeselectedInView((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 19: _t->retransformCalledSignal((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 20: { bool _r = _t->setName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum NameHandling>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUndoCommand*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->setName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum NameHandling>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->setName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->setComment((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->remove(); break;
        case 25: _t->copy(); break;
        case 26: _t->duplicate(); break;
        case 27: _t->paste((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 28: _t->paste((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->paste(); break;
        case 30: _t->moveUp(); break;
        case 31: _t->moveDown(); break;
        case 32: _t->childSelected((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 33: _t->childDeselected((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * )>(_a, &AbstractAspect::aspectDescriptionAboutToChange, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * )>(_a, &AbstractAspect::aspectDescriptionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * , int , const AbstractAspect * )>(_a, &AbstractAspect::childAspectAboutToBeAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * , const AbstractAspect * , const AbstractAspect * )>(_a, &AbstractAspect::childAspectAboutToBeAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * )>(_a, &AbstractAspect::childAspectAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * )>(_a, &AbstractAspect::childAspectAboutToBeRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * , const AbstractAspect * , const AbstractAspect * )>(_a, &AbstractAspect::childAspectRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * )>(_a, &AbstractAspect::aspectAboutToBeRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * , int )>(_a, &AbstractAspect::childAspectAboutToBeMoved, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)()>(_a, &AbstractAspect::childAspectMoved, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * )>(_a, &AbstractAspect::aspectHiddenAboutToChange, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * )>(_a, &AbstractAspect::aspectHiddenChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const QString & )>(_a, &AbstractAspect::statusInfo, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)()>(_a, &AbstractAspect::renameRequested, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(AspectType , QMenu * )>(_a, &AbstractAspect::contextMenuRequested, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * )>(_a, &AbstractAspect::selected, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * )>(_a, &AbstractAspect::deselected, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * )>(_a, &AbstractAspect::childAspectSelectedInView, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * )>(_a, &AbstractAspect::childAspectDeselectedInView, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAspect::*)(const AbstractAspect * , bool )>(_a, &AbstractAspect::retransformCalledSignal, 19))
            return;
    }
}

const QMetaObject *AbstractAspect::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractAspect::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AbstractAspectE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractAspect::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 34;
    }
    return _id;
}

// SIGNAL 0
void AbstractAspect::aspectDescriptionAboutToChange(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractAspect::aspectDescriptionChanged(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AbstractAspect::childAspectAboutToBeAdded(const AbstractAspect * _t1, int _t2, const AbstractAspect * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void AbstractAspect::childAspectAboutToBeAdded(const AbstractAspect * _t1, const AbstractAspect * _t2, const AbstractAspect * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void AbstractAspect::childAspectAdded(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AbstractAspect::childAspectAboutToBeRemoved(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void AbstractAspect::childAspectRemoved(const AbstractAspect * _t1, const AbstractAspect * _t2, const AbstractAspect * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void AbstractAspect::aspectAboutToBeRemoved(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void AbstractAspect::childAspectAboutToBeMoved(const AbstractAspect * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void AbstractAspect::childAspectMoved()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void AbstractAspect::aspectHiddenAboutToChange(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void AbstractAspect::aspectHiddenChanged(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void AbstractAspect::statusInfo(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void AbstractAspect::renameRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void AbstractAspect::contextMenuRequested(AspectType _t1, QMenu * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void AbstractAspect::selected(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void AbstractAspect::deselected(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void AbstractAspect::childAspectSelectedInView(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void AbstractAspect::childAspectDeselectedInView(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void AbstractAspect::retransformCalledSignal(const AbstractAspect * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}
QT_WARNING_POP
