/********************************************************************************
** Form generated from reading UI file 'worksheetdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WORKSHEETDOCK_H
#define UI_WORKSHEETDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_WorksheetDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    KComboBox *cbPage;
    QLabel *lHeight;
    QLabel *lName;
    QLabel *lGeometry;
    QLabel *lPage;
    KComboBox *cbOrientation;
    QSpacerItem *horizontalSpacer_5;
    QSpacerItem *verticalSpacer_3;
    QLabel *lOrientation;
    QLabel *lWidth;
    ResizableTextEdit *teComment;
    QSpacerItem *verticalSpacer;
    QLabel *lComment;
    TimedLineEdit *leName;
    QLabel *lScaleContent;
    QCheckBox *chScaleContent;
    QLabel *lSizeType;
    QComboBox *cbSizeType;
    NumberSpinBox *sbWidth;
    NumberSpinBox *sbHeight;
    QWidget *tabBackground;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer_2;
    QWidget *tabLayout;
    QGridLayout *gridLayout_3;
    QSpacerItem *verticalSpacer_5;
    QSpacerItem *verticalSpacer_6;
    QLabel *lLayout;
    QSpacerItem *verticalSpacer_7;
    QSpacerItem *horizontalSpacer_4;
    QLabel *lHorizontalSpacing;
    QLabel *lBottomMargin;
    QLabel *lMargin;
    QLabel *lRightMargin;
    QSpinBox *sbLayoutColumnCount;
    QComboBox *cbLayout;
    QSpinBox *sbLayoutRowCount;
    QLabel *lRowCount;
    QLabel *lTopMargin;
    QLabel *lLeftMargin;
    QLabel *lColumnCount;
    QLabel *lVerticalSpacing;
    QLabel *lGrid;
    QLabel *lSpacing;
    QSpacerItem *verticalSpacer_4;
    NumberSpinBox *sbLayoutBottomMargin;
    NumberSpinBox *sbLayoutTopMargin;
    NumberSpinBox *sbLayoutLeftMargin;
    NumberSpinBox *sbLayoutRightMargin;
    NumberSpinBox *sbLayoutHorizontalSpacing;
    NumberSpinBox *sbLayoutVerticalSpacing;

    void setupUi(QWidget *WorksheetDock)
    {
        if (WorksheetDock->objectName().isEmpty())
            WorksheetDock->setObjectName("WorksheetDock");
        WorksheetDock->resize(396, 583);
        verticalLayout = new QVBoxLayout(WorksheetDock);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(WorksheetDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setObjectName("gridLayout");
        cbPage = new KComboBox(tabGeneral);
        cbPage->setObjectName("cbPage");

        gridLayout->addWidget(cbPage, 5, 2, 1, 1);

        lHeight = new QLabel(tabGeneral);
        lHeight->setObjectName("lHeight");

        gridLayout->addWidget(lHeight, 8, 0, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lName->sizePolicy().hasHeightForWidth());
        lName->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        lGeometry = new QLabel(tabGeneral);
        lGeometry->setObjectName("lGeometry");
        QFont font;
        font.setBold(true);
        lGeometry->setFont(font);

        gridLayout->addWidget(lGeometry, 3, 0, 1, 1);

        lPage = new QLabel(tabGeneral);
        lPage->setObjectName("lPage");

        gridLayout->addWidget(lPage, 5, 0, 1, 1);

        cbOrientation = new KComboBox(tabGeneral);
        cbOrientation->setObjectName("cbOrientation");

        gridLayout->addWidget(cbOrientation, 6, 2, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(58, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 2, 0, 1, 1);

        lOrientation = new QLabel(tabGeneral);
        lOrientation->setObjectName("lOrientation");

        gridLayout->addWidget(lOrientation, 6, 0, 1, 1);

        lWidth = new QLabel(tabGeneral);
        lWidth->setObjectName("lWidth");

        gridLayout->addWidget(lWidth, 7, 0, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(teComment->sizePolicy().hasHeightForWidth());
        teComment->setSizePolicy(sizePolicy1);
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        verticalSpacer = new QSpacerItem(24, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 10, 0, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        sizePolicy.setHeightForWidth(lComment->sizePolicy().hasHeightForWidth());
        lComment->setSizePolicy(sizePolicy);
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        lScaleContent = new QLabel(tabGeneral);
        lScaleContent->setObjectName("lScaleContent");

        gridLayout->addWidget(lScaleContent, 9, 0, 1, 1);

        chScaleContent = new QCheckBox(tabGeneral);
        chScaleContent->setObjectName("chScaleContent");

        gridLayout->addWidget(chScaleContent, 9, 2, 1, 1);

        lSizeType = new QLabel(tabGeneral);
        lSizeType->setObjectName("lSizeType");

        gridLayout->addWidget(lSizeType, 4, 0, 1, 1);

        cbSizeType = new QComboBox(tabGeneral);
        cbSizeType->setObjectName("cbSizeType");

        gridLayout->addWidget(cbSizeType, 4, 2, 1, 1);

        sbWidth = new NumberSpinBox(tabGeneral);
        sbWidth->setObjectName("sbWidth");
        sbWidth->setMinimum(0.000000000000000);
        sbWidth->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbWidth, 7, 2, 1, 1);

        sbHeight = new NumberSpinBox(tabGeneral);
        sbHeight->setObjectName("sbHeight");
        sbHeight->setMinimum(0.000000000000000);
        sbHeight->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbHeight, 8, 2, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabBackground = new QWidget();
        tabBackground->setObjectName("tabBackground");
        verticalLayout_2 = new QVBoxLayout(tabBackground);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(2, 2, 2, 2);
        verticalSpacer_2 = new QSpacerItem(24, 238, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        tabWidget->addTab(tabBackground, QString());
        tabLayout = new QWidget();
        tabLayout->setObjectName("tabLayout");
        gridLayout_3 = new QGridLayout(tabLayout);
        gridLayout_3->setObjectName("gridLayout_3");
        verticalSpacer_5 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_5, 7, 0, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_6, 11, 0, 1, 1);

        lLayout = new QLabel(tabLayout);
        lLayout->setObjectName("lLayout");

        gridLayout_3->addWidget(lLayout, 0, 0, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_7, 1, 0, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_4, 3, 1, 1, 1);

        lHorizontalSpacing = new QLabel(tabLayout);
        lHorizontalSpacing->setObjectName("lHorizontalSpacing");

        gridLayout_3->addWidget(lHorizontalSpacing, 9, 0, 1, 1);

        lBottomMargin = new QLabel(tabLayout);
        lBottomMargin->setObjectName("lBottomMargin");

        gridLayout_3->addWidget(lBottomMargin, 4, 0, 1, 1);

        lMargin = new QLabel(tabLayout);
        lMargin->setObjectName("lMargin");
        lMargin->setFont(font);

        gridLayout_3->addWidget(lMargin, 2, 0, 1, 1);

        lRightMargin = new QLabel(tabLayout);
        lRightMargin->setObjectName("lRightMargin");

        gridLayout_3->addWidget(lRightMargin, 6, 0, 1, 1);

        sbLayoutColumnCount = new QSpinBox(tabLayout);
        sbLayoutColumnCount->setObjectName("sbLayoutColumnCount");
        sbLayoutColumnCount->setMinimum(1);

        gridLayout_3->addWidget(sbLayoutColumnCount, 14, 3, 1, 1);

        cbLayout = new QComboBox(tabLayout);
        cbLayout->setObjectName("cbLayout");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cbLayout->sizePolicy().hasHeightForWidth());
        cbLayout->setSizePolicy(sizePolicy2);

        gridLayout_3->addWidget(cbLayout, 0, 3, 1, 1);

        sbLayoutRowCount = new QSpinBox(tabLayout);
        sbLayoutRowCount->setObjectName("sbLayoutRowCount");
        sbLayoutRowCount->setMinimum(1);

        gridLayout_3->addWidget(sbLayoutRowCount, 13, 3, 1, 1);

        lRowCount = new QLabel(tabLayout);
        lRowCount->setObjectName("lRowCount");

        gridLayout_3->addWidget(lRowCount, 13, 0, 1, 1);

        lTopMargin = new QLabel(tabLayout);
        lTopMargin->setObjectName("lTopMargin");

        gridLayout_3->addWidget(lTopMargin, 3, 0, 1, 1);

        lLeftMargin = new QLabel(tabLayout);
        lLeftMargin->setObjectName("lLeftMargin");

        gridLayout_3->addWidget(lLeftMargin, 5, 0, 1, 1);

        lColumnCount = new QLabel(tabLayout);
        lColumnCount->setObjectName("lColumnCount");

        gridLayout_3->addWidget(lColumnCount, 14, 0, 1, 1);

        lVerticalSpacing = new QLabel(tabLayout);
        lVerticalSpacing->setObjectName("lVerticalSpacing");

        gridLayout_3->addWidget(lVerticalSpacing, 10, 0, 1, 1);

        lGrid = new QLabel(tabLayout);
        lGrid->setObjectName("lGrid");
        lGrid->setFont(font);

        gridLayout_3->addWidget(lGrid, 12, 0, 1, 1);

        lSpacing = new QLabel(tabLayout);
        lSpacing->setObjectName("lSpacing");
        lSpacing->setFont(font);

        gridLayout_3->addWidget(lSpacing, 8, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(24, 284, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_4, 15, 0, 1, 1);

        sbLayoutBottomMargin = new NumberSpinBox(tabLayout);
        sbLayoutBottomMargin->setObjectName("sbLayoutBottomMargin");
        sbLayoutBottomMargin->setMinimum(0.000000000000000);
        sbLayoutBottomMargin->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbLayoutBottomMargin, 4, 3, 1, 1);

        sbLayoutTopMargin = new NumberSpinBox(tabLayout);
        sbLayoutTopMargin->setObjectName("sbLayoutTopMargin");
        sbLayoutTopMargin->setMinimum(0.000000000000000);
        sbLayoutTopMargin->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbLayoutTopMargin, 3, 3, 1, 1);

        sbLayoutLeftMargin = new NumberSpinBox(tabLayout);
        sbLayoutLeftMargin->setObjectName("sbLayoutLeftMargin");
        sbLayoutLeftMargin->setMinimum(0.000000000000000);
        sbLayoutLeftMargin->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbLayoutLeftMargin, 5, 3, 1, 1);

        sbLayoutRightMargin = new NumberSpinBox(tabLayout);
        sbLayoutRightMargin->setObjectName("sbLayoutRightMargin");
        sbLayoutRightMargin->setMinimum(0.000000000000000);
        sbLayoutRightMargin->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbLayoutRightMargin, 6, 3, 1, 1);

        sbLayoutHorizontalSpacing = new NumberSpinBox(tabLayout);
        sbLayoutHorizontalSpacing->setObjectName("sbLayoutHorizontalSpacing");
        sbLayoutHorizontalSpacing->setMinimum(0.000000000000000);
        sbLayoutHorizontalSpacing->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbLayoutHorizontalSpacing, 9, 3, 1, 1);

        sbLayoutVerticalSpacing = new NumberSpinBox(tabLayout);
        sbLayoutVerticalSpacing->setObjectName("sbLayoutVerticalSpacing");
        sbLayoutVerticalSpacing->setMinimum(0.000000000000000);
        sbLayoutVerticalSpacing->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbLayoutVerticalSpacing, 10, 3, 1, 1);

        tabWidget->addTab(tabLayout, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbSizeType);
        QWidget::setTabOrder(cbSizeType, cbPage);
        QWidget::setTabOrder(cbPage, cbOrientation);
        QWidget::setTabOrder(cbOrientation, sbWidth);
        QWidget::setTabOrder(sbWidth, sbHeight);
        QWidget::setTabOrder(sbHeight, chScaleContent);
        QWidget::setTabOrder(chScaleContent, cbLayout);
        QWidget::setTabOrder(cbLayout, sbLayoutTopMargin);
        QWidget::setTabOrder(sbLayoutTopMargin, sbLayoutBottomMargin);
        QWidget::setTabOrder(sbLayoutBottomMargin, sbLayoutLeftMargin);
        QWidget::setTabOrder(sbLayoutLeftMargin, sbLayoutRightMargin);
        QWidget::setTabOrder(sbLayoutRightMargin, sbLayoutHorizontalSpacing);
        QWidget::setTabOrder(sbLayoutHorizontalSpacing, sbLayoutVerticalSpacing);
        QWidget::setTabOrder(sbLayoutVerticalSpacing, sbLayoutRowCount);
        QWidget::setTabOrder(sbLayoutRowCount, sbLayoutColumnCount);

        retranslateUi(WorksheetDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(WorksheetDock);
    } // setupUi

    void retranslateUi(QWidget *WorksheetDock)
    {
        lHeight->setText(tr2i18n("Height:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lGeometry->setText(tr2i18n("Geometry", nullptr));
        lPage->setText(tr2i18n("Page:", nullptr));
        lOrientation->setText(tr2i18n("Orientation:", nullptr));
        lWidth->setText(tr2i18n("Width:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lScaleContent->setText(tr2i18n("Scale content:", nullptr));
#if QT_CONFIG(tooltip)
        chScaleContent->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        chScaleContent->setText(QString());
        lSizeType->setText(tr2i18n("Size:", nullptr));
#if QT_CONFIG(tooltip)
        sbWidth->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbWidth->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbWidth->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        sbHeight->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbHeight->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbHeight->setSuffix(tr2i18n(" cm", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabBackground), tr2i18n("Background", nullptr));
        lLayout->setText(tr2i18n("Type:", nullptr));
        lHorizontalSpacing->setText(tr2i18n("Horizontal:", nullptr));
        lBottomMargin->setText(tr2i18n("Bottom:", nullptr));
        lMargin->setText(tr2i18n("Margins", nullptr));
        lRightMargin->setText(tr2i18n("Right:", nullptr));
        lRowCount->setText(tr2i18n("Rows:", nullptr));
        lTopMargin->setText(tr2i18n("Top:", nullptr));
        lLeftMargin->setText(tr2i18n("Left:", nullptr));
        lColumnCount->setText(tr2i18n("Columns:", nullptr));
        lVerticalSpacing->setText(tr2i18n("Vertical:", nullptr));
        lGrid->setText(tr2i18n("Grid", nullptr));
        lSpacing->setText(tr2i18n("Spacing", nullptr));
#if QT_CONFIG(tooltip)
        sbLayoutBottomMargin->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLayoutBottomMargin->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLayoutBottomMargin->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        sbLayoutTopMargin->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLayoutTopMargin->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLayoutTopMargin->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        sbLayoutLeftMargin->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLayoutLeftMargin->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLayoutLeftMargin->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        sbLayoutRightMargin->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLayoutRightMargin->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLayoutRightMargin->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        sbLayoutHorizontalSpacing->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLayoutHorizontalSpacing->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLayoutHorizontalSpacing->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        sbLayoutVerticalSpacing->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLayoutVerticalSpacing->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLayoutVerticalSpacing->setSuffix(tr2i18n(" cm", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabLayout), tr2i18n("Layout", nullptr));
        (void)WorksheetDock;
    } // retranslateUi

};

namespace Ui {
    class WorksheetDock: public Ui_WorksheetDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WORKSHEETDOCK_H

