/********************************************************************************
** Form generated from reading UI file 'referencelinedock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REFERENCELINEDOCK_H
#define UI_REFERENCELINEDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ReferenceLineDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    NumberSpinBox *sbPosition;
    QComboBox *cbPlotRanges;
    KComboBox *cbOrientation;
    QLabel *lPosition_2;
    UTCDateTimeEdit *dtePosition;
    TimedLineEdit *leName;
    QLabel *lPosition;
    QSpacerItem *verticalSpacer;
    QLabel *lComment;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_5;
    QLabel *lOrientation;
    QSpacerItem *verticalSpacer_4;
    QLabel *lName;
    ResizableTextEdit *teComment;
    QCheckBox *chkVisible;
    QLabel *lPositionDateTime;
    QLabel *lPlotRange;
    QCheckBox *chbLock;
    QWidget *tabLine;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *ReferenceLineDock)
    {
        if (ReferenceLineDock->objectName().isEmpty())
            ReferenceLineDock->setObjectName("ReferenceLineDock");
        ReferenceLineDock->resize(304, 560);
        verticalLayout = new QVBoxLayout(ReferenceLineDock);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(ReferenceLineDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(2, 2, 2, 2);
        sbPosition = new NumberSpinBox(tabGeneral);
        sbPosition->setObjectName("sbPosition");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(sbPosition->sizePolicy().hasHeightForWidth());
        sbPosition->setSizePolicy(sizePolicy);
        sbPosition->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPosition, 5, 2, 1, 1);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout->addWidget(cbPlotRanges, 8, 2, 1, 1);

        cbOrientation = new KComboBox(tabGeneral);
        cbOrientation->setObjectName("cbOrientation");

        gridLayout->addWidget(cbOrientation, 4, 2, 1, 1);

        lPosition_2 = new QLabel(tabGeneral);
        lPosition_2->setObjectName("lPosition_2");
        QFont font;
        font.setBold(true);
        lPosition_2->setFont(font);

        gridLayout->addWidget(lPosition_2, 3, 0, 1, 1);

        dtePosition = new UTCDateTimeEdit(tabGeneral);
        dtePosition->setObjectName("dtePosition");

        gridLayout->addWidget(dtePosition, 6, 2, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");
        sizePolicy.setHeightForWidth(leName->sizePolicy().hasHeightForWidth());
        leName->setSizePolicy(sizePolicy);

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        lPosition = new QLabel(tabGeneral);
        lPosition->setObjectName("lPosition");

        gridLayout->addWidget(lPosition, 5, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 694, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 9, 0, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 1, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_5, 2, 0, 1, 1);

        lOrientation = new QLabel(tabGeneral);
        lOrientation->setObjectName("lOrientation");

        gridLayout->addWidget(lOrientation, 4, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 7, 0, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lName->sizePolicy().hasHeightForWidth());
        lName->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(teComment->sizePolicy().hasHeightForWidth());
        teComment->setSizePolicy(sizePolicy2);
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");
        sizePolicy1.setHeightForWidth(chkVisible->sizePolicy().hasHeightForWidth());
        chkVisible->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(chkVisible, 11, 0, 1, 1);

        lPositionDateTime = new QLabel(tabGeneral);
        lPositionDateTime->setObjectName("lPositionDateTime");

        gridLayout->addWidget(lPositionDateTime, 6, 0, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(lPlotRange->sizePolicy().hasHeightForWidth());
        lPlotRange->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(lPlotRange, 8, 0, 1, 1);

        chbLock = new QCheckBox(tabGeneral);
        chbLock->setObjectName("chbLock");

        gridLayout->addWidget(chbLock, 10, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabLine = new QWidget();
        tabLine->setObjectName("tabLine");
        verticalLayout_2 = new QVBoxLayout(tabLine);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalSpacer_2 = new QSpacerItem(20, 496, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        tabWidget->addTab(tabLine, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbOrientation);
        QWidget::setTabOrder(cbOrientation, sbPosition);
        QWidget::setTabOrder(sbPosition, dtePosition);
        QWidget::setTabOrder(dtePosition, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chbLock);
        QWidget::setTabOrder(chbLock, chkVisible);

        retranslateUi(ReferenceLineDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ReferenceLineDock);
    } // setupUi

    void retranslateUi(QWidget *ReferenceLineDock)
    {
#if QT_CONFIG(tooltip)
        sbPosition->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPosition->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lPosition_2->setText(tr2i18n("Position", nullptr));
#if QT_CONFIG(tooltip)
        lPosition->setToolTip(tr2i18n("Horizontal position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
        lPosition->setText(tr2i18n("x:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lOrientation->setText(tr2i18n("Orientation:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lPositionDateTime->setText(tr2i18n("x:", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        chbLock->setText(tr2i18n("Locked", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabLine), tr2i18n("Line", nullptr));
        (void)ReferenceLineDock;
    } // retranslateUi

};

namespace Ui {
    class ReferenceLineDock: public Ui_ReferenceLineDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // REFERENCELINEDOCK_H

