/********************************************************************************
** Form generated from reading UI file 'settingsspreadsheetpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSSPREADSHEETPAGE_H
#define UI_SETTINGSSPREADSHEETPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SettingsSpreadsheetPage
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *lAppearance;
    QCheckBox *chkShowColumnType;
    QCheckBox *chkShowPlotDesignation;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SettingsSpreadsheetPage)
    {
        if (SettingsSpreadsheetPage->objectName().isEmpty())
            SettingsSpreadsheetPage->setObjectName("SettingsSpreadsheetPage");
        SettingsSpreadsheetPage->resize(400, 300);
        verticalLayout = new QVBoxLayout(SettingsSpreadsheetPage);
        verticalLayout->setObjectName("verticalLayout");
        lAppearance = new QLabel(SettingsSpreadsheetPage);
        lAppearance->setObjectName("lAppearance");
        QFont font;
        font.setBold(true);
        lAppearance->setFont(font);

        verticalLayout->addWidget(lAppearance);

        chkShowColumnType = new QCheckBox(SettingsSpreadsheetPage);
        chkShowColumnType->setObjectName("chkShowColumnType");

        verticalLayout->addWidget(chkShowColumnType);

        chkShowPlotDesignation = new QCheckBox(SettingsSpreadsheetPage);
        chkShowPlotDesignation->setObjectName("chkShowPlotDesignation");

        verticalLayout->addWidget(chkShowPlotDesignation);

        verticalSpacer = new QSpacerItem(20, 193, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(SettingsSpreadsheetPage);

        QMetaObject::connectSlotsByName(SettingsSpreadsheetPage);
    } // setupUi

    void retranslateUi(QWidget *SettingsSpreadsheetPage)
    {
        lAppearance->setText(tr2i18n("Header", nullptr));
        chkShowColumnType->setText(tr2i18n("Show column type", nullptr));
        chkShowPlotDesignation->setText(tr2i18n("Show plot designation", nullptr));
        (void)SettingsSpreadsheetPage;
    } // retranslateUi

};

namespace Ui {
    class SettingsSpreadsheetPage: public Ui_SettingsSpreadsheetPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGSSPREADSHEETPAGE_H

