/****************************************************************************
** Meta object code from reading C++ file 'AbstractFilter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/core/AbstractFilter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbstractFilter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14AbstractFilterE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractFilter::qt_create_metaobjectdata<qt_meta_tag_ZN14AbstractFilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractFilter",
        "inputDescriptionAboutToChange",
        "",
        "const AbstractColumn*",
        "source",
        "const AbstractAspect*",
        "aspect",
        "inputDescriptionChanged",
        "inputPlotDesignationAboutToChange",
        "inputPlotDesignationChanged",
        "inputModeAboutToChange",
        "inputModeChanged",
        "inputDataAboutToChange",
        "inputDataChanged",
        "inputRowsAboutToBeInserted",
        "before",
        "count",
        "inputRowsInserted",
        "inputRowsAboutToBeRemoved",
        "first",
        "inputRowsRemoved",
        "inputMaskingAboutToChange",
        "inputMaskingChanged",
        "inputAboutToBeDestroyed"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'inputDescriptionAboutToChange'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(1, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'inputDescriptionAboutToChange'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(1, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'inputDescriptionChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(7, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'inputDescriptionChanged'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(7, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'inputPlotDesignationAboutToChange'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(8, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'inputPlotDesignationChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(9, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'inputModeAboutToChange'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'inputModeChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'inputDataAboutToChange'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'inputDataChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'inputRowsAboutToBeInserted'
        QtMocHelpers::SlotData<void(const AbstractColumn *, int, int)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'inputRowsInserted'
        QtMocHelpers::SlotData<void(const AbstractColumn *, int, int)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'inputRowsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractColumn *, int, int)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 19 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'inputRowsRemoved'
        QtMocHelpers::SlotData<void(const AbstractColumn *, int, int)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 19 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'inputMaskingAboutToChange'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'inputMaskingChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'inputAboutToBeDestroyed'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractFilter, qt_meta_tag_ZN14AbstractFilterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractAspect::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AbstractFilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AbstractFilterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AbstractFilterE_t>.metaTypes,
    nullptr
} };

void AbstractFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractFilter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->inputDescriptionAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 1: _t->inputDescriptionAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 2: _t->inputDescriptionChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 3: _t->inputDescriptionChanged((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 4: _t->inputPlotDesignationAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 5: _t->inputPlotDesignationChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 6: _t->inputModeAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 7: _t->inputModeChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 8: _t->inputDataAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 9: _t->inputDataChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 10: _t->inputRowsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->inputRowsInserted((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 12: _t->inputRowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 13: _t->inputRowsRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 14: _t->inputMaskingAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 15: _t->inputMaskingChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 16: _t->inputAboutToBeDestroyed((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *AbstractFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AbstractFilterE_t>.strings))
        return static_cast<void*>(this);
    return AbstractAspect::qt_metacast(_clname);
}

int AbstractFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractAspect::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
