/********************************************************************************
** Form generated from reading UI file 'symbolwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SYMBOLWIDGET_H
#define UI_SYMBOLWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "kcolorbutton.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_SymbolWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *lGeneral;
    QLabel *lStyle;
    QSpacerItem *horizontalSpacer;
    KComboBox *cbStyle;
    QLabel *lSize;
    QLabel *lRotation;
    QSpinBox *sbRotation;
    QLabel *lOpacity;
    QSpinBox *sbOpacity;
    QSpacerItem *verticalSpacer;
    QLabel *lFilling;
    QLabel *lFillingStyle;
    KComboBox *cbFillingStyle;
    QLabel *lFillingColor;
    KColorButton *kcbFillingColor;
    QSpacerItem *verticalSpacer_1;
    QLabel *lBorder;
    QLabel *lBorderStyle;
    KComboBox *cbBorderStyle;
    QLabel *lBorderColor;
    KColorButton *kcbBorderColor;
    QLabel *lBorderWidth;
    QSpacerItem *verticalSpacer_2;
    NumberSpinBox *sbSize;
    NumberSpinBox *sbBorderWidth;

    void setupUi(QWidget *SymbolWidget)
    {
        if (SymbolWidget->objectName().isEmpty())
            SymbolWidget->setObjectName("SymbolWidget");
        SymbolWidget->resize(248, 490);
        gridLayout = new QGridLayout(SymbolWidget);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        lGeneral = new QLabel(SymbolWidget);
        lGeneral->setObjectName("lGeneral");
        QFont font;
        font.setBold(true);
        lGeneral->setFont(font);

        gridLayout->addWidget(lGeneral, 0, 0, 1, 1);

        lStyle = new QLabel(SymbolWidget);
        lStyle->setObjectName("lStyle");

        gridLayout->addWidget(lStyle, 1, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 1, 1, 1);

        cbStyle = new KComboBox(SymbolWidget);
        cbStyle->setObjectName("cbStyle");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbStyle->sizePolicy().hasHeightForWidth());
        cbStyle->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbStyle, 1, 2, 1, 1);

        lSize = new QLabel(SymbolWidget);
        lSize->setObjectName("lSize");

        gridLayout->addWidget(lSize, 2, 0, 1, 1);

        lRotation = new QLabel(SymbolWidget);
        lRotation->setObjectName("lRotation");

        gridLayout->addWidget(lRotation, 3, 0, 1, 1);

        sbRotation = new QSpinBox(SymbolWidget);
        sbRotation->setObjectName("sbRotation");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sbRotation->sizePolicy().hasHeightForWidth());
        sbRotation->setSizePolicy(sizePolicy1);
        sbRotation->setMinimum(-360);
        sbRotation->setMaximum(360);
        sbRotation->setSingleStep(10);
        sbRotation->setValue(0);

        gridLayout->addWidget(sbRotation, 3, 2, 1, 1);

        lOpacity = new QLabel(SymbolWidget);
        lOpacity->setObjectName("lOpacity");

        gridLayout->addWidget(lOpacity, 4, 0, 1, 1);

        sbOpacity = new QSpinBox(SymbolWidget);
        sbOpacity->setObjectName("sbOpacity");
        sizePolicy1.setHeightForWidth(sbOpacity->sizePolicy().hasHeightForWidth());
        sbOpacity->setSizePolicy(sizePolicy1);
        sbOpacity->setMinimum(0);
        sbOpacity->setMaximum(100);
        sbOpacity->setSingleStep(10);
        sbOpacity->setValue(100);

        gridLayout->addWidget(sbOpacity, 4, 2, 1, 1);

        verticalSpacer = new QSpacerItem(72, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 5, 0, 1, 1);

        lFilling = new QLabel(SymbolWidget);
        lFilling->setObjectName("lFilling");
        lFilling->setFont(font);

        gridLayout->addWidget(lFilling, 6, 0, 1, 1);

        lFillingStyle = new QLabel(SymbolWidget);
        lFillingStyle->setObjectName("lFillingStyle");

        gridLayout->addWidget(lFillingStyle, 7, 0, 1, 1);

        cbFillingStyle = new KComboBox(SymbolWidget);
        cbFillingStyle->setObjectName("cbFillingStyle");

        gridLayout->addWidget(cbFillingStyle, 7, 2, 1, 1);

        lFillingColor = new QLabel(SymbolWidget);
        lFillingColor->setObjectName("lFillingColor");

        gridLayout->addWidget(lFillingColor, 8, 0, 1, 1);

        kcbFillingColor = new KColorButton(SymbolWidget);
        kcbFillingColor->setObjectName("kcbFillingColor");
        sizePolicy1.setHeightForWidth(kcbFillingColor->sizePolicy().hasHeightForWidth());
        kcbFillingColor->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(kcbFillingColor, 8, 2, 1, 1);

        verticalSpacer_1 = new QSpacerItem(72, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_1, 9, 0, 1, 1);

        lBorder = new QLabel(SymbolWidget);
        lBorder->setObjectName("lBorder");
        lBorder->setFont(font);

        gridLayout->addWidget(lBorder, 10, 0, 1, 1);

        lBorderStyle = new QLabel(SymbolWidget);
        lBorderStyle->setObjectName("lBorderStyle");

        gridLayout->addWidget(lBorderStyle, 11, 0, 1, 1);

        cbBorderStyle = new KComboBox(SymbolWidget);
        cbBorderStyle->setObjectName("cbBorderStyle");

        gridLayout->addWidget(cbBorderStyle, 11, 2, 1, 1);

        lBorderColor = new QLabel(SymbolWidget);
        lBorderColor->setObjectName("lBorderColor");

        gridLayout->addWidget(lBorderColor, 12, 0, 1, 1);

        kcbBorderColor = new KColorButton(SymbolWidget);
        kcbBorderColor->setObjectName("kcbBorderColor");
        sizePolicy1.setHeightForWidth(kcbBorderColor->sizePolicy().hasHeightForWidth());
        kcbBorderColor->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(kcbBorderColor, 12, 2, 1, 1);

        lBorderWidth = new QLabel(SymbolWidget);
        lBorderWidth->setObjectName("lBorderWidth");

        gridLayout->addWidget(lBorderWidth, 13, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(72, 66, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 14, 0, 1, 1);

        sbSize = new NumberSpinBox(SymbolWidget);
        sbSize->setObjectName("sbSize");
        sbSize->setMinimum(0.000000000000000);
        sbSize->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbSize, 2, 2, 1, 1);

        sbBorderWidth = new NumberSpinBox(SymbolWidget);
        sbBorderWidth->setObjectName("sbBorderWidth");
        sbBorderWidth->setMinimum(0.000000000000000);
        sbBorderWidth->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbBorderWidth, 13, 2, 1, 1);

        QWidget::setTabOrder(cbStyle, sbSize);
        QWidget::setTabOrder(sbSize, sbRotation);
        QWidget::setTabOrder(sbRotation, sbOpacity);
        QWidget::setTabOrder(sbOpacity, cbFillingStyle);
        QWidget::setTabOrder(cbFillingStyle, kcbFillingColor);
        QWidget::setTabOrder(kcbFillingColor, cbBorderStyle);
        QWidget::setTabOrder(cbBorderStyle, kcbBorderColor);
        QWidget::setTabOrder(kcbBorderColor, sbBorderWidth);

        retranslateUi(SymbolWidget);

        QMetaObject::connectSlotsByName(SymbolWidget);
    } // setupUi

    void retranslateUi(QWidget *SymbolWidget)
    {
        lGeneral->setText(tr2i18n("Symbol", nullptr));
        lStyle->setText(tr2i18n("Style:", nullptr));
        lSize->setText(tr2i18n("Size:", nullptr));
        lRotation->setText(tr2i18n("Rotation:", nullptr));
#if QT_CONFIG(tooltip)
        sbRotation->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        sbRotation->setSuffix(tr2i18n("\302\260", nullptr));
        lOpacity->setText(tr2i18n("Opacity:", nullptr));
#if QT_CONFIG(tooltip)
        sbOpacity->setToolTip(tr2i18n("The opacity ranges from 0 to 100, where 0 is fully transparent and 100 is fully opaque.", nullptr));
#endif // QT_CONFIG(tooltip)
        sbOpacity->setSuffix(tr2i18n(" %", nullptr));
        lFilling->setText(tr2i18n("Filling", nullptr));
        lFillingStyle->setText(tr2i18n("Style:", nullptr));
        lFillingColor->setText(tr2i18n("Color:", nullptr));
        lBorder->setText(tr2i18n("Border", nullptr));
        lBorderStyle->setText(tr2i18n("Style:", nullptr));
        lBorderColor->setText(tr2i18n("Color:", nullptr));
        lBorderWidth->setText(tr2i18n("Width:", nullptr));
#if QT_CONFIG(tooltip)
        sbSize->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbSize->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbSize->setSuffix(tr2i18n(" pt", nullptr));
#if QT_CONFIG(tooltip)
        sbBorderWidth->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbBorderWidth->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbBorderWidth->setSuffix(tr2i18n(" pt", nullptr));
        (void)SymbolWidget;
    } // retranslateUi

};

namespace Ui {
    class SymbolWidget: public Ui_SymbolWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SYMBOLWIDGET_H

