/********************************************************************************
** Form generated from reading UI file 'histogramdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HISTOGRAMDOCK_H
#define UI_HISTOGRAMDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_HistogramDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout_3;
    QLabel *lName;
    QComboBox *cbNormalization;
    QLabel *lComment;
    QSpacerItem *verticalSpacerST;
    QLabel *lBinRangesMin;
    QSpacerItem *verticalSpacerHT;
    QSpacerItem *hsName;
    QLabel *lOrientation;
    QLabel *lBinning;
    QLabel *lXColumn;
    QLabel *lPlotRange;
    QSpacerItem *verticalSpacer_2;
    NumberSpinBox *sbBinRangesMin;
    QComboBox *cbOrientation;
    QLabel *lBinningMethod;
    QLabel *lBinRangesMaxDateTime;
    TimedLineEdit *leName;
    QSpacerItem *verticalSpacerGeneral;
    QLabel *lType;
    QCheckBox *chkAutoBinRanges;
    QLabel *lBinWidth;
    QLabel *lBinRangesMinDateTime;
    QLabel *lNormalization;
    NumberSpinBox *sbBinWidth;
    QSpacerItem *verticalSpacerST_2;
    QLabel *lBinRanges;
    QSpinBox *sbBinCount;
    QCheckBox *chkVisible;
    NumberSpinBox *sbBinRangesMax;
    QSpacerItem *verticalSpacer;
    QComboBox *cbBinningMethod;
    QLabel *lBinCount;
    UTCDateTimeEdit *dteBinRangesMax;
    UTCDateTimeEdit *dteBinRangesMin;
    ResizableTextEdit *teComment;
    QComboBox *cbPlotRanges;
    QComboBox *cbType;
    QLabel *lBinRangesMax;
    QCheckBox *chkLegendVisible;
    QWidget *tabLine;
    QVBoxLayout *verticalLayout_3;
    QSpacerItem *verticalSpacer_3;
    QWidget *tabSymbol;
    QWidget *tabValues;
    QWidget *tabAreaFilling;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer_9;
    QWidget *tabErrorBars;
    QVBoxLayout *verticalLayout_4;
    QWidget *tab;
    QGridLayout *gridLayout_5;
    QLabel *lRugLength;
    QSpacerItem *verticalSpacer_13;
    QSpacerItem *horizontalSpacer_5;
    QLabel *lRugEnabled;
    QLabel *lRugWidth;
    QLabel *lRug;
    QLabel *lRugOffset;
    QCheckBox *chkRugEnabled;
    NumberSpinBox *sbRugLength;
    NumberSpinBox *sbRugWidth;
    NumberSpinBox *sbRugOffset;

    void setupUi(QWidget *HistogramDock)
    {
        if (HistogramDock->objectName().isEmpty())
            HistogramDock->setObjectName("HistogramDock");
        HistogramDock->resize(395, 956);
        verticalLayout = new QVBoxLayout(HistogramDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(HistogramDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout_3 = new QGridLayout(tabGeneral);
        gridLayout_3->setObjectName("gridLayout_3");
        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout_3->addWidget(lName, 0, 0, 1, 1);

        cbNormalization = new QComboBox(tabGeneral);
        cbNormalization->setObjectName("cbNormalization");

        gridLayout_3->addWidget(cbNormalization, 9, 2, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(lComment, 1, 0, 1, 1);

        verticalSpacerST = new QSpacerItem(32, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacerST, 2, 0, 1, 1);

        lBinRangesMin = new QLabel(tabGeneral);
        lBinRangesMin->setObjectName("lBinRangesMin");

        gridLayout_3->addWidget(lBinRangesMin, 21, 0, 1, 1);

        verticalSpacerHT = new QSpacerItem(32, 30, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacerHT, 10, 0, 1, 1);

        hsName = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(hsName, 0, 1, 1, 1);

        lOrientation = new QLabel(tabGeneral);
        lOrientation->setObjectName("lOrientation");

        gridLayout_3->addWidget(lOrientation, 8, 0, 1, 1);

        lBinning = new QLabel(tabGeneral);
        lBinning->setObjectName("lBinning");
        QFont font;
        font.setBold(true);
        lBinning->setFont(font);

        gridLayout_3->addWidget(lBinning, 15, 0, 1, 1);

        lXColumn = new QLabel(tabGeneral);
        lXColumn->setObjectName("lXColumn");

        gridLayout_3->addWidget(lXColumn, 3, 0, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout_3->addWidget(lPlotRange, 26, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_2, 25, 0, 1, 1);

        sbBinRangesMin = new NumberSpinBox(tabGeneral);
        sbBinRangesMin->setObjectName("sbBinRangesMin");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(sbBinRangesMin->sizePolicy().hasHeightForWidth());
        sbBinRangesMin->setSizePolicy(sizePolicy);
        sbBinRangesMin->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbBinRangesMin, 21, 2, 1, 1);

        cbOrientation = new QComboBox(tabGeneral);
        cbOrientation->setObjectName("cbOrientation");

        gridLayout_3->addWidget(cbOrientation, 8, 2, 1, 1);

        lBinningMethod = new QLabel(tabGeneral);
        lBinningMethod->setObjectName("lBinningMethod");

        gridLayout_3->addWidget(lBinningMethod, 16, 0, 1, 1);

        lBinRangesMaxDateTime = new QLabel(tabGeneral);
        lBinRangesMaxDateTime->setObjectName("lBinRangesMaxDateTime");

        gridLayout_3->addWidget(lBinRangesMaxDateTime, 24, 0, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");

        gridLayout_3->addWidget(leName, 0, 2, 1, 1);

        verticalSpacerGeneral = new QSpacerItem(24, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout_3->addItem(verticalSpacerGeneral, 27, 0, 1, 1);

        lType = new QLabel(tabGeneral);
        lType->setObjectName("lType");

        gridLayout_3->addWidget(lType, 7, 0, 1, 1);

        chkAutoBinRanges = new QCheckBox(tabGeneral);
        chkAutoBinRanges->setObjectName("chkAutoBinRanges");

        gridLayout_3->addWidget(chkAutoBinRanges, 20, 2, 1, 1);

        lBinWidth = new QLabel(tabGeneral);
        lBinWidth->setObjectName("lBinWidth");

        gridLayout_3->addWidget(lBinWidth, 18, 0, 1, 1);

        lBinRangesMinDateTime = new QLabel(tabGeneral);
        lBinRangesMinDateTime->setObjectName("lBinRangesMinDateTime");

        gridLayout_3->addWidget(lBinRangesMinDateTime, 23, 0, 1, 1);

        lNormalization = new QLabel(tabGeneral);
        lNormalization->setObjectName("lNormalization");

        gridLayout_3->addWidget(lNormalization, 9, 0, 1, 1);

        sbBinWidth = new NumberSpinBox(tabGeneral);
        sbBinWidth->setObjectName("sbBinWidth");
        sizePolicy.setHeightForWidth(sbBinWidth->sizePolicy().hasHeightForWidth());
        sbBinWidth->setSizePolicy(sizePolicy);
        sbBinWidth->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbBinWidth, 18, 2, 1, 1);

        verticalSpacerST_2 = new QSpacerItem(32, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacerST_2, 6, 0, 1, 1);

        lBinRanges = new QLabel(tabGeneral);
        lBinRanges->setObjectName("lBinRanges");
        lBinRanges->setFont(font);

        gridLayout_3->addWidget(lBinRanges, 20, 0, 1, 1);

        sbBinCount = new QSpinBox(tabGeneral);
        sbBinCount->setObjectName("sbBinCount");
        sbBinCount->setMinimum(1);
        sbBinCount->setMaximum(9999);
        sbBinCount->setValue(10);

        gridLayout_3->addWidget(sbBinCount, 17, 2, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout_3->addWidget(chkVisible, 29, 0, 1, 1);

        sbBinRangesMax = new NumberSpinBox(tabGeneral);
        sbBinRangesMax->setObjectName("sbBinRangesMax");
        sizePolicy.setHeightForWidth(sbBinRangesMax->sizePolicy().hasHeightForWidth());
        sbBinRangesMax->setSizePolicy(sizePolicy);
        sbBinRangesMax->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbBinRangesMax, 22, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer, 19, 0, 1, 1);

        cbBinningMethod = new QComboBox(tabGeneral);
        cbBinningMethod->setObjectName("cbBinningMethod");

        gridLayout_3->addWidget(cbBinningMethod, 16, 2, 1, 1);

        lBinCount = new QLabel(tabGeneral);
        lBinCount->setObjectName("lBinCount");

        gridLayout_3->addWidget(lBinCount, 17, 0, 1, 1);

        dteBinRangesMax = new UTCDateTimeEdit(tabGeneral);
        dteBinRangesMax->setObjectName("dteBinRangesMax");
        dteBinRangesMax->setCalendarPopup(true);

        gridLayout_3->addWidget(dteBinRangesMax, 24, 2, 1, 1);

        dteBinRangesMin = new UTCDateTimeEdit(tabGeneral);
        dteBinRangesMin->setObjectName("dteBinRangesMin");
        dteBinRangesMin->setCalendarPopup(true);

        gridLayout_3->addWidget(dteBinRangesMin, 23, 2, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout_3->addWidget(teComment, 1, 2, 1, 1);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout_3->addWidget(cbPlotRanges, 26, 2, 1, 1);

        cbType = new QComboBox(tabGeneral);
        cbType->setObjectName("cbType");

        gridLayout_3->addWidget(cbType, 7, 2, 1, 1);

        lBinRangesMax = new QLabel(tabGeneral);
        lBinRangesMax->setObjectName("lBinRangesMax");

        gridLayout_3->addWidget(lBinRangesMax, 22, 0, 1, 1);

        chkLegendVisible = new QCheckBox(tabGeneral);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout_3->addWidget(chkLegendVisible, 28, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabLine = new QWidget();
        tabLine->setObjectName("tabLine");
        verticalLayout_3 = new QVBoxLayout(tabLine);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalSpacer_3 = new QSpacerItem(20, 793, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);

        tabWidget->addTab(tabLine, QString());
        tabSymbol = new QWidget();
        tabSymbol->setObjectName("tabSymbol");
        tabWidget->addTab(tabSymbol, QString());
        tabValues = new QWidget();
        tabValues->setObjectName("tabValues");
        tabWidget->addTab(tabValues, QString());
        tabAreaFilling = new QWidget();
        tabAreaFilling->setObjectName("tabAreaFilling");
        verticalLayout_2 = new QVBoxLayout(tabAreaFilling);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalSpacer_9 = new QSpacerItem(24, 50, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_9);

        tabWidget->addTab(tabAreaFilling, QString());
        tabErrorBars = new QWidget();
        tabErrorBars->setObjectName("tabErrorBars");
        verticalLayout_4 = new QVBoxLayout(tabErrorBars);
        verticalLayout_4->setObjectName("verticalLayout_4");
        tabWidget->addTab(tabErrorBars, QString());
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout_5 = new QGridLayout(tab);
        gridLayout_5->setObjectName("gridLayout_5");
        lRugLength = new QLabel(tab);
        lRugLength->setObjectName("lRugLength");

        gridLayout_5->addWidget(lRugLength, 2, 0, 1, 1);

        verticalSpacer_13 = new QSpacerItem(18, 50, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer_13, 5, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_5, 1, 1, 1, 1);

        lRugEnabled = new QLabel(tab);
        lRugEnabled->setObjectName("lRugEnabled");

        gridLayout_5->addWidget(lRugEnabled, 1, 0, 1, 1);

        lRugWidth = new QLabel(tab);
        lRugWidth->setObjectName("lRugWidth");

        gridLayout_5->addWidget(lRugWidth, 3, 0, 1, 1);

        lRug = new QLabel(tab);
        lRug->setObjectName("lRug");
        lRug->setFont(font);

        gridLayout_5->addWidget(lRug, 0, 0, 1, 1);

        lRugOffset = new QLabel(tab);
        lRugOffset->setObjectName("lRugOffset");

        gridLayout_5->addWidget(lRugOffset, 4, 0, 1, 1);

        chkRugEnabled = new QCheckBox(tab);
        chkRugEnabled->setObjectName("chkRugEnabled");
        sizePolicy.setHeightForWidth(chkRugEnabled->sizePolicy().hasHeightForWidth());
        chkRugEnabled->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(chkRugEnabled, 1, 2, 1, 1);

        sbRugLength = new NumberSpinBox(tab);
        sbRugLength->setObjectName("sbRugLength");
        sizePolicy.setHeightForWidth(sbRugLength->sizePolicy().hasHeightForWidth());
        sbRugLength->setSizePolicy(sizePolicy);
        sbRugLength->setMinimum(0.000000000000000);
        sbRugLength->setProperty("feedback", QVariant(true));

        gridLayout_5->addWidget(sbRugLength, 2, 2, 1, 1);

        sbRugWidth = new NumberSpinBox(tab);
        sbRugWidth->setObjectName("sbRugWidth");
        sizePolicy.setHeightForWidth(sbRugWidth->sizePolicy().hasHeightForWidth());
        sbRugWidth->setSizePolicy(sizePolicy);
        sbRugWidth->setMinimum(0.000000000000000);
        sbRugWidth->setProperty("feedback", QVariant(true));

        gridLayout_5->addWidget(sbRugWidth, 3, 2, 1, 1);

        sbRugOffset = new NumberSpinBox(tab);
        sbRugOffset->setObjectName("sbRugOffset");
        sizePolicy.setHeightForWidth(sbRugOffset->sizePolicy().hasHeightForWidth());
        sbRugOffset->setSizePolicy(sizePolicy);
        sbRugOffset->setProperty("feedback", QVariant(true));

        gridLayout_5->addWidget(sbRugOffset, 4, 2, 1, 1);

        tabWidget->addTab(tab, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbType);
        QWidget::setTabOrder(cbType, cbOrientation);
        QWidget::setTabOrder(cbOrientation, cbNormalization);
        QWidget::setTabOrder(cbNormalization, cbBinningMethod);
        QWidget::setTabOrder(cbBinningMethod, sbBinCount);
        QWidget::setTabOrder(sbBinCount, sbBinWidth);
        QWidget::setTabOrder(sbBinWidth, chkAutoBinRanges);
        QWidget::setTabOrder(chkAutoBinRanges, sbBinRangesMin);
        QWidget::setTabOrder(sbBinRangesMin, sbBinRangesMax);
        QWidget::setTabOrder(sbBinRangesMax, dteBinRangesMin);
        QWidget::setTabOrder(dteBinRangesMin, dteBinRangesMax);
        QWidget::setTabOrder(dteBinRangesMax, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);
        QWidget::setTabOrder(chkVisible, chkRugEnabled);
        QWidget::setTabOrder(chkRugEnabled, sbRugLength);
        QWidget::setTabOrder(sbRugLength, sbRugWidth);
        QWidget::setTabOrder(sbRugWidth, sbRugOffset);

        retranslateUi(HistogramDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(HistogramDock);
    } // setupUi

    void retranslateUi(QWidget *HistogramDock)
    {
        lName->setText(tr2i18n("Name:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lBinRangesMin->setText(tr2i18n("Minimum:", nullptr));
        lOrientation->setText(tr2i18n("Orientation:", nullptr));
        lBinning->setText(tr2i18n("Binning", nullptr));
        lXColumn->setText(tr2i18n("Data:", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
#if QT_CONFIG(tooltip)
        sbBinRangesMin->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbBinRangesMin->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lBinningMethod->setText(tr2i18n("Method:", nullptr));
        lBinRangesMaxDateTime->setText(tr2i18n("Maximum:", nullptr));
        lType->setText(tr2i18n("Type:", nullptr));
        chkAutoBinRanges->setText(tr2i18n("Auto", nullptr));
        lBinWidth->setText(tr2i18n("Bin Width:", nullptr));
        lBinRangesMinDateTime->setText(tr2i18n("Minimum:", nullptr));
        lNormalization->setText(tr2i18n("Normalization:", nullptr));
#if QT_CONFIG(tooltip)
        sbBinWidth->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbBinWidth->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lBinRanges->setText(tr2i18n("Bin Ranges", nullptr));
        chkVisible->setText(tr2i18n("visible", nullptr));
#if QT_CONFIG(tooltip)
        sbBinRangesMax->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbBinRangesMax->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lBinCount->setText(tr2i18n("Bin Count:", nullptr));
        lBinRangesMax->setText(tr2i18n("Maximum:", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabLine), tr2i18n("Shape", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabSymbol), tr2i18n("Symbol", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabValues), tr2i18n("Values", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAreaFilling), tr2i18n("Filling", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabErrorBars), tr2i18n("Error Bars", nullptr));
        lRugLength->setText(tr2i18n("Length:", nullptr));
        lRugEnabled->setText(tr2i18n("Enabled:", nullptr));
        lRugWidth->setText(tr2i18n("Width:", nullptr));
        lRug->setText(tr2i18n("Rug Plot", nullptr));
        lRugOffset->setText(tr2i18n("Offset:", nullptr));
        chkRugEnabled->setText(QString());
#if QT_CONFIG(tooltip)
        sbRugLength->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRugLength->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbRugLength->setSuffix(tr2i18n(" pt", nullptr));
#if QT_CONFIG(tooltip)
        sbRugWidth->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRugWidth->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbRugWidth->setSuffix(tr2i18n(" pt", nullptr));
#if QT_CONFIG(tooltip)
        sbRugOffset->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRugOffset->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbRugOffset->setSuffix(tr2i18n(" pt", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Margins", nullptr));
        (void)HistogramDock;
    } // retranslateUi

};

namespace Ui {
    class HistogramDock: public Ui_HistogramDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // HISTOGRAMDOCK_H

