/********************************************************************************
** Form generated from reading UI file 'importfilewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTFILEWIDGET_H
#define UI_IMPORTFILEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ImportFileWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *gbDataSource;
    QGridLayout *gridLayout;
    QLabel *lBaudRate;
    QLabel *lConnections;
    QLabel *lHost;
    QLabel *lField;
    QLabel *lFirstRowAsColNames;
    QComboBox *cbSourceType;
    QComboBox *cbSerialPort;
    KComboBox *cbFileType;
    QFrame *frameSubscriptions;
    QComboBox *cbConnection;
    QLabel *lFileType;
    QLabel *lFileName;
    QLabel *lLWT;
    QLabel *lDBCDatabase;
    QLabel *lPort;
    QPushButton *bOpen;
    QSpacerItem *spacerWillMessage;
    QLabel *lSerialPort;
    QTreeView *tvJson;
    QLineEdit *leHost;
    QComboBox *cbBaudRate;
    QCheckBox *chbRelativePath;
    QComboBox *cbMcapTopics;
    QPushButton *bFileInfo;
    QPushButton *bOpenDBC;
    QLabel *lSourceType;
    QPushButton *bLWT;
    QLabel *lRelativePath;
    QPushButton *bManageConnections;
    QLineEdit *lePort;
    QLabel *lFilter;
    KComboBox *cbFilter;
    QCheckBox *chbFirstRowAsColName;
    QHBoxLayout *hLayoutFilter;
    QLabel *lMcapTopics;
    QLabel *lMqttTopics;
    QSpacerItem *hsName;
    QGroupBox *gbOptions;
    QVBoxLayout *verticalLayout_3;
    QTabWidget *tabWidget;
    QWidget *tabDataFormat;
    QVBoxLayout *verticalLayout;
    QStackedWidget *swOptions;
    QWidget *page;
    QWidget *page_2;
    QWidget *tabDataPreview;
    QGridLayout *gridLayout_3;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QLabel *lPreviewLines;
    QTextEdit *tePreview;
    QPushButton *bRefreshPreview;
    QLabel *lWarningLimitedMessages;
    QSpinBox *sbPreviewPrecision;
    QSpinBox *sbPreviewLines;
    QSpacerItem *horizontalSpacer_2;
    QWidget *tabDataPortion;
    QGridLayout *gridLayout_2;
    QLabel *lStartRow;
    QSpinBox *sbEndRow;
    QLabel *lStartColumn;
    QSpinBox *sbStartColumn;
    QSpacerItem *horizontalSpacer_5;
    QSpinBox *sbStartRow;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *horizontalSpacer_3;
    QLabel *lEndColumn;
    QSpinBox *sbEndColumn;
    QSpacerItem *horizontalSpacer_6;
    QLabel *lEndRow;
    QSpacerItem *verticalSpacer;
    QGroupBox *gbUpdateOptions;
    QGridLayout *gridLayout_4;
    QComboBox *cbReadingType;
    QLabel *lUpdateType;
    QLabel *lReadingType;
    QLabel *lUpdateInterval;
    QSpinBox *sbKeepNValues;
    QLabel *lKeepLastValues;
    QLabel *lSampleSize;
    QSpinBox *sbSampleSize;
    QComboBox *cbUpdateType;
    QSpinBox *sbUpdateInterval;
    QCheckBox *chbLinkFile;

    void setupUi(QWidget *ImportFileWidget)
    {
        if (ImportFileWidget->objectName().isEmpty())
            ImportFileWidget->setObjectName("ImportFileWidget");
        ImportFileWidget->resize(530, 1249);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ImportFileWidget->sizePolicy().hasHeightForWidth());
        ImportFileWidget->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(ImportFileWidget);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        gbDataSource = new QGroupBox(ImportFileWidget);
        gbDataSource->setObjectName("gbDataSource");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(gbDataSource->sizePolicy().hasHeightForWidth());
        gbDataSource->setSizePolicy(sizePolicy1);
        gridLayout = new QGridLayout(gbDataSource);
        gridLayout->setObjectName("gridLayout");
        lBaudRate = new QLabel(gbDataSource);
        lBaudRate->setObjectName("lBaudRate");

        gridLayout->addWidget(lBaudRate, 8, 0, 1, 1);

        lConnections = new QLabel(gbDataSource);
        lConnections->setObjectName("lConnections");

        gridLayout->addWidget(lConnections, 5, 0, 1, 1);

        lHost = new QLabel(gbDataSource);
        lHost->setObjectName("lHost");

        gridLayout->addWidget(lHost, 4, 0, 1, 1);

        lField = new QLabel(gbDataSource);
        lField->setObjectName("lField");
        lField->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout->addWidget(lField, 16, 0, 1, 1);

        lFirstRowAsColNames = new QLabel(gbDataSource);
        lFirstRowAsColNames->setObjectName("lFirstRowAsColNames");

        gridLayout->addWidget(lFirstRowAsColNames, 17, 0, 1, 1);

        cbSourceType = new QComboBox(gbDataSource);
        cbSourceType->addItem(QString());
        cbSourceType->addItem(QString());
        cbSourceType->addItem(QString());
        cbSourceType->addItem(QString());
        cbSourceType->addItem(QString());
        cbSourceType->setObjectName("cbSourceType");

        gridLayout->addWidget(cbSourceType, 0, 2, 1, 3);

        cbSerialPort = new QComboBox(gbDataSource);
        cbSerialPort->setObjectName("cbSerialPort");

        gridLayout->addWidget(cbSerialPort, 7, 2, 1, 3);

        cbFileType = new KComboBox(gbDataSource);
        cbFileType->setObjectName("cbFileType");
        cbFileType->setEnabled(false);

        gridLayout->addWidget(cbFileType, 13, 2, 1, 3);

        frameSubscriptions = new QFrame(gbDataSource);
        frameSubscriptions->setObjectName("frameSubscriptions");
        frameSubscriptions->setFrameShape(QFrame::Shape::NoFrame);
        frameSubscriptions->setFrameShadow(QFrame::Shadow::Plain);

        gridLayout->addWidget(frameSubscriptions, 10, 2, 1, 3);

        cbConnection = new QComboBox(gbDataSource);
        cbConnection->setObjectName("cbConnection");

        gridLayout->addWidget(cbConnection, 5, 2, 1, 3);

        lFileType = new QLabel(gbDataSource);
        lFileType->setObjectName("lFileType");

        gridLayout->addWidget(lFileType, 13, 0, 1, 1);

        lFileName = new QLabel(gbDataSource);
        lFileName->setObjectName("lFileName");

        gridLayout->addWidget(lFileName, 1, 0, 1, 1);

        lLWT = new QLabel(gbDataSource);
        lLWT->setObjectName("lLWT");

        gridLayout->addWidget(lLWT, 11, 0, 1, 1);

        lDBCDatabase = new QLabel(gbDataSource);
        lDBCDatabase->setObjectName("lDBCDatabase");

        gridLayout->addWidget(lDBCDatabase, 2, 0, 1, 1);

        lPort = new QLabel(gbDataSource);
        lPort->setObjectName("lPort");

        gridLayout->addWidget(lPort, 6, 0, 1, 1);

        bOpen = new QPushButton(gbDataSource);
        bOpen->setObjectName("bOpen");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(bOpen->sizePolicy().hasHeightForWidth());
        bOpen->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(bOpen, 1, 5, 1, 2);

        spacerWillMessage = new QSpacerItem(40, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerWillMessage, 12, 4, 1, 1);

        lSerialPort = new QLabel(gbDataSource);
        lSerialPort->setObjectName("lSerialPort");

        gridLayout->addWidget(lSerialPort, 7, 0, 1, 1);

        tvJson = new QTreeView(gbDataSource);
        tvJson->setObjectName("tvJson");
        tvJson->setEditTriggers(QAbstractItemView::EditTrigger::NoEditTriggers);
        tvJson->setProperty("showDropIndicator", QVariant(false));
        tvJson->setIconSize(QSize(16, 16));

        gridLayout->addWidget(tvJson, 16, 2, 1, 3);

        leHost = new QLineEdit(gbDataSource);
        leHost->setObjectName("leHost");

        gridLayout->addWidget(leHost, 4, 2, 1, 3);

        cbBaudRate = new QComboBox(gbDataSource);
        cbBaudRate->setObjectName("cbBaudRate");

        gridLayout->addWidget(cbBaudRate, 8, 2, 1, 3);

        chbRelativePath = new QCheckBox(gbDataSource);
        chbRelativePath->setObjectName("chbRelativePath");

        gridLayout->addWidget(chbRelativePath, 3, 2, 1, 1);

        cbMcapTopics = new QComboBox(gbDataSource);
        cbMcapTopics->setObjectName("cbMcapTopics");
        cbMcapTopics->setEnabled(true);

        gridLayout->addWidget(cbMcapTopics, 15, 2, 1, 3);

        bFileInfo = new QPushButton(gbDataSource);
        bFileInfo->setObjectName("bFileInfo");
        bFileInfo->setEnabled(false);
        sizePolicy2.setHeightForWidth(bFileInfo->sizePolicy().hasHeightForWidth());
        bFileInfo->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(bFileInfo, 1, 7, 1, 1);

        bOpenDBC = new QPushButton(gbDataSource);
        bOpenDBC->setObjectName("bOpenDBC");

        gridLayout->addWidget(bOpenDBC, 2, 5, 1, 1);

        lSourceType = new QLabel(gbDataSource);
        lSourceType->setObjectName("lSourceType");

        gridLayout->addWidget(lSourceType, 0, 0, 1, 1);

        bLWT = new QPushButton(gbDataSource);
        bLWT->setObjectName("bLWT");

        gridLayout->addWidget(bLWT, 11, 2, 1, 2);

        lRelativePath = new QLabel(gbDataSource);
        lRelativePath->setObjectName("lRelativePath");

        gridLayout->addWidget(lRelativePath, 3, 0, 1, 1);

        bManageConnections = new QPushButton(gbDataSource);
        bManageConnections->setObjectName("bManageConnections");
        sizePolicy2.setHeightForWidth(bManageConnections->sizePolicy().hasHeightForWidth());
        bManageConnections->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(bManageConnections, 5, 5, 1, 1);

        lePort = new QLineEdit(gbDataSource);
        lePort->setObjectName("lePort");

        gridLayout->addWidget(lePort, 6, 2, 1, 3);

        lFilter = new QLabel(gbDataSource);
        lFilter->setObjectName("lFilter");

        gridLayout->addWidget(lFilter, 18, 0, 1, 1);

        cbFilter = new KComboBox(gbDataSource);
        cbFilter->setObjectName("cbFilter");
        cbFilter->setEnabled(false);
        QSizePolicy sizePolicy3(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(cbFilter->sizePolicy().hasHeightForWidth());
        cbFilter->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(cbFilter, 18, 2, 1, 3);

        chbFirstRowAsColName = new QCheckBox(gbDataSource);
        chbFirstRowAsColName->setObjectName("chbFirstRowAsColName");

        gridLayout->addWidget(chbFirstRowAsColName, 17, 2, 1, 3);

        hLayoutFilter = new QHBoxLayout();
        hLayoutFilter->setObjectName("hLayoutFilter");

        gridLayout->addLayout(hLayoutFilter, 18, 5, 1, 3);

        lMcapTopics = new QLabel(gbDataSource);
        lMcapTopics->setObjectName("lMcapTopics");

        gridLayout->addWidget(lMcapTopics, 15, 0, 1, 1);

        lMqttTopics = new QLabel(gbDataSource);
        lMqttTopics->setObjectName("lMqttTopics");
        lMqttTopics->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout->addWidget(lMqttTopics, 10, 0, 1, 1);

        hsName = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(hsName, 18, 1, 1, 1);


        verticalLayout_2->addWidget(gbDataSource);

        gbOptions = new QGroupBox(ImportFileWidget);
        gbOptions->setObjectName("gbOptions");
        gbOptions->setEnabled(false);
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(gbOptions->sizePolicy().hasHeightForWidth());
        gbOptions->setSizePolicy(sizePolicy4);
        gbOptions->setFlat(true);
        verticalLayout_3 = new QVBoxLayout(gbOptions);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(gbOptions);
        tabWidget->setObjectName("tabWidget");
        tabDataFormat = new QWidget();
        tabDataFormat->setObjectName("tabDataFormat");
        sizePolicy4.setHeightForWidth(tabDataFormat->sizePolicy().hasHeightForWidth());
        tabDataFormat->setSizePolicy(sizePolicy4);
        verticalLayout = new QVBoxLayout(tabDataFormat);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        swOptions = new QStackedWidget(tabDataFormat);
        swOptions->setObjectName("swOptions");
        sizePolicy4.setHeightForWidth(swOptions->sizePolicy().hasHeightForWidth());
        swOptions->setSizePolicy(sizePolicy4);
        page = new QWidget();
        page->setObjectName("page");
        sizePolicy4.setHeightForWidth(page->sizePolicy().hasHeightForWidth());
        page->setSizePolicy(sizePolicy4);
        swOptions->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        sizePolicy4.setHeightForWidth(page_2->sizePolicy().hasHeightForWidth());
        page_2->setSizePolicy(sizePolicy4);
        swOptions->addWidget(page_2);

        verticalLayout->addWidget(swOptions);

        tabWidget->addTab(tabDataFormat, QString());
        tabDataPreview = new QWidget();
        tabDataPreview->setObjectName("tabDataPreview");
        sizePolicy4.setHeightForWidth(tabDataPreview->sizePolicy().hasHeightForWidth());
        tabDataPreview->setSizePolicy(sizePolicy4);
        gridLayout_3 = new QGridLayout(tabDataPreview);
        gridLayout_3->setObjectName("gridLayout_3");
        label = new QLabel(tabDataPreview);
        label->setObjectName("label");

        gridLayout_3->addWidget(label, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(23, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer, 0, 3, 1, 1);

        lPreviewLines = new QLabel(tabDataPreview);
        lPreviewLines->setObjectName("lPreviewLines");
        sizePolicy.setHeightForWidth(lPreviewLines->sizePolicy().hasHeightForWidth());
        lPreviewLines->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(lPreviewLines, 0, 0, 1, 1);

        tePreview = new QTextEdit(tabDataPreview);
        tePreview->setObjectName("tePreview");
        tePreview->setUndoRedoEnabled(true);
        tePreview->setLineWrapMode(QTextEdit::LineWrapMode::NoWrap);
        tePreview->setReadOnly(true);

        gridLayout_3->addWidget(tePreview, 2, 0, 1, 6);

        bRefreshPreview = new QPushButton(tabDataPreview);
        bRefreshPreview->setObjectName("bRefreshPreview");

        gridLayout_3->addWidget(bRefreshPreview, 0, 5, 1, 1);

        lWarningLimitedMessages = new QLabel(tabDataPreview);
        lWarningLimitedMessages->setObjectName("lWarningLimitedMessages");

        gridLayout_3->addWidget(lWarningLimitedMessages, 1, 0, 1, 6);

        sbPreviewPrecision = new QSpinBox(tabDataPreview);
        sbPreviewPrecision->setObjectName("sbPreviewPrecision");
        sbPreviewPrecision->setMinimum(0);
        sbPreviewPrecision->setMaximum(100);
        sbPreviewPrecision->setValue(6);

        gridLayout_3->addWidget(sbPreviewPrecision, 0, 3, 1, 1);

        sbPreviewLines = new QSpinBox(tabDataPreview);
        sbPreviewLines->setObjectName("sbPreviewLines");
        sbPreviewLines->setMinimum(1);
        sbPreviewLines->setMaximum(10000);
        sbPreviewLines->setValue(100);

        gridLayout_3->addWidget(sbPreviewLines, 0, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 0, 4, 1, 1);

        tabWidget->addTab(tabDataPreview, QString());
        tabDataPortion = new QWidget();
        tabDataPortion->setObjectName("tabDataPortion");
        sizePolicy1.setHeightForWidth(tabDataPortion->sizePolicy().hasHeightForWidth());
        tabDataPortion->setSizePolicy(sizePolicy1);
        gridLayout_2 = new QGridLayout(tabDataPortion);
        gridLayout_2->setObjectName("gridLayout_2");
        lStartRow = new QLabel(tabDataPortion);
        lStartRow->setObjectName("lStartRow");

        gridLayout_2->addWidget(lStartRow, 0, 0, 1, 1);

        sbEndRow = new QSpinBox(tabDataPortion);
        sbEndRow->setObjectName("sbEndRow");
        sbEndRow->setMinimum(-1);
        sbEndRow->setMaximum(2147483647);
        sbEndRow->setValue(-1);

        gridLayout_2->addWidget(sbEndRow, 0, 4, 1, 1);

        lStartColumn = new QLabel(tabDataPortion);
        lStartColumn->setObjectName("lStartColumn");

        gridLayout_2->addWidget(lStartColumn, 1, 0, 1, 1);

        sbStartColumn = new QSpinBox(tabDataPortion);
        sbStartColumn->setObjectName("sbStartColumn");
        sbStartColumn->setMinimum(1);
        sbStartColumn->setMaximum(2147483647);

        gridLayout_2->addWidget(sbStartColumn, 1, 1, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_5, 1, 2, 1, 1);

        sbStartRow = new QSpinBox(tabDataPortion);
        sbStartRow->setObjectName("sbStartRow");
        sbStartRow->setMinimum(1);
        sbStartRow->setMaximum(2147483647);
        sbStartRow->setValue(1);

        gridLayout_2->addWidget(sbStartRow, 0, 1, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(108, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_4, 0, 5, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_3, 0, 2, 1, 1);

        lEndColumn = new QLabel(tabDataPortion);
        lEndColumn->setObjectName("lEndColumn");

        gridLayout_2->addWidget(lEndColumn, 1, 3, 1, 1);

        sbEndColumn = new QSpinBox(tabDataPortion);
        sbEndColumn->setObjectName("sbEndColumn");
        sbEndColumn->setMinimum(-1);
        sbEndColumn->setMaximum(2147483647);
        sbEndColumn->setValue(-1);

        gridLayout_2->addWidget(sbEndColumn, 1, 4, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(108, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_6, 1, 5, 1, 1);

        lEndRow = new QLabel(tabDataPortion);
        lEndRow->setObjectName("lEndRow");

        gridLayout_2->addWidget(lEndRow, 0, 3, 1, 1);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 3, 0, 1, 1);

        tabWidget->addTab(tabDataPortion, QString());

        verticalLayout_3->addWidget(tabWidget);


        verticalLayout_2->addWidget(gbOptions);

        gbUpdateOptions = new QGroupBox(ImportFileWidget);
        gbUpdateOptions->setObjectName("gbUpdateOptions");
        gridLayout_4 = new QGridLayout(gbUpdateOptions);
        gridLayout_4->setObjectName("gridLayout_4");
        cbReadingType = new QComboBox(gbUpdateOptions);
        cbReadingType->setObjectName("cbReadingType");

        gridLayout_4->addWidget(cbReadingType, 0, 1, 1, 1);

        lUpdateType = new QLabel(gbUpdateOptions);
        lUpdateType->setObjectName("lUpdateType");

        gridLayout_4->addWidget(lUpdateType, 2, 0, 1, 1);

        lReadingType = new QLabel(gbUpdateOptions);
        lReadingType->setObjectName("lReadingType");

        gridLayout_4->addWidget(lReadingType, 0, 0, 1, 1);

        lUpdateInterval = new QLabel(gbUpdateOptions);
        lUpdateInterval->setObjectName("lUpdateInterval");

        gridLayout_4->addWidget(lUpdateInterval, 3, 0, 1, 1);

        sbKeepNValues = new QSpinBox(gbUpdateOptions);
        sbKeepNValues->setObjectName("sbKeepNValues");
        sbKeepNValues->setMinimum(0);
        sbKeepNValues->setMaximum(999999);
        sbKeepNValues->setValue(0);

        gridLayout_4->addWidget(sbKeepNValues, 8, 1, 1, 1);

        lKeepLastValues = new QLabel(gbUpdateOptions);
        lKeepLastValues->setObjectName("lKeepLastValues");

        gridLayout_4->addWidget(lKeepLastValues, 8, 0, 1, 1);

        lSampleSize = new QLabel(gbUpdateOptions);
        lSampleSize->setObjectName("lSampleSize");

        gridLayout_4->addWidget(lSampleSize, 1, 0, 1, 1);

        sbSampleSize = new QSpinBox(gbUpdateOptions);
        sbSampleSize->setObjectName("sbSampleSize");
        sbSampleSize->setMinimum(1);
        sbSampleSize->setMaximum(10000);
        sbSampleSize->setValue(1);

        gridLayout_4->addWidget(sbSampleSize, 1, 1, 1, 1);

        cbUpdateType = new QComboBox(gbUpdateOptions);
        cbUpdateType->addItem(QString());
        cbUpdateType->addItem(QString());
        cbUpdateType->setObjectName("cbUpdateType");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(cbUpdateType->sizePolicy().hasHeightForWidth());
        cbUpdateType->setSizePolicy(sizePolicy5);

        gridLayout_4->addWidget(cbUpdateType, 2, 1, 1, 1);

        sbUpdateInterval = new QSpinBox(gbUpdateOptions);
        sbUpdateInterval->setObjectName("sbUpdateInterval");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(sbUpdateInterval->sizePolicy().hasHeightForWidth());
        sbUpdateInterval->setSizePolicy(sizePolicy6);
        sbUpdateInterval->setMinimum(5);
        sbUpdateInterval->setMaximum(60000);
        sbUpdateInterval->setValue(1000);

        gridLayout_4->addWidget(sbUpdateInterval, 3, 1, 1, 1);

        chbLinkFile = new QCheckBox(gbUpdateOptions);
        chbLinkFile->setObjectName("chbLinkFile");
        chbLinkFile->setChecked(true);

        gridLayout_4->addWidget(chbLinkFile, 9, 0, 1, 2);


        verticalLayout_2->addWidget(gbUpdateOptions);


        retranslateUi(ImportFileWidget);

        tabWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(ImportFileWidget);
    } // setupUi

    void retranslateUi(QWidget *ImportFileWidget)
    {
        gbDataSource->setTitle(tr2i18n("Data Source", nullptr));
        lBaudRate->setText(tr2i18n("Baud rate:", nullptr));
        lConnections->setText(tr2i18n("Connection:", nullptr));
        lHost->setText(tr2i18n("Host:", nullptr));
        lField->setText(tr2i18n("Field:", nullptr));
        lFirstRowAsColNames->setText(tr2i18n("First row as column names:", nullptr));
        cbSourceType->setItemText(0, tr2i18n("File or Named Pipe", nullptr));
        cbSourceType->setItemText(1, tr2i18n("Network TCP Socket", nullptr));
        cbSourceType->setItemText(2, tr2i18n("Network UDP Socket", nullptr));
        cbSourceType->setItemText(3, tr2i18n("Local Socket", nullptr));
        cbSourceType->setItemText(4, tr2i18n("Serial Port", nullptr));

        lFileType->setText(tr2i18n("Type:", nullptr));
        lFileName->setText(tr2i18n("Name:", nullptr));
        lLWT->setText(tr2i18n("LWT:", nullptr));
        lDBCDatabase->setText(tr2i18n("DBC Database", nullptr));
        lPort->setText(tr2i18n("Port:", nullptr));
#if QT_CONFIG(tooltip)
        bOpen->setToolTip(tr2i18n(" Select the file to import", nullptr));
#endif // QT_CONFIG(tooltip)
        bOpen->setText(QString());
        lSerialPort->setText(tr2i18n("Port:", nullptr));
        chbRelativePath->setText(QString());
#if QT_CONFIG(tooltip)
        bFileInfo->setToolTip(tr2i18n("Show file info", nullptr));
#endif // QT_CONFIG(tooltip)
        bFileInfo->setText(QString());
        bOpenDBC->setText(QString());
        lSourceType->setText(tr2i18n("Source:", nullptr));
        bLWT->setText(QString());
        lRelativePath->setText(tr2i18n("Relative Path:", nullptr));
        bManageConnections->setText(QString());
        lFilter->setText(tr2i18n("Filter:", nullptr));
        chbFirstRowAsColName->setText(QString());
        lMcapTopics->setText(tr2i18n("Topic:", nullptr));
        lMqttTopics->setText(tr2i18n("Topics:", nullptr));
        gbOptions->setTitle(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabDataFormat), tr2i18n("Data Format", nullptr));
        label->setText(tr2i18n("Precision:", nullptr));
        lPreviewLines->setText(tr2i18n("Number of rows to preview:", nullptr));
        bRefreshPreview->setText(tr2i18n("Refresh", nullptr));
        lWarningLimitedMessages->setText(tr2i18n("Not all variables might be visible, because of limited number of messages", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDataPreview), tr2i18n("Preview", nullptr));
        lStartRow->setText(tr2i18n("Start row:", nullptr));
#if QT_CONFIG(tooltip)
        sbEndRow->setToolTip(tr2i18n("Specify the end row to import; -1 stands for the last row", nullptr));
#endif // QT_CONFIG(tooltip)
        lStartColumn->setText(tr2i18n("Start column:", nullptr));
#if QT_CONFIG(tooltip)
        sbStartColumn->setToolTip(tr2i18n("Specify the start column for import", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        sbStartRow->setToolTip(tr2i18n("Specify the start row for import", nullptr));
#endif // QT_CONFIG(tooltip)
        lEndColumn->setText(tr2i18n("End column:", nullptr));
#if QT_CONFIG(tooltip)
        sbEndColumn->setToolTip(tr2i18n("Specify the end column to import; -1 stands for the last column", nullptr));
#endif // QT_CONFIG(tooltip)
        lEndRow->setText(tr2i18n("End row:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDataPortion), tr2i18n("Data Portion to Read", nullptr));
        gbUpdateOptions->setTitle(tr2i18n("Update Options", nullptr));
        lUpdateType->setText(tr2i18n("Update:", nullptr));
        lReadingType->setText(tr2i18n("Read:", nullptr));
        lUpdateInterval->setText(tr2i18n("Update interval:", nullptr));
        sbKeepNValues->setSpecialValueText(tr2i18n("All", nullptr));
        lKeepLastValues->setText(tr2i18n("Keep last values:", nullptr));
        lSampleSize->setText(tr2i18n("Sample size:", nullptr));
        cbUpdateType->setItemText(0, tr2i18n("Periodically", nullptr));
        cbUpdateType->setItemText(1, tr2i18n("On New Data", nullptr));

        sbUpdateInterval->setSuffix(tr2i18n(" ms", nullptr));
#if QT_CONFIG(tooltip)
        chbLinkFile->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        chbLinkFile->setText(tr2i18n("Link the file", nullptr));
        (void)ImportFileWidget;
    } // retranslateUi

};

namespace Ui {
    class ImportFileWidget: public Ui_ImportFileWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTFILEWIDGET_H

