/********************************************************************************
** Form generated from reading UI file 'boxplotdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BOXPLOTDOCK_H
#define UI_BOXPLOTDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_BoxPlotDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout_4;
    QLabel *lNotches;
    QLabel *lOrdering;
    KComboBox *cbWhiskersType;
    ResizableTextEdit *teComment;
    QFrame *frameDataColumns;
    QCheckBox *chkVariableWidth;
    QLabel *lName;
    QSpacerItem *verticalSpacer_19;
    QLabel *lPlotRange;
    QSpacerItem *verticalSpacer_7;
    QLabel *lWhiskersType;
    QLabel *lWhiskersRangeParameter;
    QLineEdit *leWhiskersRangeParameter;
    QLabel *lOrientation;
    QSpacerItem *verticalSpacer_8;
    TimedLineEdit *leName;
    QSpacerItem *verticalSpacer;
    QComboBox *cbOrdering;
    QComboBox *cbPlotRanges;
    QLabel *lDataColumn;
    QLabel *lComment;
    KComboBox *cbOrientation;
    QSpacerItem *horizontalSpacer_8;
    QLabel *lData;
    QLabel *lVariableWidth;
    QCheckBox *chkNotches;
    QCheckBox *chkVisible;
    QCheckBox *chkLegendVisible;
    QWidget *tabBox;
    QGridLayout *gridLayout_3;
    QSpacerItem *verticalSpacer_10;
    QSpacerItem *verticalSpacer_15;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer_11;
    QSpacerItem *verticalSpacer_16;
    QLabel *lMedianLine;
    QComboBox *cbNumber;
    QSpacerItem *verticalSpacer_6;
    QLabel *lNumber;
    QLabel *lFilling;
    QLabel *lWidthFactor;
    QSpinBox *sbWidthFactor;
    QSpacerItem *verticalSpacer_13;
    QLabel *lBorder;
    QSpacerItem *verticalSpacer_18;
    QSpacerItem *horizontalSpacer_7;
    QWidget *tabSymbol;
    QGridLayout *gridLayout_5;
    QLabel *lSymbolCategory;
    QFrame *frameSymbolCategory;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *rbMean;
    QRadioButton *rbMedian;
    QRadioButton *rbOutlier;
    QRadioButton *rbFarOut;
    QRadioButton *rbData;
    QRadioButton *rbWhiskerEnd;
    QSpacerItem *verticalSpacer_4;
    QCheckBox *chkJitteringEnabled;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_2;
    QWidget *tabWhiskers;
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer_12;
    QLabel *lWhiskersCap;
    QSpacerItem *verticalSpacer_5;
    QLabel *lWhiskersFormat;
    QLabel *lWhiskersCapSize;
    NumberSpinBox *sbWhiskersCapSize;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_9;
    QSpacerItem *verticalSpacer_17;
    QWidget *tabMargins;
    QGridLayout *gridLayout_2;
    QLabel *lRug;
    QLabel *lRugEnabled;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *chkRugEnabled;
    QLabel *lRugLength;
    QLabel *lRugWidth;
    QLabel *lRugOffset;
    QSpacerItem *verticalSpacer_14;
    NumberSpinBox *sbRugOffset;
    NumberSpinBox *sbRugWidth;
    NumberSpinBox *sbRugLength;

    void setupUi(QWidget *BoxPlotDock)
    {
        if (BoxPlotDock->objectName().isEmpty())
            BoxPlotDock->setObjectName("BoxPlotDock");
        BoxPlotDock->resize(351, 728);
        verticalLayout = new QVBoxLayout(BoxPlotDock);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(BoxPlotDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout_4 = new QGridLayout(tabGeneral);
        gridLayout_4->setObjectName("gridLayout_4");
        lNotches = new QLabel(tabGeneral);
        lNotches->setObjectName("lNotches");

        gridLayout_4->addWidget(lNotches, 11, 0, 1, 1);

        lOrdering = new QLabel(tabGeneral);
        lOrdering->setObjectName("lOrdering");

        gridLayout_4->addWidget(lOrdering, 6, 0, 1, 1);

        cbWhiskersType = new KComboBox(tabGeneral);
        cbWhiskersType->setObjectName("cbWhiskersType");

        gridLayout_4->addWidget(cbWhiskersType, 7, 2, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout_4->addWidget(teComment, 1, 2, 1, 1);

        frameDataColumns = new QFrame(tabGeneral);
        frameDataColumns->setObjectName("frameDataColumns");
        frameDataColumns->setFrameShape(QFrame::Shape::NoFrame);
        frameDataColumns->setFrameShadow(QFrame::Shadow::Raised);

        gridLayout_4->addWidget(frameDataColumns, 4, 2, 1, 1);

        chkVariableWidth = new QCheckBox(tabGeneral);
        chkVariableWidth->setObjectName("chkVariableWidth");

        gridLayout_4->addWidget(chkVariableWidth, 10, 2, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout_4->addWidget(lName, 0, 0, 1, 1);

        verticalSpacer_19 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_19, 12, 0, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout_4->addWidget(lPlotRange, 13, 0, 1, 1);

        verticalSpacer_7 = new QSpacerItem(72, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_7, 2, 0, 1, 1);

        lWhiskersType = new QLabel(tabGeneral);
        lWhiskersType->setObjectName("lWhiskersType");

        gridLayout_4->addWidget(lWhiskersType, 7, 0, 1, 1);

        lWhiskersRangeParameter = new QLabel(tabGeneral);
        lWhiskersRangeParameter->setObjectName("lWhiskersRangeParameter");

        gridLayout_4->addWidget(lWhiskersRangeParameter, 8, 0, 1, 1);

        leWhiskersRangeParameter = new QLineEdit(tabGeneral);
        leWhiskersRangeParameter->setObjectName("leWhiskersRangeParameter");

        gridLayout_4->addWidget(leWhiskersRangeParameter, 8, 2, 1, 1);

        lOrientation = new QLabel(tabGeneral);
        lOrientation->setObjectName("lOrientation");

        gridLayout_4->addWidget(lOrientation, 9, 0, 1, 1);

        verticalSpacer_8 = new QSpacerItem(72, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_8, 5, 0, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");

        gridLayout_4->addWidget(leName, 0, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 420, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer, 14, 0, 1, 1);

        cbOrdering = new QComboBox(tabGeneral);
        cbOrdering->setObjectName("cbOrdering");

        gridLayout_4->addWidget(cbOrdering, 6, 2, 1, 1);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout_4->addWidget(cbPlotRanges, 13, 2, 1, 1);

        lDataColumn = new QLabel(tabGeneral);
        lDataColumn->setObjectName("lDataColumn");
        lDataColumn->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout_4->addWidget(lDataColumn, 4, 0, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(lComment, 1, 0, 1, 1);

        cbOrientation = new KComboBox(tabGeneral);
        cbOrientation->setObjectName("cbOrientation");

        gridLayout_4->addWidget(cbOrientation, 9, 2, 1, 1);

        horizontalSpacer_8 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_8, 0, 1, 1, 1);

        lData = new QLabel(tabGeneral);
        lData->setObjectName("lData");
        QFont font;
        font.setBold(true);
        lData->setFont(font);

        gridLayout_4->addWidget(lData, 3, 0, 1, 1);

        lVariableWidth = new QLabel(tabGeneral);
        lVariableWidth->setObjectName("lVariableWidth");

        gridLayout_4->addWidget(lVariableWidth, 10, 0, 1, 1);

        chkNotches = new QCheckBox(tabGeneral);
        chkNotches->setObjectName("chkNotches");

        gridLayout_4->addWidget(chkNotches, 11, 2, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout_4->addWidget(chkVisible, 16, 0, 1, 1);

        chkLegendVisible = new QCheckBox(tabGeneral);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout_4->addWidget(chkLegendVisible, 15, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabBox = new QWidget();
        tabBox->setObjectName("tabBox");
        gridLayout_3 = new QGridLayout(tabBox);
        gridLayout_3->setObjectName("gridLayout_3");
        verticalSpacer_10 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_10, 5, 0, 1, 1);

        verticalSpacer_15 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_15, 9, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_3, 3, 0, 1, 1);

        verticalSpacer_11 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_11, 6, 0, 1, 1);

        verticalSpacer_16 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_16, 11, 0, 1, 1);

        lMedianLine = new QLabel(tabBox);
        lMedianLine->setObjectName("lMedianLine");
        lMedianLine->setFont(font);

        gridLayout_3->addWidget(lMedianLine, 10, 0, 1, 1);

        cbNumber = new QComboBox(tabBox);
        cbNumber->setObjectName("cbNumber");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbNumber->sizePolicy().hasHeightForWidth());
        cbNumber->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(cbNumber, 0, 2, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_6, 12, 0, 1, 1);

        lNumber = new QLabel(tabBox);
        lNumber->setObjectName("lNumber");

        gridLayout_3->addWidget(lNumber, 0, 0, 1, 1);

        lFilling = new QLabel(tabBox);
        lFilling->setObjectName("lFilling");
        lFilling->setFont(font);

        gridLayout_3->addWidget(lFilling, 4, 0, 1, 1);

        lWidthFactor = new QLabel(tabBox);
        lWidthFactor->setObjectName("lWidthFactor");

        gridLayout_3->addWidget(lWidthFactor, 2, 0, 1, 1);

        sbWidthFactor = new QSpinBox(tabBox);
        sbWidthFactor->setObjectName("sbWidthFactor");
        sizePolicy.setHeightForWidth(sbWidthFactor->sizePolicy().hasHeightForWidth());
        sbWidthFactor->setSizePolicy(sizePolicy);
        sbWidthFactor->setMaximum(100);
        sbWidthFactor->setSingleStep(10);
        sbWidthFactor->setValue(100);

        gridLayout_3->addWidget(sbWidthFactor, 2, 2, 1, 1);

        verticalSpacer_13 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_13, 8, 0, 1, 1);

        lBorder = new QLabel(tabBox);
        lBorder->setObjectName("lBorder");
        lBorder->setFont(font);

        gridLayout_3->addWidget(lBorder, 7, 0, 1, 1);

        verticalSpacer_18 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_18, 1, 0, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_7, 0, 1, 1, 1);

        tabWidget->addTab(tabBox, QString());
        tabSymbol = new QWidget();
        tabSymbol->setObjectName("tabSymbol");
        gridLayout_5 = new QGridLayout(tabSymbol);
        gridLayout_5->setObjectName("gridLayout_5");
        lSymbolCategory = new QLabel(tabSymbol);
        lSymbolCategory->setObjectName("lSymbolCategory");
        lSymbolCategory->setFont(font);
        lSymbolCategory->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout_5->addWidget(lSymbolCategory, 0, 0, 1, 1);

        frameSymbolCategory = new QFrame(tabSymbol);
        frameSymbolCategory->setObjectName("frameSymbolCategory");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(frameSymbolCategory->sizePolicy().hasHeightForWidth());
        frameSymbolCategory->setSizePolicy(sizePolicy1);
        frameSymbolCategory->setFrameShape(QFrame::Shape::NoFrame);
        frameSymbolCategory->setFrameShadow(QFrame::Shadow::Raised);
        verticalLayout_2 = new QVBoxLayout(frameSymbolCategory);
        verticalLayout_2->setObjectName("verticalLayout_2");
        rbMean = new QRadioButton(frameSymbolCategory);
        rbMean->setObjectName("rbMean");
        rbMean->setChecked(true);

        verticalLayout_2->addWidget(rbMean);

        rbMedian = new QRadioButton(frameSymbolCategory);
        rbMedian->setObjectName("rbMedian");

        verticalLayout_2->addWidget(rbMedian);

        rbOutlier = new QRadioButton(frameSymbolCategory);
        rbOutlier->setObjectName("rbOutlier");

        verticalLayout_2->addWidget(rbOutlier);

        rbFarOut = new QRadioButton(frameSymbolCategory);
        rbFarOut->setObjectName("rbFarOut");

        verticalLayout_2->addWidget(rbFarOut);

        rbData = new QRadioButton(frameSymbolCategory);
        rbData->setObjectName("rbData");

        verticalLayout_2->addWidget(rbData);

        rbWhiskerEnd = new QRadioButton(frameSymbolCategory);
        rbWhiskerEnd->setObjectName("rbWhiskerEnd");

        verticalLayout_2->addWidget(rbWhiskerEnd);

        verticalSpacer_4 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_4);

        chkJitteringEnabled = new QCheckBox(frameSymbolCategory);
        chkJitteringEnabled->setObjectName("chkJitteringEnabled");

        verticalLayout_2->addWidget(chkJitteringEnabled);


        gridLayout_5->addWidget(frameSymbolCategory, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_5->addItem(horizontalSpacer, 1, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(72, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_5->addItem(verticalSpacer_2, 2, 0, 1, 1);

        tabWidget->addTab(tabSymbol, QString());
        tabWhiskers = new QWidget();
        tabWhiskers->setObjectName("tabWhiskers");
        gridLayout = new QGridLayout(tabWhiskers);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer_12 = new QSpacerItem(20, 104, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_12, 6, 0, 1, 1);

        lWhiskersCap = new QLabel(tabWhiskers);
        lWhiskersCap->setObjectName("lWhiskersCap");
        lWhiskersCap->setFont(font);

        gridLayout->addWidget(lWhiskersCap, 3, 0, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_5, 2, 0, 1, 1);

        lWhiskersFormat = new QLabel(tabWhiskers);
        lWhiskersFormat->setObjectName("lWhiskersFormat");
        lWhiskersFormat->setFont(font);

        gridLayout->addWidget(lWhiskersFormat, 0, 0, 1, 1);

        lWhiskersCapSize = new QLabel(tabWhiskers);
        lWhiskersCapSize->setObjectName("lWhiskersCapSize");

        gridLayout->addWidget(lWhiskersCapSize, 4, 0, 1, 1);

        sbWhiskersCapSize = new NumberSpinBox(tabWhiskers);
        sbWhiskersCapSize->setObjectName("sbWhiskersCapSize");
        sizePolicy.setHeightForWidth(sbWhiskersCapSize->sizePolicy().hasHeightForWidth());
        sbWhiskersCapSize->setSizePolicy(sizePolicy);
        sbWhiskersCapSize->setMinimum(0.000000000000000);
        sbWhiskersCapSize->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbWhiskersCapSize, 4, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 1, 1, 1);

        verticalSpacer_9 = new QSpacerItem(38, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_9, 1, 0, 1, 1);

        verticalSpacer_17 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_17, 5, 0, 1, 1);

        tabWidget->addTab(tabWhiskers, QString());
        tabMargins = new QWidget();
        tabMargins->setObjectName("tabMargins");
        gridLayout_2 = new QGridLayout(tabMargins);
        gridLayout_2->setObjectName("gridLayout_2");
        lRug = new QLabel(tabMargins);
        lRug->setObjectName("lRug");
        lRug->setFont(font);

        gridLayout_2->addWidget(lRug, 0, 0, 1, 1);

        lRugEnabled = new QLabel(tabMargins);
        lRugEnabled->setObjectName("lRugEnabled");

        gridLayout_2->addWidget(lRugEnabled, 1, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_5, 1, 1, 1, 1);

        chkRugEnabled = new QCheckBox(tabMargins);
        chkRugEnabled->setObjectName("chkRugEnabled");
        sizePolicy.setHeightForWidth(chkRugEnabled->sizePolicy().hasHeightForWidth());
        chkRugEnabled->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(chkRugEnabled, 1, 2, 1, 1);

        lRugLength = new QLabel(tabMargins);
        lRugLength->setObjectName("lRugLength");

        gridLayout_2->addWidget(lRugLength, 2, 0, 1, 1);

        lRugWidth = new QLabel(tabMargins);
        lRugWidth->setObjectName("lRugWidth");

        gridLayout_2->addWidget(lRugWidth, 3, 0, 1, 1);

        lRugOffset = new QLabel(tabMargins);
        lRugOffset->setObjectName("lRugOffset");

        gridLayout_2->addWidget(lRugOffset, 4, 0, 1, 1);

        verticalSpacer_14 = new QSpacerItem(18, 494, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_14, 5, 0, 1, 1);

        sbRugOffset = new NumberSpinBox(tabMargins);
        sbRugOffset->setObjectName("sbRugOffset");
        sizePolicy.setHeightForWidth(sbRugOffset->sizePolicy().hasHeightForWidth());
        sbRugOffset->setSizePolicy(sizePolicy);
        sbRugOffset->setProperty("feedback", QVariant(true));

        gridLayout_2->addWidget(sbRugOffset, 4, 2, 1, 1);

        sbRugWidth = new NumberSpinBox(tabMargins);
        sbRugWidth->setObjectName("sbRugWidth");
        sizePolicy.setHeightForWidth(sbRugWidth->sizePolicy().hasHeightForWidth());
        sbRugWidth->setSizePolicy(sizePolicy);
        sbRugWidth->setMinimum(0.000000000000000);
        sbRugWidth->setProperty("feedback", QVariant(true));

        gridLayout_2->addWidget(sbRugWidth, 3, 2, 1, 1);

        sbRugLength = new NumberSpinBox(tabMargins);
        sbRugLength->setObjectName("sbRugLength");
        sizePolicy.setHeightForWidth(sbRugLength->sizePolicy().hasHeightForWidth());
        sbRugLength->setSizePolicy(sizePolicy);
        sbRugLength->setMinimum(0.000000000000000);
        sbRugLength->setProperty("feedback", QVariant(true));

        gridLayout_2->addWidget(sbRugLength, 2, 2, 1, 1);

        tabWidget->addTab(tabMargins, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbOrdering);
        QWidget::setTabOrder(cbOrdering, cbWhiskersType);
        QWidget::setTabOrder(cbWhiskersType, leWhiskersRangeParameter);
        QWidget::setTabOrder(leWhiskersRangeParameter, cbOrientation);
        QWidget::setTabOrder(cbOrientation, chkVariableWidth);
        QWidget::setTabOrder(chkVariableWidth, chkNotches);
        QWidget::setTabOrder(chkNotches, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);
        QWidget::setTabOrder(chkVisible, cbNumber);
        QWidget::setTabOrder(cbNumber, sbWidthFactor);
        QWidget::setTabOrder(sbWidthFactor, rbMean);
        QWidget::setTabOrder(rbMean, rbMedian);
        QWidget::setTabOrder(rbMedian, rbOutlier);
        QWidget::setTabOrder(rbOutlier, rbFarOut);
        QWidget::setTabOrder(rbFarOut, rbData);
        QWidget::setTabOrder(rbData, rbWhiskerEnd);
        QWidget::setTabOrder(rbWhiskerEnd, chkJitteringEnabled);
        QWidget::setTabOrder(chkJitteringEnabled, sbWhiskersCapSize);
        QWidget::setTabOrder(sbWhiskersCapSize, chkRugEnabled);
        QWidget::setTabOrder(chkRugEnabled, sbRugOffset);
        QWidget::setTabOrder(sbRugOffset, sbRugWidth);
        QWidget::setTabOrder(sbRugWidth, sbRugLength);

        retranslateUi(BoxPlotDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(BoxPlotDock);
    } // setupUi

    void retranslateUi(QWidget *BoxPlotDock)
    {
        lNotches->setText(tr2i18n("Notches", nullptr));
        lOrdering->setText(tr2i18n("Ordering:", nullptr));
        chkVariableWidth->setText(QString());
        lName->setText(tr2i18n("Name:", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        lWhiskersType->setText(tr2i18n("Whiskers:", nullptr));
        lWhiskersRangeParameter->setText(tr2i18n("k:", nullptr));
        lOrientation->setText(tr2i18n("Direction:", nullptr));
        lDataColumn->setText(tr2i18n("Column:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lData->setText(tr2i18n("Data", nullptr));
        lVariableWidth->setText(tr2i18n("Variable Width:", nullptr));
        chkNotches->setText(QString());
        chkVisible->setText(tr2i18n("Visible", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        lMedianLine->setText(tr2i18n("Median Line", nullptr));
        lNumber->setText(tr2i18n("Column", nullptr));
        lFilling->setText(tr2i18n("Filling", nullptr));
        lWidthFactor->setText(tr2i18n("Width", nullptr));
        sbWidthFactor->setSuffix(tr2i18n("%", nullptr));
        lBorder->setText(tr2i18n("Border", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabBox), tr2i18n("Box", nullptr));
        lSymbolCategory->setText(tr2i18n("Category", nullptr));
        rbMean->setText(tr2i18n("Mean", nullptr));
        rbMedian->setText(tr2i18n("Median", nullptr));
        rbOutlier->setText(tr2i18n("Outlier", nullptr));
        rbFarOut->setText(tr2i18n("Far Out", nullptr));
        rbData->setText(tr2i18n("Data (excl. Outlier and Far Out)", nullptr));
        rbWhiskerEnd->setText(tr2i18n("Whisker End", nullptr));
        chkJitteringEnabled->setText(tr2i18n("Jitter", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabSymbol), tr2i18n("Markers", nullptr));
        lWhiskersCap->setText(tr2i18n("Cap", nullptr));
        lWhiskersFormat->setText(tr2i18n("Line", nullptr));
        lWhiskersCapSize->setText(tr2i18n("Size:", nullptr));
#if QT_CONFIG(tooltip)
        sbWhiskersCapSize->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbWhiskersCapSize->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbWhiskersCapSize->setSuffix(tr2i18n(" pt", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabWhiskers), tr2i18n("Whiskers", nullptr));
        lRug->setText(tr2i18n("Rug Plot", nullptr));
        lRugEnabled->setText(tr2i18n("Enabled:", nullptr));
        chkRugEnabled->setText(QString());
        lRugLength->setText(tr2i18n("Length:", nullptr));
        lRugWidth->setText(tr2i18n("Width:", nullptr));
        lRugOffset->setText(tr2i18n("Offset:", nullptr));
#if QT_CONFIG(tooltip)
        sbRugOffset->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRugOffset->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbRugOffset->setSuffix(tr2i18n(" pt", nullptr));
#if QT_CONFIG(tooltip)
        sbRugWidth->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRugWidth->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbRugWidth->setSuffix(tr2i18n(" pt", nullptr));
#if QT_CONFIG(tooltip)
        sbRugLength->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRugLength->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbRugLength->setSuffix(tr2i18n(" pt", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabMargins), tr2i18n("Margins", nullptr));
        (void)BoxPlotDock;
    } // retranslateUi

};

namespace Ui {
    class BoxPlotDock: public Ui_BoxPlotDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BOXPLOTDOCK_H

