/********************************************************************************
** Form generated from reading UI file 'fitsoptionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FITSOPTIONSWIDGET_H
#define UI_FITSOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FITSOptionsWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *sbPreviewLines;
    QSpacerItem *horizontalSpacer;
    QPushButton *bRefreshPreview;
    QSplitter *splitter;
    QTreeWidget *twExtensions;
    QTableWidget *twPreview;

    void setupUi(QWidget *FITSOptionsWidget)
    {
        if (FITSOptionsWidget->objectName().isEmpty())
            FITSOptionsWidget->setObjectName("FITSOptionsWidget");
        FITSOptionsWidget->resize(520, 243);
        gridLayout = new QGridLayout(FITSOptionsWidget);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(FITSOptionsWidget);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        sbPreviewLines = new QSpinBox(FITSOptionsWidget);
        sbPreviewLines->setObjectName("sbPreviewLines");
        sbPreviewLines->setMaximum(10000);
        sbPreviewLines->setValue(100);

        horizontalLayout->addWidget(sbPreviewLines);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        bRefreshPreview = new QPushButton(FITSOptionsWidget);
        bRefreshPreview->setObjectName("bRefreshPreview");

        horizontalLayout->addWidget(bRefreshPreview);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        splitter = new QSplitter(FITSOptionsWidget);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        twExtensions = new QTreeWidget(splitter);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        twExtensions->setHeaderItem(__qtreewidgetitem);
        twExtensions->setObjectName("twExtensions");
        splitter->addWidget(twExtensions);
        twExtensions->header()->setStretchLastSection(false);
        twPreview = new QTableWidget(splitter);
        twPreview->setObjectName("twPreview");
        splitter->addWidget(twPreview);

        gridLayout->addWidget(splitter, 1, 0, 1, 1);


        retranslateUi(FITSOptionsWidget);

        QMetaObject::connectSlotsByName(FITSOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *FITSOptionsWidget)
    {
        label->setText(tr2i18n("Number of rows to preview:", nullptr));
        bRefreshPreview->setText(tr2i18n("Refresh", nullptr));
        (void)FITSOptionsWidget;
    } // retranslateUi

};

namespace Ui {
    class FITSOptionsWidget: public Ui_FITSOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FITSOPTIONSWIDGET_H

