/********************************************************************************
** Form generated from reading UI file 'fitsheadereditwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FITSHEADEREDITWIDGET_H
#define UI_FITSHEADEREDITWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FITSHeaderEditWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QSplitter *splitter;
    QTreeWidget *twExtensions;
    QTableWidget *twKeywordsTable;
    QPushButton *bOpen;
    QPushButton *bClose;
    QSpacerItem *horizontalSpacer;
    QPushButton *bAddUnit;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *bAddKey;
    QPushButton *bRemoveKey;

    void setupUi(QWidget *FITSHeaderEditWidget)
    {
        if (FITSHeaderEditWidget->objectName().isEmpty())
            FITSHeaderEditWidget->setObjectName("FITSHeaderEditWidget");
        FITSHeaderEditWidget->resize(804, 501);
        verticalLayout = new QVBoxLayout(FITSHeaderEditWidget);
        verticalLayout->setObjectName("verticalLayout");
        groupBox_2 = new QGroupBox(FITSHeaderEditWidget);
        groupBox_2->setObjectName("groupBox_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName("gridLayout");
        splitter = new QSplitter(groupBox_2);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        twExtensions = new QTreeWidget(splitter);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        twExtensions->setHeaderItem(__qtreewidgetitem);
        twExtensions->setObjectName("twExtensions");
        splitter->addWidget(twExtensions);
        twExtensions->header()->setVisible(false);
        twKeywordsTable = new QTableWidget(splitter);
        twKeywordsTable->setObjectName("twKeywordsTable");
        splitter->addWidget(twKeywordsTable);

        gridLayout->addWidget(splitter, 0, 0, 1, 7);

        bOpen = new QPushButton(groupBox_2);
        bOpen->setObjectName("bOpen");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(bOpen->sizePolicy().hasHeightForWidth());
        bOpen->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(bOpen, 1, 0, 1, 1);

        bClose = new QPushButton(groupBox_2);
        bClose->setObjectName("bClose");

        gridLayout->addWidget(bClose, 1, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(773, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 2, 1, 1);

        bAddUnit = new QPushButton(groupBox_2);
        bAddUnit->setObjectName("bAddUnit");

        gridLayout->addWidget(bAddUnit, 1, 3, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 1, 4, 1, 1);

        bAddKey = new QPushButton(groupBox_2);
        bAddKey->setObjectName("bAddKey");

        gridLayout->addWidget(bAddKey, 1, 5, 1, 1);

        bRemoveKey = new QPushButton(groupBox_2);
        bRemoveKey->setObjectName("bRemoveKey");

        gridLayout->addWidget(bRemoveKey, 1, 6, 1, 1);


        verticalLayout->addWidget(groupBox_2);


        retranslateUi(FITSHeaderEditWidget);

        QMetaObject::connectSlotsByName(FITSHeaderEditWidget);
    } // setupUi

    void retranslateUi(QWidget *FITSHeaderEditWidget)
    {
        groupBox_2->setTitle(QString());
#if QT_CONFIG(tooltip)
        bOpen->setToolTip(tr2i18n(" Select the file to import", nullptr));
#endif // QT_CONFIG(tooltip)
        bOpen->setText(tr2i18n("Open File...", nullptr));
        bClose->setText(tr2i18n("Close File", nullptr));
        bAddUnit->setText(QString());
        bAddKey->setText(QString());
        bRemoveKey->setText(QString());
        (void)FITSHeaderEditWidget;
    } // retranslateUi

};

namespace Ui {
    class FITSHeaderEditWidget: public Ui_FITSHeaderEditWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FITSHEADEREDITWIDGET_H

