/********************************************************************************
** Form generated from reading UI file 'xyfourierfiltercurvedockgeneraltab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XYFOURIERFILTERCURVEDOCKGENERALTAB_H
#define UI_XYFOURIERFILTERCURVEDOCKGENERALTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_XYFourierFilterCurveDockGeneralTab
{
public:
    QGridLayout *gridLayout_2;
    QLabel *lXRange;
    QLabel *lCutoff;
    QLabel *lForm;
    QCheckBox *chkVisible;
    QSpacerItem *verticalSpacer_4;
    QLabel *lDataSourceType;
    QHBoxLayout *horizontalLayout_2;
    NumberSpinBox *sbCutoff2;
    QComboBox *cbUnit2;
    QComboBox *cbPlotRanges;
    QTextEdit *teResult;
    QLabel *lName;
    QFrame *frameRange;
    QGridLayout *gridLayout;
    QLabel *lMin;
    QLineEdit *leMin;
    QLabel *lMax;
    QLineEdit *leMax;
    QLabel *lMinDateTime;
    UTCDateTimeEdit *dateTimeEditMin;
    QLabel *lMaxDateTime;
    UTCDateTimeEdit *dateTimeEditMax;
    QHBoxLayout *horizontalLayout_3;
    QComboBox *cbForm;
    QLabel *lOrder;
    QSpinBox *sbOrder;
    QHBoxLayout *horizontalLayout;
    NumberSpinBox *sbCutoff;
    QComboBox *cbUnit;
    ResizableTextEdit *teComment;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_3;
    QLabel *lCutoff2;
    QLabel *lYColumn;
    KComboBox *cbType;
    QLabel *lData;
    QLabel *lPlotRange;
    TimedLineEdit *leName;
    QFrame *line_2;
    QPushButton *pbRecalculate;
    QLabel *lXColumn;
    QCheckBox *cbAutoRange;
    QSpacerItem *verticalSpacer_5;
    QSpacerItem *horizontalSpacer_5;
    QLabel *lComment;
    QLabel *lFilter;
    QLabel *lType;
    QComboBox *cbDataSourceType;
    QLabel *lResults;
    QSpacerItem *verticalSpacerGeneral;
    QLabel *lDataSourceCurve;
    QCheckBox *chkLegendVisible;

    void setupUi(QWidget *XYFourierFilterCurveDockGeneralTab)
    {
        if (XYFourierFilterCurveDockGeneralTab->objectName().isEmpty())
            XYFourierFilterCurveDockGeneralTab->setObjectName("XYFourierFilterCurveDockGeneralTab");
        XYFourierFilterCurveDockGeneralTab->resize(353, 953);
        gridLayout_2 = new QGridLayout(XYFourierFilterCurveDockGeneralTab);
        gridLayout_2->setObjectName("gridLayout_2");
        lXRange = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lXRange->setObjectName("lXRange");

        gridLayout_2->addWidget(lXRange, 8, 0, 1, 1);

        lCutoff = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lCutoff->setObjectName("lCutoff");

        gridLayout_2->addWidget(lCutoff, 14, 0, 1, 1);

        lForm = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lForm->setObjectName("lForm");

        gridLayout_2->addWidget(lForm, 13, 0, 1, 1);

        chkVisible = new QCheckBox(XYFourierFilterCurveDockGeneralTab);
        chkVisible->setObjectName("chkVisible");

        gridLayout_2->addWidget(chkVisible, 24, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_4, 10, 2, 1, 2);

        lDataSourceType = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lDataSourceType->setObjectName("lDataSourceType");

        gridLayout_2->addWidget(lDataSourceType, 4, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        sbCutoff2 = new NumberSpinBox(XYFourierFilterCurveDockGeneralTab);
        sbCutoff2->setObjectName("sbCutoff2");
        sbCutoff2->setMinimum(0.000000000000000);
        sbCutoff2->setProperty("feedback", QVariant(false));

        horizontalLayout_2->addWidget(sbCutoff2);

        cbUnit2 = new QComboBox(XYFourierFilterCurveDockGeneralTab);
        cbUnit2->setObjectName("cbUnit2");

        horizontalLayout_2->addWidget(cbUnit2);


        gridLayout_2->addLayout(horizontalLayout_2, 15, 2, 1, 2);

        cbPlotRanges = new QComboBox(XYFourierFilterCurveDockGeneralTab);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout_2->addWidget(cbPlotRanges, 21, 2, 1, 2);

        teResult = new QTextEdit(XYFourierFilterCurveDockGeneralTab);
        teResult->setObjectName("teResult");
        teResult->setReadOnly(true);

        gridLayout_2->addWidget(teResult, 17, 2, 1, 2);

        lName = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lName->setObjectName("lName");

        gridLayout_2->addWidget(lName, 0, 0, 1, 1);

        frameRange = new QFrame(XYFourierFilterCurveDockGeneralTab);
        frameRange->setObjectName("frameRange");
        frameRange->setFrameShape(QFrame::Shape::NoFrame);
        frameRange->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout = new QGridLayout(frameRange);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, -1);
        lMin = new QLabel(frameRange);
        lMin->setObjectName("lMin");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lMin->sizePolicy().hasHeightForWidth());
        lMin->setSizePolicy(sizePolicy);
        lMin->setMinimumSize(QSize(50, 0));

        gridLayout->addWidget(lMin, 0, 0, 1, 1);

        leMin = new QLineEdit(frameRange);
        leMin->setObjectName("leMin");

        gridLayout->addWidget(leMin, 0, 1, 1, 1);

        lMax = new QLabel(frameRange);
        lMax->setObjectName("lMax");
        sizePolicy.setHeightForWidth(lMax->sizePolicy().hasHeightForWidth());
        lMax->setSizePolicy(sizePolicy);
        lMax->setMinimumSize(QSize(50, 0));

        gridLayout->addWidget(lMax, 1, 0, 1, 1);

        leMax = new QLineEdit(frameRange);
        leMax->setObjectName("leMax");

        gridLayout->addWidget(leMax, 1, 1, 1, 1);

        lMinDateTime = new QLabel(frameRange);
        lMinDateTime->setObjectName("lMinDateTime");
        sizePolicy.setHeightForWidth(lMinDateTime->sizePolicy().hasHeightForWidth());
        lMinDateTime->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lMinDateTime, 2, 0, 1, 1);

        dateTimeEditMin = new UTCDateTimeEdit(frameRange);
        dateTimeEditMin->setObjectName("dateTimeEditMin");

        gridLayout->addWidget(dateTimeEditMin, 2, 1, 1, 1);

        lMaxDateTime = new QLabel(frameRange);
        lMaxDateTime->setObjectName("lMaxDateTime");
        sizePolicy.setHeightForWidth(lMaxDateTime->sizePolicy().hasHeightForWidth());
        lMaxDateTime->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lMaxDateTime, 3, 0, 1, 1);

        dateTimeEditMax = new UTCDateTimeEdit(frameRange);
        dateTimeEditMax->setObjectName("dateTimeEditMax");

        gridLayout->addWidget(dateTimeEditMax, 3, 1, 1, 1);


        gridLayout_2->addWidget(frameRange, 9, 2, 1, 2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        cbForm = new QComboBox(XYFourierFilterCurveDockGeneralTab);
        cbForm->setObjectName("cbForm");

        horizontalLayout_3->addWidget(cbForm);

        lOrder = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lOrder->setObjectName("lOrder");
        lOrder->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_3->addWidget(lOrder);

        sbOrder = new QSpinBox(XYFourierFilterCurveDockGeneralTab);
        sbOrder->setObjectName("sbOrder");
        sbOrder->setMinimum(1);
        sbOrder->setMaximum(10);
        sbOrder->setValue(1);

        horizontalLayout_3->addWidget(sbOrder);


        gridLayout_2->addLayout(horizontalLayout_3, 13, 2, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        sbCutoff = new NumberSpinBox(XYFourierFilterCurveDockGeneralTab);
        sbCutoff->setObjectName("sbCutoff");
        sbCutoff->setMinimum(0.000000000000000);
        sbCutoff->setProperty("feedback", QVariant(false));

        horizontalLayout->addWidget(sbCutoff);

        cbUnit = new QComboBox(XYFourierFilterCurveDockGeneralTab);
        cbUnit->setObjectName("cbUnit");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbUnit->sizePolicy().hasHeightForWidth());
        cbUnit->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(cbUnit);


        gridLayout_2->addLayout(horizontalLayout, 14, 2, 1, 2);

        teComment = new ResizableTextEdit(XYFourierFilterCurveDockGeneralTab);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout_2->addWidget(teComment, 1, 2, 1, 2);

        horizontalSpacer_2 = new QSpacerItem(312, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 20, 2, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_3, 2, 2, 1, 2);

        lCutoff2 = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lCutoff2->setObjectName("lCutoff2");

        gridLayout_2->addWidget(lCutoff2, 15, 0, 1, 1);

        lYColumn = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lYColumn->setObjectName("lYColumn");

        gridLayout_2->addWidget(lYColumn, 7, 0, 1, 1);

        cbType = new KComboBox(XYFourierFilterCurveDockGeneralTab);
        cbType->setObjectName("cbType");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cbType->sizePolicy().hasHeightForWidth());
        cbType->setSizePolicy(sizePolicy2);

        gridLayout_2->addWidget(cbType, 12, 2, 1, 2);

        lData = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lData->setObjectName("lData");
        QFont font;
        font.setBold(true);
        lData->setFont(font);

        gridLayout_2->addWidget(lData, 3, 0, 1, 1);

        lPlotRange = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout_2->addWidget(lPlotRange, 21, 0, 1, 1);

        leName = new TimedLineEdit(XYFourierFilterCurveDockGeneralTab);
        leName->setObjectName("leName");

        gridLayout_2->addWidget(leName, 0, 2, 1, 2);

        line_2 = new QFrame(XYFourierFilterCurveDockGeneralTab);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(line_2, 19, 0, 1, 4);

        pbRecalculate = new QPushButton(XYFourierFilterCurveDockGeneralTab);
        pbRecalculate->setObjectName("pbRecalculate");

        gridLayout_2->addWidget(pbRecalculate, 20, 3, 1, 1);

        lXColumn = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lXColumn->setObjectName("lXColumn");

        gridLayout_2->addWidget(lXColumn, 6, 0, 1, 1);

        cbAutoRange = new QCheckBox(XYFourierFilterCurveDockGeneralTab);
        cbAutoRange->setObjectName("cbAutoRange");
        cbAutoRange->setChecked(true);

        gridLayout_2->addWidget(cbAutoRange, 8, 2, 1, 2);

        verticalSpacer_5 = new QSpacerItem(38, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_5, 16, 2, 1, 2);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        lComment = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(lComment, 1, 0, 1, 1);

        lFilter = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lFilter->setObjectName("lFilter");
        lFilter->setFont(font);

        gridLayout_2->addWidget(lFilter, 11, 0, 1, 1);

        lType = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lType->setObjectName("lType");

        gridLayout_2->addWidget(lType, 12, 0, 1, 1);

        cbDataSourceType = new QComboBox(XYFourierFilterCurveDockGeneralTab);
        cbDataSourceType->setObjectName("cbDataSourceType");
        sizePolicy2.setHeightForWidth(cbDataSourceType->sizePolicy().hasHeightForWidth());
        cbDataSourceType->setSizePolicy(sizePolicy2);

        gridLayout_2->addWidget(cbDataSourceType, 4, 2, 1, 2);

        lResults = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lResults->setObjectName("lResults");
        lResults->setFont(font);
        lResults->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout_2->addWidget(lResults, 17, 0, 1, 1);

        verticalSpacerGeneral = new QSpacerItem(24, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacerGeneral, 22, 0, 1, 1);

        lDataSourceCurve = new QLabel(XYFourierFilterCurveDockGeneralTab);
        lDataSourceCurve->setObjectName("lDataSourceCurve");

        gridLayout_2->addWidget(lDataSourceCurve, 5, 0, 1, 1);

        chkLegendVisible = new QCheckBox(XYFourierFilterCurveDockGeneralTab);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout_2->addWidget(chkLegendVisible, 23, 0, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbDataSourceType);
        QWidget::setTabOrder(cbDataSourceType, cbAutoRange);
        QWidget::setTabOrder(cbAutoRange, leMin);
        QWidget::setTabOrder(leMin, leMax);
        QWidget::setTabOrder(leMax, dateTimeEditMin);
        QWidget::setTabOrder(dateTimeEditMin, dateTimeEditMax);
        QWidget::setTabOrder(dateTimeEditMax, cbType);
        QWidget::setTabOrder(cbType, cbForm);
        QWidget::setTabOrder(cbForm, sbOrder);
        QWidget::setTabOrder(sbOrder, sbCutoff);
        QWidget::setTabOrder(sbCutoff, cbUnit);
        QWidget::setTabOrder(cbUnit, sbCutoff2);
        QWidget::setTabOrder(sbCutoff2, cbUnit2);
        QWidget::setTabOrder(cbUnit2, teResult);
        QWidget::setTabOrder(teResult, pbRecalculate);
        QWidget::setTabOrder(pbRecalculate, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);

        retranslateUi(XYFourierFilterCurveDockGeneralTab);

        QMetaObject::connectSlotsByName(XYFourierFilterCurveDockGeneralTab);
    } // setupUi

    void retranslateUi(QWidget *XYFourierFilterCurveDockGeneralTab)
    {
        lXRange->setText(tr2i18n("X-Range:", nullptr));
        lCutoff->setText(tr2i18n("Cutoff:", nullptr));
        lForm->setText(tr2i18n("Form:", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lDataSourceType->setText(tr2i18n("Source:", nullptr));
#if QT_CONFIG(tooltip)
        sbCutoff2->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbCutoff2->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lName->setText(tr2i18n("Name:", nullptr));
        lMin->setText(tr2i18n("Minimum:", nullptr));
        lMax->setText(tr2i18n("Maximum:", nullptr));
        lMinDateTime->setText(tr2i18n("Minimum:", nullptr));
        lMaxDateTime->setText(tr2i18n("Maximum:", nullptr));
        lOrder->setText(tr2i18n("Order:", nullptr));
#if QT_CONFIG(tooltip)
        sbCutoff->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbCutoff->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lCutoff2->setText(tr2i18n("Cutoff2:", nullptr));
        lYColumn->setText(tr2i18n("Y-Data:", nullptr));
        lData->setText(tr2i18n("Data", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        pbRecalculate->setText(tr2i18n("Recalculate", nullptr));
        lXColumn->setText(tr2i18n("X-Data:", nullptr));
        cbAutoRange->setText(tr2i18n("Auto", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lFilter->setText(tr2i18n("Filter", nullptr));
        lType->setText(tr2i18n("Type:", nullptr));
        lResults->setText(tr2i18n("Results:", nullptr));
        lDataSourceCurve->setText(tr2i18n("Curve:", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        (void)XYFourierFilterCurveDockGeneralTab;
    } // retranslateUi

};

namespace Ui {
    class XYFourierFilterCurveDockGeneralTab: public Ui_XYFourierFilterCurveDockGeneralTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // XYFOURIERFILTERCURVEDOCKGENERALTAB_H

