/********************************************************************************
** Form generated from reading UI file 'projectdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTDOCK_H
#define UI_PROJECTDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_ProjectDock
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *gbGeneral;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer_5;
    QLabel *lVersion_2;
    QLabel *label_5;
    QLabel *lSaveDockStates;
    TimedLineEdit *leName;
    QLabel *label_6;
    QLabel *label_7;
    QLabel *label;
    QLineEdit *leFileName;
    QLabel *lModified;
    QCheckBox *chkSaveCalculations;
    QLabel *lCreated;
    ResizableTextEdit *teComment;
    QSpacerItem *verticalSpacer;
    QLineEdit *leAuthor;
    QLabel *lSettings;
    QLabel *label_2;
    QLabel *lVersion;
    QFrame *lineSettings;
    QCheckBox *chkSaveDockStates;
    QLabel *label_9;
    QLabel *lSaveCalculations;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer_3;

    void setupUi(QWidget *ProjectDock)
    {
        if (ProjectDock->objectName().isEmpty())
            ProjectDock->setObjectName("ProjectDock");
        ProjectDock->resize(404, 739);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ProjectDock->sizePolicy().hasHeightForWidth());
        ProjectDock->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(ProjectDock);
        verticalLayout->setObjectName("verticalLayout");
        gbGeneral = new QGroupBox(ProjectDock);
        gbGeneral->setObjectName("gbGeneral");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(gbGeneral->sizePolicy().hasHeightForWidth());
        gbGeneral->setSizePolicy(sizePolicy1);
        gbGeneral->setFlat(true);
        gridLayout = new QGridLayout(gbGeneral);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        lVersion_2 = new QLabel(gbGeneral);
        lVersion_2->setObjectName("lVersion_2");

        gridLayout->addWidget(lVersion_2, 1, 0, 1, 1);

        label_5 = new QLabel(gbGeneral);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 5, 0, 1, 1);

        lSaveDockStates = new QLabel(gbGeneral);
        lSaveDockStates->setObjectName("lSaveDockStates");

        gridLayout->addWidget(lSaveDockStates, 11, 0, 1, 1);

        leName = new TimedLineEdit(gbGeneral);
        leName->setObjectName("leName");
        leName->setEnabled(true);
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(leName->sizePolicy().hasHeightForWidth());
        leName->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(leName, 3, 2, 1, 1);

        label_6 = new QLabel(gbGeneral);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 6, 0, 1, 1);

        label_7 = new QLabel(gbGeneral);
        label_7->setObjectName("label_7");

        gridLayout->addWidget(label_7, 3, 0, 1, 1);

        label = new QLabel(gbGeneral);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        leFileName = new QLineEdit(gbGeneral);
        leFileName->setObjectName("leFileName");
        leFileName->setEnabled(true);
        sizePolicy2.setHeightForWidth(leFileName->sizePolicy().hasHeightForWidth());
        leFileName->setSizePolicy(sizePolicy2);
        leFileName->setReadOnly(true);

        gridLayout->addWidget(leFileName, 0, 2, 1, 1);

        lModified = new QLabel(gbGeneral);
        lModified->setObjectName("lModified");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(lModified->sizePolicy().hasHeightForWidth());
        lModified->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(lModified, 6, 2, 1, 1);

        chkSaveCalculations = new QCheckBox(gbGeneral);
        chkSaveCalculations->setObjectName("chkSaveCalculations");

        gridLayout->addWidget(chkSaveCalculations, 12, 2, 1, 1);

        lCreated = new QLabel(gbGeneral);
        lCreated->setObjectName("lCreated");
        sizePolicy3.setHeightForWidth(lCreated->sizePolicy().hasHeightForWidth());
        lCreated->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(lCreated, 5, 2, 1, 1);

        teComment = new ResizableTextEdit(gbGeneral);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);
        teComment->setReadOnly(false);

        gridLayout->addWidget(teComment, 7, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 8, 0, 1, 1);

        leAuthor = new QLineEdit(gbGeneral);
        leAuthor->setObjectName("leAuthor");

        gridLayout->addWidget(leAuthor, 4, 2, 1, 1);

        lSettings = new QLabel(gbGeneral);
        lSettings->setObjectName("lSettings");
        QFont font;
        font.setBold(true);
        lSettings->setFont(font);

        gridLayout->addWidget(lSettings, 10, 0, 1, 1);

        label_2 = new QLabel(gbGeneral);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 4, 0, 1, 1);

        lVersion = new QLabel(gbGeneral);
        lVersion->setObjectName("lVersion");
        sizePolicy3.setHeightForWidth(lVersion->sizePolicy().hasHeightForWidth());
        lVersion->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(lVersion, 1, 2, 1, 1);

        lineSettings = new QFrame(gbGeneral);
        lineSettings->setObjectName("lineSettings");
        lineSettings->setFrameShape(QFrame::Shape::HLine);
        lineSettings->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(lineSettings, 9, 0, 1, 3);

        chkSaveDockStates = new QCheckBox(gbGeneral);
        chkSaveDockStates->setObjectName("chkSaveDockStates");

        gridLayout->addWidget(chkSaveDockStates, 11, 2, 1, 1);

        label_9 = new QLabel(gbGeneral);
        label_9->setObjectName("label_9");
        label_9->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_9, 7, 0, 1, 1);

        lSaveCalculations = new QLabel(gbGeneral);
        lSaveCalculations->setObjectName("lSaveCalculations");

        gridLayout->addWidget(lSaveCalculations, 12, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 2, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_3, 13, 0, 1, 1);


        verticalLayout->addWidget(gbGeneral);

        QWidget::setTabOrder(leFileName, leName);
        QWidget::setTabOrder(leName, leAuthor);
        QWidget::setTabOrder(leAuthor, teComment);
        QWidget::setTabOrder(teComment, chkSaveDockStates);
        QWidget::setTabOrder(chkSaveDockStates, chkSaveCalculations);

        retranslateUi(ProjectDock);

        QMetaObject::connectSlotsByName(ProjectDock);
    } // setupUi

    void retranslateUi(QWidget *ProjectDock)
    {
        gbGeneral->setTitle(QString());
        lVersion_2->setText(tr2i18n("Version:", nullptr));
        label_5->setText(tr2i18n("Created:", nullptr));
        lSaveDockStates->setText(tr2i18n("Save Dock States:", nullptr));
        label_6->setText(tr2i18n("Modified:", nullptr));
        label_7->setText(tr2i18n("Name:", nullptr));
        label->setText(tr2i18n("File Name:", nullptr));
        lModified->setText(QString());
        chkSaveCalculations->setText(QString());
        lCreated->setText(QString());
        lSettings->setText(tr2i18n("Settings:", nullptr));
        label_2->setText(tr2i18n("Author:", nullptr));
        lVersion->setText(QString());
        chkSaveDockStates->setText(QString());
        label_9->setText(tr2i18n("Comment:", nullptr));
        lSaveCalculations->setText(tr2i18n("Save Calculations:", nullptr));
        (void)ProjectDock;
    } // retranslateUi

};

namespace Ui {
    class ProjectDock: public Ui_ProjectDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROJECTDOCK_H

