/********************************************************************************
** Form generated from reading UI file 'mcapoptionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MCAPOPTIONSWIDGET_H
#define UI_MCAPOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_McapOptionsWidget
{
public:
    QGridLayout *gridLayout;
    KComboBox *cbDateTimeFormat;
    QSpacerItem *horizontalSpacer;
    QCheckBox *chbConvertNaNToZero;
    QSpacerItem *verticalSpacer_4;
    QLabel *lDateTimeFormat;
    QCheckBox *chbCreateIndex;

    void setupUi(QWidget *McapOptionsWidget)
    {
        if (McapOptionsWidget->objectName().isEmpty())
            McapOptionsWidget->setObjectName("McapOptionsWidget");
        McapOptionsWidget->resize(632, 227);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(McapOptionsWidget->sizePolicy().hasHeightForWidth());
        McapOptionsWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(McapOptionsWidget);
        gridLayout->setObjectName("gridLayout");
        cbDateTimeFormat = new KComboBox(McapOptionsWidget);
        cbDateTimeFormat->setObjectName("cbDateTimeFormat");
        sizePolicy.setHeightForWidth(cbDateTimeFormat->sizePolicy().hasHeightForWidth());
        cbDateTimeFormat->setSizePolicy(sizePolicy);
        cbDateTimeFormat->setEditable(true);

        gridLayout->addWidget(cbDateTimeFormat, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);

        chbConvertNaNToZero = new QCheckBox(McapOptionsWidget);
        chbConvertNaNToZero->setObjectName("chbConvertNaNToZero");
        chbConvertNaNToZero->setChecked(false);

        gridLayout->addWidget(chbConvertNaNToZero, 2, 2, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 44, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_4, 4, 0, 1, 1);

        lDateTimeFormat = new QLabel(McapOptionsWidget);
        lDateTimeFormat->setObjectName("lDateTimeFormat");

        gridLayout->addWidget(lDateTimeFormat, 0, 0, 1, 1);

        chbCreateIndex = new QCheckBox(McapOptionsWidget);
        chbCreateIndex->setObjectName("chbCreateIndex");

        gridLayout->addWidget(chbCreateIndex, 2, 0, 1, 1);


        retranslateUi(McapOptionsWidget);

        QMetaObject::connectSlotsByName(McapOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *McapOptionsWidget)
    {
        chbConvertNaNToZero->setText(tr2i18n("Convert NaN to 0", nullptr));
        lDateTimeFormat->setText(tr2i18n("DateTime format:", nullptr));
        chbCreateIndex->setText(tr2i18n("Create index column", nullptr));
        (void)McapOptionsWidget;
    } // retranslateUi

};

namespace Ui {
    class McapOptionsWidget: public Ui_McapOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MCAPOPTIONSWIDGET_H

