/********************************************************************************
** Form generated from reading UI file 'xycurvedock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XYCURVEDOCK_H
#define UI_XYCURVEDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "kcolorbutton.h"
#include "kcombobox.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_XYCurveDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QWidget *tabLine;
    QGridLayout *gridLayout_4;
    KComboBox *cbLineType;
    QLabel *lLineType;
    QSpacerItem *verticalSpacer_4;
    QCheckBox *chkLineIncreasingXOnly;
    QSpinBox *sbLineInterpolationPointsCount;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer;
    QLabel *lDropLines;
    QLabel *lLineInterpolationPointsCount;
    QLabel *lLineSkipGaps;
    QLabel *lValuesGeneral_2;
    QLabel *lLineIncreasingXOnly;
    QCheckBox *chkLineSkipGaps;
    QSpacerItem *verticalSpacer_12;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *horizontalSpacer;
    QWidget *tabSymbol;
    QWidget *tabValues;
    QGridLayout *gridLayout_3;
    QLabel *lValuesColumn;
    QLabel *lValuesPrecision;
    QSpinBox *sbValuesPrecision;
    QLineEdit *leValuesSuffix;
    QLabel *lValuesText;
    QLabel *lValuesSuffix;
    QLabel *lValuesOpacity;
    QLabel *lValuesFont;
    QLabel *lValuesGeneral;
    KFontRequester *kfrValuesFont;
    KColorButton *kcbValuesColor;
    QSpinBox *sbValuesOpacity;
    QSpacerItem *horizontalSpacer_3;
    QLabel *lValuesDistance;
    KComboBox *cbValuesNumericFormat;
    KComboBox *cbValuesType;
    QLabel *lValuesColor;
    KComboBox *cbValuesPosition;
    QLineEdit *leValuesPrefix;
    QLabel *lValuesRotation;
    QLabel *lValuesPrefix;
    QSpacerItem *verticalSpacer_8;
    QSpacerItem *verticalSpacer_7;
    QLabel *lValuesFormat;
    QSpinBox *sbValuesRotation;
    QLabel *lValuesPosition;
    QLabel *lValuesNumericFormat;
    QSpacerItem *verticalSpacer_6;
    QLabel *lValuesDateTimeFormat;
    QComboBox *cbValuesDateTimeFormat;
    QLabel *lValuesType;
    NumberSpinBox *sbValuesDistance;
    QWidget *tabAreaFilling;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer_2;
    QWidget *tabErrorBars;
    QVBoxLayout *verticalLayout_3;
    QWidget *tabMarginalPlots;
    QGridLayout *gridLayout;
    QCheckBox *chkRugEnabled;
    QLabel *lRugEnabled;
    QSpacerItem *horizontalSpacer_5;
    QLabel *lRugLength;
    QLabel *lRugOffset;
    QLabel *lRugWidth;
    QLabel *lRugOrientation;
    QLabel *lRug;
    QComboBox *cbRugOrientation;
    QSpacerItem *verticalSpacer_13;
    NumberSpinBox *sbRugLength;
    NumberSpinBox *sbRugWidth;
    NumberSpinBox *sbRugOffset;

    void setupUi(QWidget *XYCurveDock)
    {
        if (XYCurveDock->objectName().isEmpty())
            XYCurveDock->setObjectName("XYCurveDock");
        XYCurveDock->resize(383, 776);
        verticalLayout = new QVBoxLayout(XYCurveDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(XYCurveDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        tabWidget->addTab(tabGeneral, QString());
        tabLine = new QWidget();
        tabLine->setObjectName("tabLine");
        gridLayout_4 = new QGridLayout(tabLine);
        gridLayout_4->setObjectName("gridLayout_4");
        cbLineType = new KComboBox(tabLine);
        cbLineType->setObjectName("cbLineType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbLineType->sizePolicy().hasHeightForWidth());
        cbLineType->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(cbLineType, 1, 2, 1, 1);

        lLineType = new QLabel(tabLine);
        lLineType->setObjectName("lLineType");

        gridLayout_4->addWidget(lLineType, 1, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_4, 8, 0, 1, 1);

        chkLineIncreasingXOnly = new QCheckBox(tabLine);
        chkLineIncreasingXOnly->setObjectName("chkLineIncreasingXOnly");

        gridLayout_4->addWidget(chkLineIncreasingXOnly, 4, 2, 1, 1);

        sbLineInterpolationPointsCount = new QSpinBox(tabLine);
        sbLineInterpolationPointsCount->setObjectName("sbLineInterpolationPointsCount");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sbLineInterpolationPointsCount->sizePolicy().hasHeightForWidth());
        sbLineInterpolationPointsCount->setSizePolicy(sizePolicy1);
        sbLineInterpolationPointsCount->setMinimum(1);

        gridLayout_4->addWidget(sbLineInterpolationPointsCount, 2, 2, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer_3, 9, 0, 1, 1);

        verticalSpacer = new QSpacerItem(32, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer, 6, 0, 1, 1);

        lDropLines = new QLabel(tabLine);
        lDropLines->setObjectName("lDropLines");
        QFont font;
        font.setBold(true);
        lDropLines->setFont(font);

        gridLayout_4->addWidget(lDropLines, 7, 0, 1, 1);

        lLineInterpolationPointsCount = new QLabel(tabLine);
        lLineInterpolationPointsCount->setObjectName("lLineInterpolationPointsCount");

        gridLayout_4->addWidget(lLineInterpolationPointsCount, 2, 0, 1, 1);

        lLineSkipGaps = new QLabel(tabLine);
        lLineSkipGaps->setObjectName("lLineSkipGaps");

        gridLayout_4->addWidget(lLineSkipGaps, 3, 0, 1, 1);

        lValuesGeneral_2 = new QLabel(tabLine);
        lValuesGeneral_2->setObjectName("lValuesGeneral_2");
        lValuesGeneral_2->setFont(font);

        gridLayout_4->addWidget(lValuesGeneral_2, 0, 0, 1, 1);

        lLineIncreasingXOnly = new QLabel(tabLine);
        lLineIncreasingXOnly->setObjectName("lLineIncreasingXOnly");

        gridLayout_4->addWidget(lLineIncreasingXOnly, 4, 0, 1, 1);

        chkLineSkipGaps = new QCheckBox(tabLine);
        chkLineSkipGaps->setObjectName("chkLineSkipGaps");

        gridLayout_4->addWidget(chkLineSkipGaps, 3, 2, 1, 1);

        verticalSpacer_12 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_12, 5, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_2, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer, 0, 2, 1, 1);

        tabWidget->addTab(tabLine, QString());
        tabSymbol = new QWidget();
        tabSymbol->setObjectName("tabSymbol");
        tabWidget->addTab(tabSymbol, QString());
        tabValues = new QWidget();
        tabValues->setObjectName("tabValues");
        gridLayout_3 = new QGridLayout(tabValues);
        gridLayout_3->setObjectName("gridLayout_3");
        lValuesColumn = new QLabel(tabValues);
        lValuesColumn->setObjectName("lValuesColumn");

        gridLayout_3->addWidget(lValuesColumn, 2, 0, 1, 1);

        lValuesPrecision = new QLabel(tabValues);
        lValuesPrecision->setObjectName("lValuesPrecision");

        gridLayout_3->addWidget(lValuesPrecision, 10, 0, 1, 1);

        sbValuesPrecision = new QSpinBox(tabValues);
        sbValuesPrecision->setObjectName("sbValuesPrecision");
        sizePolicy1.setHeightForWidth(sbValuesPrecision->sizePolicy().hasHeightForWidth());
        sbValuesPrecision->setSizePolicy(sizePolicy1);
        sbValuesPrecision->setMinimum(0);
        sbValuesPrecision->setMaximum(16);
        sbValuesPrecision->setValue(0);

        gridLayout_3->addWidget(sbValuesPrecision, 10, 2, 1, 1);

        leValuesSuffix = new QLineEdit(tabValues);
        leValuesSuffix->setObjectName("leValuesSuffix");
        sizePolicy1.setHeightForWidth(leValuesSuffix->sizePolicy().hasHeightForWidth());
        leValuesSuffix->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(leValuesSuffix, 15, 2, 1, 1);

        lValuesText = new QLabel(tabValues);
        lValuesText->setObjectName("lValuesText");
        lValuesText->setFont(font);

        gridLayout_3->addWidget(lValuesText, 13, 0, 1, 1);

        lValuesSuffix = new QLabel(tabValues);
        lValuesSuffix->setObjectName("lValuesSuffix");

        gridLayout_3->addWidget(lValuesSuffix, 15, 0, 1, 1);

        lValuesOpacity = new QLabel(tabValues);
        lValuesOpacity->setObjectName("lValuesOpacity");

        gridLayout_3->addWidget(lValuesOpacity, 6, 0, 1, 1);

        lValuesFont = new QLabel(tabValues);
        lValuesFont->setObjectName("lValuesFont");

        gridLayout_3->addWidget(lValuesFont, 16, 0, 1, 1);

        lValuesGeneral = new QLabel(tabValues);
        lValuesGeneral->setObjectName("lValuesGeneral");
        lValuesGeneral->setFont(font);

        gridLayout_3->addWidget(lValuesGeneral, 0, 0, 1, 1);

        kfrValuesFont = new KFontRequester(tabValues);
        kfrValuesFont->setObjectName("kfrValuesFont");

        gridLayout_3->addWidget(kfrValuesFont, 16, 2, 1, 1);

        kcbValuesColor = new KColorButton(tabValues);
        kcbValuesColor->setObjectName("kcbValuesColor");
        sizePolicy1.setHeightForWidth(kcbValuesColor->sizePolicy().hasHeightForWidth());
        kcbValuesColor->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(kcbValuesColor, 17, 2, 1, 1);

        sbValuesOpacity = new QSpinBox(tabValues);
        sbValuesOpacity->setObjectName("sbValuesOpacity");
        sizePolicy1.setHeightForWidth(sbValuesOpacity->sizePolicy().hasHeightForWidth());
        sbValuesOpacity->setSizePolicy(sizePolicy1);
        sbValuesOpacity->setMinimum(0);
        sbValuesOpacity->setMaximum(100);
        sbValuesOpacity->setSingleStep(10);
        sbValuesOpacity->setValue(100);

        gridLayout_3->addWidget(sbValuesOpacity, 6, 2, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_3, 1, 1, 1, 1);

        lValuesDistance = new QLabel(tabValues);
        lValuesDistance->setObjectName("lValuesDistance");
        lValuesDistance->setWordWrap(true);

        gridLayout_3->addWidget(lValuesDistance, 4, 0, 1, 1);

        cbValuesNumericFormat = new KComboBox(tabValues);
        cbValuesNumericFormat->setObjectName("cbValuesNumericFormat");

        gridLayout_3->addWidget(cbValuesNumericFormat, 9, 2, 1, 1);

        cbValuesType = new KComboBox(tabValues);
        cbValuesType->setObjectName("cbValuesType");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cbValuesType->sizePolicy().hasHeightForWidth());
        cbValuesType->setSizePolicy(sizePolicy2);

        gridLayout_3->addWidget(cbValuesType, 1, 2, 1, 1);

        lValuesColor = new QLabel(tabValues);
        lValuesColor->setObjectName("lValuesColor");

        gridLayout_3->addWidget(lValuesColor, 17, 0, 1, 1);

        cbValuesPosition = new KComboBox(tabValues);
        cbValuesPosition->setObjectName("cbValuesPosition");

        gridLayout_3->addWidget(cbValuesPosition, 3, 2, 1, 1);

        leValuesPrefix = new QLineEdit(tabValues);
        leValuesPrefix->setObjectName("leValuesPrefix");
        sizePolicy1.setHeightForWidth(leValuesPrefix->sizePolicy().hasHeightForWidth());
        leValuesPrefix->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(leValuesPrefix, 14, 2, 1, 1);

        lValuesRotation = new QLabel(tabValues);
        lValuesRotation->setObjectName("lValuesRotation");

        gridLayout_3->addWidget(lValuesRotation, 5, 0, 1, 1);

        lValuesPrefix = new QLabel(tabValues);
        lValuesPrefix->setObjectName("lValuesPrefix");

        gridLayout_3->addWidget(lValuesPrefix, 14, 0, 1, 1);

        verticalSpacer_8 = new QSpacerItem(28, 47, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_8, 18, 0, 1, 1);

        verticalSpacer_7 = new QSpacerItem(86, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_7, 12, 0, 1, 2);

        lValuesFormat = new QLabel(tabValues);
        lValuesFormat->setObjectName("lValuesFormat");
        lValuesFormat->setFont(font);

        gridLayout_3->addWidget(lValuesFormat, 8, 0, 1, 1);

        sbValuesRotation = new QSpinBox(tabValues);
        sbValuesRotation->setObjectName("sbValuesRotation");
        sizePolicy1.setHeightForWidth(sbValuesRotation->sizePolicy().hasHeightForWidth());
        sbValuesRotation->setSizePolicy(sizePolicy1);
        sbValuesRotation->setMinimum(-360);
        sbValuesRotation->setMaximum(360);
        sbValuesRotation->setSingleStep(10);

        gridLayout_3->addWidget(sbValuesRotation, 5, 2, 1, 1);

        lValuesPosition = new QLabel(tabValues);
        lValuesPosition->setObjectName("lValuesPosition");

        gridLayout_3->addWidget(lValuesPosition, 3, 0, 1, 1);

        lValuesNumericFormat = new QLabel(tabValues);
        lValuesNumericFormat->setObjectName("lValuesNumericFormat");

        gridLayout_3->addWidget(lValuesNumericFormat, 9, 0, 1, 1);

        verticalSpacer_6 = new QSpacerItem(86, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_6, 7, 0, 1, 2);

        lValuesDateTimeFormat = new QLabel(tabValues);
        lValuesDateTimeFormat->setObjectName("lValuesDateTimeFormat");

        gridLayout_3->addWidget(lValuesDateTimeFormat, 11, 0, 1, 1);

        cbValuesDateTimeFormat = new QComboBox(tabValues);
        cbValuesDateTimeFormat->setObjectName("cbValuesDateTimeFormat");

        gridLayout_3->addWidget(cbValuesDateTimeFormat, 11, 2, 1, 1);

        lValuesType = new QLabel(tabValues);
        lValuesType->setObjectName("lValuesType");

        gridLayout_3->addWidget(lValuesType, 1, 0, 1, 1);

        sbValuesDistance = new NumberSpinBox(tabValues);
        sbValuesDistance->setObjectName("sbValuesDistance");
        sbValuesDistance->setMinimum(0.000000000000000);
        sbValuesDistance->setProperty("feedback", QVariant(true));

        gridLayout_3->addWidget(sbValuesDistance, 4, 2, 1, 1);

        tabWidget->addTab(tabValues, QString());
        tabAreaFilling = new QWidget();
        tabAreaFilling->setObjectName("tabAreaFilling");
        verticalLayout_2 = new QVBoxLayout(tabAreaFilling);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        tabWidget->addTab(tabAreaFilling, QString());
        tabErrorBars = new QWidget();
        tabErrorBars->setObjectName("tabErrorBars");
        verticalLayout_3 = new QVBoxLayout(tabErrorBars);
        verticalLayout_3->setObjectName("verticalLayout_3");
        tabWidget->addTab(tabErrorBars, QString());
        tabMarginalPlots = new QWidget();
        tabMarginalPlots->setObjectName("tabMarginalPlots");
        gridLayout = new QGridLayout(tabMarginalPlots);
        gridLayout->setObjectName("gridLayout");
        chkRugEnabled = new QCheckBox(tabMarginalPlots);
        chkRugEnabled->setObjectName("chkRugEnabled");
        sizePolicy2.setHeightForWidth(chkRugEnabled->sizePolicy().hasHeightForWidth());
        chkRugEnabled->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(chkRugEnabled, 1, 2, 1, 1);

        lRugEnabled = new QLabel(tabMarginalPlots);
        lRugEnabled->setObjectName("lRugEnabled");

        gridLayout->addWidget(lRugEnabled, 1, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 1, 1, 1, 1);

        lRugLength = new QLabel(tabMarginalPlots);
        lRugLength->setObjectName("lRugLength");

        gridLayout->addWidget(lRugLength, 3, 0, 1, 1);

        lRugOffset = new QLabel(tabMarginalPlots);
        lRugOffset->setObjectName("lRugOffset");

        gridLayout->addWidget(lRugOffset, 5, 0, 1, 1);

        lRugWidth = new QLabel(tabMarginalPlots);
        lRugWidth->setObjectName("lRugWidth");

        gridLayout->addWidget(lRugWidth, 4, 0, 1, 1);

        lRugOrientation = new QLabel(tabMarginalPlots);
        lRugOrientation->setObjectName("lRugOrientation");

        gridLayout->addWidget(lRugOrientation, 2, 0, 1, 1);

        lRug = new QLabel(tabMarginalPlots);
        lRug->setObjectName("lRug");
        lRug->setFont(font);

        gridLayout->addWidget(lRug, 0, 0, 1, 1);

        cbRugOrientation = new QComboBox(tabMarginalPlots);
        cbRugOrientation->setObjectName("cbRugOrientation");

        gridLayout->addWidget(cbRugOrientation, 2, 2, 1, 1);

        verticalSpacer_13 = new QSpacerItem(18, 600, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_13, 6, 0, 1, 1);

        sbRugLength = new NumberSpinBox(tabMarginalPlots);
        sbRugLength->setObjectName("sbRugLength");
        sbRugLength->setMinimum(0.000000000000000);
        sbRugLength->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbRugLength, 3, 2, 1, 1);

        sbRugWidth = new NumberSpinBox(tabMarginalPlots);
        sbRugWidth->setObjectName("sbRugWidth");
        sbRugWidth->setMinimum(0.000000000000000);
        sbRugWidth->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbRugWidth, 4, 2, 1, 1);

        sbRugOffset = new NumberSpinBox(tabMarginalPlots);
        sbRugOffset->setObjectName("sbRugOffset");
        sbRugOffset->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbRugOffset, 5, 2, 1, 1);

        tabWidget->addTab(tabMarginalPlots, QString());

        verticalLayout->addWidget(tabWidget);


        retranslateUi(XYCurveDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(XYCurveDock);
    } // setupUi

    void retranslateUi(QWidget *XYCurveDock)
    {
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        lLineType->setText(tr2i18n("Type:", nullptr));
        chkLineIncreasingXOnly->setText(QString());
#if QT_CONFIG(tooltip)
        sbLineInterpolationPointsCount->setToolTip(tr2i18n("intermediate points to evaluate between each two points", nullptr));
#endif // QT_CONFIG(tooltip)
        lDropLines->setText(tr2i18n("Drop lines", nullptr));
#if QT_CONFIG(tooltip)
        lLineInterpolationPointsCount->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        lLineInterpolationPointsCount->setText(tr2i18n("Interm. points:", nullptr));
        lLineSkipGaps->setText(tr2i18n("Ignore Gaps:", nullptr));
        lValuesGeneral_2->setText(tr2i18n("Connection", nullptr));
        lLineIncreasingXOnly->setText(tr2i18n("Monoton incr. X:", nullptr));
        chkLineSkipGaps->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabLine), tr2i18n("Line", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabSymbol), tr2i18n("Symbol", nullptr));
        lValuesColumn->setText(tr2i18n("Column:", nullptr));
        lValuesPrecision->setText(tr2i18n("Precision:", nullptr));
        lValuesText->setText(tr2i18n("Text", nullptr));
        lValuesSuffix->setText(tr2i18n("Suffix:", nullptr));
        lValuesOpacity->setText(tr2i18n("Opacity:", nullptr));
        lValuesFont->setText(tr2i18n("Font:", nullptr));
        lValuesGeneral->setText(tr2i18n("General", nullptr));
#if QT_CONFIG(tooltip)
        sbValuesOpacity->setToolTip(tr2i18n("The opacity ranges from 0 to 100, where 0 is fully transparent and 100 is fully opaque.", nullptr));
#endif // QT_CONFIG(tooltip)
        sbValuesOpacity->setSuffix(tr2i18n(" %", nullptr));
        lValuesDistance->setText(tr2i18n("Distance:", nullptr));
        lValuesColor->setText(tr2i18n("Color:", nullptr));
        lValuesRotation->setText(tr2i18n("Rotation:", nullptr));
        lValuesPrefix->setText(tr2i18n("Prefix:", nullptr));
        lValuesFormat->setText(tr2i18n("Format", nullptr));
        sbValuesRotation->setSuffix(tr2i18n("\302\260", nullptr));
        lValuesPosition->setText(tr2i18n("Position:", nullptr));
        lValuesNumericFormat->setText(tr2i18n("Numeric:", nullptr));
        lValuesDateTimeFormat->setText(tr2i18n("DateTime:", nullptr));
        lValuesType->setText(tr2i18n("Type:", nullptr));
#if QT_CONFIG(tooltip)
        sbValuesDistance->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbValuesDistance->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbValuesDistance->setSuffix(tr2i18n(" pt", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabValues), tr2i18n("Values", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAreaFilling), tr2i18n("Filling", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabErrorBars), tr2i18n("Error Bars", nullptr));
        chkRugEnabled->setText(QString());
        lRugEnabled->setText(tr2i18n("Enabled:", nullptr));
        lRugLength->setText(tr2i18n("Length:", nullptr));
        lRugOffset->setText(tr2i18n("Offset:", nullptr));
        lRugWidth->setText(tr2i18n("Width:", nullptr));
        lRugOrientation->setText(tr2i18n("Orientation:", nullptr));
        lRug->setText(tr2i18n("Rug Plot", nullptr));
#if QT_CONFIG(tooltip)
        sbRugLength->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRugLength->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        sbRugWidth->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRugWidth->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        sbRugOffset->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRugOffset->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        tabWidget->setTabText(tabWidget->indexOf(tabMarginalPlots), tr2i18n("Margins", nullptr));
        (void)XYCurveDock;
    } // retranslateUi

};

namespace Ui {
    class XYCurveDock: public Ui_XYCurveDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // XYCURVEDOCK_H

