/********************************************************************************
** Form generated from reading UI file 'exportspreadsheetwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXPORTSPREADSHEETWIDGET_H
#define UI_EXPORTSPREADSHEETWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ExportSpreadsheetWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *gbExport;
    QGridLayout *gridLayout;
    QLabel *lFileName;
    QLineEdit *leFileName;
    QPushButton *bOpen;
    QComboBox *cbFormat;
    QLabel *lFormat;
    QGroupBox *gbOptions;
    QGridLayout *gridLayout_2;
    QCheckBox *chkCaptions;
    QCheckBox *chkMatrixVHeader;
    QCheckBox *chkColumnsAsUnits;
    QCheckBox *chkGridLines;
    QCheckBox *chkEmptyRows;
    QCheckBox *chkHeaders;
    QLabel *lExportArea;
    QLabel *lMatrixHHeader;
    QLabel *lEmptyRows;
    QLabel *lMatrixVHeader;
    QCheckBox *chkMatrixHHeader;
    QComboBox *cbLaTeXExport;
    QLabel *lSeparator;
    QComboBox *cbDecimalSeparator;
    QWidget *mcapwidget;
    QGridLayout *mcapgroup;
    QComboBox *cbCompressionLevel;
    QGroupBox *compressionGroup;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *rbNone;
    QRadioButton *rbLZ4;
    QRadioButton *rbZSTD;
    QLabel *label;
    QLabel *lExportToFITS;
    QLabel *lDecimalSeparator;
    KComboBox *cbSeparator;
    QLabel *lGridLines;
    QComboBox *cbExportToFITS;
    QLabel *lHeader;
    QLabel *lCaptions;
    QLabel *lExportHeader;
    QCheckBox *chkExportHeader;
    QLabel *lColumnAsUnits;

    void setupUi(QWidget *ExportSpreadsheetWidget)
    {
        if (ExportSpreadsheetWidget->objectName().isEmpty())
            ExportSpreadsheetWidget->setObjectName("ExportSpreadsheetWidget");
        ExportSpreadsheetWidget->resize(615, 780);
        verticalLayout = new QVBoxLayout(ExportSpreadsheetWidget);
        verticalLayout->setObjectName("verticalLayout");
        gbExport = new QGroupBox(ExportSpreadsheetWidget);
        gbExport->setObjectName("gbExport");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(gbExport->sizePolicy().hasHeightForWidth());
        gbExport->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(gbExport);
        gridLayout->setObjectName("gridLayout");
        lFileName = new QLabel(gbExport);
        lFileName->setObjectName("lFileName");

        gridLayout->addWidget(lFileName, 1, 0, 1, 1);

        leFileName = new QLineEdit(gbExport);
        leFileName->setObjectName("leFileName");
        leFileName->setClearButtonEnabled(true);

        gridLayout->addWidget(leFileName, 1, 2, 1, 1);

        bOpen = new QPushButton(gbExport);
        bOpen->setObjectName("bOpen");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(bOpen->sizePolicy().hasHeightForWidth());
        bOpen->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(bOpen, 1, 3, 1, 1);

        cbFormat = new QComboBox(gbExport);
        cbFormat->setObjectName("cbFormat");

        gridLayout->addWidget(cbFormat, 0, 2, 1, 1);

        lFormat = new QLabel(gbExport);
        lFormat->setObjectName("lFormat");

        gridLayout->addWidget(lFormat, 0, 0, 1, 2);


        verticalLayout->addWidget(gbExport);

        gbOptions = new QGroupBox(ExportSpreadsheetWidget);
        gbOptions->setObjectName("gbOptions");
        gridLayout_2 = new QGridLayout(gbOptions);
        gridLayout_2->setObjectName("gridLayout_2");
        chkCaptions = new QCheckBox(gbOptions);
        chkCaptions->setObjectName("chkCaptions");
        chkCaptions->setChecked(true);

        gridLayout_2->addWidget(chkCaptions, 6, 1, 1, 1);

        chkMatrixVHeader = new QCheckBox(gbOptions);
        chkMatrixVHeader->setObjectName("chkMatrixVHeader");
        chkMatrixVHeader->setChecked(true);

        gridLayout_2->addWidget(chkMatrixVHeader, 1, 1, 1, 1);

        chkColumnsAsUnits = new QCheckBox(gbOptions);
        chkColumnsAsUnits->setObjectName("chkColumnsAsUnits");

        gridLayout_2->addWidget(chkColumnsAsUnits, 11, 1, 1, 1);

        chkGridLines = new QCheckBox(gbOptions);
        chkGridLines->setObjectName("chkGridLines");
        chkGridLines->setChecked(true);

        gridLayout_2->addWidget(chkGridLines, 5, 1, 1, 1);

        chkEmptyRows = new QCheckBox(gbOptions);
        chkEmptyRows->setObjectName("chkEmptyRows");

        gridLayout_2->addWidget(chkEmptyRows, 8, 1, 1, 1);

        chkHeaders = new QCheckBox(gbOptions);
        chkHeaders->setObjectName("chkHeaders");
        chkHeaders->setChecked(true);

        gridLayout_2->addWidget(chkHeaders, 7, 1, 1, 1);

        lExportArea = new QLabel(gbOptions);
        lExportArea->setObjectName("lExportArea");

        gridLayout_2->addWidget(lExportArea, 9, 0, 1, 1);

        lMatrixHHeader = new QLabel(gbOptions);
        lMatrixHHeader->setObjectName("lMatrixHHeader");

        gridLayout_2->addWidget(lMatrixHHeader, 2, 0, 1, 1);

        lEmptyRows = new QLabel(gbOptions);
        lEmptyRows->setObjectName("lEmptyRows");

        gridLayout_2->addWidget(lEmptyRows, 8, 0, 1, 1);

        lMatrixVHeader = new QLabel(gbOptions);
        lMatrixVHeader->setObjectName("lMatrixVHeader");

        gridLayout_2->addWidget(lMatrixVHeader, 1, 0, 1, 1);

        chkMatrixHHeader = new QCheckBox(gbOptions);
        chkMatrixHHeader->setObjectName("chkMatrixHHeader");
        chkMatrixHHeader->setChecked(true);

        gridLayout_2->addWidget(chkMatrixHHeader, 2, 1, 1, 1);

        cbLaTeXExport = new QComboBox(gbOptions);
        cbLaTeXExport->setObjectName("cbLaTeXExport");

        gridLayout_2->addWidget(cbLaTeXExport, 9, 1, 1, 1);

        lSeparator = new QLabel(gbOptions);
        lSeparator->setObjectName("lSeparator");

        gridLayout_2->addWidget(lSeparator, 3, 0, 1, 1);

        cbDecimalSeparator = new QComboBox(gbOptions);
        cbDecimalSeparator->setObjectName("cbDecimalSeparator");

        gridLayout_2->addWidget(cbDecimalSeparator, 4, 1, 1, 1);

        mcapwidget = new QWidget(gbOptions);
        mcapwidget->setObjectName("mcapwidget");
        mcapgroup = new QGridLayout(mcapwidget);
        mcapgroup->setObjectName("mcapgroup");
        cbCompressionLevel = new QComboBox(mcapwidget);
        cbCompressionLevel->setObjectName("cbCompressionLevel");

        mcapgroup->addWidget(cbCompressionLevel, 1, 1, 1, 1);

        compressionGroup = new QGroupBox(mcapwidget);
        compressionGroup->setObjectName("compressionGroup");
        verticalLayout_2 = new QVBoxLayout(compressionGroup);
        verticalLayout_2->setObjectName("verticalLayout_2");
        rbNone = new QRadioButton(compressionGroup);
        rbNone->setObjectName("rbNone");

        verticalLayout_2->addWidget(rbNone);

        rbLZ4 = new QRadioButton(compressionGroup);
        rbLZ4->setObjectName("rbLZ4");

        verticalLayout_2->addWidget(rbLZ4);

        rbZSTD = new QRadioButton(compressionGroup);
        rbZSTD->setObjectName("rbZSTD");

        verticalLayout_2->addWidget(rbZSTD);


        mcapgroup->addWidget(compressionGroup, 0, 0, 3, 1);

        label = new QLabel(mcapwidget);
        label->setObjectName("label");

        mcapgroup->addWidget(label, 0, 1, 1, 1);


        gridLayout_2->addWidget(mcapwidget, 12, 0, 1, 2);

        lExportToFITS = new QLabel(gbOptions);
        lExportToFITS->setObjectName("lExportToFITS");

        gridLayout_2->addWidget(lExportToFITS, 10, 0, 1, 1);

        lDecimalSeparator = new QLabel(gbOptions);
        lDecimalSeparator->setObjectName("lDecimalSeparator");

        gridLayout_2->addWidget(lDecimalSeparator, 4, 0, 1, 1);

        cbSeparator = new KComboBox(gbOptions);
        cbSeparator->setObjectName("cbSeparator");
        cbSeparator->setEditable(true);

        gridLayout_2->addWidget(cbSeparator, 3, 1, 1, 1);

        lGridLines = new QLabel(gbOptions);
        lGridLines->setObjectName("lGridLines");

        gridLayout_2->addWidget(lGridLines, 5, 0, 1, 1);

        cbExportToFITS = new QComboBox(gbOptions);
        cbExportToFITS->setObjectName("cbExportToFITS");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cbExportToFITS->sizePolicy().hasHeightForWidth());
        cbExportToFITS->setSizePolicy(sizePolicy2);

        gridLayout_2->addWidget(cbExportToFITS, 10, 1, 1, 1);

        lHeader = new QLabel(gbOptions);
        lHeader->setObjectName("lHeader");

        gridLayout_2->addWidget(lHeader, 7, 0, 1, 1);

        lCaptions = new QLabel(gbOptions);
        lCaptions->setObjectName("lCaptions");

        gridLayout_2->addWidget(lCaptions, 6, 0, 1, 1);

        lExportHeader = new QLabel(gbOptions);
        lExportHeader->setObjectName("lExportHeader");

        gridLayout_2->addWidget(lExportHeader, 0, 0, 1, 1);

        chkExportHeader = new QCheckBox(gbOptions);
        chkExportHeader->setObjectName("chkExportHeader");
        sizePolicy2.setHeightForWidth(chkExportHeader->sizePolicy().hasHeightForWidth());
        chkExportHeader->setSizePolicy(sizePolicy2);
        chkExportHeader->setChecked(true);

        gridLayout_2->addWidget(chkExportHeader, 0, 1, 1, 1);

        lColumnAsUnits = new QLabel(gbOptions);
        lColumnAsUnits->setObjectName("lColumnAsUnits");

        gridLayout_2->addWidget(lColumnAsUnits, 11, 0, 1, 1);


        verticalLayout->addWidget(gbOptions);


        retranslateUi(ExportSpreadsheetWidget);

        QMetaObject::connectSlotsByName(ExportSpreadsheetWidget);
    } // setupUi

    void retranslateUi(QWidget *ExportSpreadsheetWidget)
    {
        gbExport->setTitle(tr2i18n("Export", nullptr));
        lFileName->setText(tr2i18n("File name:", nullptr));
#if QT_CONFIG(tooltip)
        leFileName->setToolTip(tr2i18n("Specify the name of the file to export.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        bOpen->setToolTip(tr2i18n(" Select the file to import", nullptr));
#endif // QT_CONFIG(tooltip)
        bOpen->setText(QString());
        lFormat->setText(tr2i18n("Format:", nullptr));
        gbOptions->setTitle(tr2i18n("Options", nullptr));
        chkCaptions->setText(QString());
        chkMatrixVHeader->setText(QString());
        chkColumnsAsUnits->setText(QString());
        chkGridLines->setText(QString());
        chkEmptyRows->setText(QString());
        chkHeaders->setText(QString());
        lExportArea->setText(tr2i18n("Area to export:", nullptr));
        lMatrixHHeader->setText(tr2i18n("Export horizontal header:", nullptr));
        lEmptyRows->setText(tr2i18n("Skip empty rows:", nullptr));
        lMatrixVHeader->setText(tr2i18n("Export vertical header:", nullptr));
        chkMatrixHHeader->setText(QString());
        lSeparator->setText(tr2i18n("Separating string:", nullptr));
        compressionGroup->setTitle(tr2i18n("Compression", nullptr));
        rbNone->setText(tr2i18n("None", nullptr));
        rbLZ4->setText(tr2i18n("LZ4", nullptr));
        rbZSTD->setText(tr2i18n("ZSTD", nullptr));
        label->setText(tr2i18n("Compression Level", nullptr));
        lExportToFITS->setText(tr2i18n("Export to:", nullptr));
        lDecimalSeparator->setText(tr2i18n("Decimal separator:", nullptr));
        lGridLines->setText(tr2i18n("Grid lines:", nullptr));
        lHeader->setText(tr2i18n("Headers:", nullptr));
        lCaptions->setText(tr2i18n("Table captions:", nullptr));
        lExportHeader->setText(tr2i18n("Export header:", nullptr));
        chkExportHeader->setText(QString());
        lColumnAsUnits->setText(tr2i18n("Comments as column units:", nullptr));
        (void)ExportSpreadsheetWidget;
    } // retranslateUi

};

namespace Ui {
    class ExportSpreadsheetWidget: public Ui_ExportSpreadsheetWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXPORTSPREADSHEETWIDGET_H

