/********************************************************************************
** Form generated from reading UI file 'fitsheadereditaddunitwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FITSHEADEREDITADDUNITWIDGET_H
#define UI_FITSHEADEREDITADDUNITWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FITSHeaderEditAddUnitDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *lUnit;
    QLineEdit *leUnit;

    void setupUi(QWidget *FITSHeaderEditAddUnitDialog)
    {
        if (FITSHeaderEditAddUnitDialog->objectName().isEmpty())
            FITSHeaderEditAddUnitDialog->setObjectName("FITSHeaderEditAddUnitDialog");
        FITSHeaderEditAddUnitDialog->resize(393, 57);
        gridLayout = new QGridLayout(FITSHeaderEditAddUnitDialog);
        gridLayout->setObjectName("gridLayout");
        lUnit = new QLabel(FITSHeaderEditAddUnitDialog);
        lUnit->setObjectName("lUnit");

        gridLayout->addWidget(lUnit, 0, 0, 1, 1);

        leUnit = new QLineEdit(FITSHeaderEditAddUnitDialog);
        leUnit->setObjectName("leUnit");
        leUnit->setClearButtonEnabled(true);

        gridLayout->addWidget(leUnit, 0, 1, 1, 1);


        retranslateUi(FITSHeaderEditAddUnitDialog);

        QMetaObject::connectSlotsByName(FITSHeaderEditAddUnitDialog);
    } // setupUi

    void retranslateUi(QWidget *FITSHeaderEditAddUnitDialog)
    {
        lUnit->setText(tr2i18n("Unit:", nullptr));
        (void)FITSHeaderEditAddUnitDialog;
    } // retranslateUi

};

namespace Ui {
    class FITSHeaderEditAddUnitDialog: public Ui_FITSHeaderEditAddUnitDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FITSHEADEREDITADDUNITWIDGET_H

