/********************************************************************************
** Form generated from reading UI file 'importoriginlayersdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTORIGINLAYERSDIALOG_H
#define UI_IMPORTORIGINLAYERSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ImportOriginLayersDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *lInfo;
    QLabel *lGraphLayer;
    QSpacerItem *verticalSpacer;
    QComboBox *cbGraphLayer;
    QDialogButtonBox *buttonBox;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QDialog *ImportOriginLayersDialog)
    {
        if (ImportOriginLayersDialog->objectName().isEmpty())
            ImportOriginLayersDialog->setObjectName("ImportOriginLayersDialog");
        ImportOriginLayersDialog->resize(400, 242);
        gridLayout = new QGridLayout(ImportOriginLayersDialog);
        gridLayout->setObjectName("gridLayout");
        lInfo = new QLabel(ImportOriginLayersDialog);
        lInfo->setObjectName("lInfo");

        gridLayout->addWidget(lInfo, 0, 0, 1, 2);

        lGraphLayer = new QLabel(ImportOriginLayersDialog);
        lGraphLayer->setObjectName("lGraphLayer");

        gridLayout->addWidget(lGraphLayer, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);

        cbGraphLayer = new QComboBox(ImportOriginLayersDialog);
        cbGraphLayer->setObjectName("cbGraphLayer");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbGraphLayer->sizePolicy().hasHeightForWidth());
        cbGraphLayer->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbGraphLayer, 2, 1, 1, 1);

        buttonBox = new QDialogButtonBox(ImportOriginLayersDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Ok);

        gridLayout->addWidget(buttonBox, 4, 0, 1, 2);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 3, 0, 1, 1);


        retranslateUi(ImportOriginLayersDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ImportOriginLayersDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ImportOriginLayersDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ImportOriginLayersDialog);
    } // setupUi

    void retranslateUi(QDialog *ImportOriginLayersDialog)
    {
        ImportOriginLayersDialog->setWindowTitle(tr2i18n("Dialog", nullptr));
        lInfo->setText(QString());
        lGraphLayer->setText(tr2i18n("Import As", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ImportOriginLayersDialog: public Ui_ImportOriginLayersDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTORIGINLAYERSDIALOG_H

