/****************************************************************************
** Meta object code from reading C++ file 'Axis.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/plots/cartesian/Axis.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Axis.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4AxisE_t {};
} // unnamed namespace

template <> constexpr inline auto Axis::qt_create_metaobjectdata<qt_meta_tag_ZN4AxisE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Axis",
        "orientationChanged",
        "",
        "Orientation",
        "positionChanged",
        "Position",
        "scaleChanged",
        "RangeT::Scale",
        "rangeScaleChanged",
        "startChanged",
        "rangeTypeChanged",
        "RangeType",
        "endChanged",
        "rangeChanged",
        "Range<double>",
        "zeroOffsetChanged",
        "scalingFactorChanged",
        "showScaleOffsetChanged",
        "logicalPositionChanged",
        "shiftSignal",
        "delta",
        "Dimension",
        "dim",
        "index",
        "titleOffsetXChanged",
        "titleOffsetYChanged",
        "arrowTypeChanged",
        "ArrowType",
        "arrowPositionChanged",
        "ArrowPosition",
        "arrowSizeChanged",
        "majorTicksDirectionChanged",
        "TicksDirection",
        "majorTicksTypeChanged",
        "TicksType",
        "majorTicksAutoNumberChanged",
        "majorTicksNumberChanged",
        "majorTicksSpacingChanged",
        "majorTicksColumnChanged",
        "const AbstractColumn*",
        "majorTicksStartTypeChanged",
        "TicksStartType",
        "majorTickStartOffsetChanged",
        "majorTickStartValueChanged",
        "majorTicksLengthChanged",
        "minorTicksDirectionChanged",
        "minorTicksTypeChanged",
        "minorTicksAutoNumberChanged",
        "minorTicksNumberChanged",
        "minorTicksIncrementChanged",
        "minorTicksColumnChanged",
        "minorTicksLengthChanged",
        "labelsFormatChanged",
        "LabelsFormat",
        "labelsFormatAutoChanged",
        "labelsAutoPrecisionChanged",
        "labelsPrecisionChanged",
        "labelsDateTimeFormatChanged",
        "labelsPositionChanged",
        "LabelsPosition",
        "labelsOffsetChanged",
        "labelsRotationAngleChanged",
        "labelsTextTypeChanged",
        "LabelsTextType",
        "labelsTextColumnChanged",
        "labelsColorChanged",
        "QColor",
        "labelsFontChanged",
        "QFont",
        "labelsBackgroundTypeChanged",
        "LabelsBackgroundType",
        "labelsBackgroundColorChanged",
        "labelsPrefixChanged",
        "labelsSuffixChanged",
        "labelsOpacityChanged",
        "labelChanged",
        "retransformTicks",
        "majorTicksColumnAboutToBeRemoved",
        "const AbstractAspect*",
        "minorTicksColumnAboutToBeRemoved",
        "orientationChangedSlot",
        "QAction*",
        "lineStyleChanged",
        "lineColorChanged",
        "Decimal",
        "ScientificE",
        "Powers10",
        "Powers2",
        "PowersE",
        "MultipliesPi",
        "Scientific",
        "TotalNumber",
        "Spacing",
        "CustomColumn",
        "CustomValues",
        "ColumnLabels"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'orientationChanged'
        QtMocHelpers::SignalData<void(Orientation)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(enum Position)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(double)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void(RangeT::Scale)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'rangeScaleChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'startChanged'
        QtMocHelpers::SignalData<void(double)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'rangeTypeChanged'
        QtMocHelpers::SignalData<void(enum RangeType)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Signal 'endChanged'
        QtMocHelpers::SignalData<void(double)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'rangeChanged'
        QtMocHelpers::SignalData<void(Range<double>)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Signal 'zeroOffsetChanged'
        QtMocHelpers::SignalData<void(qreal)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'scalingFactorChanged'
        QtMocHelpers::SignalData<void(qreal)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'showScaleOffsetChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'logicalPositionChanged'
        QtMocHelpers::SignalData<void(double)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'shiftSignal'
        QtMocHelpers::SignalData<void(int, Dimension, int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 }, { 0x80000000 | 21, 22 }, { QMetaType::Int, 23 },
        }}),
        // Signal 'titleOffsetXChanged'
        QtMocHelpers::SignalData<void(qreal)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'titleOffsetYChanged'
        QtMocHelpers::SignalData<void(qreal)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'arrowTypeChanged'
        QtMocHelpers::SignalData<void(enum ArrowType)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 2 },
        }}),
        // Signal 'arrowPositionChanged'
        QtMocHelpers::SignalData<void(enum ArrowPosition)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Signal 'arrowSizeChanged'
        QtMocHelpers::SignalData<void(qreal)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'majorTicksDirectionChanged'
        QtMocHelpers::SignalData<void(TicksDirection)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 2 },
        }}),
        // Signal 'majorTicksTypeChanged'
        QtMocHelpers::SignalData<void(enum TicksType)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 2 },
        }}),
        // Signal 'majorTicksAutoNumberChanged'
        QtMocHelpers::SignalData<void(bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'majorTicksNumberChanged'
        QtMocHelpers::SignalData<void(int)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'majorTicksSpacingChanged'
        QtMocHelpers::SignalData<void(qreal)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'majorTicksColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 2 },
        }}),
        // Signal 'majorTicksStartTypeChanged'
        QtMocHelpers::SignalData<void(enum TicksStartType)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 2 },
        }}),
        // Signal 'majorTickStartOffsetChanged'
        QtMocHelpers::SignalData<void(qreal)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'majorTickStartValueChanged'
        QtMocHelpers::SignalData<void(qreal)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'majorTicksLengthChanged'
        QtMocHelpers::SignalData<void(qreal)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'minorTicksDirectionChanged'
        QtMocHelpers::SignalData<void(TicksDirection)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 2 },
        }}),
        // Signal 'minorTicksTypeChanged'
        QtMocHelpers::SignalData<void(enum TicksType)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 2 },
        }}),
        // Signal 'minorTicksAutoNumberChanged'
        QtMocHelpers::SignalData<void(bool)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'minorTicksNumberChanged'
        QtMocHelpers::SignalData<void(int)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'minorTicksIncrementChanged'
        QtMocHelpers::SignalData<void(qreal)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'minorTicksColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 2 },
        }}),
        // Signal 'minorTicksLengthChanged'
        QtMocHelpers::SignalData<void(qreal)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'labelsFormatChanged'
        QtMocHelpers::SignalData<void(enum LabelsFormat)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 53, 2 },
        }}),
        // Signal 'labelsFormatAutoChanged'
        QtMocHelpers::SignalData<void(bool)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'labelsAutoPrecisionChanged'
        QtMocHelpers::SignalData<void(bool)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'labelsPrecisionChanged'
        QtMocHelpers::SignalData<void(int)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'labelsDateTimeFormatChanged'
        QtMocHelpers::SignalData<void(const QString &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'labelsPositionChanged'
        QtMocHelpers::SignalData<void(enum LabelsPosition)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 2 },
        }}),
        // Signal 'labelsOffsetChanged'
        QtMocHelpers::SignalData<void(double)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'labelsRotationAngleChanged'
        QtMocHelpers::SignalData<void(qreal)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'labelsTextTypeChanged'
        QtMocHelpers::SignalData<void(enum LabelsTextType)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 2 },
        }}),
        // Signal 'labelsTextColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 2 },
        }}),
        // Signal 'labelsColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 66, 2 },
        }}),
        // Signal 'labelsFontChanged'
        QtMocHelpers::SignalData<void(QFont)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 68, 2 },
        }}),
        // Signal 'labelsBackgroundTypeChanged'
        QtMocHelpers::SignalData<void(enum LabelsBackgroundType)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 70, 2 },
        }}),
        // Signal 'labelsBackgroundColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 66, 2 },
        }}),
        // Signal 'labelsPrefixChanged'
        QtMocHelpers::SignalData<void(QString)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'labelsSuffixChanged'
        QtMocHelpers::SignalData<void(QString)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'labelsOpacityChanged'
        QtMocHelpers::SignalData<void(qreal)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'labelChanged'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'retransformTicks'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'majorTicksColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(77, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 78, 2 },
        }}),
        // Slot 'minorTicksColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(79, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 78, 2 },
        }}),
        // Slot 'orientationChangedSlot'
        QtMocHelpers::SlotData<void(QAction *)>(80, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 81, 2 },
        }}),
        // Slot 'lineStyleChanged'
        QtMocHelpers::SlotData<void(QAction *)>(82, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 81, 2 },
        }}),
        // Slot 'lineColorChanged'
        QtMocHelpers::SlotData<void(QAction *)>(83, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 81, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'LabelsFormat'
        QtMocHelpers::EnumData<enum LabelsFormat>(53, 53, QMC::EnumIsScoped).add({
            {   84, LabelsFormat::Decimal },
            {   85, LabelsFormat::ScientificE },
            {   86, LabelsFormat::Powers10 },
            {   87, LabelsFormat::Powers2 },
            {   88, LabelsFormat::PowersE },
            {   89, LabelsFormat::MultipliesPi },
            {   90, LabelsFormat::Scientific },
        }),
        // enum 'TicksType'
        QtMocHelpers::EnumData<enum TicksType>(34, 34, QMC::EnumIsScoped).add({
            {   91, TicksType::TotalNumber },
            {   92, TicksType::Spacing },
            {   93, TicksType::CustomColumn },
            {   94, TicksType::CustomValues },
            {   95, TicksType::ColumnLabels },
        }),
    };
    return QtMocHelpers::metaObjectData<Axis, qt_meta_tag_ZN4AxisE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Axis::staticMetaObject = { {
    QMetaObject::SuperData::link<WorksheetElement::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4AxisE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4AxisE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4AxisE_t>.metaTypes,
    nullptr
} };

void Axis::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Axis *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->orientationChanged((*reinterpret_cast<std::add_pointer_t<Orientation>>(_a[1]))); break;
        case 1: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<enum Position>>(_a[1]))); break;
        case 2: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 3: _t->scaleChanged((*reinterpret_cast<std::add_pointer_t<RangeT::Scale>>(_a[1]))); break;
        case 4: _t->rangeScaleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->startChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->rangeTypeChanged((*reinterpret_cast<std::add_pointer_t<enum RangeType>>(_a[1]))); break;
        case 7: _t->endChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 8: _t->rangeChanged((*reinterpret_cast<std::add_pointer_t<Range<double>>>(_a[1]))); break;
        case 9: _t->zeroOffsetChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 10: _t->scalingFactorChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 11: _t->showScaleOffsetChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->logicalPositionChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 13: _t->shiftSignal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 14: _t->titleOffsetXChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 15: _t->titleOffsetYChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 16: _t->arrowTypeChanged((*reinterpret_cast<std::add_pointer_t<enum ArrowType>>(_a[1]))); break;
        case 17: _t->arrowPositionChanged((*reinterpret_cast<std::add_pointer_t<enum ArrowPosition>>(_a[1]))); break;
        case 18: _t->arrowSizeChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 19: _t->majorTicksDirectionChanged((*reinterpret_cast<std::add_pointer_t<TicksDirection>>(_a[1]))); break;
        case 20: _t->majorTicksTypeChanged((*reinterpret_cast<std::add_pointer_t<enum TicksType>>(_a[1]))); break;
        case 21: _t->majorTicksAutoNumberChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->majorTicksNumberChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->majorTicksSpacingChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 24: _t->majorTicksColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 25: _t->majorTicksStartTypeChanged((*reinterpret_cast<std::add_pointer_t<enum TicksStartType>>(_a[1]))); break;
        case 26: _t->majorTickStartOffsetChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 27: _t->majorTickStartValueChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 28: _t->majorTicksLengthChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 29: _t->minorTicksDirectionChanged((*reinterpret_cast<std::add_pointer_t<TicksDirection>>(_a[1]))); break;
        case 30: _t->minorTicksTypeChanged((*reinterpret_cast<std::add_pointer_t<enum TicksType>>(_a[1]))); break;
        case 31: _t->minorTicksAutoNumberChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->minorTicksNumberChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->minorTicksIncrementChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 34: _t->minorTicksColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 35: _t->minorTicksLengthChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 36: _t->labelsFormatChanged((*reinterpret_cast<std::add_pointer_t<enum LabelsFormat>>(_a[1]))); break;
        case 37: _t->labelsFormatAutoChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->labelsAutoPrecisionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->labelsPrecisionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 40: _t->labelsDateTimeFormatChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 41: _t->labelsPositionChanged((*reinterpret_cast<std::add_pointer_t<enum LabelsPosition>>(_a[1]))); break;
        case 42: _t->labelsOffsetChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 43: _t->labelsRotationAngleChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 44: _t->labelsTextTypeChanged((*reinterpret_cast<std::add_pointer_t<enum LabelsTextType>>(_a[1]))); break;
        case 45: _t->labelsTextColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 46: _t->labelsColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 47: _t->labelsFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 48: _t->labelsBackgroundTypeChanged((*reinterpret_cast<std::add_pointer_t<enum LabelsBackgroundType>>(_a[1]))); break;
        case 49: _t->labelsBackgroundColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 50: _t->labelsPrefixChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 51: _t->labelsSuffixChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 52: _t->labelsOpacityChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 53: _t->labelChanged(); break;
        case 54: _t->retransformTicks(); break;
        case 55: _t->majorTicksColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 56: _t->minorTicksColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 57: _t->orientationChangedSlot((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 58: _t->lineStyleChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 59: _t->lineColorChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(Orientation )>(_a, &Axis::orientationChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(Position )>(_a, &Axis::positionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(double )>(_a, &Axis::positionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(RangeT::Scale )>(_a, &Axis::scaleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(bool )>(_a, &Axis::rangeScaleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(double )>(_a, &Axis::startChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(RangeType )>(_a, &Axis::rangeTypeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(double )>(_a, &Axis::endChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(Range<double> )>(_a, &Axis::rangeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::zeroOffsetChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::scalingFactorChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(bool )>(_a, &Axis::showScaleOffsetChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(double )>(_a, &Axis::logicalPositionChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(int , Dimension , int )>(_a, &Axis::shiftSignal, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::titleOffsetXChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::titleOffsetYChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(ArrowType )>(_a, &Axis::arrowTypeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(ArrowPosition )>(_a, &Axis::arrowPositionChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::arrowSizeChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(TicksDirection )>(_a, &Axis::majorTicksDirectionChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(TicksType )>(_a, &Axis::majorTicksTypeChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(bool )>(_a, &Axis::majorTicksAutoNumberChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(int )>(_a, &Axis::majorTicksNumberChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::majorTicksSpacingChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(const AbstractColumn * )>(_a, &Axis::majorTicksColumnChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(TicksStartType )>(_a, &Axis::majorTicksStartTypeChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::majorTickStartOffsetChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::majorTickStartValueChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::majorTicksLengthChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(TicksDirection )>(_a, &Axis::minorTicksDirectionChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(TicksType )>(_a, &Axis::minorTicksTypeChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(bool )>(_a, &Axis::minorTicksAutoNumberChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(int )>(_a, &Axis::minorTicksNumberChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::minorTicksIncrementChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(const AbstractColumn * )>(_a, &Axis::minorTicksColumnChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::minorTicksLengthChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(LabelsFormat )>(_a, &Axis::labelsFormatChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(bool )>(_a, &Axis::labelsFormatAutoChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(bool )>(_a, &Axis::labelsAutoPrecisionChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(int )>(_a, &Axis::labelsPrecisionChanged, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(const QString & )>(_a, &Axis::labelsDateTimeFormatChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(LabelsPosition )>(_a, &Axis::labelsPositionChanged, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(double )>(_a, &Axis::labelsOffsetChanged, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::labelsRotationAngleChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(LabelsTextType )>(_a, &Axis::labelsTextTypeChanged, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(const AbstractColumn * )>(_a, &Axis::labelsTextColumnChanged, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(QColor )>(_a, &Axis::labelsColorChanged, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(QFont )>(_a, &Axis::labelsFontChanged, 47))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(LabelsBackgroundType )>(_a, &Axis::labelsBackgroundTypeChanged, 48))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(QColor )>(_a, &Axis::labelsBackgroundColorChanged, 49))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(QString )>(_a, &Axis::labelsPrefixChanged, 50))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(QString )>(_a, &Axis::labelsSuffixChanged, 51))
            return;
        if (QtMocHelpers::indexOfMethod<void (Axis::*)(qreal )>(_a, &Axis::labelsOpacityChanged, 52))
            return;
    }
}

const QMetaObject *Axis::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Axis::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4AxisE_t>.strings))
        return static_cast<void*>(this);
    return WorksheetElement::qt_metacast(_clname);
}

int Axis::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WorksheetElement::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 60)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 60;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 60)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 60;
    }
    return _id;
}

// SIGNAL 0
void Axis::orientationChanged(Orientation _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Axis::positionChanged(Position _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Axis::positionChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Axis::scaleChanged(RangeT::Scale _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Axis::rangeScaleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Axis::startChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Axis::rangeTypeChanged(RangeType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Axis::endChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Axis::rangeChanged(Range<double> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Axis::zeroOffsetChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Axis::scalingFactorChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Axis::showScaleOffsetChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Axis::logicalPositionChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Axis::shiftSignal(int _t1, Dimension _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3);
}

// SIGNAL 14
void Axis::titleOffsetXChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Axis::titleOffsetYChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Axis::arrowTypeChanged(ArrowType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Axis::arrowPositionChanged(ArrowPosition _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Axis::arrowSizeChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Axis::majorTicksDirectionChanged(TicksDirection _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void Axis::majorTicksTypeChanged(TicksType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void Axis::majorTicksAutoNumberChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void Axis::majorTicksNumberChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void Axis::majorTicksSpacingChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void Axis::majorTicksColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void Axis::majorTicksStartTypeChanged(TicksStartType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void Axis::majorTickStartOffsetChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void Axis::majorTickStartValueChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void Axis::majorTicksLengthChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void Axis::minorTicksDirectionChanged(TicksDirection _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1);
}

// SIGNAL 30
void Axis::minorTicksTypeChanged(TicksType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1);
}

// SIGNAL 31
void Axis::minorTicksAutoNumberChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1);
}

// SIGNAL 32
void Axis::minorTicksNumberChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 32, nullptr, _t1);
}

// SIGNAL 33
void Axis::minorTicksIncrementChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 33, nullptr, _t1);
}

// SIGNAL 34
void Axis::minorTicksColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 34, nullptr, _t1);
}

// SIGNAL 35
void Axis::minorTicksLengthChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 35, nullptr, _t1);
}

// SIGNAL 36
void Axis::labelsFormatChanged(LabelsFormat _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 36, nullptr, _t1);
}

// SIGNAL 37
void Axis::labelsFormatAutoChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 37, nullptr, _t1);
}

// SIGNAL 38
void Axis::labelsAutoPrecisionChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 38, nullptr, _t1);
}

// SIGNAL 39
void Axis::labelsPrecisionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 39, nullptr, _t1);
}

// SIGNAL 40
void Axis::labelsDateTimeFormatChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 40, nullptr, _t1);
}

// SIGNAL 41
void Axis::labelsPositionChanged(LabelsPosition _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 41, nullptr, _t1);
}

// SIGNAL 42
void Axis::labelsOffsetChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 42, nullptr, _t1);
}

// SIGNAL 43
void Axis::labelsRotationAngleChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 43, nullptr, _t1);
}

// SIGNAL 44
void Axis::labelsTextTypeChanged(LabelsTextType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 44, nullptr, _t1);
}

// SIGNAL 45
void Axis::labelsTextColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 45, nullptr, _t1);
}

// SIGNAL 46
void Axis::labelsColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 46, nullptr, _t1);
}

// SIGNAL 47
void Axis::labelsFontChanged(QFont _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 47, nullptr, _t1);
}

// SIGNAL 48
void Axis::labelsBackgroundTypeChanged(LabelsBackgroundType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 48, nullptr, _t1);
}

// SIGNAL 49
void Axis::labelsBackgroundColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 49, nullptr, _t1);
}

// SIGNAL 50
void Axis::labelsPrefixChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 50, nullptr, _t1);
}

// SIGNAL 51
void Axis::labelsSuffixChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 51, nullptr, _t1);
}

// SIGNAL 52
void Axis::labelsOpacityChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 52, nullptr, _t1);
}
QT_WARNING_POP
