/********************************************************************************
** Form generated from reading UI file 'rescalewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RESCALEWIDGET_H
#define UI_RESCALEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RescaleWidget
{
public:
    QGridLayout *gridLayout;
    QLineEdit *leMin;
    QLabel *lInfo;
    QDialogButtonBox *buttonBox;
    QSpacerItem *verticalSpacer;
    QLineEdit *leMax;
    QLabel *lInterval;
    QLabel *lMin;
    QLabel *lMax;
    QSpacerItem *spacerInfo;

    void setupUi(QWidget *RescaleWidget)
    {
        if (RescaleWidget->objectName().isEmpty())
            RescaleWidget->setObjectName("RescaleWidget");
        RescaleWidget->resize(377, 254);
        gridLayout = new QGridLayout(RescaleWidget);
        gridLayout->setObjectName("gridLayout");
        leMin = new QLineEdit(RescaleWidget);
        leMin->setObjectName("leMin");

        gridLayout->addWidget(leMin, 2, 1, 1, 1);

        lInfo = new QLabel(RescaleWidget);
        lInfo->setObjectName("lInfo");

        gridLayout->addWidget(lInfo, 5, 0, 1, 2);

        buttonBox = new QDialogButtonBox(RescaleWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 7, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 6, 1, 1, 1);

        leMax = new QLineEdit(RescaleWidget);
        leMax->setObjectName("leMax");

        gridLayout->addWidget(leMax, 3, 1, 1, 1);

        lInterval = new QLabel(RescaleWidget);
        lInterval->setObjectName("lInterval");
        QFont font;
        font.setBold(true);
        lInterval->setFont(font);

        gridLayout->addWidget(lInterval, 1, 0, 1, 1);

        lMin = new QLabel(RescaleWidget);
        lMin->setObjectName("lMin");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lMin->sizePolicy().hasHeightForWidth());
        lMin->setSizePolicy(sizePolicy);
        lMin->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lMin, 2, 0, 1, 1);

        lMax = new QLabel(RescaleWidget);
        lMax->setObjectName("lMax");
        lMax->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lMax, 3, 0, 1, 1);

        spacerInfo = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(spacerInfo, 4, 0, 1, 1);

        QWidget::setTabOrder(leMin, leMax);

        retranslateUi(RescaleWidget);

        QMetaObject::connectSlotsByName(RescaleWidget);
    } // setupUi

    void retranslateUi(QWidget *RescaleWidget)
    {
        lInfo->setText(QString());
        lInterval->setText(QString());
        lMin->setText(tr2i18n("a:", nullptr));
        lMax->setText(tr2i18n("b:", nullptr));
        (void)RescaleWidget;
    } // retranslateUi

};

namespace Ui {
    class RescaleWidget: public Ui_RescaleWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RESCALEWIDGET_H

