/********************************************************************************
** Form generated from reading UI file 'settingsnotebookpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSNOTEBOOKPAGE_H
#define UI_SETTINGSNOTEBOOKPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SettingsNotebookPage
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QCheckBox *chkSyntaxHighlighting;
    QCheckBox *chkSyntaxCompletion;
    QCheckBox *chkLineNumbers;
    QCheckBox *chkLatexTypesetting;
    QCheckBox *chkAnimations;
    QSpacerItem *verticalSpacer_4;
    QLabel *label_2;
    QCheckBox *chkReevaluateEntries;
    QCheckBox *chkAskConfirmation;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SettingsNotebookPage)
    {
        if (SettingsNotebookPage->objectName().isEmpty())
            SettingsNotebookPage->setObjectName("SettingsNotebookPage");
        SettingsNotebookPage->resize(371, 348);
        verticalLayout = new QVBoxLayout(SettingsNotebookPage);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(SettingsNotebookPage);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        verticalLayout->addWidget(label);

        chkSyntaxHighlighting = new QCheckBox(SettingsNotebookPage);
        chkSyntaxHighlighting->setObjectName("chkSyntaxHighlighting");

        verticalLayout->addWidget(chkSyntaxHighlighting);

        chkSyntaxCompletion = new QCheckBox(SettingsNotebookPage);
        chkSyntaxCompletion->setObjectName("chkSyntaxCompletion");

        verticalLayout->addWidget(chkSyntaxCompletion);

        chkLineNumbers = new QCheckBox(SettingsNotebookPage);
        chkLineNumbers->setObjectName("chkLineNumbers");

        verticalLayout->addWidget(chkLineNumbers);

        chkLatexTypesetting = new QCheckBox(SettingsNotebookPage);
        chkLatexTypesetting->setObjectName("chkLatexTypesetting");

        verticalLayout->addWidget(chkLatexTypesetting);

        chkAnimations = new QCheckBox(SettingsNotebookPage);
        chkAnimations->setObjectName("chkAnimations");

        verticalLayout->addWidget(chkAnimations);

        verticalSpacer_4 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_4);

        label_2 = new QLabel(SettingsNotebookPage);
        label_2->setObjectName("label_2");
        label_2->setFont(font);

        verticalLayout->addWidget(label_2);

        chkReevaluateEntries = new QCheckBox(SettingsNotebookPage);
        chkReevaluateEntries->setObjectName("chkReevaluateEntries");

        verticalLayout->addWidget(chkReevaluateEntries);

        chkAskConfirmation = new QCheckBox(SettingsNotebookPage);
        chkAskConfirmation->setObjectName("chkAskConfirmation");

        verticalLayout->addWidget(chkAskConfirmation);

        verticalSpacer = new QSpacerItem(20, 67, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(SettingsNotebookPage);

        QMetaObject::connectSlotsByName(SettingsNotebookPage);
    } // setupUi

    void retranslateUi(QWidget *SettingsNotebookPage)
    {
        SettingsNotebookPage->setWindowTitle(tr2i18n("Form", nullptr));
        label->setText(tr2i18n("Appearance", nullptr));
        chkSyntaxHighlighting->setText(tr2i18n("Syntax Highlighting", nullptr));
        chkSyntaxCompletion->setText(tr2i18n("Syntax Completion", nullptr));
        chkLineNumbers->setText(tr2i18n("Line Numbers", nullptr));
        chkLatexTypesetting->setText(tr2i18n("LaTeX Typesetting", nullptr));
        chkAnimations->setText(tr2i18n("Animations", nullptr));
        label_2->setText(tr2i18n("Evaluation", nullptr));
        chkReevaluateEntries->setText(tr2i18n("Re-evaluate entries automatically", nullptr));
        chkAskConfirmation->setText(tr2i18n("Ask for confirmation when restarting", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SettingsNotebookPage: public Ui_SettingsNotebookPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGSNOTEBOOKPAGE_H

