/****************************************************************************
** Meta object code from reading C++ file 'XYCurve.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/plots/cartesian/XYCurve.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'XYCurve.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7XYCurveE_t {};
} // unnamed namespace

template <> constexpr inline auto XYCurve::qt_create_metaobjectdata<qt_meta_tag_ZN7XYCurveE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XYCurve",
        "linesUpdated",
        "",
        "const XYCurve*",
        "QList<QLineF>",
        "pointsUpdated",
        "startIndex",
        "endIndex",
        "QList<QPointF>",
        "logicalPoints",
        "xDataChanged",
        "yDataChanged",
        "valuesDataChanged",
        "selected",
        "pos",
        "xColumnChanged",
        "const AbstractColumn*",
        "yColumnChanged",
        "lineTypeChanged",
        "XYCurve::LineType",
        "lineSkipGapsChanged",
        "lineIncreasingXOnlyChanged",
        "lineInterpolationPointsCountChanged",
        "dropLineTypeChanged",
        "XYCurve::DropLineType",
        "valuesTypeChanged",
        "XYCurve::ValuesType",
        "valuesColumnChanged",
        "valuesPositionChanged",
        "XYCurve::ValuesPosition",
        "valuesDistanceChanged",
        "valuesRotationAngleChanged",
        "valuesOpacityChanged",
        "valuesNumericFormatChanged",
        "valuesPrecisionChanged",
        "valuesDateTimeFormatChanged",
        "valuesPrefixChanged",
        "valuesSuffixChanged",
        "valuesFontChanged",
        "QFont",
        "valuesColorChanged",
        "QColor",
        "rugEnabledChanged",
        "rugOrientationChanged",
        "WorksheetElement::Orientation",
        "rugLengthChanged",
        "rugWidthChanged",
        "rugOffsetChanged",
        "updateValues",
        "updateErrorBars",
        "xColumnAboutToBeRemoved",
        "const AbstractAspect*",
        "yColumnAboutToBeRemoved",
        "valuesColumnAboutToBeRemoved",
        "navigateTo"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'linesUpdated'
        QtMocHelpers::SignalData<void(const XYCurve *, const QVector<QLineF> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'pointsUpdated'
        QtMocHelpers::SignalData<void(const XYCurve *, const int, const int, const QVector<QPointF> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Int, 6 }, { QMetaType::Int, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'xDataChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yDataChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'valuesDataChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selected'
        QtMocHelpers::SignalData<void(double)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 14 },
        }}),
        // Signal 'xColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Signal 'yColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Signal 'lineTypeChanged'
        QtMocHelpers::SignalData<void(XYCurve::LineType)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Signal 'lineSkipGapsChanged'
        QtMocHelpers::SignalData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'lineIncreasingXOnlyChanged'
        QtMocHelpers::SignalData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'lineInterpolationPointsCountChanged'
        QtMocHelpers::SignalData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'dropLineTypeChanged'
        QtMocHelpers::SignalData<void(XYCurve::DropLineType)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 2 },
        }}),
        // Signal 'valuesTypeChanged'
        QtMocHelpers::SignalData<void(XYCurve::ValuesType)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
        // Signal 'valuesColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Signal 'valuesPositionChanged'
        QtMocHelpers::SignalData<void(XYCurve::ValuesPosition)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Signal 'valuesDistanceChanged'
        QtMocHelpers::SignalData<void(qreal)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'valuesRotationAngleChanged'
        QtMocHelpers::SignalData<void(qreal)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'valuesOpacityChanged'
        QtMocHelpers::SignalData<void(qreal)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'valuesNumericFormatChanged'
        QtMocHelpers::SignalData<void(char)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Char, 2 },
        }}),
        // Signal 'valuesPrecisionChanged'
        QtMocHelpers::SignalData<void(int)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'valuesDateTimeFormatChanged'
        QtMocHelpers::SignalData<void(QString)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'valuesPrefixChanged'
        QtMocHelpers::SignalData<void(QString)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'valuesSuffixChanged'
        QtMocHelpers::SignalData<void(QString)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'valuesFontChanged'
        QtMocHelpers::SignalData<void(QFont)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 2 },
        }}),
        // Signal 'valuesColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 2 },
        }}),
        // Signal 'rugEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'rugOrientationChanged'
        QtMocHelpers::SignalData<void(WorksheetElement::Orientation)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 2 },
        }}),
        // Signal 'rugLengthChanged'
        QtMocHelpers::SignalData<void(double)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'rugWidthChanged'
        QtMocHelpers::SignalData<void(double)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'rugOffsetChanged'
        QtMocHelpers::SignalData<void(double)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'updateValues'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateErrorBars'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'xColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 2 },
        }}),
        // Slot 'yColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 2 },
        }}),
        // Slot 'valuesColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 2 },
        }}),
        // Slot 'navigateTo'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XYCurve, qt_meta_tag_ZN7XYCurveE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XYCurve::staticMetaObject = { {
    QMetaObject::SuperData::link<Plot::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7XYCurveE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7XYCurveE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7XYCurveE_t>.metaTypes,
    nullptr
} };

void XYCurve::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XYCurve *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->linesUpdated((*reinterpret_cast<std::add_pointer_t<const XYCurve*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QLineF>>>(_a[2]))); break;
        case 1: _t->pointsUpdated((*reinterpret_cast<std::add_pointer_t<const XYCurve*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QList<QPointF>>>(_a[4]))); break;
        case 2: _t->xDataChanged(); break;
        case 3: _t->yDataChanged(); break;
        case 4: _t->valuesDataChanged(); break;
        case 5: _t->selected((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->xColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 7: _t->yColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 8: _t->lineTypeChanged((*reinterpret_cast<std::add_pointer_t<XYCurve::LineType>>(_a[1]))); break;
        case 9: _t->lineSkipGapsChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->lineIncreasingXOnlyChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->lineInterpolationPointsCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->dropLineTypeChanged((*reinterpret_cast<std::add_pointer_t<XYCurve::DropLineType>>(_a[1]))); break;
        case 13: _t->valuesTypeChanged((*reinterpret_cast<std::add_pointer_t<XYCurve::ValuesType>>(_a[1]))); break;
        case 14: _t->valuesColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 15: _t->valuesPositionChanged((*reinterpret_cast<std::add_pointer_t<XYCurve::ValuesPosition>>(_a[1]))); break;
        case 16: _t->valuesDistanceChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 17: _t->valuesRotationAngleChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 18: _t->valuesOpacityChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 19: _t->valuesNumericFormatChanged((*reinterpret_cast<std::add_pointer_t<char>>(_a[1]))); break;
        case 20: _t->valuesPrecisionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->valuesDateTimeFormatChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->valuesPrefixChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->valuesSuffixChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->valuesFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 25: _t->valuesColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 26: _t->rugEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->rugOrientationChanged((*reinterpret_cast<std::add_pointer_t<WorksheetElement::Orientation>>(_a[1]))); break;
        case 28: _t->rugLengthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 29: _t->rugWidthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 30: _t->rugOffsetChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 31: _t->updateValues(); break;
        case 32: _t->updateErrorBars(); break;
        case 33: _t->xColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 34: _t->yColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 35: _t->valuesColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 36: _t->navigateTo(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(const XYCurve * , const QVector<QLineF> & )>(_a, &XYCurve::linesUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(const XYCurve * , const int , const int , const QVector<QPointF> & )>(_a, &XYCurve::pointsUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)()>(_a, &XYCurve::xDataChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)()>(_a, &XYCurve::yDataChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)()>(_a, &XYCurve::valuesDataChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(double )>(_a, &XYCurve::selected, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(const AbstractColumn * )>(_a, &XYCurve::xColumnChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(const AbstractColumn * )>(_a, &XYCurve::yColumnChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(XYCurve::LineType )>(_a, &XYCurve::lineTypeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(bool )>(_a, &XYCurve::lineSkipGapsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(bool )>(_a, &XYCurve::lineIncreasingXOnlyChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(int )>(_a, &XYCurve::lineInterpolationPointsCountChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(XYCurve::DropLineType )>(_a, &XYCurve::dropLineTypeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(XYCurve::ValuesType )>(_a, &XYCurve::valuesTypeChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(const AbstractColumn * )>(_a, &XYCurve::valuesColumnChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(XYCurve::ValuesPosition )>(_a, &XYCurve::valuesPositionChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(qreal )>(_a, &XYCurve::valuesDistanceChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(qreal )>(_a, &XYCurve::valuesRotationAngleChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(qreal )>(_a, &XYCurve::valuesOpacityChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(char )>(_a, &XYCurve::valuesNumericFormatChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(int )>(_a, &XYCurve::valuesPrecisionChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(QString )>(_a, &XYCurve::valuesDateTimeFormatChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(QString )>(_a, &XYCurve::valuesPrefixChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(QString )>(_a, &XYCurve::valuesSuffixChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(QFont )>(_a, &XYCurve::valuesFontChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(QColor )>(_a, &XYCurve::valuesColorChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(bool )>(_a, &XYCurve::rugEnabledChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(WorksheetElement::Orientation )>(_a, &XYCurve::rugOrientationChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(double )>(_a, &XYCurve::rugLengthChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(double )>(_a, &XYCurve::rugWidthChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYCurve::*)(double )>(_a, &XYCurve::rugOffsetChanged, 30))
            return;
    }
}

const QMetaObject *XYCurve::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XYCurve::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7XYCurveE_t>.strings))
        return static_cast<void*>(this);
    return Plot::qt_metacast(_clname);
}

int XYCurve::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Plot::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 37)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 37;
    }
    return _id;
}

// SIGNAL 0
void XYCurve::linesUpdated(const XYCurve * _t1, const QVector<QLineF> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void XYCurve::pointsUpdated(const XYCurve * _t1, const int _t2, const int _t3, const QVector<QPointF> & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void XYCurve::xDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void XYCurve::yDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void XYCurve::valuesDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void XYCurve::selected(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void XYCurve::xColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void XYCurve::yColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void XYCurve::lineTypeChanged(XYCurve::LineType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void XYCurve::lineSkipGapsChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void XYCurve::lineIncreasingXOnlyChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void XYCurve::lineInterpolationPointsCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void XYCurve::dropLineTypeChanged(XYCurve::DropLineType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void XYCurve::valuesTypeChanged(XYCurve::ValuesType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void XYCurve::valuesColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void XYCurve::valuesPositionChanged(XYCurve::ValuesPosition _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void XYCurve::valuesDistanceChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void XYCurve::valuesRotationAngleChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void XYCurve::valuesOpacityChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void XYCurve::valuesNumericFormatChanged(char _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void XYCurve::valuesPrecisionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void XYCurve::valuesDateTimeFormatChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void XYCurve::valuesPrefixChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void XYCurve::valuesSuffixChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void XYCurve::valuesFontChanged(QFont _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void XYCurve::valuesColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void XYCurve::rugEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void XYCurve::rugOrientationChanged(WorksheetElement::Orientation _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void XYCurve::rugLengthChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void XYCurve::rugWidthChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1);
}

// SIGNAL 30
void XYCurve::rugOffsetChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1);
}
QT_WARNING_POP
