/********************************************************************************
** Form generated from reading UI file 'odsoptionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ODSOPTIONSWIDGET_H
#define UI_ODSOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OdsOptionsWidget
{
public:
    QGridLayout *gridLayout;
    QSplitter *splitter;
    QTreeWidget *twDataRegions;
    QTableWidget *twPreview;
    QHBoxLayout *horizontalLayout;
    QLabel *lPreviewRows;
    QSpinBox *sbPreviewLines;
    QSpacerItem *horizontalSpacer;
    QPushButton *bRefreshPreview;

    void setupUi(QWidget *OdsOptionsWidget)
    {
        if (OdsOptionsWidget->objectName().isEmpty())
            OdsOptionsWidget->setObjectName("OdsOptionsWidget");
        OdsOptionsWidget->resize(579, 299);
        gridLayout = new QGridLayout(OdsOptionsWidget);
        gridLayout->setObjectName("gridLayout");
        splitter = new QSplitter(OdsOptionsWidget);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        twDataRegions = new QTreeWidget(splitter);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        twDataRegions->setHeaderItem(__qtreewidgetitem);
        twDataRegions->setObjectName("twDataRegions");
        splitter->addWidget(twDataRegions);
        twDataRegions->header()->setStretchLastSection(false);
        twPreview = new QTableWidget(splitter);
        twPreview->setObjectName("twPreview");
        splitter->addWidget(twPreview);

        gridLayout->addWidget(splitter, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        lPreviewRows = new QLabel(OdsOptionsWidget);
        lPreviewRows->setObjectName("lPreviewRows");

        horizontalLayout->addWidget(lPreviewRows);

        sbPreviewLines = new QSpinBox(OdsOptionsWidget);
        sbPreviewLines->setObjectName("sbPreviewLines");
        sbPreviewLines->setMaximum(10000);
        sbPreviewLines->setValue(100);

        horizontalLayout->addWidget(sbPreviewLines);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        bRefreshPreview = new QPushButton(OdsOptionsWidget);
        bRefreshPreview->setObjectName("bRefreshPreview");

        horizontalLayout->addWidget(bRefreshPreview);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);


        retranslateUi(OdsOptionsWidget);

        QMetaObject::connectSlotsByName(OdsOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *OdsOptionsWidget)
    {
        OdsOptionsWidget->setWindowTitle(tr2i18n("Form", nullptr));
        lPreviewRows->setText(tr2i18n("Number of rows to preview:", nullptr));
        bRefreshPreview->setText(tr2i18n("Refresh", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OdsOptionsWidget: public Ui_OdsOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ODSOPTIONSWIDGET_H

