/********************************************************************************
** Form generated from reading UI file 'importdatasetwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTDATASETWIDGET_H
#define UI_IMPORTDATASETWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "src/frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_ImportDatasetWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *lCollections;
    QScrollArea *saDetails;
    QWidget *scrollAreaWidgetContents;
    QGridLayout *gridLayout_3;
    QLabel *lInfo;
    QLabel *lCategories;
    QTreeWidget *twCategories;
    QSpacerItem *horizontalSpacer;
    QListWidget *lwDatasets;
    QHBoxLayout *horizontalLayout;
    QLabel *lSearch;
    TimedLineEdit *leSearch;
    QComboBox *cbCollections;

    void setupUi(QWidget *ImportDatasetWidget)
    {
        if (ImportDatasetWidget->objectName().isEmpty())
            ImportDatasetWidget->setObjectName("ImportDatasetWidget");
        ImportDatasetWidget->resize(919, 757);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ImportDatasetWidget->sizePolicy().hasHeightForWidth());
        ImportDatasetWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(ImportDatasetWidget);
        gridLayout->setObjectName("gridLayout");
        lCollections = new QLabel(ImportDatasetWidget);
        lCollections->setObjectName("lCollections");

        gridLayout->addWidget(lCollections, 0, 0, 1, 1);

        saDetails = new QScrollArea(ImportDatasetWidget);
        saDetails->setObjectName("saDetails");
        sizePolicy.setHeightForWidth(saDetails->sizePolicy().hasHeightForWidth());
        saDetails->setSizePolicy(sizePolicy);
        saDetails->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        saDetails->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 239, 741));
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(scrollAreaWidgetContents->sizePolicy().hasHeightForWidth());
        scrollAreaWidgetContents->setSizePolicy(sizePolicy1);
        gridLayout_3 = new QGridLayout(scrollAreaWidgetContents);
        gridLayout_3->setObjectName("gridLayout_3");
        lInfo = new QLabel(scrollAreaWidgetContents);
        lInfo->setObjectName("lInfo");
        sizePolicy.setHeightForWidth(lInfo->sizePolicy().hasHeightForWidth());
        lInfo->setSizePolicy(sizePolicy);
        lInfo->setTextFormat(Qt::RichText);
        lInfo->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        lInfo->setWordWrap(true);

        gridLayout_3->addWidget(lInfo, 0, 0, 1, 1);

        saDetails->setWidget(scrollAreaWidgetContents);

        gridLayout->addWidget(saDetails, 0, 4, 3, 1);

        lCategories = new QLabel(ImportDatasetWidget);
        lCategories->setObjectName("lCategories");
        lCategories->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        gridLayout->addWidget(lCategories, 1, 0, 1, 1);

        twCategories = new QTreeWidget(ImportDatasetWidget);
        twCategories->setObjectName("twCategories");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(twCategories->sizePolicy().hasHeightForWidth());
        twCategories->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(twCategories, 1, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 2, 1, 1);

        lwDatasets = new QListWidget(ImportDatasetWidget);
        lwDatasets->setObjectName("lwDatasets");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(lwDatasets->sizePolicy().hasHeightForWidth());
        lwDatasets->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(lwDatasets, 1, 3, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        lSearch = new QLabel(ImportDatasetWidget);
        lSearch->setObjectName("lSearch");
        sizePolicy3.setHeightForWidth(lSearch->sizePolicy().hasHeightForWidth());
        lSearch->setSizePolicy(sizePolicy3);

        horizontalLayout->addWidget(lSearch);

        leSearch = new TimedLineEdit(ImportDatasetWidget);
        leSearch->setObjectName("leSearch");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(leSearch->sizePolicy().hasHeightForWidth());
        leSearch->setSizePolicy(sizePolicy4);
        leSearch->setClearButtonEnabled(true);

        horizontalLayout->addWidget(leSearch);


        gridLayout->addLayout(horizontalLayout, 2, 1, 1, 3);

        cbCollections = new QComboBox(ImportDatasetWidget);
        cbCollections->setObjectName("cbCollections");

        gridLayout->addWidget(cbCollections, 0, 1, 1, 3);

        QWidget::setTabOrder(cbCollections, twCategories);
        QWidget::setTabOrder(twCategories, lwDatasets);
        QWidget::setTabOrder(lwDatasets, leSearch);
        QWidget::setTabOrder(leSearch, saDetails);

        retranslateUi(ImportDatasetWidget);

        QMetaObject::connectSlotsByName(ImportDatasetWidget);
    } // setupUi

    void retranslateUi(QWidget *ImportDatasetWidget)
    {
        lCollections->setText(tr2i18n("Collection:", nullptr));
        lInfo->setText(QString());
        lCategories->setText(tr2i18n("Dataset:", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = twCategories->headerItem();
        ___qtreewidgetitem->setText(0, tr2i18n("Categories", nullptr));
        lSearch->setText(QString());
        (void)ImportDatasetWidget;
    } // retranslateUi

};

namespace Ui {
    class ImportDatasetWidget: public Ui_ImportDatasetWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTDATASETWIDGET_H

