/****************************************************************************
** Meta object code from reading C++ file 'Symbol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/plots/cartesian/Symbol.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Symbol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6SymbolE_t {};
} // unnamed namespace

template <> constexpr inline auto Symbol::qt_create_metaobjectdata<qt_meta_tag_ZN6SymbolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Symbol",
        "styleChanged",
        "",
        "Symbol::Style",
        "sizeChanged",
        "rotationAngleChanged",
        "opacityChanged",
        "brushChanged",
        "QBrush",
        "penChanged",
        "QPen",
        "colorChanged",
        "QColor",
        "updateRequested",
        "updatePixmapRequested",
        "Style",
        "NoSymbols",
        "Circle",
        "Square",
        "EquilateralTriangle",
        "RightTriangle",
        "Bar",
        "PeakedBar",
        "SkewedBar",
        "Diamond",
        "Lozenge",
        "Tie",
        "TinyTie",
        "Plus",
        "Boomerang",
        "SmallBoomerang",
        "Star4",
        "Star5",
        "Line",
        "Cross",
        "Heart",
        "Lightning",
        "X",
        "Asterisk",
        "Tri",
        "XPlus",
        "TallPlus",
        "LatinCross",
        "DotPlus",
        "Hash",
        "SquareX",
        "SquarePlus",
        "SquareHalf",
        "SquareDiag",
        "SquareTriangle",
        "CircleHalf",
        "CircleDot",
        "CircleX",
        "CircleTri",
        "Peace",
        "Flower",
        "Flower2",
        "Flower3",
        "Flower5",
        "Flower6",
        "Star",
        "Star3",
        "Star6",
        "Pentagon",
        "Hexagon",
        "Latin",
        "David",
        "Home",
        "Pin",
        "Female",
        "Male",
        "Spade",
        "Club",
        "SquareDot",
        "TriangleDot",
        "TriangleHalf",
        "TriangleLine"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'styleChanged'
        QtMocHelpers::SignalData<void(Symbol::Style)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void(qreal)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'rotationAngleChanged'
        QtMocHelpers::SignalData<void(qreal)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'opacityChanged'
        QtMocHelpers::SignalData<void(qreal)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'brushChanged'
        QtMocHelpers::SignalData<void(QBrush)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'penChanged'
        QtMocHelpers::SignalData<void(const QPen &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Signal 'updateRequested'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updatePixmapRequested'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Style'
        QtMocHelpers::EnumData<enum Style>(15, 15, QMC::EnumIsScoped).add({
            {   16, Style::NoSymbols },
            {   17, Style::Circle },
            {   18, Style::Square },
            {   19, Style::EquilateralTriangle },
            {   20, Style::RightTriangle },
            {   21, Style::Bar },
            {   22, Style::PeakedBar },
            {   23, Style::SkewedBar },
            {   24, Style::Diamond },
            {   25, Style::Lozenge },
            {   26, Style::Tie },
            {   27, Style::TinyTie },
            {   28, Style::Plus },
            {   29, Style::Boomerang },
            {   30, Style::SmallBoomerang },
            {   31, Style::Star4 },
            {   32, Style::Star5 },
            {   33, Style::Line },
            {   34, Style::Cross },
            {   35, Style::Heart },
            {   36, Style::Lightning },
            {   37, Style::X },
            {   38, Style::Asterisk },
            {   39, Style::Tri },
            {   40, Style::XPlus },
            {   41, Style::TallPlus },
            {   42, Style::LatinCross },
            {   43, Style::DotPlus },
            {   44, Style::Hash },
            {   45, Style::SquareX },
            {   46, Style::SquarePlus },
            {   47, Style::SquareHalf },
            {   48, Style::SquareDiag },
            {   49, Style::SquareTriangle },
            {   50, Style::CircleHalf },
            {   51, Style::CircleDot },
            {   52, Style::CircleX },
            {   53, Style::CircleTri },
            {   54, Style::Peace },
            {   55, Style::Flower },
            {   56, Style::Flower2 },
            {   57, Style::Flower3 },
            {   58, Style::Flower5 },
            {   59, Style::Flower6 },
            {   60, Style::Star },
            {   61, Style::Star3 },
            {   62, Style::Star6 },
            {   63, Style::Pentagon },
            {   64, Style::Hexagon },
            {   65, Style::Latin },
            {   66, Style::David },
            {   67, Style::Home },
            {   68, Style::Pin },
            {   69, Style::Female },
            {   70, Style::Male },
            {   71, Style::Spade },
            {   72, Style::Club },
            {   73, Style::SquareDot },
            {   74, Style::TriangleDot },
            {   75, Style::TriangleHalf },
            {   76, Style::TriangleLine },
        }),
    };
    return QtMocHelpers::metaObjectData<Symbol, qt_meta_tag_ZN6SymbolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Symbol::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractAspect::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SymbolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SymbolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6SymbolE_t>.metaTypes,
    nullptr
} };

void Symbol::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Symbol *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->styleChanged((*reinterpret_cast<std::add_pointer_t<Symbol::Style>>(_a[1]))); break;
        case 1: _t->sizeChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 2: _t->rotationAngleChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 3: _t->opacityChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 4: _t->brushChanged((*reinterpret_cast<std::add_pointer_t<QBrush>>(_a[1]))); break;
        case 5: _t->penChanged((*reinterpret_cast<std::add_pointer_t<QPen>>(_a[1]))); break;
        case 6: _t->colorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 7: _t->updateRequested(); break;
        case 8: _t->updatePixmapRequested(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Symbol::*)(Symbol::Style )>(_a, &Symbol::styleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Symbol::*)(qreal )>(_a, &Symbol::sizeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Symbol::*)(qreal )>(_a, &Symbol::rotationAngleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Symbol::*)(qreal )>(_a, &Symbol::opacityChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Symbol::*)(QBrush )>(_a, &Symbol::brushChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Symbol::*)(const QPen & )>(_a, &Symbol::penChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Symbol::*)(const QColor & )>(_a, &Symbol::colorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Symbol::*)()>(_a, &Symbol::updateRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Symbol::*)()>(_a, &Symbol::updatePixmapRequested, 8))
            return;
    }
}

const QMetaObject *Symbol::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Symbol::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SymbolE_t>.strings))
        return static_cast<void*>(this);
    return AbstractAspect::qt_metacast(_clname);
}

int Symbol::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractAspect::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Symbol::styleChanged(Symbol::Style _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Symbol::sizeChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Symbol::rotationAngleChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Symbol::opacityChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Symbol::brushChanged(QBrush _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Symbol::penChanged(const QPen & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Symbol::colorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Symbol::updateRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Symbol::updatePixmapRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
