/****************************************************************************
** Meta object code from reading C++ file 'Value.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/plots/cartesian/Value.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Value.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5ValueE_t {};
} // unnamed namespace

template <> constexpr inline auto Value::qt_create_metaobjectdata<qt_meta_tag_ZN5ValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Value",
        "typeChanged",
        "",
        "Value::Type",
        "columnChanged",
        "const AbstractColumn*",
        "positionChanged",
        "Value::Position",
        "distanceChanged",
        "rotationAngleChanged",
        "opacityChanged",
        "numericFormatChanged",
        "precisionChanged",
        "dateTimeFormatChanged",
        "prefixChanged",
        "suffixChanged",
        "fontChanged",
        "QFont",
        "colorChanged",
        "QColor",
        "updateRequested",
        "updatePixmapRequested",
        "columnAboutToBeRemoved",
        "const AbstractAspect*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(Value::Type)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'columnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(Value::Position)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'distanceChanged'
        QtMocHelpers::SignalData<void(double)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'rotationAngleChanged'
        QtMocHelpers::SignalData<void(double)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'opacityChanged'
        QtMocHelpers::SignalData<void(double)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'numericFormatChanged'
        QtMocHelpers::SignalData<void(char)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Char, 2 },
        }}),
        // Signal 'precisionChanged'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'dateTimeFormatChanged'
        QtMocHelpers::SignalData<void(QString)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'prefixChanged'
        QtMocHelpers::SignalData<void(QString)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'suffixChanged'
        QtMocHelpers::SignalData<void(QString)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void(QFont)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void(QColor)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Signal 'updateRequested'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updatePixmapRequested'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'columnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Value, qt_meta_tag_ZN5ValueE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Value::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractAspect::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5ValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5ValueE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5ValueE_t>.metaTypes,
    nullptr
} };

void Value::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Value *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<Value::Type>>(_a[1]))); break;
        case 1: _t->columnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 2: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<Value::Position>>(_a[1]))); break;
        case 3: _t->distanceChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->rotationAngleChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->opacityChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->numericFormatChanged((*reinterpret_cast<std::add_pointer_t<char>>(_a[1]))); break;
        case 7: _t->precisionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->dateTimeFormatChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->prefixChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->suffixChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->fontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 12: _t->colorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 13: _t->updateRequested(); break;
        case 14: _t->updatePixmapRequested(); break;
        case 15: _t->columnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Value::*)(Value::Type )>(_a, &Value::typeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)(const AbstractColumn * )>(_a, &Value::columnChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)(Value::Position )>(_a, &Value::positionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)(double )>(_a, &Value::distanceChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)(double )>(_a, &Value::rotationAngleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)(double )>(_a, &Value::opacityChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)(char )>(_a, &Value::numericFormatChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)(int )>(_a, &Value::precisionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)(QString )>(_a, &Value::dateTimeFormatChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)(QString )>(_a, &Value::prefixChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)(QString )>(_a, &Value::suffixChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)(QFont )>(_a, &Value::fontChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)(QColor )>(_a, &Value::colorChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)()>(_a, &Value::updateRequested, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Value::*)()>(_a, &Value::updatePixmapRequested, 14))
            return;
    }
}

const QMetaObject *Value::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Value::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5ValueE_t>.strings))
        return static_cast<void*>(this);
    return AbstractAspect::qt_metacast(_clname);
}

int Value::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractAspect::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void Value::typeChanged(Value::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Value::columnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Value::positionChanged(Value::Position _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Value::distanceChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Value::rotationAngleChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Value::opacityChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Value::numericFormatChanged(char _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Value::precisionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Value::dateTimeFormatChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Value::prefixChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Value::suffixChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Value::fontChanged(QFont _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Value::colorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Value::updateRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Value::updatePixmapRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
