/****************************************************************************
** Meta object code from reading C++ file 'LabelWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/widgets/LabelWidget.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'LabelWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11LabelWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto LabelWidget::qt_create_metaobjectdata<qt_meta_tag_ZN11LabelWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LabelWidget",
        "dataChanged",
        "",
        "labelFontColorChangedSignal",
        "QColor",
        "textChanged",
        "charFormatChanged",
        "QTextCharFormat",
        "modeChanged",
        "updateMode",
        "TextLabel::Mode",
        "mode",
        "fontColorChanged",
        "updateBackground",
        "backgroundColorChanged",
        "fontBoldChanged",
        "fontItalicChanged",
        "fontUnderlineChanged",
        "fontStrikeOutChanged",
        "fontSuperScriptChanged",
        "fontSubScriptChanged",
        "charMenu",
        "insertChar",
        "fontChanged",
        "QFont",
        "teXFontChanged",
        "fontSizeChanged",
        "alignLeft",
        "alignCenter",
        "alignRight",
        "alignJustify",
        "dateTimeMenu",
        "insertDateTime",
        "QAction*",
        "positionXChanged",
        "positionYChanged",
        "customPositionXChanged",
        "customPositionYChanged",
        "horizontalAlignmentChanged",
        "verticalAlignmentChanged",
        "positionXLogicalChanged",
        "positionXLogicalDateTimeChanged",
        "positionYLogicalChanged",
        "rotationChanged",
        "offsetXChanged",
        "offsetYChanged",
        "borderShapeChanged",
        "lockChanged",
        "bindingChanged",
        "checked",
        "showPlaceholderTextChanged",
        "labelTextWrapperChanged",
        "TextLabel::TextWrapper",
        "labelTeXImageUpdated",
        "TeXRenderer::Result",
        "labelTeXFontChanged",
        "labelFontColorChanged",
        "labelBackgroundColorChanged",
        "labelPositionChanged",
        "TextLabel::PositionWrapper",
        "labelHorizontalAlignmentChanged",
        "TextLabel::HorizontalAlignment",
        "labelVerticalAlignmentChanged",
        "TextLabel::VerticalAlignment",
        "labelPositionLogicalChanged",
        "QPointF",
        "labelCoordinateBindingEnabledChanged",
        "labelOffsetXChanged",
        "labelOffsetYChanged",
        "labelRotationAngleChanged",
        "labelBorderShapeChanged",
        "TextLabel::BorderShape",
        "labelLockChanged",
        "labelCartesianPlotParent",
        "on",
        "labelModeChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'labelFontColorChangedSignal'
        QtMocHelpers::SignalData<void(const QColor &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'textChanged'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'charFormatChanged'
        QtMocHelpers::SlotData<void(const QTextCharFormat &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'modeChanged'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'updateMode'
        QtMocHelpers::SlotData<void(TextLabel::Mode)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'fontColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'updateBackground'
        QtMocHelpers::SlotData<void() const>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'backgroundColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'fontBoldChanged'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'fontItalicChanged'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'fontUnderlineChanged'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'fontStrikeOutChanged'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'fontSuperScriptChanged'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'fontSubScriptChanged'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'charMenu'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'insertChar'
        QtMocHelpers::SlotData<void(QChar)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QChar, 2 },
        }}),
        // Slot 'fontChanged'
        QtMocHelpers::SlotData<void(const QFont &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 2 },
        }}),
        // Slot 'teXFontChanged'
        QtMocHelpers::SlotData<void(const QFont &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 2 },
        }}),
        // Slot 'fontSizeChanged'
        QtMocHelpers::SlotData<void(int)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'alignLeft'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'alignCenter'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'alignRight'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'alignJustify'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'dateTimeMenu'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'insertDateTime'
        QtMocHelpers::SlotData<void(QAction *)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 2 },
        }}),
        // Slot 'positionXChanged'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'positionYChanged'
        QtMocHelpers::SlotData<void(int)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'customPositionXChanged'
        QtMocHelpers::SlotData<void(double)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'customPositionYChanged'
        QtMocHelpers::SlotData<void(double)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'horizontalAlignmentChanged'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'verticalAlignmentChanged'
        QtMocHelpers::SlotData<void(int)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'positionXLogicalChanged'
        QtMocHelpers::SlotData<void(double)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'positionXLogicalDateTimeChanged'
        QtMocHelpers::SlotData<void(qint64)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 2 },
        }}),
        // Slot 'positionYLogicalChanged'
        QtMocHelpers::SlotData<void(double)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'rotationChanged'
        QtMocHelpers::SlotData<void(int)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'offsetXChanged'
        QtMocHelpers::SlotData<void(double)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'offsetYChanged'
        QtMocHelpers::SlotData<void(double)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'borderShapeChanged'
        QtMocHelpers::SlotData<void(int)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'lockChanged'
        QtMocHelpers::SlotData<void(bool)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'bindingChanged'
        QtMocHelpers::SlotData<void(bool)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 49 },
        }}),
        // Slot 'showPlaceholderTextChanged'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 49 },
        }}),
        // Slot 'labelTextWrapperChanged'
        QtMocHelpers::SlotData<void(const TextLabel::TextWrapper &)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 52, 2 },
        }}),
        // Slot 'labelTeXImageUpdated'
        QtMocHelpers::SlotData<void(const TeXRenderer::Result &)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 54, 2 },
        }}),
        // Slot 'labelTeXFontChanged'
        QtMocHelpers::SlotData<void(const QFont &)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 2 },
        }}),
        // Slot 'labelFontColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'labelBackgroundColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'labelPositionChanged'
        QtMocHelpers::SlotData<void(const TextLabel::PositionWrapper &)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 59, 2 },
        }}),
        // Slot 'labelHorizontalAlignmentChanged'
        QtMocHelpers::SlotData<void(TextLabel::HorizontalAlignment)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 61, 2 },
        }}),
        // Slot 'labelVerticalAlignmentChanged'
        QtMocHelpers::SlotData<void(TextLabel::VerticalAlignment)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 63, 2 },
        }}),
        // Slot 'labelPositionLogicalChanged'
        QtMocHelpers::SlotData<void(QPointF)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 65, 2 },
        }}),
        // Slot 'labelCoordinateBindingEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'labelOffsetXChanged'
        QtMocHelpers::SlotData<void(qreal)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'labelOffsetYChanged'
        QtMocHelpers::SlotData<void(qreal)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'labelRotationAngleChanged'
        QtMocHelpers::SlotData<void(qreal)>(69, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'labelBorderShapeChanged'
        QtMocHelpers::SlotData<void(TextLabel::BorderShape)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 71, 2 },
        }}),
        // Slot 'labelLockChanged'
        QtMocHelpers::SlotData<void(bool)>(72, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'labelCartesianPlotParent'
        QtMocHelpers::SlotData<void(bool)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 74 },
        }}),
        // Slot 'labelModeChanged'
        QtMocHelpers::SlotData<void(TextLabel::Mode)>(75, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LabelWidget, qt_meta_tag_ZN11LabelWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LabelWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseDock::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11LabelWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11LabelWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11LabelWidgetE_t>.metaTypes,
    nullptr
} };

void LabelWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LabelWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->labelFontColorChangedSignal((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 2: _t->textChanged(); break;
        case 3: _t->charFormatChanged((*reinterpret_cast<std::add_pointer_t<QTextCharFormat>>(_a[1]))); break;
        case 4: _t->modeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->updateMode((*reinterpret_cast<std::add_pointer_t<TextLabel::Mode>>(_a[1]))); break;
        case 6: _t->fontColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 7: _t->updateBackground(); break;
        case 8: _t->backgroundColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 9: _t->fontBoldChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->fontItalicChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->fontUnderlineChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->fontStrikeOutChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->fontSuperScriptChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->fontSubScriptChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->charMenu(); break;
        case 16: _t->insertChar((*reinterpret_cast<std::add_pointer_t<QChar>>(_a[1]))); break;
        case 17: _t->fontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 18: _t->teXFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 19: _t->fontSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->alignLeft(); break;
        case 21: _t->alignCenter(); break;
        case 22: _t->alignRight(); break;
        case 23: _t->alignJustify(); break;
        case 24: _t->dateTimeMenu(); break;
        case 25: _t->insertDateTime((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 26: _t->positionXChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->positionYChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->customPositionXChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 29: _t->customPositionYChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 30: _t->horizontalAlignmentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->verticalAlignmentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->positionXLogicalChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 33: _t->positionXLogicalDateTimeChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 34: _t->positionYLogicalChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 35: _t->rotationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->offsetXChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 37: _t->offsetYChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 38: _t->borderShapeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->lockChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->bindingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->showPlaceholderTextChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->labelTextWrapperChanged((*reinterpret_cast<std::add_pointer_t<TextLabel::TextWrapper>>(_a[1]))); break;
        case 43: _t->labelTeXImageUpdated((*reinterpret_cast<std::add_pointer_t<TeXRenderer::Result>>(_a[1]))); break;
        case 44: _t->labelTeXFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 45: _t->labelFontColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 46: _t->labelBackgroundColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 47: _t->labelPositionChanged((*reinterpret_cast<std::add_pointer_t<TextLabel::PositionWrapper>>(_a[1]))); break;
        case 48: _t->labelHorizontalAlignmentChanged((*reinterpret_cast<std::add_pointer_t<TextLabel::HorizontalAlignment>>(_a[1]))); break;
        case 49: _t->labelVerticalAlignmentChanged((*reinterpret_cast<std::add_pointer_t<TextLabel::VerticalAlignment>>(_a[1]))); break;
        case 50: _t->labelPositionLogicalChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 51: _t->labelCoordinateBindingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 52: _t->labelOffsetXChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 53: _t->labelOffsetYChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 54: _t->labelRotationAngleChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 55: _t->labelBorderShapeChanged((*reinterpret_cast<std::add_pointer_t<TextLabel::BorderShape>>(_a[1]))); break;
        case 56: _t->labelLockChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 57: _t->labelCartesianPlotParent((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 58: _t->labelModeChanged((*reinterpret_cast<std::add_pointer_t<TextLabel::Mode>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LabelWidget::*)(bool )>(_a, &LabelWidget::dataChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LabelWidget::*)(const QColor & )>(_a, &LabelWidget::labelFontColorChangedSignal, 1))
            return;
    }
}

const QMetaObject *LabelWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LabelWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11LabelWidgetE_t>.strings))
        return static_cast<void*>(this);
    return BaseDock::qt_metacast(_clname);
}

int LabelWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseDock::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 59)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 59;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 59)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 59;
    }
    return _id;
}

// SIGNAL 0
void LabelWidget::dataChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void LabelWidget::labelFontColorChangedSignal(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
