/****************************************************************************
** Meta object code from reading C++ file 'AspectTreeModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/core/AspectTreeModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AspectTreeModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15AspectTreeModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AspectTreeModel::qt_create_metaobjectdata<qt_meta_tag_ZN15AspectTreeModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AspectTreeModel",
        "renameRequested",
        "",
        "QModelIndex",
        "indexSelected",
        "indexDeselected",
        "hiddenAspectSelected",
        "const AbstractAspect*",
        "statusInfo",
        "aspectDescriptionChanged",
        "aspectAboutToBeAdded",
        "parent",
        "before",
        "child",
        "aspectAdded",
        "aspectAboutToBeRemoved",
        "aspectRemoved",
        "aspectHiddenAboutToChange",
        "aspectHiddenChanged",
        "aspectSelectedInView",
        "aspectDeselectedInView",
        "renameRequestedSlot",
        "aspectAboutToBeMoved",
        "destinationRow",
        "aspectMoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'renameRequested'
        QtMocHelpers::SignalData<void(const QModelIndex &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'indexSelected'
        QtMocHelpers::SignalData<void(const QModelIndex &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'indexDeselected'
        QtMocHelpers::SignalData<void(const QModelIndex &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'hiddenAspectSelected'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'statusInfo'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'aspectDescriptionChanged'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'aspectAboutToBeAdded'
        QtMocHelpers::SlotData<void(const AbstractAspect *, const AbstractAspect *, const AbstractAspect *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 11 }, { 0x80000000 | 7, 12 }, { 0x80000000 | 7, 13 },
        }}),
        // Slot 'aspectAdded'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 11 },
        }}),
        // Slot 'aspectAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'aspectRemoved'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'aspectHiddenAboutToChange'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'aspectHiddenChanged'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'aspectSelectedInView'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'aspectDeselectedInView'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'renameRequestedSlot'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'aspectAboutToBeMoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *, int)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 }, { QMetaType::Int, 23 },
        }}),
        // Slot 'aspectMoved'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AspectTreeModel, qt_meta_tag_ZN15AspectTreeModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AspectTreeModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AspectTreeModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AspectTreeModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15AspectTreeModelE_t>.metaTypes,
    nullptr
} };

void AspectTreeModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AspectTreeModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->renameRequested((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 1: _t->indexSelected((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 2: _t->indexDeselected((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 3: _t->hiddenAspectSelected((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 4: _t->statusInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->aspectDescriptionChanged((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 6: _t->aspectAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[3]))); break;
        case 7: _t->aspectAdded((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 8: _t->aspectAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 9: _t->aspectRemoved(); break;
        case 10: _t->aspectHiddenAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 11: _t->aspectHiddenChanged((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 12: _t->aspectSelectedInView((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 13: _t->aspectDeselectedInView((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 14: _t->renameRequestedSlot(); break;
        case 15: _t->aspectAboutToBeMoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->aspectMoved(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AspectTreeModel::*)(const QModelIndex & )>(_a, &AspectTreeModel::renameRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AspectTreeModel::*)(const QModelIndex & )>(_a, &AspectTreeModel::indexSelected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AspectTreeModel::*)(const QModelIndex & )>(_a, &AspectTreeModel::indexDeselected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AspectTreeModel::*)(const AbstractAspect * )>(_a, &AspectTreeModel::hiddenAspectSelected, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AspectTreeModel::*)(const QString & )>(_a, &AspectTreeModel::statusInfo, 4))
            return;
    }
}

const QMetaObject *AspectTreeModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AspectTreeModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AspectTreeModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int AspectTreeModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void AspectTreeModel::renameRequested(const QModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AspectTreeModel::indexSelected(const QModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AspectTreeModel::indexDeselected(const QModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AspectTreeModel::hiddenAspectSelected(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AspectTreeModel::statusInfo(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
