/********************************************************************************
** Form generated from reading UI file 'importprojectwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTPROJECTWIDGET_H
#define UI_IMPORTPROJECTWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ImportProjectWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *gbProject;
    QHBoxLayout *horizontalLayout;
    QLabel *lFileName;
    QPushButton *bOpen;
    QGroupBox *gbObjects;
    QGridLayout *gridLayout;
    QTreeView *tvPreview;
    QLabel *lGraphLayer;
    QCheckBox *chbUnusedObjects;
    QComboBox *cbGraphLayer;
    QLabel *lUnusedObjects;
    QSpacerItem *verticalSpacer;
    QGroupBox *gbImportTo;
    QHBoxLayout *horizontalLayout_2;
    QLabel *lFolder;

    void setupUi(QWidget *ImportProjectWidget)
    {
        if (ImportProjectWidget->objectName().isEmpty())
            ImportProjectWidget->setObjectName("ImportProjectWidget");
        ImportProjectWidget->resize(542, 645);
        verticalLayout = new QVBoxLayout(ImportProjectWidget);
        verticalLayout->setObjectName("verticalLayout");
        gbProject = new QGroupBox(ImportProjectWidget);
        gbProject->setObjectName("gbProject");
        horizontalLayout = new QHBoxLayout(gbProject);
        horizontalLayout->setObjectName("horizontalLayout");
        lFileName = new QLabel(gbProject);
        lFileName->setObjectName("lFileName");

        horizontalLayout->addWidget(lFileName);

        bOpen = new QPushButton(gbProject);
        bOpen->setObjectName("bOpen");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(bOpen->sizePolicy().hasHeightForWidth());
        bOpen->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(bOpen);


        verticalLayout->addWidget(gbProject);

        gbObjects = new QGroupBox(ImportProjectWidget);
        gbObjects->setObjectName("gbObjects");
        gridLayout = new QGridLayout(gbObjects);
        gridLayout->setObjectName("gridLayout");
        tvPreview = new QTreeView(gbObjects);
        tvPreview->setObjectName("tvPreview");

        gridLayout->addWidget(tvPreview, 0, 0, 1, 2);

        lGraphLayer = new QLabel(gbObjects);
        lGraphLayer->setObjectName("lGraphLayer");

        gridLayout->addWidget(lGraphLayer, 3, 0, 2, 1);

        chbUnusedObjects = new QCheckBox(gbObjects);
        chbUnusedObjects->setObjectName("chbUnusedObjects");

        gridLayout->addWidget(chbUnusedObjects, 2, 1, 2, 1);

        cbGraphLayer = new QComboBox(gbObjects);
        cbGraphLayer->setObjectName("cbGraphLayer");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbGraphLayer->sizePolicy().hasHeightForWidth());
        cbGraphLayer->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbGraphLayer, 4, 1, 1, 1);

        lUnusedObjects = new QLabel(gbObjects);
        lUnusedObjects->setObjectName("lUnusedObjects");

        gridLayout->addWidget(lUnusedObjects, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);


        verticalLayout->addWidget(gbObjects);

        gbImportTo = new QGroupBox(ImportProjectWidget);
        gbImportTo->setObjectName("gbImportTo");
        horizontalLayout_2 = new QHBoxLayout(gbImportTo);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        lFolder = new QLabel(gbImportTo);
        lFolder->setObjectName("lFolder");

        horizontalLayout_2->addWidget(lFolder);


        verticalLayout->addWidget(gbImportTo);


        retranslateUi(ImportProjectWidget);

        QMetaObject::connectSlotsByName(ImportProjectWidget);
    } // setupUi

    void retranslateUi(QWidget *ImportProjectWidget)
    {
        gbProject->setTitle(tr2i18n("Project", nullptr));
        lFileName->setText(tr2i18n("File name:", nullptr));
#if QT_CONFIG(tooltip)
        bOpen->setToolTip(tr2i18n(" Select the file to import", nullptr));
#endif // QT_CONFIG(tooltip)
        bOpen->setText(QString());
        gbObjects->setTitle(tr2i18n("Objects to Import", nullptr));
        lGraphLayer->setText(tr2i18n("Graph Layers:", nullptr));
        chbUnusedObjects->setText(QString());
        lUnusedObjects->setText(tr2i18n("Unused Objects:", nullptr));
        gbImportTo->setTitle(tr2i18n("Import to", nullptr));
        lFolder->setText(tr2i18n("Folder:", nullptr));
        (void)ImportProjectWidget;
    } // retranslateUi

};

namespace Ui {
    class ImportProjectWidget: public Ui_ImportProjectWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTPROJECTWIDGET_H

