/********************************************************************************
** Form generated from reading UI file 'exportworksheetwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXPORTWORKSHEETWIDGET_H
#define UI_EXPORTWORKSHEETWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ExportWorksheetWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *gbExport;
    QGridLayout *gridLayout;
    QPushButton *bOpen;
    KComboBox *cbFormat;
    QLabel *lFileName;
    QLabel *lOutputFormat;
    QLineEdit *leFileName;
    QLabel *lExportTo;
    QComboBox *cbExportTo;
    QGroupBox *gbOptions;
    QGridLayout *gridLayout_2;
    QLabel *lExportArea;
    KComboBox *cbExportArea;
    QLabel *lExportBackground;
    QCheckBox *chkExportBackground;
    QLabel *lResolution;
    QComboBox *cbResolution;

    void setupUi(QWidget *ExportWorksheetWidget)
    {
        if (ExportWorksheetWidget->objectName().isEmpty())
            ExportWorksheetWidget->setObjectName("ExportWorksheetWidget");
        ExportWorksheetWidget->resize(741, 410);
        verticalLayout = new QVBoxLayout(ExportWorksheetWidget);
        verticalLayout->setObjectName("verticalLayout");
        gbExport = new QGroupBox(ExportWorksheetWidget);
        gbExport->setObjectName("gbExport");
        gridLayout = new QGridLayout(gbExport);
        gridLayout->setObjectName("gridLayout");
        bOpen = new QPushButton(gbExport);
        bOpen->setObjectName("bOpen");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(bOpen->sizePolicy().hasHeightForWidth());
        bOpen->setSizePolicy(sizePolicy);

        gridLayout->addWidget(bOpen, 2, 2, 1, 1);

        cbFormat = new KComboBox(gbExport);
        cbFormat->setObjectName("cbFormat");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbFormat->sizePolicy().hasHeightForWidth());
        cbFormat->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbFormat, 0, 1, 1, 1);

        lFileName = new QLabel(gbExport);
        lFileName->setObjectName("lFileName");

        gridLayout->addWidget(lFileName, 2, 0, 1, 1);

        lOutputFormat = new QLabel(gbExport);
        lOutputFormat->setObjectName("lOutputFormat");

        gridLayout->addWidget(lOutputFormat, 0, 0, 1, 1);

        leFileName = new QLineEdit(gbExport);
        leFileName->setObjectName("leFileName");
        leFileName->setClearButtonEnabled(true);

        gridLayout->addWidget(leFileName, 2, 1, 1, 1);

        lExportTo = new QLabel(gbExport);
        lExportTo->setObjectName("lExportTo");

        gridLayout->addWidget(lExportTo, 1, 0, 1, 1);

        cbExportTo = new QComboBox(gbExport);
        cbExportTo->setObjectName("cbExportTo");
        sizePolicy1.setHeightForWidth(cbExportTo->sizePolicy().hasHeightForWidth());
        cbExportTo->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbExportTo, 1, 1, 1, 1);


        verticalLayout->addWidget(gbExport);

        gbOptions = new QGroupBox(ExportWorksheetWidget);
        gbOptions->setObjectName("gbOptions");
        gridLayout_2 = new QGridLayout(gbOptions);
        gridLayout_2->setObjectName("gridLayout_2");
        lExportArea = new QLabel(gbOptions);
        lExportArea->setObjectName("lExportArea");

        gridLayout_2->addWidget(lExportArea, 0, 0, 1, 1);

        cbExportArea = new KComboBox(gbOptions);
        cbExportArea->setObjectName("cbExportArea");
        sizePolicy1.setHeightForWidth(cbExportArea->sizePolicy().hasHeightForWidth());
        cbExportArea->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(cbExportArea, 0, 1, 1, 1);

        lExportBackground = new QLabel(gbOptions);
        lExportBackground->setObjectName("lExportBackground");

        gridLayout_2->addWidget(lExportBackground, 1, 0, 1, 1);

        chkExportBackground = new QCheckBox(gbOptions);
        chkExportBackground->setObjectName("chkExportBackground");
        chkExportBackground->setChecked(true);

        gridLayout_2->addWidget(chkExportBackground, 1, 1, 1, 1);

        lResolution = new QLabel(gbOptions);
        lResolution->setObjectName("lResolution");

        gridLayout_2->addWidget(lResolution, 2, 0, 1, 1);

        cbResolution = new QComboBox(gbOptions);
        cbResolution->setObjectName("cbResolution");
        cbResolution->setEditable(true);

        gridLayout_2->addWidget(cbResolution, 2, 1, 1, 1);


        verticalLayout->addWidget(gbOptions);

        QWidget::setTabOrder(cbFormat, cbExportTo);
        QWidget::setTabOrder(cbExportTo, leFileName);
        QWidget::setTabOrder(leFileName, bOpen);
        QWidget::setTabOrder(bOpen, cbExportArea);
        QWidget::setTabOrder(cbExportArea, chkExportBackground);
        QWidget::setTabOrder(chkExportBackground, cbResolution);

        retranslateUi(ExportWorksheetWidget);

        QMetaObject::connectSlotsByName(ExportWorksheetWidget);
    } // setupUi

    void retranslateUi(QWidget *ExportWorksheetWidget)
    {
        gbExport->setTitle(tr2i18n("Export", nullptr));
#if QT_CONFIG(tooltip)
        bOpen->setToolTip(tr2i18n(" Select the file to import", nullptr));
#endif // QT_CONFIG(tooltip)
        bOpen->setText(QString());
        lFileName->setText(tr2i18n("File Name:", nullptr));
        lOutputFormat->setText(tr2i18n("Format:", nullptr));
#if QT_CONFIG(tooltip)
        leFileName->setToolTip(tr2i18n("Specify the name of the file to export.", nullptr));
#endif // QT_CONFIG(tooltip)
        lExportTo->setText(tr2i18n("Target:", nullptr));
        gbOptions->setTitle(tr2i18n("Options", nullptr));
        lExportArea->setText(tr2i18n("Area to Export:", nullptr));
#if QT_CONFIG(tooltip)
        lExportBackground->setToolTip(tr2i18n("Check this option if the worksheet background should be exported.", nullptr));
#endif // QT_CONFIG(tooltip)
        lExportBackground->setText(tr2i18n("Export Background:", nullptr));
#if QT_CONFIG(tooltip)
        chkExportBackground->setToolTip(tr2i18n("Check this option if the worksheet background should be exported.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkExportBackground->setText(QString());
        lResolution->setText(tr2i18n("Resolution:", nullptr));
        (void)ExportWorksheetWidget;
    } // retranslateUi

};

namespace Ui {
    class ExportWorksheetWidget: public Ui_ExportWorksheetWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXPORTWORKSHEETWIDGET_H

