/********************************************************************************
** Form generated from reading UI file 'CANOptionsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CANOPTIONSWIDGET_H
#define UI_CANOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CANOptionsWidget
{
public:
    QGridLayout *gridLayout_2;
    QGridLayout *gridLayout;
    QComboBox *cbImportMode;
    QLabel *label_2;
    QCheckBox *cbConvertSeconds;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *CANOptionsWidget)
    {
        if (CANOptionsWidget->objectName().isEmpty())
            CANOptionsWidget->setObjectName("CANOptionsWidget");
        CANOptionsWidget->resize(400, 300);
        gridLayout_2 = new QGridLayout(CANOptionsWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        cbImportMode = new QComboBox(CANOptionsWidget);
        cbImportMode->setObjectName("cbImportMode");

        gridLayout->addWidget(cbImportMode, 1, 1, 1, 1);

        label_2 = new QLabel(CANOptionsWidget);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        cbConvertSeconds = new QCheckBox(CANOptionsWidget);
        cbConvertSeconds->setObjectName("cbConvertSeconds");
        cbConvertSeconds->setChecked(true);

        gridLayout->addWidget(cbConvertSeconds, 0, 0, 1, 2);


        gridLayout_2->addLayout(gridLayout, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 2, 0, 1, 1);


        retranslateUi(CANOptionsWidget);

        QMetaObject::connectSlotsByName(CANOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *CANOptionsWidget)
    {
        CANOptionsWidget->setWindowTitle(tr2i18n("Form", nullptr));
        label_2->setText(tr2i18n("Import mode:", nullptr));
        cbConvertSeconds->setText(tr2i18n("Convert time to seconds", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CANOptionsWidget: public Ui_CANOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CANOPTIONSWIDGET_H

