/****************************************************************************
** Meta object code from reading C++ file 'Background.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/Background.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Background.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10BackgroundE_t {};
} // unnamed namespace

template <> constexpr inline auto Background::qt_create_metaobjectdata<qt_meta_tag_ZN10BackgroundE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Background",
        "enabledChanged",
        "",
        "positionChanged",
        "Position",
        "typeChanged",
        "Type",
        "colorStyleChanged",
        "ColorStyle",
        "imageStyleChanged",
        "ImageStyle",
        "brushStyleChanged",
        "Qt::BrushStyle",
        "firstColorChanged",
        "QColor",
        "secondColorChanged",
        "fileNameChanged",
        "opacityChanged",
        "updatePositionRequested",
        "updateRequested"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(enum Position)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(enum Type)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'colorStyleChanged'
        QtMocHelpers::SignalData<void(enum ColorStyle)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'imageStyleChanged'
        QtMocHelpers::SignalData<void(enum ImageStyle)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'brushStyleChanged'
        QtMocHelpers::SignalData<void(Qt::BrushStyle)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Signal 'firstColorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Signal 'secondColorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Signal 'fileNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'opacityChanged'
        QtMocHelpers::SignalData<void(float)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'updatePositionRequested'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateRequested'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Background, qt_meta_tag_ZN10BackgroundE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Background::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractAspect::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10BackgroundE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10BackgroundE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10BackgroundE_t>.metaTypes,
    nullptr
} };

void Background::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Background *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<enum Position>>(_a[1]))); break;
        case 2: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<enum Type>>(_a[1]))); break;
        case 3: _t->colorStyleChanged((*reinterpret_cast<std::add_pointer_t<enum ColorStyle>>(_a[1]))); break;
        case 4: _t->imageStyleChanged((*reinterpret_cast<std::add_pointer_t<enum ImageStyle>>(_a[1]))); break;
        case 5: _t->brushStyleChanged((*reinterpret_cast<std::add_pointer_t<Qt::BrushStyle>>(_a[1]))); break;
        case 6: _t->firstColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 7: _t->secondColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 8: _t->fileNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->opacityChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 10: _t->updatePositionRequested(); break;
        case 11: _t->updateRequested(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Background::*)(bool )>(_a, &Background::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Background::*)(Position )>(_a, &Background::positionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Background::*)(Type )>(_a, &Background::typeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Background::*)(ColorStyle )>(_a, &Background::colorStyleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Background::*)(ImageStyle )>(_a, &Background::imageStyleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Background::*)(Qt::BrushStyle )>(_a, &Background::brushStyleChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Background::*)(const QColor & )>(_a, &Background::firstColorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Background::*)(const QColor & )>(_a, &Background::secondColorChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Background::*)(const QString & )>(_a, &Background::fileNameChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Background::*)(float )>(_a, &Background::opacityChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Background::*)()>(_a, &Background::updatePositionRequested, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Background::*)()>(_a, &Background::updateRequested, 11))
            return;
    }
}

const QMetaObject *Background::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Background::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10BackgroundE_t>.strings))
        return static_cast<void*>(this);
    return AbstractAspect::qt_metacast(_clname);
}

int Background::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractAspect::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Background::enabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Background::positionChanged(Position _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Background::typeChanged(Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Background::colorStyleChanged(ColorStyle _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Background::imageStyleChanged(ImageStyle _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Background::brushStyleChanged(Qt::BrushStyle _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Background::firstColorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Background::secondColorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Background::fileNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Background::opacityChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Background::updatePositionRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Background::updateRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
