/****************************************************************************
** Meta object code from reading C++ file 'Line.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/Line.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Line.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4LineE_t {};
} // unnamed namespace

template <> constexpr inline auto Line::qt_create_metaobjectdata<qt_meta_tag_ZN4LineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Line",
        "histogramLineTypeChanged",
        "",
        "Histogram::LineType",
        "dropLineTypeChanged",
        "XYCurve::DropLineType",
        "styleChanged",
        "Qt::PenStyle",
        "widthChanged",
        "colorChanged",
        "QColor",
        "opacityChanged",
        "updateRequested",
        "updatePixmapRequested"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'histogramLineTypeChanged'
        QtMocHelpers::SignalData<void(Histogram::LineType)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'dropLineTypeChanged'
        QtMocHelpers::SignalData<void(XYCurve::DropLineType)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'styleChanged'
        QtMocHelpers::SignalData<void(Qt::PenStyle)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void(double)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'opacityChanged'
        QtMocHelpers::SignalData<void(float)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'updateRequested'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updatePixmapRequested'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Line, qt_meta_tag_ZN4LineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Line::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractAspect::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4LineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4LineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4LineE_t>.metaTypes,
    nullptr
} };

void Line::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Line *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->histogramLineTypeChanged((*reinterpret_cast<std::add_pointer_t<Histogram::LineType>>(_a[1]))); break;
        case 1: _t->dropLineTypeChanged((*reinterpret_cast<std::add_pointer_t<XYCurve::DropLineType>>(_a[1]))); break;
        case 2: _t->styleChanged((*reinterpret_cast<std::add_pointer_t<Qt::PenStyle>>(_a[1]))); break;
        case 3: _t->widthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->colorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 5: _t->opacityChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 6: _t->updateRequested(); break;
        case 7: _t->updatePixmapRequested(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Line::*)(Histogram::LineType )>(_a, &Line::histogramLineTypeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Line::*)(XYCurve::DropLineType )>(_a, &Line::dropLineTypeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Line::*)(Qt::PenStyle )>(_a, &Line::styleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Line::*)(double )>(_a, &Line::widthChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Line::*)(const QColor & )>(_a, &Line::colorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Line::*)(float )>(_a, &Line::opacityChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Line::*)()>(_a, &Line::updateRequested, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Line::*)()>(_a, &Line::updatePixmapRequested, 7))
            return;
    }
}

const QMetaObject *Line::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Line::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4LineE_t>.strings))
        return static_cast<void*>(this);
    return AbstractAspect::qt_metacast(_clname);
}

int Line::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractAspect::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Line::histogramLineTypeChanged(Histogram::LineType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Line::dropLineTypeChanged(XYCurve::DropLineType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Line::styleChanged(Qt::PenStyle _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Line::widthChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Line::colorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Line::opacityChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Line::updateRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Line::updatePixmapRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
