/****************************************************************************
** Meta object code from reading C++ file 'XYFitCurveDock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/dockwidgets/XYFitCurveDock.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'XYFitCurveDock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14XYFitCurveDockE_t {};
} // unnamed namespace

template <> constexpr inline auto XYFitCurveDock::qt_create_metaobjectdata<qt_meta_tag_ZN14XYFitCurveDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XYFitCurveDock",
        "dataSourceTypeChanged",
        "",
        "dataSourceCurveChanged",
        "QModelIndex",
        "xWeightChanged",
        "yWeightChanged",
        "categoryChanged",
        "modelTypeChanged",
        "algorithmChanged",
        "xDataColumnChanged",
        "yDataColumnChanged",
        "xErrorColumnChanged",
        "yErrorColumnChanged",
        "showDataOptions",
        "showWeightsOptions",
        "showFitOptions",
        "showParameters",
        "showResults",
        "showConstants",
        "showFunctions",
        "updateParameterList",
        "parametersChanged",
        "updateParameterWidget",
        "parametersValid",
        "showOptions",
        "insertFunction",
        "insertConstant",
        "recalculateClicked",
        "updateModelEquation",
        "expressionChanged",
        "enableRecalculate",
        "resultParametersContextMenuRequest",
        "QPoint",
        "resultGoodnessContextMenuRequest",
        "resultLogContextMenuRequest",
        "resultCopy",
        "copyAll",
        "resultCopyAll",
        "curveDataSourceTypeChanged",
        "XYAnalysisCurve::DataSourceType",
        "curveDataSourceCurveChanged",
        "const XYCurve*",
        "curveDataSourceHistogramChanged",
        "const Histogram*",
        "curveXDataColumnChanged",
        "const AbstractColumn*",
        "curveYDataColumnChanged",
        "curveXErrorColumnChanged",
        "curveYErrorColumnChanged",
        "curveFitDataChanged",
        "XYFitCurve::FitData",
        "dataChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'dataSourceTypeChanged'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'dataSourceCurveChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'xWeightChanged'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'yWeightChanged'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'categoryChanged'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'modelTypeChanged'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'algorithmChanged'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'xDataColumnChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'yDataColumnChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'xErrorColumnChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'yErrorColumnChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'showDataOptions'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showWeightsOptions'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showFitOptions'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showParameters'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showResults'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showConstants'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showFunctions'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateParameterList'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'parametersChanged'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'parametersChanged'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'parametersValid'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showOptions'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'insertFunction'
        QtMocHelpers::SlotData<void(const QString &) const>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'insertConstant'
        QtMocHelpers::SlotData<void(const QString &) const>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'recalculateClicked'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateModelEquation'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'expressionChanged'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableRecalculate'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resultParametersContextMenuRequest'
        QtMocHelpers::SlotData<void(QPoint)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 2 },
        }}),
        // Slot 'resultGoodnessContextMenuRequest'
        QtMocHelpers::SlotData<void(QPoint)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 2 },
        }}),
        // Slot 'resultLogContextMenuRequest'
        QtMocHelpers::SlotData<void(QPoint)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 2 },
        }}),
        // Slot 'resultCopy'
        QtMocHelpers::SlotData<void(bool)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'resultCopy'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'resultCopyAll'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'curveDataSourceTypeChanged'
        QtMocHelpers::SlotData<void(XYAnalysisCurve::DataSourceType)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 2 },
        }}),
        // Slot 'curveDataSourceCurveChanged'
        QtMocHelpers::SlotData<void(const XYCurve *)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 2 },
        }}),
        // Slot 'curveDataSourceHistogramChanged'
        QtMocHelpers::SlotData<void(const Histogram *)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 2 },
        }}),
        // Slot 'curveXDataColumnChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 2 },
        }}),
        // Slot 'curveYDataColumnChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 2 },
        }}),
        // Slot 'curveXErrorColumnChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 2 },
        }}),
        // Slot 'curveYErrorColumnChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 2 },
        }}),
        // Slot 'curveFitDataChanged'
        QtMocHelpers::SlotData<void(const XYFitCurve::FitData &)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 2 },
        }}),
        // Slot 'dataChanged'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XYFitCurveDock, qt_meta_tag_ZN14XYFitCurveDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XYFitCurveDock::staticMetaObject = { {
    QMetaObject::SuperData::link<XYCurveDock::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14XYFitCurveDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14XYFitCurveDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14XYFitCurveDockE_t>.metaTypes,
    nullptr
} };

void XYFitCurveDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XYFitCurveDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataSourceTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->dataSourceCurveChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 2: _t->xWeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->yWeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->categoryChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->modelTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->algorithmChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->xDataColumnChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 8: _t->yDataColumnChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: _t->xErrorColumnChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 10: _t->yErrorColumnChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 11: _t->showDataOptions((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->showWeightsOptions((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->showFitOptions((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->showParameters((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->showResults((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->showConstants(); break;
        case 17: _t->showFunctions(); break;
        case 18: _t->updateParameterList(); break;
        case 19: _t->parametersChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->parametersChanged(); break;
        case 21: _t->parametersValid((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->showOptions(); break;
        case 23: _t->insertFunction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->insertConstant((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->recalculateClicked(); break;
        case 26: _t->updateModelEquation(); break;
        case 27: _t->expressionChanged(); break;
        case 28: _t->enableRecalculate(); break;
        case 29: _t->resultParametersContextMenuRequest((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 30: _t->resultGoodnessContextMenuRequest((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 31: _t->resultLogContextMenuRequest((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 32: _t->resultCopy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->resultCopy(); break;
        case 34: _t->resultCopyAll(); break;
        case 35: _t->curveDataSourceTypeChanged((*reinterpret_cast<std::add_pointer_t<XYAnalysisCurve::DataSourceType>>(_a[1]))); break;
        case 36: _t->curveDataSourceCurveChanged((*reinterpret_cast<std::add_pointer_t<const XYCurve*>>(_a[1]))); break;
        case 37: _t->curveDataSourceHistogramChanged((*reinterpret_cast<std::add_pointer_t<const Histogram*>>(_a[1]))); break;
        case 38: _t->curveXDataColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 39: _t->curveYDataColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 40: _t->curveXErrorColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 41: _t->curveYErrorColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 42: _t->curveFitDataChanged((*reinterpret_cast<std::add_pointer_t<XYFitCurve::FitData>>(_a[1]))); break;
        case 43: _t->dataChanged(); break;
        default: ;
        }
    }
}

const QMetaObject *XYFitCurveDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XYFitCurveDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14XYFitCurveDockE_t>.strings))
        return static_cast<void*>(this);
    return XYCurveDock::qt_metacast(_clname);
}

int XYFitCurveDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XYCurveDock::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 44;
    }
    return _id;
}
QT_WARNING_POP
