/********************************************************************************
** Form generated from reading UI file 'importkaggledatasetwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTKAGGLEDATASETWIDGET_H
#define UI_IMPORTKAGGLEDATASETWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "src/frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_ImportKaggleDatasetWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QSplitter *splitter;
    QWidget *topContainer;
    QGridLayout *gridLayout_5;
    QLabel *lCategories;
    QListWidget *lwDatasets;
    QScrollArea *saDetails;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout;
    QLabel *lInfo;
    QHBoxLayout *horizontalLayout;
    QLabel *lSearch;
    TimedLineEdit *leSearch;
    QSpacerItem *horizontalSpacer;
    QToolButton *bPrev;
    QToolButton *bNext;
    QSpacerItem *horizontalSpacer_2;
    QToolButton *bDownload;
    QWidget *bottomContainer;

    void setupUi(QWidget *ImportKaggleDatasetWidget)
    {
        if (ImportKaggleDatasetWidget->objectName().isEmpty())
            ImportKaggleDatasetWidget->setObjectName("ImportKaggleDatasetWidget");
        ImportKaggleDatasetWidget->resize(748, 736);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ImportKaggleDatasetWidget->sizePolicy().hasHeightForWidth());
        ImportKaggleDatasetWidget->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(ImportKaggleDatasetWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        splitter = new QSplitter(ImportKaggleDatasetWidget);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Vertical);
        topContainer = new QWidget(splitter);
        topContainer->setObjectName("topContainer");
        gridLayout_5 = new QGridLayout(topContainer);
        gridLayout_5->setObjectName("gridLayout_5");
        lCategories = new QLabel(topContainer);
        lCategories->setObjectName("lCategories");
        lCategories->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        gridLayout_5->addWidget(lCategories, 1, 1, 1, 1);

        lwDatasets = new QListWidget(topContainer);
        lwDatasets->setObjectName("lwDatasets");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lwDatasets->sizePolicy().hasHeightForWidth());
        lwDatasets->setSizePolicy(sizePolicy1);

        gridLayout_5->addWidget(lwDatasets, 2, 1, 1, 1);

        saDetails = new QScrollArea(topContainer);
        saDetails->setObjectName("saDetails");
        sizePolicy.setHeightForWidth(saDetails->sizePolicy().hasHeightForWidth());
        saDetails->setSizePolicy(sizePolicy);
        saDetails->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        saDetails->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 351, 569));
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(scrollAreaWidgetContents->sizePolicy().hasHeightForWidth());
        scrollAreaWidgetContents->setSizePolicy(sizePolicy2);
        verticalLayout = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout->setObjectName("verticalLayout");
        lInfo = new QLabel(scrollAreaWidgetContents);
        lInfo->setObjectName("lInfo");
        sizePolicy.setHeightForWidth(lInfo->sizePolicy().hasHeightForWidth());
        lInfo->setSizePolicy(sizePolicy);
        lInfo->setTextFormat(Qt::MarkdownText);
        lInfo->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        lInfo->setWordWrap(true);

        verticalLayout->addWidget(lInfo);

        saDetails->setWidget(scrollAreaWidgetContents);

        gridLayout_5->addWidget(saDetails, 2, 2, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        lSearch = new QLabel(topContainer);
        lSearch->setObjectName("lSearch");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(lSearch->sizePolicy().hasHeightForWidth());
        lSearch->setSizePolicy(sizePolicy3);

        horizontalLayout->addWidget(lSearch);

        leSearch = new TimedLineEdit(topContainer);
        leSearch->setObjectName("leSearch");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(leSearch->sizePolicy().hasHeightForWidth());
        leSearch->setSizePolicy(sizePolicy4);
        leSearch->setClearButtonEnabled(true);

        horizontalLayout->addWidget(leSearch);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        bPrev = new QToolButton(topContainer);
        bPrev->setObjectName("bPrev");
        bPrev->setEnabled(false);

        horizontalLayout->addWidget(bPrev);

        bNext = new QToolButton(topContainer);
        bNext->setObjectName("bNext");
        bNext->setEnabled(false);

        horizontalLayout->addWidget(bNext);

        horizontalSpacer_2 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        bDownload = new QToolButton(topContainer);
        bDownload->setObjectName("bDownload");
        bDownload->setEnabled(false);

        horizontalLayout->addWidget(bDownload);


        gridLayout_5->addLayout(horizontalLayout, 3, 1, 1, 1);

        splitter->addWidget(topContainer);
        bottomContainer = new QWidget(splitter);
        bottomContainer->setObjectName("bottomContainer");
        splitter->addWidget(bottomContainer);

        verticalLayout_2->addWidget(splitter);


        retranslateUi(ImportKaggleDatasetWidget);

        QMetaObject::connectSlotsByName(ImportKaggleDatasetWidget);
    } // setupUi

    void retranslateUi(QWidget *ImportKaggleDatasetWidget)
    {
        lCategories->setText(QString());
        lInfo->setText(QString());
        lSearch->setText(QString());
        bPrev->setText(QString());
        bNext->setText(QString());
        bDownload->setText(QString());
        (void)ImportKaggleDatasetWidget;
    } // retranslateUi

};

namespace Ui {
    class ImportKaggleDatasetWidget: public Ui_ImportKaggleDatasetWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTKAGGLEDATASETWIDGET_H

