/********************************************************************************
** Form generated from reading UI file 'xyfunctioncurvedockgeneraltab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XYFUNCTIONCURVEDOCKGENERALTAB_H
#define UI_XYFUNCTIONCURVEDOCKGENERALTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ExpressionTextEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_XYFunctionCurveDockGeneralTab
{
public:
    QGridLayout *gridLayout_3;
    QFrame *equationFrame;
    QGridLayout *gridLayout;
    ExpressionTextEdit *teFunction;
    QToolButton *tbConstants;
    QToolButton *tbFunctions;
    TimedLineEdit *leName;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_3;
    QLabel *lFunc;
    QFrame *line_2;
    QFrame *frameVariables;
    QCheckBox *chkVisible;
    QLabel *lPlotRange;
    QLabel *lVariable;
    QLabel *lFunction;
    QLabel *lName;
    QFrame *frameCurves;
    QComboBox *cbPlotRanges;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_3;
    QToolButton *bAddVariable;
    ResizableTextEdit *teComment;
    QCheckBox *chkLegendVisible;
    QLabel *lComment;
    QPushButton *pbRecalculate;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacerGeneral;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *XYFunctionCurveDockGeneralTab)
    {
        if (XYFunctionCurveDockGeneralTab->objectName().isEmpty())
            XYFunctionCurveDockGeneralTab->setObjectName("XYFunctionCurveDockGeneralTab");
        XYFunctionCurveDockGeneralTab->resize(343, 691);
        gridLayout_3 = new QGridLayout(XYFunctionCurveDockGeneralTab);
        gridLayout_3->setObjectName("gridLayout_3");
        equationFrame = new QFrame(XYFunctionCurveDockGeneralTab);
        equationFrame->setObjectName("equationFrame");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(equationFrame->sizePolicy().hasHeightForWidth());
        equationFrame->setSizePolicy(sizePolicy);
        equationFrame->setMaximumSize(QSize(16777215, 16777215));
        equationFrame->setFrameShape(QFrame::Shape::NoFrame);
        gridLayout = new QGridLayout(equationFrame);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        teFunction = new ExpressionTextEdit(equationFrame);
        teFunction->setObjectName("teFunction");
        teFunction->setMaximumSize(QSize(16777215, 50));

        gridLayout->addWidget(teFunction, 0, 1, 3, 1);

        tbConstants = new QToolButton(equationFrame);
        tbConstants->setObjectName("tbConstants");

        gridLayout->addWidget(tbConstants, 1, 2, 1, 1);

        tbFunctions = new QToolButton(equationFrame);
        tbFunctions->setObjectName("tbFunctions");

        gridLayout->addWidget(tbFunctions, 0, 2, 1, 1);


        gridLayout_3->addWidget(equationFrame, 8, 4, 2, 2);

        leName = new TimedLineEdit(XYFunctionCurveDockGeneralTab);
        leName->setObjectName("leName");

        gridLayout_3->addWidget(leName, 0, 4, 1, 2);

        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer, 0, 3, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 10, 4, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_3, 2, 0, 1, 1);

        lFunc = new QLabel(XYFunctionCurveDockGeneralTab);
        lFunc->setObjectName("lFunc");
        QFont font;
        font.setBold(true);
        lFunc->setFont(font);

        gridLayout_3->addWidget(lFunc, 7, 0, 1, 1);

        line_2 = new QFrame(XYFunctionCurveDockGeneralTab);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::VLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_3->addWidget(line_2, 12, 0, 1, 6);

        frameVariables = new QFrame(XYFunctionCurveDockGeneralTab);
        frameVariables->setObjectName("frameVariables");
        frameVariables->setMinimumSize(QSize(0, 0));
        frameVariables->setFrameShape(QFrame::Shape::NoFrame);
        frameVariables->setFrameShadow(QFrame::Shadow::Raised);

        gridLayout_3->addWidget(frameVariables, 4, 0, 1, 1);

        chkVisible = new QCheckBox(XYFunctionCurveDockGeneralTab);
        chkVisible->setObjectName("chkVisible");

        gridLayout_3->addWidget(chkVisible, 16, 0, 1, 2);

        lPlotRange = new QLabel(XYFunctionCurveDockGeneralTab);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout_3->addWidget(lPlotRange, 13, 0, 1, 1);

        lVariable = new QLabel(XYFunctionCurveDockGeneralTab);
        lVariable->setObjectName("lVariable");
        lVariable->setFont(font);

        gridLayout_3->addWidget(lVariable, 3, 0, 1, 1);

        lFunction = new QLabel(XYFunctionCurveDockGeneralTab);
        lFunction->setObjectName("lFunction");
        QFont font1;
        font1.setBold(false);
        lFunction->setFont(font1);
        lFunction->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout_3->addWidget(lFunction, 8, 0, 2, 1);

        lName = new QLabel(XYFunctionCurveDockGeneralTab);
        lName->setObjectName("lName");

        gridLayout_3->addWidget(lName, 0, 0, 1, 3);

        frameCurves = new QFrame(XYFunctionCurveDockGeneralTab);
        frameCurves->setObjectName("frameCurves");
        frameCurves->setFrameShape(QFrame::Shape::NoFrame);
        frameCurves->setFrameShadow(QFrame::Shadow::Raised);

        gridLayout_3->addWidget(frameCurves, 4, 4, 1, 2);

        cbPlotRanges = new QComboBox(XYFunctionCurveDockGeneralTab);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout_3->addWidget(cbPlotRanges, 13, 4, 1, 2);

        frame = new QFrame(XYFunctionCurveDockGeneralTab);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::Shape::StyledPanel);
        frame->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalSpacer_3 = new QSpacerItem(187, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);

        bAddVariable = new QToolButton(frame);
        bAddVariable->setObjectName("bAddVariable");

        horizontalLayout->addWidget(bAddVariable);


        gridLayout_3->addWidget(frame, 5, 4, 1, 2);

        teComment = new ResizableTextEdit(XYFunctionCurveDockGeneralTab);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout_3->addWidget(teComment, 1, 4, 1, 2);

        chkLegendVisible = new QCheckBox(XYFunctionCurveDockGeneralTab);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout_3->addWidget(chkLegendVisible, 15, 0, 1, 1);

        lComment = new QLabel(XYFunctionCurveDockGeneralTab);
        lComment->setObjectName("lComment");

        gridLayout_3->addWidget(lComment, 1, 0, 1, 3);

        pbRecalculate = new QPushButton(XYFunctionCurveDockGeneralTab);
        pbRecalculate->setObjectName("pbRecalculate");

        gridLayout_3->addWidget(pbRecalculate, 10, 5, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer, 14, 0, 1, 1);

        verticalSpacerGeneral = new QSpacerItem(24, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacerGeneral, 11, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_2, 6, 0, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, bAddVariable);
        QWidget::setTabOrder(bAddVariable, teFunction);
        QWidget::setTabOrder(teFunction, tbFunctions);
        QWidget::setTabOrder(tbFunctions, tbConstants);
        QWidget::setTabOrder(tbConstants, pbRecalculate);
        QWidget::setTabOrder(pbRecalculate, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);

        retranslateUi(XYFunctionCurveDockGeneralTab);

        QMetaObject::connectSlotsByName(XYFunctionCurveDockGeneralTab);
    } // setupUi

    void retranslateUi(QWidget *XYFunctionCurveDockGeneralTab)
    {
#if QT_CONFIG(tooltip)
        tbConstants->setToolTip(tr2i18n("Constants", nullptr));
#endif // QT_CONFIG(tooltip)
        tbConstants->setText(QString());
#if QT_CONFIG(tooltip)
        tbFunctions->setToolTip(tr2i18n("Functions", nullptr));
#endif // QT_CONFIG(tooltip)
        tbFunctions->setText(QString());
        lFunc->setText(tr2i18n("Function:", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        lVariable->setText(tr2i18n("Variables:", nullptr));
        lFunction->setText(tr2i18n("f(x) = ", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        bAddVariable->setText(tr2i18n("...", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        pbRecalculate->setText(tr2i18n("Recalculate", nullptr));
        (void)XYFunctionCurveDockGeneralTab;
    } // retranslateUi

};

namespace Ui {
    class XYFunctionCurveDockGeneralTab: public Ui_XYFunctionCurveDockGeneralTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // XYFUNCTIONCURVEDOCKGENERALTAB_H

