/********************************************************************************
** Form generated from reading UI file 'datapickerimagewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DATAPICKERIMAGEWIDGET_H
#define UI_DATAPICKERIMAGEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_DatapickerImageWidget
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tGeneral;
    QGridLayout *gridLayout_4;
    NumberSpinBox *sbTernaryScale;
    QSpacerItem *verticalSpacer_9;
    QSpacerItem *verticalSpacer;
    QLabel *lName;
    TimedLineEdit *leName;
    QHBoxLayout *horizontalLayout;
    QLineEdit *leFileName;
    QPushButton *bOpen;
    QSpinBox *sbPointSeparation;
    QLabel *lRefPoint;
    QLabel *lRefPoint2;
    QLabel *lTernaryScale;
    QLabel *lRotation;
    QLabel *lSegments;
    NumberSpinBox *sbRotation;
    QSpinBox *sbMinSegmentLength;
    QLabel *lMinSegmentLength;
    QLabel *label;
    QComboBox *cbGraphType;
    QLabel *lRefPoint1;
    QGridLayout *gridLayout;
    UTCDateTimeEdit *dtePositionX2;
    UTCDateTimeEdit *dtePositionX3;
    NumberSpinBox *sbPositionY1;
    NumberSpinBox *sbPositionZ3;
    NumberSpinBox *sbPositionX1;
    QLabel *lPositionX3;
    QLabel *lPositionY1;
    QLabel *lPositionX1;
    QLabel *lPositionZ2;
    QLabel *lPositionY3;
    UTCDateTimeEdit *dtePositionX1;
    NumberSpinBox *sbPositionX3;
    NumberSpinBox *sbPositionZ2;
    QLabel *lPositionX2;
    NumberSpinBox *sbPositionY2;
    NumberSpinBox *sbPositionX2;
    QLabel *lPositionY2;
    NumberSpinBox *sbPositionY3;
    QLabel *lPositionZ1;
    QLabel *lPositionZ3;
    NumberSpinBox *sbPositionZ1;
    QRadioButton *rbRefPoint3;
    QRadioButton *rbRefPoint2;
    QRadioButton *rbRefPoint1;
    QLabel *lRefPoint3;
    QLabel *lPlot;
    QLabel *lComment;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *cbFileEmbedd;
    QCheckBox *cbFileRelativePath;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_7;
    QLabel *lPlotType;
    QSpacerItem *verticalSpacer_4;
    ResizableTextEdit *teComment;
    QLabel *lPointSeparation;
    QSpacerItem *verticalSpacer_8;
    QCheckBox *cbDatetime;
    QLabel *label_2;
    QWidget *tSymbol;
    QGridLayout *gridLayout_5;
    QCheckBox *chbSymbolVisible;
    QSpacerItem *verticalSpacer_3;
    QWidget *tEdit;
    QGridLayout *gridLayout_2;
    QWidget *wForegroud;
    QWidget *whHue;
    QWidget *wSaturation;
    QLabel *lIntensity;
    QWidget *whValue;
    QWidget *whForeground;
    QWidget *whIntensity;
    QComboBox *cbPlotImageType;
    QWidget *wIntensity;
    QSpacerItem *verticalSpacer_6;
    QLabel *lValue;
    QLabel *lHue;
    QSpacerItem *verticalSpacer_2;
    QLabel *lPlotImageType;
    QWidget *whSaturation;
    QWidget *wHue;
    QLabel *lSaturation;
    QLabel *lForeground;
    QWidget *wValue;
    QSpacerItem *horizontalSpacer_7;

    void setupUi(QWidget *DatapickerImageWidget)
    {
        if (DatapickerImageWidget->objectName().isEmpty())
            DatapickerImageWidget->setObjectName("DatapickerImageWidget");
        DatapickerImageWidget->resize(632, 777);
        verticalLayout = new QVBoxLayout(DatapickerImageWidget);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(DatapickerImageWidget);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        tGeneral = new QWidget();
        tGeneral->setObjectName("tGeneral");
        gridLayout_4 = new QGridLayout(tGeneral);
        gridLayout_4->setObjectName("gridLayout_4");
        sbTernaryScale = new NumberSpinBox(tGeneral);
        sbTernaryScale->setObjectName("sbTernaryScale");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sbTernaryScale->sizePolicy().hasHeightForWidth());
        sbTernaryScale->setSizePolicy(sizePolicy1);
        sbTernaryScale->setProperty("feedback", QVariant(true));

        gridLayout_4->addWidget(sbTernaryScale, 19, 4, 1, 1);

        verticalSpacer_9 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_9, 18, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 231, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer, 24, 0, 1, 1);

        lName = new QLabel(tGeneral);
        lName->setObjectName("lName");

        gridLayout_4->addWidget(lName, 0, 0, 1, 2);

        leName = new TimedLineEdit(tGeneral);
        leName->setObjectName("leName");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(leName->sizePolicy().hasHeightForWidth());
        leName->setSizePolicy(sizePolicy2);
        leName->setClearButtonEnabled(true);

        gridLayout_4->addWidget(leName, 0, 4, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        leFileName = new QLineEdit(tGeneral);
        leFileName->setObjectName("leFileName");
        leFileName->setClearButtonEnabled(true);

        horizontalLayout->addWidget(leFileName);

        bOpen = new QPushButton(tGeneral);
        bOpen->setObjectName("bOpen");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(bOpen->sizePolicy().hasHeightForWidth());
        bOpen->setSizePolicy(sizePolicy3);

        horizontalLayout->addWidget(bOpen);


        gridLayout_4->addLayout(horizontalLayout, 6, 4, 1, 1);

        sbPointSeparation = new QSpinBox(tGeneral);
        sbPointSeparation->setObjectName("sbPointSeparation");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(sbPointSeparation->sizePolicy().hasHeightForWidth());
        sbPointSeparation->setSizePolicy(sizePolicy4);

        gridLayout_4->addWidget(sbPointSeparation, 23, 4, 1, 1);

        lRefPoint = new QLabel(tGeneral);
        lRefPoint->setObjectName("lRefPoint");
        QFont font;
        font.setBold(true);
        lRefPoint->setFont(font);
        lRefPoint->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_4->addWidget(lRefPoint, 11, 0, 1, 1);

        lRefPoint2 = new QLabel(tGeneral);
        lRefPoint2->setObjectName("lRefPoint2");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(lRefPoint2->sizePolicy().hasHeightForWidth());
        lRefPoint2->setSizePolicy(sizePolicy5);
        lRefPoint2->setAlignment(Qt::AlignRight);

        gridLayout_4->addWidget(lRefPoint2, 16, 0, 1, 1);

        lTernaryScale = new QLabel(tGeneral);
        lTernaryScale->setObjectName("lTernaryScale");

        gridLayout_4->addWidget(lTernaryScale, 19, 0, 1, 2);

        lRotation = new QLabel(tGeneral);
        lRotation->setObjectName("lRotation");

        gridLayout_4->addWidget(lRotation, 9, 0, 1, 3);

        lSegments = new QLabel(tGeneral);
        lSegments->setObjectName("lSegments");
        lSegments->setFont(font);

        gridLayout_4->addWidget(lSegments, 21, 0, 1, 3);

        sbRotation = new NumberSpinBox(tGeneral);
        sbRotation->setObjectName("sbRotation");
        sizePolicy1.setHeightForWidth(sbRotation->sizePolicy().hasHeightForWidth());
        sbRotation->setSizePolicy(sizePolicy1);
        sbRotation->setProperty("feedback", QVariant(false));

        gridLayout_4->addWidget(sbRotation, 9, 4, 1, 1);

        sbMinSegmentLength = new QSpinBox(tGeneral);
        sbMinSegmentLength->setObjectName("sbMinSegmentLength");
        sizePolicy4.setHeightForWidth(sbMinSegmentLength->sizePolicy().hasHeightForWidth());
        sbMinSegmentLength->setSizePolicy(sizePolicy4);

        gridLayout_4->addWidget(sbMinSegmentLength, 22, 4, 1, 1);

        lMinSegmentLength = new QLabel(tGeneral);
        lMinSegmentLength->setObjectName("lMinSegmentLength");

        gridLayout_4->addWidget(lMinSegmentLength, 22, 0, 1, 2);

        label = new QLabel(tGeneral);
        label->setObjectName("label");
        label->setFont(font);

        gridLayout_4->addWidget(label, 3, 0, 1, 2);

        cbGraphType = new QComboBox(tGeneral);
        cbGraphType->setObjectName("cbGraphType");

        gridLayout_4->addWidget(cbGraphType, 8, 4, 1, 1);

        lRefPoint1 = new QLabel(tGeneral);
        lRefPoint1->setObjectName("lRefPoint1");
        sizePolicy5.setHeightForWidth(lRefPoint1->sizePolicy().hasHeightForWidth());
        lRefPoint1->setSizePolicy(sizePolicy5);
        lRefPoint1->setAlignment(Qt::AlignRight);

        gridLayout_4->addWidget(lRefPoint1, 15, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        dtePositionX2 = new UTCDateTimeEdit(tGeneral);
        dtePositionX2->setObjectName("dtePositionX2");
        sizePolicy4.setHeightForWidth(dtePositionX2->sizePolicy().hasHeightForWidth());
        dtePositionX2->setSizePolicy(sizePolicy4);

        gridLayout->addWidget(dtePositionX2, 1, 4, 1, 1);

        dtePositionX3 = new UTCDateTimeEdit(tGeneral);
        dtePositionX3->setObjectName("dtePositionX3");
        sizePolicy4.setHeightForWidth(dtePositionX3->sizePolicy().hasHeightForWidth());
        dtePositionX3->setSizePolicy(sizePolicy4);

        gridLayout->addWidget(dtePositionX3, 2, 4, 1, 1);

        sbPositionY1 = new NumberSpinBox(tGeneral);
        sbPositionY1->setObjectName("sbPositionY1");
        sizePolicy4.setHeightForWidth(sbPositionY1->sizePolicy().hasHeightForWidth());
        sbPositionY1->setSizePolicy(sizePolicy4);
        sbPositionY1->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionY1, 0, 6, 1, 1);

        sbPositionZ3 = new NumberSpinBox(tGeneral);
        sbPositionZ3->setObjectName("sbPositionZ3");
        sizePolicy4.setHeightForWidth(sbPositionZ3->sizePolicy().hasHeightForWidth());
        sbPositionZ3->setSizePolicy(sizePolicy4);
        sbPositionZ3->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionZ3, 2, 8, 1, 1);

        sbPositionX1 = new NumberSpinBox(tGeneral);
        sbPositionX1->setObjectName("sbPositionX1");
        sizePolicy4.setHeightForWidth(sbPositionX1->sizePolicy().hasHeightForWidth());
        sbPositionX1->setSizePolicy(sizePolicy4);
        sbPositionX1->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionX1, 0, 3, 1, 1);

        lPositionX3 = new QLabel(tGeneral);
        lPositionX3->setObjectName("lPositionX3");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(lPositionX3->sizePolicy().hasHeightForWidth());
        lPositionX3->setSizePolicy(sizePolicy6);
        lPositionX3->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(lPositionX3, 2, 2, 1, 1);

        lPositionY1 = new QLabel(tGeneral);
        lPositionY1->setObjectName("lPositionY1");
        sizePolicy6.setHeightForWidth(lPositionY1->sizePolicy().hasHeightForWidth());
        lPositionY1->setSizePolicy(sizePolicy6);
        lPositionY1->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(lPositionY1, 0, 5, 1, 1);

        lPositionX1 = new QLabel(tGeneral);
        lPositionX1->setObjectName("lPositionX1");
        lPositionX1->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(lPositionX1, 0, 2, 1, 1);

        lPositionZ2 = new QLabel(tGeneral);
        lPositionZ2->setObjectName("lPositionZ2");
        lPositionZ2->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(lPositionZ2, 1, 7, 1, 1);

        lPositionY3 = new QLabel(tGeneral);
        lPositionY3->setObjectName("lPositionY3");
        sizePolicy6.setHeightForWidth(lPositionY3->sizePolicy().hasHeightForWidth());
        lPositionY3->setSizePolicy(sizePolicy6);
        lPositionY3->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(lPositionY3, 2, 5, 1, 1);

        dtePositionX1 = new UTCDateTimeEdit(tGeneral);
        dtePositionX1->setObjectName("dtePositionX1");
        sizePolicy4.setHeightForWidth(dtePositionX1->sizePolicy().hasHeightForWidth());
        dtePositionX1->setSizePolicy(sizePolicy4);

        gridLayout->addWidget(dtePositionX1, 0, 4, 1, 1);

        sbPositionX3 = new NumberSpinBox(tGeneral);
        sbPositionX3->setObjectName("sbPositionX3");
        sizePolicy4.setHeightForWidth(sbPositionX3->sizePolicy().hasHeightForWidth());
        sbPositionX3->setSizePolicy(sizePolicy4);
        sbPositionX3->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionX3, 2, 3, 1, 1);

        sbPositionZ2 = new NumberSpinBox(tGeneral);
        sbPositionZ2->setObjectName("sbPositionZ2");
        sizePolicy4.setHeightForWidth(sbPositionZ2->sizePolicy().hasHeightForWidth());
        sbPositionZ2->setSizePolicy(sizePolicy4);
        sbPositionZ2->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionZ2, 1, 8, 1, 1);

        lPositionX2 = new QLabel(tGeneral);
        lPositionX2->setObjectName("lPositionX2");
        sizePolicy6.setHeightForWidth(lPositionX2->sizePolicy().hasHeightForWidth());
        lPositionX2->setSizePolicy(sizePolicy6);
        lPositionX2->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(lPositionX2, 1, 2, 1, 1);

        sbPositionY2 = new NumberSpinBox(tGeneral);
        sbPositionY2->setObjectName("sbPositionY2");
        sizePolicy4.setHeightForWidth(sbPositionY2->sizePolicy().hasHeightForWidth());
        sbPositionY2->setSizePolicy(sizePolicy4);
        sbPositionY2->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionY2, 1, 6, 1, 1);

        sbPositionX2 = new NumberSpinBox(tGeneral);
        sbPositionX2->setObjectName("sbPositionX2");
        sizePolicy4.setHeightForWidth(sbPositionX2->sizePolicy().hasHeightForWidth());
        sbPositionX2->setSizePolicy(sizePolicy4);
        sbPositionX2->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionX2, 1, 3, 1, 1);

        lPositionY2 = new QLabel(tGeneral);
        lPositionY2->setObjectName("lPositionY2");
        sizePolicy6.setHeightForWidth(lPositionY2->sizePolicy().hasHeightForWidth());
        lPositionY2->setSizePolicy(sizePolicy6);
        lPositionY2->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(lPositionY2, 1, 5, 1, 1);

        sbPositionY3 = new NumberSpinBox(tGeneral);
        sbPositionY3->setObjectName("sbPositionY3");
        sizePolicy4.setHeightForWidth(sbPositionY3->sizePolicy().hasHeightForWidth());
        sbPositionY3->setSizePolicy(sizePolicy4);
        sbPositionY3->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionY3, 2, 6, 1, 1);

        lPositionZ1 = new QLabel(tGeneral);
        lPositionZ1->setObjectName("lPositionZ1");
        lPositionZ1->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(lPositionZ1, 0, 7, 1, 1);

        lPositionZ3 = new QLabel(tGeneral);
        lPositionZ3->setObjectName("lPositionZ3");
        sizePolicy6.setHeightForWidth(lPositionZ3->sizePolicy().hasHeightForWidth());
        lPositionZ3->setSizePolicy(sizePolicy6);
        lPositionZ3->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(lPositionZ3, 2, 7, 1, 1);

        sbPositionZ1 = new NumberSpinBox(tGeneral);
        sbPositionZ1->setObjectName("sbPositionZ1");
        sizePolicy4.setHeightForWidth(sbPositionZ1->sizePolicy().hasHeightForWidth());
        sbPositionZ1->setSizePolicy(sizePolicy4);
        sbPositionZ1->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionZ1, 0, 8, 1, 1);

        rbRefPoint3 = new QRadioButton(tGeneral);
        rbRefPoint3->setObjectName("rbRefPoint3");
        rbRefPoint3->setEnabled(false);

        gridLayout->addWidget(rbRefPoint3, 2, 0, 1, 1);

        rbRefPoint2 = new QRadioButton(tGeneral);
        rbRefPoint2->setObjectName("rbRefPoint2");
        rbRefPoint2->setEnabled(false);

        gridLayout->addWidget(rbRefPoint2, 1, 0, 1, 1);

        rbRefPoint1 = new QRadioButton(tGeneral);
        rbRefPoint1->setObjectName("rbRefPoint1");
        rbRefPoint1->setEnabled(false);
        QSizePolicy sizePolicy7(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(rbRefPoint1->sizePolicy().hasHeightForWidth());
        rbRefPoint1->setSizePolicy(sizePolicy7);

        gridLayout->addWidget(rbRefPoint1, 0, 0, 1, 1);


        gridLayout_4->addLayout(gridLayout, 15, 4, 3, 1);

        lRefPoint3 = new QLabel(tGeneral);
        lRefPoint3->setObjectName("lRefPoint3");
        sizePolicy5.setHeightForWidth(lRefPoint3->sizePolicy().hasHeightForWidth());
        lRefPoint3->setSizePolicy(sizePolicy5);
        lRefPoint3->setAlignment(Qt::AlignRight);

        gridLayout_4->addWidget(lRefPoint3, 17, 0, 1, 1);

        lPlot = new QLabel(tGeneral);
        lPlot->setObjectName("lPlot");

        gridLayout_4->addWidget(lPlot, 6, 0, 1, 2);

        lComment = new QLabel(tGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_4->addWidget(lComment, 1, 0, 1, 3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        cbFileEmbedd = new QCheckBox(tGeneral);
        cbFileEmbedd->setObjectName("cbFileEmbedd");

        horizontalLayout_2->addWidget(cbFileEmbedd);

        cbFileRelativePath = new QCheckBox(tGeneral);
        cbFileRelativePath->setObjectName("cbFileRelativePath");

        horizontalLayout_2->addWidget(cbFileRelativePath);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        gridLayout_4->addLayout(horizontalLayout_2, 7, 4, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_7, 2, 0, 1, 1);

        lPlotType = new QLabel(tGeneral);
        lPlotType->setObjectName("lPlotType");

        gridLayout_4->addWidget(lPlotType, 8, 0, 1, 2);

        verticalSpacer_4 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_4, 20, 0, 1, 1);

        teComment = new ResizableTextEdit(tGeneral);
        teComment->setObjectName("teComment");
        sizePolicy2.setHeightForWidth(teComment->sizePolicy().hasHeightForWidth());
        teComment->setSizePolicy(sizePolicy2);

        gridLayout_4->addWidget(teComment, 1, 4, 1, 1);

        lPointSeparation = new QLabel(tGeneral);
        lPointSeparation->setObjectName("lPointSeparation");

        gridLayout_4->addWidget(lPointSeparation, 23, 0, 1, 1);

        verticalSpacer_8 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_8, 10, 0, 1, 1);

        cbDatetime = new QCheckBox(tGeneral);
        cbDatetime->setObjectName("cbDatetime");

        gridLayout_4->addWidget(cbDatetime, 12, 4, 1, 1);

        label_2 = new QLabel(tGeneral);
        label_2->setObjectName("label_2");

        gridLayout_4->addWidget(label_2, 12, 0, 1, 1);

        tabWidget->addTab(tGeneral, QString());
        tSymbol = new QWidget();
        tSymbol->setObjectName("tSymbol");
        gridLayout_5 = new QGridLayout(tSymbol);
        gridLayout_5->setObjectName("gridLayout_5");
        chbSymbolVisible = new QCheckBox(tSymbol);
        chbSymbolVisible->setObjectName("chbSymbolVisible");

        gridLayout_5->addWidget(chbSymbolVisible, 1, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer_3, 0, 0, 1, 1);

        tabWidget->addTab(tSymbol, QString());
        tEdit = new QWidget();
        tEdit->setObjectName("tEdit");
        gridLayout_2 = new QGridLayout(tEdit);
        gridLayout_2->setObjectName("gridLayout_2");
        wForegroud = new QWidget(tEdit);
        wForegroud->setObjectName("wForegroud");

        gridLayout_2->addWidget(wForegroud, 11, 2, 1, 1);

        whHue = new QWidget(tEdit);
        whHue->setObjectName("whHue");

        gridLayout_2->addWidget(whHue, 2, 2, 1, 1);

        wSaturation = new QWidget(tEdit);
        wSaturation->setObjectName("wSaturation");

        gridLayout_2->addWidget(wSaturation, 5, 2, 1, 1);

        lIntensity = new QLabel(tEdit);
        lIntensity->setObjectName("lIntensity");

        gridLayout_2->addWidget(lIntensity, 9, 0, 1, 1);

        whValue = new QWidget(tEdit);
        whValue->setObjectName("whValue");

        gridLayout_2->addWidget(whValue, 6, 2, 1, 1);

        whForeground = new QWidget(tEdit);
        whForeground->setObjectName("whForeground");

        gridLayout_2->addWidget(whForeground, 10, 2, 1, 1);

        whIntensity = new QWidget(tEdit);
        whIntensity->setObjectName("whIntensity");

        gridLayout_2->addWidget(whIntensity, 8, 2, 1, 1);

        cbPlotImageType = new QComboBox(tEdit);
        cbPlotImageType->setObjectName("cbPlotImageType");
        sizePolicy1.setHeightForWidth(cbPlotImageType->sizePolicy().hasHeightForWidth());
        cbPlotImageType->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(cbPlotImageType, 0, 2, 1, 1);

        wIntensity = new QWidget(tEdit);
        wIntensity->setObjectName("wIntensity");

        gridLayout_2->addWidget(wIntensity, 9, 2, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_6, 1, 0, 1, 1);

        lValue = new QLabel(tEdit);
        lValue->setObjectName("lValue");

        gridLayout_2->addWidget(lValue, 7, 0, 1, 1);

        lHue = new QLabel(tEdit);
        lHue->setObjectName("lHue");

        gridLayout_2->addWidget(lHue, 3, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 12, 0, 1, 1);

        lPlotImageType = new QLabel(tEdit);
        lPlotImageType->setObjectName("lPlotImageType");

        gridLayout_2->addWidget(lPlotImageType, 0, 0, 1, 1);

        whSaturation = new QWidget(tEdit);
        whSaturation->setObjectName("whSaturation");

        gridLayout_2->addWidget(whSaturation, 4, 2, 1, 1);

        wHue = new QWidget(tEdit);
        wHue->setObjectName("wHue");

        gridLayout_2->addWidget(wHue, 3, 2, 1, 1);

        lSaturation = new QLabel(tEdit);
        lSaturation->setObjectName("lSaturation");

        gridLayout_2->addWidget(lSaturation, 5, 0, 1, 1);

        lForeground = new QLabel(tEdit);
        lForeground->setObjectName("lForeground");

        gridLayout_2->addWidget(lForeground, 11, 0, 1, 1);

        wValue = new QWidget(tEdit);
        wValue->setObjectName("wValue");

        gridLayout_2->addWidget(wValue, 7, 2, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_7, 0, 1, 1, 1);

        tabWidget->addTab(tEdit, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, leFileName);
        QWidget::setTabOrder(leFileName, bOpen);
        QWidget::setTabOrder(bOpen, cbGraphType);
        QWidget::setTabOrder(cbGraphType, sbRotation);
        QWidget::setTabOrder(sbRotation, sbPositionX1);
        QWidget::setTabOrder(sbPositionX1, sbPositionY1);
        QWidget::setTabOrder(sbPositionY1, sbPositionZ1);
        QWidget::setTabOrder(sbPositionZ1, sbPositionX2);
        QWidget::setTabOrder(sbPositionX2, sbPositionY2);
        QWidget::setTabOrder(sbPositionY2, sbPositionZ2);
        QWidget::setTabOrder(sbPositionZ2, sbPositionX3);
        QWidget::setTabOrder(sbPositionX3, sbPositionY3);
        QWidget::setTabOrder(sbPositionY3, sbPositionZ3);
        QWidget::setTabOrder(sbPositionZ3, sbTernaryScale);
        QWidget::setTabOrder(sbTernaryScale, sbMinSegmentLength);
        QWidget::setTabOrder(sbMinSegmentLength, sbPointSeparation);
        QWidget::setTabOrder(sbPointSeparation, cbPlotImageType);
        QWidget::setTabOrder(cbPlotImageType, chbSymbolVisible);

        retranslateUi(DatapickerImageWidget);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DatapickerImageWidget);
    } // setupUi

    void retranslateUi(QWidget *DatapickerImageWidget)
    {
#if QT_CONFIG(tooltip)
        sbTernaryScale->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbTernaryScale->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lName->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        leFileName->setToolTip(tr2i18n("Specify the name of the image file.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        bOpen->setToolTip(tr2i18n(" Select the image file", nullptr));
#endif // QT_CONFIG(tooltip)
        bOpen->setText(QString());
#if QT_CONFIG(tooltip)
        sbPointSeparation->setToolTip(tr2i18n("Number of pixels between two neighbor data points", nullptr));
#endif // QT_CONFIG(tooltip)
        sbPointSeparation->setSuffix(tr2i18n(" px", nullptr));
        sbPointSeparation->setPrefix(QString());
        lRefPoint->setText(tr2i18n("References", nullptr));
        lRefPoint2->setText(tr2i18n("2.", nullptr));
        lTernaryScale->setText(tr2i18n("x+y+z=", nullptr));
        lRotation->setText(tr2i18n("Rotation:", nullptr));
        lSegments->setText(tr2i18n("Segments", nullptr));
#if QT_CONFIG(tooltip)
        sbRotation->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRotation->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbRotation->setSuffix(tr2i18n("\302\260", nullptr));
#if QT_CONFIG(tooltip)
        sbMinSegmentLength->setToolTip(tr2i18n("Minimum segment length detection", nullptr));
#endif // QT_CONFIG(tooltip)
        sbMinSegmentLength->setSuffix(tr2i18n(" px", nullptr));
#if QT_CONFIG(tooltip)
        lMinSegmentLength->setToolTip(tr2i18n("Minimum segment length detection", nullptr));
#endif // QT_CONFIG(tooltip)
        lMinSegmentLength->setText(tr2i18n("Min. Length:", nullptr));
        label->setText(tr2i18n("Plot", nullptr));
#if QT_CONFIG(tooltip)
        cbGraphType->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        lRefPoint1->setText(tr2i18n("1.", nullptr));
        dtePositionX2->setDisplayFormat(tr2i18n("dd.MM.yyyy HH:mm", nullptr));
        dtePositionX3->setDisplayFormat(tr2i18n("dd.MM.yyyy HH:mm", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionY1->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionY1->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        sbPositionZ3->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionZ3->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        sbPositionX1->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionX1->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lPositionX3->setText(tr2i18n("x=", nullptr));
        lPositionY1->setText(tr2i18n("y=", nullptr));
        lPositionX1->setText(tr2i18n("x=", nullptr));
        lPositionZ2->setText(tr2i18n("z=", nullptr));
        lPositionY3->setText(tr2i18n("y=", nullptr));
        dtePositionX1->setDisplayFormat(tr2i18n("dd.MM.yyyy HH:mm", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionX3->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionX3->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        sbPositionZ2->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionZ2->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lPositionX2->setText(tr2i18n("x=", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionY2->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionY2->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        sbPositionX2->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionX2->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lPositionY2->setText(tr2i18n("y=", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionY3->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionY3->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lPositionZ1->setText(tr2i18n("z=", nullptr));
        lPositionZ3->setText(tr2i18n("z=", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionZ1->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionZ1->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbRefPoint3->setText(QString());
        rbRefPoint2->setText(QString());
        rbRefPoint1->setText(QString());
        lRefPoint3->setText(tr2i18n("3.", nullptr));
        lPlot->setText(tr2i18n("Image:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        cbFileEmbedd->setText(tr2i18n("Embedd", nullptr));
        cbFileRelativePath->setText(tr2i18n("Relative Path", nullptr));
        lPlotType->setText(tr2i18n("Type:", nullptr));
#if QT_CONFIG(tooltip)
        lPointSeparation->setToolTip(tr2i18n("Number of pixels between two neighbor data points", nullptr));
#endif // QT_CONFIG(tooltip)
        lPointSeparation->setText(tr2i18n("Separation:", nullptr));
        cbDatetime->setText(QString());
        label_2->setText(tr2i18n("Datetime", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tGeneral), tr2i18n("General", nullptr));
        chbSymbolVisible->setText(tr2i18n("Visible", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tSymbol), tr2i18n("Ref. Points Symbol", nullptr));
        lIntensity->setText(tr2i18n("Intensity:", nullptr));
#if QT_CONFIG(tooltip)
        cbPlotImageType->setToolTip(tr2i18n("Vertical position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
        lValue->setText(tr2i18n("Value:", nullptr));
        lHue->setText(tr2i18n("Hue:", nullptr));
        lPlotImageType->setText(tr2i18n("Current Image:", nullptr));
        lSaturation->setText(tr2i18n("Saturation:", nullptr));
        lForeground->setText(tr2i18n("Foreground:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tEdit), tr2i18n("Edit Image", nullptr));
        (void)DatapickerImageWidget;
    } // retranslateUi

};

namespace Ui {
    class DatapickerImageWidget: public Ui_DatapickerImageWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DATAPICKERIMAGEWIDGET_H

