/****************************************************************************
** Meta object code from reading C++ file 'MQTTSubscriptionWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/datasources/MQTTSubscriptionWidget.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MQTTSubscriptionWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22MQTTSubscriptionWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto MQTTSubscriptionWidget::qt_create_metaobjectdata<qt_meta_tag_ZN22MQTTSubscriptionWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MQTTSubscriptionWidget",
        "subscriptionChanged",
        "",
        "makeSubscription",
        "name",
        "QoS",
        "MQTTUnsubscribeFromTopic",
        "QList<QTreeWidgetItem*>",
        "children",
        "removeMQTTSubscription",
        "addBeforeRemoveSubscription",
        "reparentTopic",
        "topic",
        "parent",
        "enableWill",
        "mqttAvailableTopicDoubleClicked",
        "QTreeWidgetItem*",
        "item",
        "column",
        "mqttSubscribedTopicDoubleClicked",
        "mqttSubscribe",
        "mqttUnsubscribe",
        "setTopicCompleter",
        "scrollToTopicTreeItem",
        "rootName",
        "scrollToSubsriptionTreeItem",
        "topicTimeout",
        "updateSubscriptionTree",
        "clearWidgets",
        "onDisconnect"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'subscriptionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'makeSubscription'
        QtMocHelpers::SignalData<void(const QString &, quint8)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::UChar, 5 },
        }}),
        // Signal 'MQTTUnsubscribeFromTopic'
        QtMocHelpers::SignalData<void(const QString &, QVector<QTreeWidgetItem*>)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'removeMQTTSubscription'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'addBeforeRemoveSubscription'
        QtMocHelpers::SignalData<void(const QString &, quint8)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::UChar, 2 },
        }}),
        // Signal 'reparentTopic'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'enableWill'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'mqttAvailableTopicDoubleClicked'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'mqttSubscribedTopicDoubleClicked'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'mqttSubscribe'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'mqttUnsubscribe'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setTopicCompleter'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'scrollToTopicTreeItem'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'scrollToSubsriptionTreeItem'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'topicTimeout'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSubscriptionTree'
        QtMocHelpers::SlotData<void(const QVector<QString> &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
        // Slot 'clearWidgets'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDisconnect'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MQTTSubscriptionWidget, qt_meta_tag_ZN22MQTTSubscriptionWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MQTTSubscriptionWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22MQTTSubscriptionWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22MQTTSubscriptionWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22MQTTSubscriptionWidgetE_t>.metaTypes,
    nullptr
} };

void MQTTSubscriptionWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MQTTSubscriptionWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->subscriptionChanged(); break;
        case 1: _t->makeSubscription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint8>>(_a[2]))); break;
        case 2: _t->MQTTUnsubscribeFromTopic((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QTreeWidgetItem*>>>(_a[2]))); break;
        case 3: _t->removeMQTTSubscription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->addBeforeRemoveSubscription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint8>>(_a[2]))); break;
        case 5: _t->reparentTopic((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->enableWill((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->mqttAvailableTopicDoubleClicked((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->mqttSubscribedTopicDoubleClicked((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->mqttSubscribe(); break;
        case 10: _t->mqttUnsubscribe(); break;
        case 11: _t->setTopicCompleter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->scrollToTopicTreeItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->scrollToSubsriptionTreeItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->topicTimeout(); break;
        case 15: _t->updateSubscriptionTree((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1]))); break;
        case 16: _t->clearWidgets(); break;
        case 17: _t->onDisconnect(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MQTTSubscriptionWidget::*)()>(_a, &MQTTSubscriptionWidget::subscriptionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MQTTSubscriptionWidget::*)(const QString & , quint8 )>(_a, &MQTTSubscriptionWidget::makeSubscription, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MQTTSubscriptionWidget::*)(const QString & , QVector<QTreeWidgetItem*> )>(_a, &MQTTSubscriptionWidget::MQTTUnsubscribeFromTopic, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MQTTSubscriptionWidget::*)(const QString & )>(_a, &MQTTSubscriptionWidget::removeMQTTSubscription, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MQTTSubscriptionWidget::*)(const QString & , quint8 )>(_a, &MQTTSubscriptionWidget::addBeforeRemoveSubscription, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MQTTSubscriptionWidget::*)(const QString & , const QString & )>(_a, &MQTTSubscriptionWidget::reparentTopic, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MQTTSubscriptionWidget::*)(bool )>(_a, &MQTTSubscriptionWidget::enableWill, 6))
            return;
    }
}

const QMetaObject *MQTTSubscriptionWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MQTTSubscriptionWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22MQTTSubscriptionWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int MQTTSubscriptionWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void MQTTSubscriptionWidget::subscriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MQTTSubscriptionWidget::makeSubscription(const QString & _t1, quint8 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void MQTTSubscriptionWidget::MQTTUnsubscribeFromTopic(const QString & _t1, QVector<QTreeWidgetItem*> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void MQTTSubscriptionWidget::removeMQTTSubscription(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MQTTSubscriptionWidget::addBeforeRemoveSubscription(const QString & _t1, quint8 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void MQTTSubscriptionWidget::reparentTopic(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void MQTTSubscriptionWidget::enableWill(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
