/********************************************************************************
** Form generated from reading UI file 'statisticsspreadsheetdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STATISTICSSPREADSHEETDOCK_H
#define UI_STATISTICSSPREADSHEETDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_StatisticsSpreadsheetDock
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QCheckBox *cbCount;
    QCheckBox *cbMinimum;
    QCheckBox *cbMaximum;
    QCheckBox *cbArithmeticMean;
    QCheckBox *cbGeometricMean;
    QCheckBox *cbHarmonicMean;
    QCheckBox *cbContraharmonicMean;
    QCheckBox *cbMode;
    QCheckBox *cbFirstQuartile;
    QCheckBox *cbMedian;
    QCheckBox *cbThirdQuartile;
    QCheckBox *cbTrimean;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_2;
    QCheckBox *cbRange;
    QCheckBox *cbVariance;
    QCheckBox *cbStandardDeviation;
    QCheckBox *cbMeanDeviation;
    QCheckBox *cbMeanDeviationAroundMedian;
    QCheckBox *cbMedianDeviation;
    QCheckBox *cbIQR;
    QSpacerItem *verticalSpacer_3;
    QLabel *label_3;
    QCheckBox *cbSkewness;
    QCheckBox *cbKurtosis;
    QCheckBox *cbEntropy;
    QSpacerItem *verticalSpacer_4;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QPushButton *bSelectAll;
    QPushButton *bSelectNone;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;
    QFrame *line;

    void setupUi(QWidget *StatisticsSpreadsheetDock)
    {
        if (StatisticsSpreadsheetDock->objectName().isEmpty())
            StatisticsSpreadsheetDock->setObjectName("StatisticsSpreadsheetDock");
        StatisticsSpreadsheetDock->resize(343, 875);
        verticalLayout = new QVBoxLayout(StatisticsSpreadsheetDock);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(StatisticsSpreadsheetDock);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        verticalLayout->addWidget(label);

        cbCount = new QCheckBox(StatisticsSpreadsheetDock);
        cbCount->setObjectName("cbCount");
        cbCount->setChecked(false);

        verticalLayout->addWidget(cbCount);

        cbMinimum = new QCheckBox(StatisticsSpreadsheetDock);
        cbMinimum->setObjectName("cbMinimum");
        cbMinimum->setChecked(false);

        verticalLayout->addWidget(cbMinimum);

        cbMaximum = new QCheckBox(StatisticsSpreadsheetDock);
        cbMaximum->setObjectName("cbMaximum");
        cbMaximum->setChecked(false);

        verticalLayout->addWidget(cbMaximum);

        cbArithmeticMean = new QCheckBox(StatisticsSpreadsheetDock);
        cbArithmeticMean->setObjectName("cbArithmeticMean");
        cbArithmeticMean->setChecked(false);

        verticalLayout->addWidget(cbArithmeticMean);

        cbGeometricMean = new QCheckBox(StatisticsSpreadsheetDock);
        cbGeometricMean->setObjectName("cbGeometricMean");

        verticalLayout->addWidget(cbGeometricMean);

        cbHarmonicMean = new QCheckBox(StatisticsSpreadsheetDock);
        cbHarmonicMean->setObjectName("cbHarmonicMean");

        verticalLayout->addWidget(cbHarmonicMean);

        cbContraharmonicMean = new QCheckBox(StatisticsSpreadsheetDock);
        cbContraharmonicMean->setObjectName("cbContraharmonicMean");

        verticalLayout->addWidget(cbContraharmonicMean);

        cbMode = new QCheckBox(StatisticsSpreadsheetDock);
        cbMode->setObjectName("cbMode");

        verticalLayout->addWidget(cbMode);

        cbFirstQuartile = new QCheckBox(StatisticsSpreadsheetDock);
        cbFirstQuartile->setObjectName("cbFirstQuartile");

        verticalLayout->addWidget(cbFirstQuartile);

        cbMedian = new QCheckBox(StatisticsSpreadsheetDock);
        cbMedian->setObjectName("cbMedian");

        verticalLayout->addWidget(cbMedian);

        cbThirdQuartile = new QCheckBox(StatisticsSpreadsheetDock);
        cbThirdQuartile->setObjectName("cbThirdQuartile");

        verticalLayout->addWidget(cbThirdQuartile);

        cbTrimean = new QCheckBox(StatisticsSpreadsheetDock);
        cbTrimean->setObjectName("cbTrimean");

        verticalLayout->addWidget(cbTrimean);

        verticalSpacer_2 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);

        label_2 = new QLabel(StatisticsSpreadsheetDock);
        label_2->setObjectName("label_2");
        label_2->setFont(font);

        verticalLayout->addWidget(label_2);

        cbRange = new QCheckBox(StatisticsSpreadsheetDock);
        cbRange->setObjectName("cbRange");

        verticalLayout->addWidget(cbRange);

        cbVariance = new QCheckBox(StatisticsSpreadsheetDock);
        cbVariance->setObjectName("cbVariance");
        cbVariance->setChecked(false);

        verticalLayout->addWidget(cbVariance);

        cbStandardDeviation = new QCheckBox(StatisticsSpreadsheetDock);
        cbStandardDeviation->setObjectName("cbStandardDeviation");
        cbStandardDeviation->setChecked(false);

        verticalLayout->addWidget(cbStandardDeviation);

        cbMeanDeviation = new QCheckBox(StatisticsSpreadsheetDock);
        cbMeanDeviation->setObjectName("cbMeanDeviation");

        verticalLayout->addWidget(cbMeanDeviation);

        cbMeanDeviationAroundMedian = new QCheckBox(StatisticsSpreadsheetDock);
        cbMeanDeviationAroundMedian->setObjectName("cbMeanDeviationAroundMedian");

        verticalLayout->addWidget(cbMeanDeviationAroundMedian);

        cbMedianDeviation = new QCheckBox(StatisticsSpreadsheetDock);
        cbMedianDeviation->setObjectName("cbMedianDeviation");

        verticalLayout->addWidget(cbMedianDeviation);

        cbIQR = new QCheckBox(StatisticsSpreadsheetDock);
        cbIQR->setObjectName("cbIQR");

        verticalLayout->addWidget(cbIQR);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_3);

        label_3 = new QLabel(StatisticsSpreadsheetDock);
        label_3->setObjectName("label_3");
        label_3->setFont(font);

        verticalLayout->addWidget(label_3);

        cbSkewness = new QCheckBox(StatisticsSpreadsheetDock);
        cbSkewness->setObjectName("cbSkewness");

        verticalLayout->addWidget(cbSkewness);

        cbKurtosis = new QCheckBox(StatisticsSpreadsheetDock);
        cbKurtosis->setObjectName("cbKurtosis");

        verticalLayout->addWidget(cbKurtosis);

        cbEntropy = new QCheckBox(StatisticsSpreadsheetDock);
        cbEntropy->setObjectName("cbEntropy");

        verticalLayout->addWidget(cbEntropy);

        verticalSpacer_4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_4);

        frame = new QFrame(StatisticsSpreadsheetDock);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setObjectName("horizontalLayout");
        bSelectAll = new QPushButton(frame);
        bSelectAll->setObjectName("bSelectAll");

        horizontalLayout->addWidget(bSelectAll);

        bSelectNone = new QPushButton(frame);
        bSelectNone->setObjectName("bSelectNone");

        horizontalLayout->addWidget(bSelectNone);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addWidget(frame);

        verticalSpacer = new QSpacerItem(20, 250, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        line = new QFrame(StatisticsSpreadsheetDock);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);


        retranslateUi(StatisticsSpreadsheetDock);

        QMetaObject::connectSlotsByName(StatisticsSpreadsheetDock);
    } // setupUi

    void retranslateUi(QWidget *StatisticsSpreadsheetDock)
    {
        StatisticsSpreadsheetDock->setWindowTitle(tr2i18n("Form", nullptr));
        label->setText(tr2i18n("Location Measures", nullptr));
        cbCount->setText(tr2i18n("Count", nullptr));
        cbMinimum->setText(tr2i18n("Minimum", nullptr));
        cbMaximum->setText(tr2i18n("Maximum", nullptr));
        cbArithmeticMean->setText(tr2i18n("Arithmetic mean", nullptr));
        cbGeometricMean->setText(tr2i18n("Geometric mean", nullptr));
        cbHarmonicMean->setText(tr2i18n("Harmonic mean", nullptr));
        cbContraharmonicMean->setText(tr2i18n("Contraharmonic mean", nullptr));
        cbMode->setText(tr2i18n("Mode", nullptr));
        cbFirstQuartile->setText(tr2i18n("First quartile", nullptr));
        cbMedian->setText(tr2i18n("Median", nullptr));
        cbThirdQuartile->setText(tr2i18n("Third quartile", nullptr));
        cbTrimean->setText(tr2i18n("Trimean", nullptr));
        label_2->setText(tr2i18n("Dispersion Measures", nullptr));
        cbRange->setText(tr2i18n("Range", nullptr));
        cbVariance->setText(tr2i18n("Variance", nullptr));
        cbStandardDeviation->setText(tr2i18n("Standard deviation", nullptr));
        cbMeanDeviation->setText(tr2i18n("Mean absolute deviation around mean", nullptr));
        cbMeanDeviationAroundMedian->setText(tr2i18n("Mean absolute deviation around median", nullptr));
        cbMedianDeviation->setText(tr2i18n("Median absolute deviation", nullptr));
        cbIQR->setText(tr2i18n("Interquartile range", nullptr));
        label_3->setText(tr2i18n("Shape Measures", nullptr));
        cbSkewness->setText(tr2i18n("Skewness", nullptr));
        cbKurtosis->setText(tr2i18n("Kurtosis", nullptr));
        cbEntropy->setText(tr2i18n("Entropy", nullptr));
        bSelectAll->setText(tr2i18n("Select All", nullptr));
        bSelectNone->setText(tr2i18n("Select None", nullptr));
    } // retranslateUi

};

namespace Ui {
    class StatisticsSpreadsheetDock: public Ui_StatisticsSpreadsheetDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STATISTICSSPREADSHEETDOCK_H

