/********************************************************************************
** Form generated from reading UI file 'xyintegrationcurvedockgeneraltab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XYINTEGRATIONCURVEDOCKGENERALTAB_H
#define UI_XYINTEGRATIONCURVEDOCKGENERALTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_XYIntegrationCurveDockGeneralTab
{
public:
    QGridLayout *gridLayout_2;
    ResizableTextEdit *teComment;
    QSpacerItem *horizontalSpacer;
    QLabel *lYColumn;
    QCheckBox *chkVisible;
    QLabel *lPlotRange;
    QLabel *lXRange;
    QSpacerItem *horizontalSpacer_2;
    QComboBox *cbPlotRanges;
    QCheckBox *cbAutoRange;
    QFrame *line_2;
    QLabel *lResults;
    QLabel *lEval;
    QPushButton *pbRecalculate;
    QLabel *lComment;
    QLabel *lMethod;
    QLabel *lDataSourceType;
    QLabel *lIntegration;
    QLabel *lXColumn;
    QCheckBox *cbAbsolute;
    TimedLineEdit *leName;
    QSpacerItem *verticalSpacer_4;
    QLabel *lData;
    QSpacerItem *verticalSpacer_3;
    QTextEdit *teResult;
    QSpacerItem *verticalSpacer;
    QFrame *frameRange;
    QGridLayout *gridLayout;
    QLabel *lMax;
    QLabel *lMaxDateTime;
    QLabel *lMinDateTime;
    QLabel *lMin;
    UTCDateTimeEdit *dateTimeEditMin;
    UTCDateTimeEdit *dateTimeEditMax;
    QLineEdit *leMin;
    QLineEdit *leMax;
    QComboBox *cbMethod;
    QLabel *lName;
    QComboBox *cbDataSourceType;
    QLabel *lDataSourceCurve;
    QCheckBox *chkLegendVisible;

    void setupUi(QWidget *XYIntegrationCurveDockGeneralTab)
    {
        if (XYIntegrationCurveDockGeneralTab->objectName().isEmpty())
            XYIntegrationCurveDockGeneralTab->setObjectName("XYIntegrationCurveDockGeneralTab");
        XYIntegrationCurveDockGeneralTab->resize(419, 861);
        gridLayout_2 = new QGridLayout(XYIntegrationCurveDockGeneralTab);
        gridLayout_2->setObjectName("gridLayout_2");
        teComment = new ResizableTextEdit(XYIntegrationCurveDockGeneralTab);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout_2->addWidget(teComment, 1, 2, 1, 4);

        horizontalSpacer = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 1, 1, 1);

        lYColumn = new QLabel(XYIntegrationCurveDockGeneralTab);
        lYColumn->setObjectName("lYColumn");

        gridLayout_2->addWidget(lYColumn, 7, 0, 1, 1);

        chkVisible = new QCheckBox(XYIntegrationCurveDockGeneralTab);
        chkVisible->setObjectName("chkVisible");

        gridLayout_2->addWidget(chkVisible, 22, 0, 1, 1);

        lPlotRange = new QLabel(XYIntegrationCurveDockGeneralTab);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout_2->addWidget(lPlotRange, 19, 0, 1, 1);

        lXRange = new QLabel(XYIntegrationCurveDockGeneralTab);
        lXRange->setObjectName("lXRange");

        gridLayout_2->addWidget(lXRange, 8, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(266, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 18, 3, 1, 1);

        cbPlotRanges = new QComboBox(XYIntegrationCurveDockGeneralTab);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout_2->addWidget(cbPlotRanges, 19, 2, 1, 3);

        cbAutoRange = new QCheckBox(XYIntegrationCurveDockGeneralTab);
        cbAutoRange->setObjectName("cbAutoRange");
        cbAutoRange->setChecked(true);

        gridLayout_2->addWidget(cbAutoRange, 8, 2, 1, 3);

        line_2 = new QFrame(XYIntegrationCurveDockGeneralTab);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(line_2, 16, 0, 2, 6);

        lResults = new QLabel(XYIntegrationCurveDockGeneralTab);
        lResults->setObjectName("lResults");
        QFont font;
        font.setBold(true);
        lResults->setFont(font);
        lResults->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout_2->addWidget(lResults, 15, 0, 1, 1);

        lEval = new QLabel(XYIntegrationCurveDockGeneralTab);
        lEval->setObjectName("lEval");

        gridLayout_2->addWidget(lEval, 14, 0, 1, 1);

        pbRecalculate = new QPushButton(XYIntegrationCurveDockGeneralTab);
        pbRecalculate->setObjectName("pbRecalculate");

        gridLayout_2->addWidget(pbRecalculate, 18, 4, 1, 1);

        lComment = new QLabel(XYIntegrationCurveDockGeneralTab);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(lComment, 1, 0, 1, 1);

        lMethod = new QLabel(XYIntegrationCurveDockGeneralTab);
        lMethod->setObjectName("lMethod");

        gridLayout_2->addWidget(lMethod, 12, 0, 1, 1);

        lDataSourceType = new QLabel(XYIntegrationCurveDockGeneralTab);
        lDataSourceType->setObjectName("lDataSourceType");

        gridLayout_2->addWidget(lDataSourceType, 4, 0, 1, 1);

        lIntegration = new QLabel(XYIntegrationCurveDockGeneralTab);
        lIntegration->setObjectName("lIntegration");
        lIntegration->setFont(font);

        gridLayout_2->addWidget(lIntegration, 11, 0, 1, 1);

        lXColumn = new QLabel(XYIntegrationCurveDockGeneralTab);
        lXColumn->setObjectName("lXColumn");

        gridLayout_2->addWidget(lXColumn, 6, 0, 1, 1);

        cbAbsolute = new QCheckBox(XYIntegrationCurveDockGeneralTab);
        cbAbsolute->setObjectName("cbAbsolute");

        gridLayout_2->addWidget(cbAbsolute, 13, 2, 1, 3);

        leName = new TimedLineEdit(XYIntegrationCurveDockGeneralTab);
        leName->setObjectName("leName");

        gridLayout_2->addWidget(leName, 0, 2, 1, 4);

        verticalSpacer_4 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_4, 10, 3, 1, 2);

        lData = new QLabel(XYIntegrationCurveDockGeneralTab);
        lData->setObjectName("lData");
        lData->setFont(font);

        gridLayout_2->addWidget(lData, 3, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_3, 2, 2, 1, 3);

        teResult = new QTextEdit(XYIntegrationCurveDockGeneralTab);
        teResult->setObjectName("teResult");
        teResult->setReadOnly(true);

        gridLayout_2->addWidget(teResult, 15, 2, 1, 4);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 20, 0, 1, 1);

        frameRange = new QFrame(XYIntegrationCurveDockGeneralTab);
        frameRange->setObjectName("frameRange");
        frameRange->setFrameShape(QFrame::Shape::NoFrame);
        frameRange->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout = new QGridLayout(frameRange);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, -1);
        lMax = new QLabel(frameRange);
        lMax->setObjectName("lMax");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lMax->sizePolicy().hasHeightForWidth());
        lMax->setSizePolicy(sizePolicy);
        lMax->setMinimumSize(QSize(50, 0));

        gridLayout->addWidget(lMax, 1, 0, 1, 1);

        lMaxDateTime = new QLabel(frameRange);
        lMaxDateTime->setObjectName("lMaxDateTime");
        sizePolicy.setHeightForWidth(lMaxDateTime->sizePolicy().hasHeightForWidth());
        lMaxDateTime->setSizePolicy(sizePolicy);
        lMaxDateTime->setMinimumSize(QSize(50, 0));

        gridLayout->addWidget(lMaxDateTime, 3, 0, 1, 1);

        lMinDateTime = new QLabel(frameRange);
        lMinDateTime->setObjectName("lMinDateTime");
        sizePolicy.setHeightForWidth(lMinDateTime->sizePolicy().hasHeightForWidth());
        lMinDateTime->setSizePolicy(sizePolicy);
        lMinDateTime->setMinimumSize(QSize(50, 0));

        gridLayout->addWidget(lMinDateTime, 2, 0, 1, 1);

        lMin = new QLabel(frameRange);
        lMin->setObjectName("lMin");
        sizePolicy.setHeightForWidth(lMin->sizePolicy().hasHeightForWidth());
        lMin->setSizePolicy(sizePolicy);
        lMin->setMinimumSize(QSize(50, 0));

        gridLayout->addWidget(lMin, 0, 0, 1, 1);

        dateTimeEditMin = new UTCDateTimeEdit(frameRange);
        dateTimeEditMin->setObjectName("dateTimeEditMin");
        dateTimeEditMin->setCalendarPopup(true);

        gridLayout->addWidget(dateTimeEditMin, 2, 1, 1, 1);

        dateTimeEditMax = new UTCDateTimeEdit(frameRange);
        dateTimeEditMax->setObjectName("dateTimeEditMax");
        dateTimeEditMax->setCalendarPopup(true);

        gridLayout->addWidget(dateTimeEditMax, 3, 1, 1, 1);

        leMin = new QLineEdit(frameRange);
        leMin->setObjectName("leMin");

        gridLayout->addWidget(leMin, 0, 1, 1, 1);

        leMax = new QLineEdit(frameRange);
        leMax->setObjectName("leMax");

        gridLayout->addWidget(leMax, 1, 1, 1, 1);


        gridLayout_2->addWidget(frameRange, 9, 2, 1, 4);

        cbMethod = new QComboBox(XYIntegrationCurveDockGeneralTab);
        cbMethod->setObjectName("cbMethod");

        gridLayout_2->addWidget(cbMethod, 12, 2, 1, 4);

        lName = new QLabel(XYIntegrationCurveDockGeneralTab);
        lName->setObjectName("lName");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lName->sizePolicy().hasHeightForWidth());
        lName->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(lName, 0, 0, 1, 1);

        cbDataSourceType = new QComboBox(XYIntegrationCurveDockGeneralTab);
        cbDataSourceType->setObjectName("cbDataSourceType");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cbDataSourceType->sizePolicy().hasHeightForWidth());
        cbDataSourceType->setSizePolicy(sizePolicy2);

        gridLayout_2->addWidget(cbDataSourceType, 4, 2, 1, 4);

        lDataSourceCurve = new QLabel(XYIntegrationCurveDockGeneralTab);
        lDataSourceCurve->setObjectName("lDataSourceCurve");

        gridLayout_2->addWidget(lDataSourceCurve, 5, 0, 1, 1);

        chkLegendVisible = new QCheckBox(XYIntegrationCurveDockGeneralTab);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout_2->addWidget(chkLegendVisible, 21, 0, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbDataSourceType);
        QWidget::setTabOrder(cbDataSourceType, cbAutoRange);
        QWidget::setTabOrder(cbAutoRange, leMin);
        QWidget::setTabOrder(leMin, leMax);
        QWidget::setTabOrder(leMax, dateTimeEditMin);
        QWidget::setTabOrder(dateTimeEditMin, dateTimeEditMax);
        QWidget::setTabOrder(dateTimeEditMax, cbMethod);
        QWidget::setTabOrder(cbMethod, cbAbsolute);
        QWidget::setTabOrder(cbAbsolute, teResult);
        QWidget::setTabOrder(teResult, pbRecalculate);
        QWidget::setTabOrder(pbRecalculate, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);

        retranslateUi(XYIntegrationCurveDockGeneralTab);

        QMetaObject::connectSlotsByName(XYIntegrationCurveDockGeneralTab);
    } // setupUi

    void retranslateUi(QWidget *XYIntegrationCurveDockGeneralTab)
    {
        lYColumn->setText(tr2i18n("Y-Data:", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        lXRange->setText(tr2i18n("X-Range:", nullptr));
        cbAutoRange->setText(tr2i18n("Auto", nullptr));
        lResults->setText(tr2i18n("Results:", nullptr));
        lEval->setText(QString());
        pbRecalculate->setText(tr2i18n("Recalculate", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lMethod->setText(tr2i18n("Method:", nullptr));
        lDataSourceType->setText(tr2i18n("Source:", nullptr));
        lIntegration->setText(tr2i18n("Integration", nullptr));
        lXColumn->setText(tr2i18n("X-Data:", nullptr));
        cbAbsolute->setText(tr2i18n("Absolute area", nullptr));
        lData->setText(tr2i18n("Data", nullptr));
        lMax->setText(tr2i18n("Maximum:", nullptr));
        lMaxDateTime->setText(tr2i18n("Maximum:", nullptr));
        lMinDateTime->setText(tr2i18n("Minimum:", nullptr));
        lMin->setText(tr2i18n("Minimum:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lDataSourceCurve->setText(tr2i18n("Curve:", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        (void)XYIntegrationCurveDockGeneralTab;
    } // retranslateUi

};

namespace Ui {
    class XYIntegrationCurveDockGeneralTab: public Ui_XYIntegrationCurveDockGeneralTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // XYINTEGRATIONCURVEDOCKGENERALTAB_H

