/****************************************************************************
** Meta object code from reading C++ file 'Histogram.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/plots/cartesian/Histogram.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Histogram.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9HistogramE_t {};
} // unnamed namespace

template <> constexpr inline auto Histogram::qt_create_metaobjectdata<qt_meta_tag_ZN9HistogramE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Histogram",
        "dataDataChanged",
        "",
        "dataColumnChanged",
        "const AbstractColumn*",
        "typeChanged",
        "Histogram::Type",
        "orientationChanged",
        "Histogram::Orientation",
        "normalizationChanged",
        "Histogram::Normalization",
        "binningMethodChanged",
        "Histogram::BinningMethod",
        "binCountChanged",
        "binWidthChanged",
        "autoBinRangesChanged",
        "binRangesMinChanged",
        "binRangesMaxChanged",
        "rugEnabledChanged",
        "rugLengthChanged",
        "rugWidthChanged",
        "rugOffsetChanged",
        "createDataSpreadsheet",
        "updateValues",
        "updateErrorBars",
        "dataColumnAboutToBeRemoved",
        "const AbstractAspect*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataDataChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(Histogram::Type)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'orientationChanged'
        QtMocHelpers::SignalData<void(Histogram::Orientation)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'normalizationChanged'
        QtMocHelpers::SignalData<void(Histogram::Normalization)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'binningMethodChanged'
        QtMocHelpers::SignalData<void(Histogram::BinningMethod)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Signal 'binCountChanged'
        QtMocHelpers::SignalData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'binWidthChanged'
        QtMocHelpers::SignalData<void(double)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'autoBinRangesChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'binRangesMinChanged'
        QtMocHelpers::SignalData<void(double)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'binRangesMaxChanged'
        QtMocHelpers::SignalData<void(double)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'rugEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'rugLengthChanged'
        QtMocHelpers::SignalData<void(double)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'rugWidthChanged'
        QtMocHelpers::SignalData<void(double)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'rugOffsetChanged'
        QtMocHelpers::SignalData<void(double)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'createDataSpreadsheet'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateValues'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateErrorBars'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'dataColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Histogram, qt_meta_tag_ZN9HistogramE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Histogram::staticMetaObject = { {
    QMetaObject::SuperData::link<Plot::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9HistogramE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9HistogramE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9HistogramE_t>.metaTypes,
    nullptr
} };

void Histogram::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Histogram *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataDataChanged(); break;
        case 1: _t->dataColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 2: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<Histogram::Type>>(_a[1]))); break;
        case 3: _t->orientationChanged((*reinterpret_cast<std::add_pointer_t<Histogram::Orientation>>(_a[1]))); break;
        case 4: _t->normalizationChanged((*reinterpret_cast<std::add_pointer_t<Histogram::Normalization>>(_a[1]))); break;
        case 5: _t->binningMethodChanged((*reinterpret_cast<std::add_pointer_t<Histogram::BinningMethod>>(_a[1]))); break;
        case 6: _t->binCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->binWidthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 8: _t->autoBinRangesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->binRangesMinChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->binRangesMaxChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 11: _t->rugEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->rugLengthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 13: _t->rugWidthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 14: _t->rugOffsetChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: _t->createDataSpreadsheet(); break;
        case 16: _t->updateValues(); break;
        case 17: _t->updateErrorBars(); break;
        case 18: _t->dataColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)()>(_a, &Histogram::dataDataChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(const AbstractColumn * )>(_a, &Histogram::dataColumnChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(Histogram::Type )>(_a, &Histogram::typeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(Histogram::Orientation )>(_a, &Histogram::orientationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(Histogram::Normalization )>(_a, &Histogram::normalizationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(Histogram::BinningMethod )>(_a, &Histogram::binningMethodChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(int )>(_a, &Histogram::binCountChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(double )>(_a, &Histogram::binWidthChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(bool )>(_a, &Histogram::autoBinRangesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(double )>(_a, &Histogram::binRangesMinChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(double )>(_a, &Histogram::binRangesMaxChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(bool )>(_a, &Histogram::rugEnabledChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(double )>(_a, &Histogram::rugLengthChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(double )>(_a, &Histogram::rugWidthChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Histogram::*)(double )>(_a, &Histogram::rugOffsetChanged, 14))
            return;
    }
}

const QMetaObject *Histogram::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Histogram::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9HistogramE_t>.strings))
        return static_cast<void*>(this);
    return Plot::qt_metacast(_clname);
}

int Histogram::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Plot::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void Histogram::dataDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Histogram::dataColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Histogram::typeChanged(Histogram::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Histogram::orientationChanged(Histogram::Orientation _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Histogram::normalizationChanged(Histogram::Normalization _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Histogram::binningMethodChanged(Histogram::BinningMethod _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Histogram::binCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Histogram::binWidthChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Histogram::autoBinRangesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Histogram::binRangesMinChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Histogram::binRangesMaxChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Histogram::rugEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Histogram::rugLengthChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Histogram::rugWidthChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Histogram::rugOffsetChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}
QT_WARNING_POP
