/********************************************************************************
** Form generated from reading UI file 'cartesianplotdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CARTESIANPLOTDOCK_H
#define UI_CARTESIANPLOTDOCK_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_CartesianPlotDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    QLineEdit *leRangePoints;
    QLabel *lPlotRanges;
    QLabel *lYRanges;
    TimedLineEdit *leName;
    QTableWidget *twPlotRanges;
    QSpacerItem *verticalSpacer;
    QSpacerItem *horizontalSpacer_4;
    QLabel *lXRanges;
    QSpacerItem *verticalSpacer_4;
    ResizableTextEdit *teComment;
    QTableWidget *twYRanges;
    QSpacerItem *verticalSpacer_11;
    QLabel *lRangePoints;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_8;
    QToolButton *tbAddXRange;
    QToolButton *tbRemoveXRange;
    QComboBox *cbRangeType;
    QLabel *lRangeType;
    QTableWidget *twXRanges;
    QSpacerItem *verticalSpacer_13;
    QCheckBox *cbNiceExtend;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_7;
    QToolButton *tbAddPlotRange;
    QToolButton *tbRemovePlotRange;
    QLabel *lComment;
    QLabel *lName;
    QSpacerItem *verticalSpacer_12;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_9;
    QToolButton *tbAddYRange;
    QToolButton *tbRemoveYRange;
    QLabel *lNiceExtend;
    QSpacerItem *verticalSpacer_6;
    QCheckBox *chkVisible;
    QWidget *tabTitle;
    QWidget *tabLayout_2;
    QGridLayout *gridLayout_4;
    QLabel *lBottomMargin;
    QLabel *lPaddingHorizontal;
    NumberSpinBox *sbTop;
    QLabel *lGeometry;
    NumberSpinBox *sbPaddingHorizontal;
    QLabel *lPadding;
    QCheckBox *cbPaddingSymmetric;
    QLabel *label_8;
    QLabel *lPaddingVerticalDown;
    NumberSpinBox *sbWidth;
    NumberSpinBox *sbPaddingVertical;
    NumberSpinBox *sbPaddingRight;
    QSpacerItem *verticalSpacer_14;
    QSpacerItem *verticalSpacer_10;
    QLabel *lRightMargin;
    NumberSpinBox *sbLeft;
    QSpacerItem *horizontalSpacer_11;
    QLabel *lTopMargin;
    QLabel *lLeftMargin;
    QLabel *lPaddingHorizontalRight;
    NumberSpinBox *sbHeight;
    NumberSpinBox *sbPaddingBottom;
    QLabel *lPaddingVertical;
    QWidget *tabScales;
    QGridLayout *gridLayout_3;
    QLabel *lYBreakEnd;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_5;
    QLabel *lXBreakEnd;
    QCheckBox *chkXBreak;
    QLineEdit *leYBreakStart;
    QLineEdit *leXBreakStart;
    QLineEdit *leYBreakEnd;
    QSpacerItem *horizontalSpacer_2;
    QFrame *frameXBreakEdit;
    QHBoxLayout *horizontalLayout;
    QPushButton *bAddXBreak;
    QPushButton *bRemoveXBreak;
    QComboBox *cbXBreak;
    QLabel *lYBreakPosition;
    QLineEdit *leXBreakEnd;
    QLabel *lXBreakStyle;
    QSpinBox *sbYBreakPosition;
    QLabel *label_3;
    QLabel *label_2;
    QLabel *label_4;
    QFrame *frameYBreakEdit;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *bAddYBreak;
    QPushButton *bRemoveYBreak;
    QComboBox *cbYBreak;
    QLabel *lXBreakStart;
    QLabel *label;
    QComboBox *cbYBreakStyle;
    QLabel *lYBreakStyle;
    QCheckBox *chkYBreak;
    QComboBox *cbXBreakStyle;
    QSpinBox *sbXBreakPosition;
    QLabel *lXBreakPosition;
    QLabel *lYBreakStart;
    QSpacerItem *verticalSpacer_8;
    QSpacerItem *verticalSpacer_2;
    QWidget *tabPlotArea;
    QGridLayout *gridLayout_2;
    QLabel *label_10;
    QSpacerItem *horizontalSpacer_3;
    QFrame *frameBorderType;
    QHBoxLayout *horizontalLayout_6;
    QToolButton *tbBorderTypeLeft;
    QToolButton *tbBorderTypeTop;
    QToolButton *tbBorderTypeRight;
    QToolButton *tbBorderTypeBottom;
    QSpacerItem *horizontalSpacer_10;
    QSpacerItem *verticalSpacer_7;
    QLabel *lBorder;
    NumberSpinBox *sbBorderCornerRadius;
    QSpacerItem *verticalSpacer_5;
    QSpacerItem *verticalSpacer_3;
    QLabel *lBackground;
    QLabel *lBorderCornerRadius;
    QSpacerItem *verticalSpacer_15;
    QWidget *tabCursor;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_9;
    QSpacerItem *verticalSpacer_9;

    void setupUi(QWidget *CartesianPlotDock)
    {
        if (CartesianPlotDock->objectName().isEmpty())
            CartesianPlotDock->setObjectName("CartesianPlotDock");
        CartesianPlotDock->resize(385, 826);
        verticalLayout = new QVBoxLayout(CartesianPlotDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(CartesianPlotDock);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(tabGeneral->sizePolicy().hasHeightForWidth());
        tabGeneral->setSizePolicy(sizePolicy1);
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setObjectName("gridLayout");
        leRangePoints = new QLineEdit(tabGeneral);
        leRangePoints->setObjectName("leRangePoints");

        gridLayout->addWidget(leRangePoints, 5, 4, 1, 1);

        lPlotRanges = new QLabel(tabGeneral);
        lPlotRanges->setObjectName("lPlotRanges");
        QFont font;
        font.setBold(true);
        lPlotRanges->setFont(font);

        gridLayout->addWidget(lPlotRanges, 18, 0, 1, 1);

        lYRanges = new QLabel(tabGeneral);
        lYRanges->setObjectName("lYRanges");
        lYRanges->setFont(font);

        gridLayout->addWidget(lYRanges, 14, 0, 1, 2);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");
        leName->setClearButtonEnabled(true);

        gridLayout->addWidget(leName, 0, 4, 1, 1);

        twPlotRanges = new QTableWidget(tabGeneral);
        if (twPlotRanges->columnCount() < 4)
            twPlotRanges->setColumnCount(4);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        twPlotRanges->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        twPlotRanges->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        twPlotRanges->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        twPlotRanges->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        twPlotRanges->setObjectName("twPlotRanges");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(twPlotRanges->sizePolicy().hasHeightForWidth());
        twPlotRanges->setSizePolicy(sizePolicy2);
        twPlotRanges->setVerticalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        twPlotRanges->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        twPlotRanges->horizontalHeader()->setDefaultSectionSize(100);
        twPlotRanges->horizontalHeader()->setStretchLastSection(true);

        gridLayout->addWidget(twPlotRanges, 20, 0, 1, 6);

        verticalSpacer = new QSpacerItem(28, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 22, 0, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 0, 2, 1, 1);

        lXRanges = new QLabel(tabGeneral);
        lXRanges->setObjectName("lXRanges");
        lXRanges->setFont(font);

        gridLayout->addWidget(lXRanges, 8, 0, 1, 2);

        verticalSpacer_4 = new QSpacerItem(28, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 2, 0, 1, 3);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 4, 1, 1);

        twYRanges = new QTableWidget(tabGeneral);
        if (twYRanges->columnCount() < 5)
            twYRanges->setColumnCount(5);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        twYRanges->setHorizontalHeaderItem(0, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        twYRanges->setHorizontalHeaderItem(1, __qtablewidgetitem5);
        QTableWidgetItem *__qtablewidgetitem6 = new QTableWidgetItem();
        twYRanges->setHorizontalHeaderItem(2, __qtablewidgetitem6);
        QTableWidgetItem *__qtablewidgetitem7 = new QTableWidgetItem();
        twYRanges->setHorizontalHeaderItem(3, __qtablewidgetitem7);
        QTableWidgetItem *__qtablewidgetitem8 = new QTableWidgetItem();
        twYRanges->setHorizontalHeaderItem(4, __qtablewidgetitem8);
        twYRanges->setObjectName("twYRanges");
        sizePolicy2.setHeightForWidth(twYRanges->sizePolicy().hasHeightForWidth());
        twYRanges->setSizePolicy(sizePolicy2);
        twYRanges->setVerticalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        twYRanges->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        twYRanges->horizontalHeader()->setCascadingSectionResizes(true);
        twYRanges->horizontalHeader()->setDefaultSectionSize(60);
        twYRanges->horizontalHeader()->setStretchLastSection(true);
        twYRanges->verticalHeader()->setCascadingSectionResizes(true);
        twYRanges->verticalHeader()->setMinimumSectionSize(10);

        gridLayout->addWidget(twYRanges, 15, 0, 1, 6);

        verticalSpacer_11 = new QSpacerItem(28, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_11, 7, 0, 1, 2);

        lRangePoints = new QLabel(tabGeneral);
        lRangePoints->setObjectName("lRangePoints");

        gridLayout->addWidget(lRangePoints, 5, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(0);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_8);

        tbAddXRange = new QToolButton(tabGeneral);
        tbAddXRange->setObjectName("tbAddXRange");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        tbAddXRange->setIcon(icon);

        horizontalLayout_3->addWidget(tbAddXRange);

        tbRemoveXRange = new QToolButton(tabGeneral);
        tbRemoveXRange->setObjectName("tbRemoveXRange");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        tbRemoveXRange->setIcon(icon1);

        horizontalLayout_3->addWidget(tbRemoveXRange);


        gridLayout->addLayout(horizontalLayout_3, 8, 4, 1, 1);

        cbRangeType = new QComboBox(tabGeneral);
        cbRangeType->setObjectName("cbRangeType");

        gridLayout->addWidget(cbRangeType, 3, 4, 1, 1);

        lRangeType = new QLabel(tabGeneral);
        lRangeType->setObjectName("lRangeType");

        gridLayout->addWidget(lRangeType, 3, 0, 1, 1);

        twXRanges = new QTableWidget(tabGeneral);
        if (twXRanges->columnCount() < 5)
            twXRanges->setColumnCount(5);
        QTableWidgetItem *__qtablewidgetitem9 = new QTableWidgetItem();
        twXRanges->setHorizontalHeaderItem(0, __qtablewidgetitem9);
        QTableWidgetItem *__qtablewidgetitem10 = new QTableWidgetItem();
        twXRanges->setHorizontalHeaderItem(1, __qtablewidgetitem10);
        QTableWidgetItem *__qtablewidgetitem11 = new QTableWidgetItem();
        twXRanges->setHorizontalHeaderItem(2, __qtablewidgetitem11);
        QTableWidgetItem *__qtablewidgetitem12 = new QTableWidgetItem();
        twXRanges->setHorizontalHeaderItem(3, __qtablewidgetitem12);
        QTableWidgetItem *__qtablewidgetitem13 = new QTableWidgetItem();
        twXRanges->setHorizontalHeaderItem(4, __qtablewidgetitem13);
        twXRanges->setObjectName("twXRanges");
        sizePolicy2.setHeightForWidth(twXRanges->sizePolicy().hasHeightForWidth());
        twXRanges->setSizePolicy(sizePolicy2);
        twXRanges->setVerticalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        twXRanges->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        twXRanges->setColumnCount(5);
        twXRanges->horizontalHeader()->setCascadingSectionResizes(true);
        twXRanges->horizontalHeader()->setDefaultSectionSize(60);
        twXRanges->horizontalHeader()->setStretchLastSection(true);
        twXRanges->verticalHeader()->setCascadingSectionResizes(true);
        twXRanges->verticalHeader()->setMinimumSectionSize(10);

        gridLayout->addWidget(twXRanges, 11, 0, 1, 6);

        verticalSpacer_13 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_13, 21, 0, 1, 1);

        cbNiceExtend = new QCheckBox(tabGeneral);
        cbNiceExtend->setObjectName("cbNiceExtend");
        cbNiceExtend->setChecked(true);

        gridLayout->addWidget(cbNiceExtend, 6, 4, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(0);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_7);

        tbAddPlotRange = new QToolButton(tabGeneral);
        tbAddPlotRange->setObjectName("tbAddPlotRange");
        tbAddPlotRange->setIcon(icon);

        horizontalLayout_4->addWidget(tbAddPlotRange);

        tbRemovePlotRange = new QToolButton(tabGeneral);
        tbRemovePlotRange->setObjectName("tbRemovePlotRange");
        tbRemovePlotRange->setIcon(icon1);

        horizontalLayout_4->addWidget(tbRemovePlotRange);


        gridLayout->addLayout(horizontalLayout_4, 18, 4, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 2);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 2);

        verticalSpacer_12 = new QSpacerItem(28, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_12, 17, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(0);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_9);

        tbAddYRange = new QToolButton(tabGeneral);
        tbAddYRange->setObjectName("tbAddYRange");
        tbAddYRange->setIcon(icon);

        horizontalLayout_5->addWidget(tbAddYRange);

        tbRemoveYRange = new QToolButton(tabGeneral);
        tbRemoveYRange->setObjectName("tbRemoveYRange");
        tbRemoveYRange->setIcon(icon1);

        horizontalLayout_5->addWidget(tbRemoveYRange);


        gridLayout->addLayout(horizontalLayout_5, 14, 3, 1, 2);

        lNiceExtend = new QLabel(tabGeneral);
        lNiceExtend->setObjectName("lNiceExtend");

        gridLayout->addWidget(lNiceExtend, 6, 0, 1, 1);

        verticalSpacer_6 = new QSpacerItem(28, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_6, 13, 0, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout->addWidget(chkVisible, 23, 0, 1, 3);

        tabWidget->addTab(tabGeneral, QString());
        tabTitle = new QWidget();
        tabTitle->setObjectName("tabTitle");
        tabWidget->addTab(tabTitle, QString());
        tabLayout_2 = new QWidget();
        tabLayout_2->setObjectName("tabLayout_2");
        gridLayout_4 = new QGridLayout(tabLayout_2);
        gridLayout_4->setObjectName("gridLayout_4");
        lBottomMargin = new QLabel(tabLayout_2);
        lBottomMargin->setObjectName("lBottomMargin");

        gridLayout_4->addWidget(lBottomMargin, 3, 0, 1, 1);

        lPaddingHorizontal = new QLabel(tabLayout_2);
        lPaddingHorizontal->setObjectName("lPaddingHorizontal");

        gridLayout_4->addWidget(lPaddingHorizontal, 8, 0, 1, 1);

        sbTop = new NumberSpinBox(tabLayout_2);
        sbTop->setObjectName("sbTop");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(sbTop->sizePolicy().hasHeightForWidth());
        sbTop->setSizePolicy(sizePolicy3);
        sbTop->setProperty("feedback", QVariant(true));

        gridLayout_4->addWidget(sbTop, 2, 2, 1, 1);

        lGeometry = new QLabel(tabLayout_2);
        lGeometry->setObjectName("lGeometry");
        lGeometry->setFont(font);

        gridLayout_4->addWidget(lGeometry, 0, 0, 1, 1);

        sbPaddingHorizontal = new NumberSpinBox(tabLayout_2);
        sbPaddingHorizontal->setObjectName("sbPaddingHorizontal");
        sizePolicy3.setHeightForWidth(sbPaddingHorizontal->sizePolicy().hasHeightForWidth());
        sbPaddingHorizontal->setSizePolicy(sizePolicy3);
        sbPaddingHorizontal->setProperty("feedback", QVariant(true));

        gridLayout_4->addWidget(sbPaddingHorizontal, 8, 2, 1, 1);

        lPadding = new QLabel(tabLayout_2);
        lPadding->setObjectName("lPadding");
        lPadding->setFont(font);

        gridLayout_4->addWidget(lPadding, 6, 0, 1, 1);

        cbPaddingSymmetric = new QCheckBox(tabLayout_2);
        cbPaddingSymmetric->setObjectName("cbPaddingSymmetric");

        gridLayout_4->addWidget(cbPaddingSymmetric, 7, 2, 1, 1);

        label_8 = new QLabel(tabLayout_2);
        label_8->setObjectName("label_8");

        gridLayout_4->addWidget(label_8, 7, 0, 1, 1);

        lPaddingVerticalDown = new QLabel(tabLayout_2);
        lPaddingVerticalDown->setObjectName("lPaddingVerticalDown");

        gridLayout_4->addWidget(lPaddingVerticalDown, 11, 0, 1, 1);

        sbWidth = new NumberSpinBox(tabLayout_2);
        sbWidth->setObjectName("sbWidth");
        sizePolicy3.setHeightForWidth(sbWidth->sizePolicy().hasHeightForWidth());
        sbWidth->setSizePolicy(sizePolicy3);
        sbWidth->setProperty("feedback", QVariant(true));

        gridLayout_4->addWidget(sbWidth, 3, 2, 1, 1);

        sbPaddingVertical = new NumberSpinBox(tabLayout_2);
        sbPaddingVertical->setObjectName("sbPaddingVertical");
        sizePolicy3.setHeightForWidth(sbPaddingVertical->sizePolicy().hasHeightForWidth());
        sbPaddingVertical->setSizePolicy(sizePolicy3);
        sbPaddingVertical->setProperty("feedback", QVariant(true));

        gridLayout_4->addWidget(sbPaddingVertical, 9, 2, 1, 1);

        sbPaddingRight = new NumberSpinBox(tabLayout_2);
        sbPaddingRight->setObjectName("sbPaddingRight");
        sizePolicy3.setHeightForWidth(sbPaddingRight->sizePolicy().hasHeightForWidth());
        sbPaddingRight->setSizePolicy(sizePolicy3);
        sbPaddingRight->setProperty("feedback", QVariant(true));

        gridLayout_4->addWidget(sbPaddingRight, 10, 2, 1, 1);

        verticalSpacer_14 = new QSpacerItem(20, 614, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer_14, 12, 0, 1, 1);

        verticalSpacer_10 = new QSpacerItem(28, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_10, 5, 0, 1, 1);

        lRightMargin = new QLabel(tabLayout_2);
        lRightMargin->setObjectName("lRightMargin");

        gridLayout_4->addWidget(lRightMargin, 4, 0, 1, 1);

        sbLeft = new NumberSpinBox(tabLayout_2);
        sbLeft->setObjectName("sbLeft");
        sizePolicy3.setHeightForWidth(sbLeft->sizePolicy().hasHeightForWidth());
        sbLeft->setSizePolicy(sizePolicy3);
        sbLeft->setProperty("feedback", QVariant(true));

        gridLayout_4->addWidget(sbLeft, 1, 2, 1, 1);

        horizontalSpacer_11 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_11, 1, 1, 1, 1);

        lTopMargin = new QLabel(tabLayout_2);
        lTopMargin->setObjectName("lTopMargin");

        gridLayout_4->addWidget(lTopMargin, 1, 0, 1, 1);

        lLeftMargin = new QLabel(tabLayout_2);
        lLeftMargin->setObjectName("lLeftMargin");

        gridLayout_4->addWidget(lLeftMargin, 2, 0, 1, 1);

        lPaddingHorizontalRight = new QLabel(tabLayout_2);
        lPaddingHorizontalRight->setObjectName("lPaddingHorizontalRight");

        gridLayout_4->addWidget(lPaddingHorizontalRight, 10, 0, 1, 1);

        sbHeight = new NumberSpinBox(tabLayout_2);
        sbHeight->setObjectName("sbHeight");
        sizePolicy3.setHeightForWidth(sbHeight->sizePolicy().hasHeightForWidth());
        sbHeight->setSizePolicy(sizePolicy3);
        sbHeight->setProperty("feedback", QVariant(true));

        gridLayout_4->addWidget(sbHeight, 4, 2, 1, 1);

        sbPaddingBottom = new NumberSpinBox(tabLayout_2);
        sbPaddingBottom->setObjectName("sbPaddingBottom");
        sizePolicy3.setHeightForWidth(sbPaddingBottom->sizePolicy().hasHeightForWidth());
        sbPaddingBottom->setSizePolicy(sizePolicy3);
        sbPaddingBottom->setProperty("feedback", QVariant(true));

        gridLayout_4->addWidget(sbPaddingBottom, 11, 2, 1, 1);

        lPaddingVertical = new QLabel(tabLayout_2);
        lPaddingVertical->setObjectName("lPaddingVertical");

        gridLayout_4->addWidget(lPaddingVertical, 9, 0, 1, 1);

        tabWidget->addTab(tabLayout_2, QString());
        tabScales = new QWidget();
        tabScales->setObjectName("tabScales");
        gridLayout_3 = new QGridLayout(tabScales);
        gridLayout_3->setObjectName("gridLayout_3");
        lYBreakEnd = new QLabel(tabScales);
        lYBreakEnd->setObjectName("lYBreakEnd");

        gridLayout_3->addWidget(lYBreakEnd, 11, 0, 1, 2);

        horizontalSpacer = new QSpacerItem(25, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer, 1, 5, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_5, 1, 3, 1, 1);

        lXBreakEnd = new QLabel(tabScales);
        lXBreakEnd->setObjectName("lXBreakEnd");

        gridLayout_3->addWidget(lXBreakEnd, 3, 0, 1, 3);

        chkXBreak = new QCheckBox(tabScales);
        chkXBreak->setObjectName("chkXBreak");

        gridLayout_3->addWidget(chkXBreak, 1, 4, 1, 1);

        leYBreakStart = new QLineEdit(tabScales);
        leYBreakStart->setObjectName("leYBreakStart");

        gridLayout_3->addWidget(leYBreakStart, 10, 4, 1, 3);

        leXBreakStart = new QLineEdit(tabScales);
        leXBreakStart->setObjectName("leXBreakStart");

        gridLayout_3->addWidget(leXBreakStart, 2, 4, 1, 3);

        leYBreakEnd = new QLineEdit(tabScales);
        leYBreakEnd->setObjectName("leYBreakEnd");

        gridLayout_3->addWidget(leYBreakEnd, 11, 4, 1, 3);

        horizontalSpacer_2 = new QSpacerItem(31, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 9, 5, 1, 1);

        frameXBreakEdit = new QFrame(tabScales);
        frameXBreakEdit->setObjectName("frameXBreakEdit");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(frameXBreakEdit->sizePolicy().hasHeightForWidth());
        frameXBreakEdit->setSizePolicy(sizePolicy4);
        frameXBreakEdit->setFrameShape(QFrame::Shape::NoFrame);
        frameXBreakEdit->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout = new QHBoxLayout(frameXBreakEdit);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        bAddXBreak = new QPushButton(frameXBreakEdit);
        bAddXBreak->setObjectName("bAddXBreak");

        horizontalLayout->addWidget(bAddXBreak);

        bRemoveXBreak = new QPushButton(frameXBreakEdit);
        bRemoveXBreak->setObjectName("bRemoveXBreak");

        horizontalLayout->addWidget(bRemoveXBreak);

        cbXBreak = new QComboBox(frameXBreakEdit);
        cbXBreak->setObjectName("cbXBreak");

        horizontalLayout->addWidget(cbXBreak);


        gridLayout_3->addWidget(frameXBreakEdit, 1, 6, 1, 1);

        lYBreakPosition = new QLabel(tabScales);
        lYBreakPosition->setObjectName("lYBreakPosition");

        gridLayout_3->addWidget(lYBreakPosition, 12, 0, 1, 2);

        leXBreakEnd = new QLineEdit(tabScales);
        leXBreakEnd->setObjectName("leXBreakEnd");

        gridLayout_3->addWidget(leXBreakEnd, 3, 4, 1, 3);

        lXBreakStyle = new QLabel(tabScales);
        lXBreakStyle->setObjectName("lXBreakStyle");

        gridLayout_3->addWidget(lXBreakStyle, 5, 0, 1, 2);

        sbYBreakPosition = new QSpinBox(tabScales);
        sbYBreakPosition->setObjectName("sbYBreakPosition");
        sbYBreakPosition->setSingleStep(10);

        gridLayout_3->addWidget(sbYBreakPosition, 12, 4, 1, 3);

        label_3 = new QLabel(tabScales);
        label_3->setObjectName("label_3");
        label_3->setFont(font);

        gridLayout_3->addWidget(label_3, 8, 0, 1, 2);

        label_2 = new QLabel(tabScales);
        label_2->setObjectName("label_2");

        gridLayout_3->addWidget(label_2, 1, 0, 1, 3);

        label_4 = new QLabel(tabScales);
        label_4->setObjectName("label_4");

        gridLayout_3->addWidget(label_4, 9, 0, 1, 2);

        frameYBreakEdit = new QFrame(tabScales);
        frameYBreakEdit->setObjectName("frameYBreakEdit");
        sizePolicy4.setHeightForWidth(frameYBreakEdit->sizePolicy().hasHeightForWidth());
        frameYBreakEdit->setSizePolicy(sizePolicy4);
        frameYBreakEdit->setFrameShape(QFrame::Shape::NoFrame);
        frameYBreakEdit->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout_2 = new QHBoxLayout(frameYBreakEdit);
        horizontalLayout_2->setSpacing(0);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        bAddYBreak = new QPushButton(frameYBreakEdit);
        bAddYBreak->setObjectName("bAddYBreak");

        horizontalLayout_2->addWidget(bAddYBreak);

        bRemoveYBreak = new QPushButton(frameYBreakEdit);
        bRemoveYBreak->setObjectName("bRemoveYBreak");

        horizontalLayout_2->addWidget(bRemoveYBreak);

        cbYBreak = new QComboBox(frameYBreakEdit);
        cbYBreak->setObjectName("cbYBreak");

        horizontalLayout_2->addWidget(cbYBreak);


        gridLayout_3->addWidget(frameYBreakEdit, 9, 6, 1, 1);

        lXBreakStart = new QLabel(tabScales);
        lXBreakStart->setObjectName("lXBreakStart");

        gridLayout_3->addWidget(lXBreakStart, 2, 0, 1, 2);

        label = new QLabel(tabScales);
        label->setObjectName("label");
        label->setFont(font);

        gridLayout_3->addWidget(label, 0, 0, 1, 2);

        cbYBreakStyle = new QComboBox(tabScales);
        cbYBreakStyle->setObjectName("cbYBreakStyle");

        gridLayout_3->addWidget(cbYBreakStyle, 13, 4, 1, 3);

        lYBreakStyle = new QLabel(tabScales);
        lYBreakStyle->setObjectName("lYBreakStyle");

        gridLayout_3->addWidget(lYBreakStyle, 13, 0, 1, 2);

        chkYBreak = new QCheckBox(tabScales);
        chkYBreak->setObjectName("chkYBreak");

        gridLayout_3->addWidget(chkYBreak, 9, 4, 1, 1);

        cbXBreakStyle = new QComboBox(tabScales);
        cbXBreakStyle->setObjectName("cbXBreakStyle");

        gridLayout_3->addWidget(cbXBreakStyle, 5, 4, 1, 3);

        sbXBreakPosition = new QSpinBox(tabScales);
        sbXBreakPosition->setObjectName("sbXBreakPosition");
        sbXBreakPosition->setSingleStep(10);

        gridLayout_3->addWidget(sbXBreakPosition, 4, 4, 1, 3);

        lXBreakPosition = new QLabel(tabScales);
        lXBreakPosition->setObjectName("lXBreakPosition");

        gridLayout_3->addWidget(lXBreakPosition, 4, 0, 1, 2);

        lYBreakStart = new QLabel(tabScales);
        lYBreakStart->setObjectName("lYBreakStart");

        gridLayout_3->addWidget(lYBreakStart, 10, 0, 1, 2);

        verticalSpacer_8 = new QSpacerItem(28, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_8, 7, 0, 1, 2);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_2, 14, 0, 1, 2);

        tabWidget->addTab(tabScales, QString());
        tabPlotArea = new QWidget();
        tabPlotArea->setObjectName("tabPlotArea");
        gridLayout_2 = new QGridLayout(tabPlotArea);
        gridLayout_2->setObjectName("gridLayout_2");
        label_10 = new QLabel(tabPlotArea);
        label_10->setObjectName("label_10");

        gridLayout_2->addWidget(label_10, 4, 0, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_3, 4, 1, 1, 1);

        frameBorderType = new QFrame(tabPlotArea);
        frameBorderType->setObjectName("frameBorderType");
        frameBorderType->setFrameShape(QFrame::Shape::NoFrame);
        frameBorderType->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout_6 = new QHBoxLayout(frameBorderType);
        horizontalLayout_6->setSpacing(0);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setContentsMargins(0, 0, 0, 0);
        tbBorderTypeLeft = new QToolButton(frameBorderType);
        tbBorderTypeLeft->setObjectName("tbBorderTypeLeft");
        tbBorderTypeLeft->setText(QString::fromUtf8(""));
        tbBorderTypeLeft->setCheckable(true);

        horizontalLayout_6->addWidget(tbBorderTypeLeft);

        tbBorderTypeTop = new QToolButton(frameBorderType);
        tbBorderTypeTop->setObjectName("tbBorderTypeTop");
        tbBorderTypeTop->setText(QString::fromUtf8(""));
        tbBorderTypeTop->setCheckable(true);

        horizontalLayout_6->addWidget(tbBorderTypeTop);

        tbBorderTypeRight = new QToolButton(frameBorderType);
        tbBorderTypeRight->setObjectName("tbBorderTypeRight");
        tbBorderTypeRight->setText(QString::fromUtf8(""));
        tbBorderTypeRight->setCheckable(true);

        horizontalLayout_6->addWidget(tbBorderTypeRight);

        tbBorderTypeBottom = new QToolButton(frameBorderType);
        tbBorderTypeBottom->setObjectName("tbBorderTypeBottom");
        tbBorderTypeBottom->setText(QString::fromUtf8(""));
        tbBorderTypeBottom->setCheckable(true);

        horizontalLayout_6->addWidget(tbBorderTypeBottom);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_10);


        gridLayout_2->addWidget(frameBorderType, 4, 2, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_7, 8, 0, 1, 1);

        lBorder = new QLabel(tabPlotArea);
        lBorder->setObjectName("lBorder");
        lBorder->setFont(font);

        gridLayout_2->addWidget(lBorder, 3, 0, 1, 1);

        sbBorderCornerRadius = new NumberSpinBox(tabPlotArea);
        sbBorderCornerRadius->setObjectName("sbBorderCornerRadius");
        sizePolicy3.setHeightForWidth(sbBorderCornerRadius->sizePolicy().hasHeightForWidth());
        sbBorderCornerRadius->setSizePolicy(sizePolicy3);
        sbBorderCornerRadius->setProperty("feedback", QVariant(true));

        gridLayout_2->addWidget(sbBorderCornerRadius, 6, 2, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_5, 5, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(72, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_3, 1, 0, 1, 1);

        lBackground = new QLabel(tabPlotArea);
        lBackground->setObjectName("lBackground");
        lBackground->setFont(font);

        gridLayout_2->addWidget(lBackground, 0, 0, 1, 1);

        lBorderCornerRadius = new QLabel(tabPlotArea);
        lBorderCornerRadius->setObjectName("lBorderCornerRadius");

        gridLayout_2->addWidget(lBorderCornerRadius, 6, 0, 1, 1);

        verticalSpacer_15 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_15, 2, 0, 1, 1);

        tabWidget->addTab(tabPlotArea, QString());
        tabCursor = new QWidget();
        tabCursor->setObjectName("tabCursor");
        verticalLayout_2 = new QVBoxLayout(tabCursor);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_9 = new QLabel(tabCursor);
        label_9->setObjectName("label_9");
        label_9->setFont(font);

        verticalLayout_2->addWidget(label_9);

        verticalSpacer_9 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_9);

        tabWidget->addTab(tabCursor, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbRangeType);
        QWidget::setTabOrder(cbRangeType, leRangePoints);
        QWidget::setTabOrder(leRangePoints, cbNiceExtend);
        QWidget::setTabOrder(cbNiceExtend, tbAddXRange);
        QWidget::setTabOrder(tbAddXRange, tbRemoveXRange);
        QWidget::setTabOrder(tbRemoveXRange, twXRanges);
        QWidget::setTabOrder(twXRanges, tbAddYRange);
        QWidget::setTabOrder(tbAddYRange, tbRemoveYRange);
        QWidget::setTabOrder(tbRemoveYRange, twYRanges);
        QWidget::setTabOrder(twYRanges, tbAddPlotRange);
        QWidget::setTabOrder(tbAddPlotRange, tbRemovePlotRange);
        QWidget::setTabOrder(tbRemovePlotRange, twPlotRanges);
        QWidget::setTabOrder(twPlotRanges, chkVisible);
        QWidget::setTabOrder(chkVisible, leYBreakEnd);
        QWidget::setTabOrder(leYBreakEnd, sbYBreakPosition);
        QWidget::setTabOrder(sbYBreakPosition, cbYBreakStyle);
        QWidget::setTabOrder(cbYBreakStyle, leYBreakStart);
        QWidget::setTabOrder(leYBreakStart, bAddXBreak);
        QWidget::setTabOrder(bAddXBreak, cbYBreak);
        QWidget::setTabOrder(cbYBreak, chkYBreak);
        QWidget::setTabOrder(chkYBreak, cbXBreak);
        QWidget::setTabOrder(cbXBreak, leXBreakStart);
        QWidget::setTabOrder(leXBreakStart, chkXBreak);
        QWidget::setTabOrder(chkXBreak, leXBreakEnd);
        QWidget::setTabOrder(leXBreakEnd, bRemoveXBreak);
        QWidget::setTabOrder(bRemoveXBreak, bAddYBreak);
        QWidget::setTabOrder(bAddYBreak, bRemoveYBreak);
        QWidget::setTabOrder(bRemoveYBreak, sbXBreakPosition);
        QWidget::setTabOrder(sbXBreakPosition, cbXBreakStyle);
        QWidget::setTabOrder(cbXBreakStyle, sbTop);
        QWidget::setTabOrder(sbTop, sbPaddingHorizontal);
        QWidget::setTabOrder(sbPaddingHorizontal, cbPaddingSymmetric);
        QWidget::setTabOrder(cbPaddingSymmetric, sbWidth);
        QWidget::setTabOrder(sbWidth, sbPaddingVertical);
        QWidget::setTabOrder(sbPaddingVertical, sbPaddingRight);
        QWidget::setTabOrder(sbPaddingRight, sbLeft);
        QWidget::setTabOrder(sbLeft, sbHeight);
        QWidget::setTabOrder(sbHeight, sbPaddingBottom);
        QWidget::setTabOrder(sbPaddingBottom, tbBorderTypeLeft);
        QWidget::setTabOrder(tbBorderTypeLeft, tbBorderTypeTop);
        QWidget::setTabOrder(tbBorderTypeTop, tbBorderTypeRight);
        QWidget::setTabOrder(tbBorderTypeRight, tbBorderTypeBottom);
        QWidget::setTabOrder(tbBorderTypeBottom, sbBorderCornerRadius);

        retranslateUi(CartesianPlotDock);
        QObject::connect(tbAddPlotRange, SIGNAL(clicked()), CartesianPlotDock, SLOT(addPlotRange()));
        QObject::connect(tbRemovePlotRange, SIGNAL(clicked()), CartesianPlotDock, SLOT(removePlotRange()));
        QObject::connect(tbAddXRange, SIGNAL(clicked()), CartesianPlotDock, SLOT(addXRange()));
        QObject::connect(tbRemoveXRange, SIGNAL(clicked()), CartesianPlotDock, SLOT(removeXRange()));
        QObject::connect(tbAddYRange, SIGNAL(clicked()), CartesianPlotDock, SLOT(addYRange()));
        QObject::connect(tbRemoveYRange, SIGNAL(clicked()), CartesianPlotDock, SLOT(removeYRange()));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(CartesianPlotDock);
    } // setupUi

    void retranslateUi(QWidget *CartesianPlotDock)
    {
        QTableWidgetItem *___qtablewidgetitem = twPlotRanges->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("X Range", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = twPlotRanges->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Y Range", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = twPlotRanges->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Default", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = twPlotRanges->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("Name", nullptr));
#if QT_CONFIG(tooltip)
        twPlotRanges->setToolTip(tr2i18n("List of plot ranges", nullptr));
#endif // QT_CONFIG(tooltip)
        QTableWidgetItem *___qtablewidgetitem4 = twYRanges->horizontalHeaderItem(0);
        ___qtablewidgetitem4->setText(tr2i18n("Auto", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = twYRanges->horizontalHeaderItem(1);
        ___qtablewidgetitem5->setText(tr2i18n("Format", nullptr));
        QTableWidgetItem *___qtablewidgetitem6 = twYRanges->horizontalHeaderItem(2);
        ___qtablewidgetitem6->setText(tr2i18n("Start", nullptr));
        QTableWidgetItem *___qtablewidgetitem7 = twYRanges->horizontalHeaderItem(3);
        ___qtablewidgetitem7->setText(tr2i18n("End", nullptr));
        QTableWidgetItem *___qtablewidgetitem8 = twYRanges->horizontalHeaderItem(4);
        ___qtablewidgetitem8->setText(tr2i18n("Scale", nullptr));
#if QT_CONFIG(tooltip)
        twYRanges->setToolTip(tr2i18n("list of y ranges", nullptr));
#endif // QT_CONFIG(tooltip)
        lRangePoints->setText(tr2i18n("Points:", nullptr));
#if QT_CONFIG(tooltip)
        tbAddXRange->setToolTip(tr2i18n("<html><head/><body><p>Add a new x range</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tbRemoveXRange->setToolTip(tr2i18n("Remove the current selected x range", nullptr));
#endif // QT_CONFIG(tooltip)
        tbRemoveXRange->setText(tr2i18n("...", nullptr));
        lRangeType->setText(tr2i18n("Data Range:", nullptr));
        QTableWidgetItem *___qtablewidgetitem9 = twXRanges->horizontalHeaderItem(0);
        ___qtablewidgetitem9->setText(tr2i18n("Auto", nullptr));
        QTableWidgetItem *___qtablewidgetitem10 = twXRanges->horizontalHeaderItem(1);
        ___qtablewidgetitem10->setText(tr2i18n("Format", nullptr));
        QTableWidgetItem *___qtablewidgetitem11 = twXRanges->horizontalHeaderItem(2);
        ___qtablewidgetitem11->setText(tr2i18n("Start", nullptr));
        QTableWidgetItem *___qtablewidgetitem12 = twXRanges->horizontalHeaderItem(3);
        ___qtablewidgetitem12->setText(tr2i18n("End", nullptr));
        QTableWidgetItem *___qtablewidgetitem13 = twXRanges->horizontalHeaderItem(4);
        ___qtablewidgetitem13->setText(tr2i18n("Scale", nullptr));
#if QT_CONFIG(tooltip)
        twXRanges->setToolTip(tr2i18n("List of x ranges", nullptr));
#endif // QT_CONFIG(tooltip)
        cbNiceExtend->setText(tr2i18n("Auto", nullptr));
#if QT_CONFIG(tooltip)
        tbAddPlotRange->setToolTip(tr2i18n("Add new plot range", nullptr));
#endif // QT_CONFIG(tooltip)
        tbAddPlotRange->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        tbRemovePlotRange->setToolTip(tr2i18n("Remove current plot range", nullptr));
#endif // QT_CONFIG(tooltip)
        tbRemovePlotRange->setText(tr2i18n("...", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        tbAddYRange->setToolTip(tr2i18n("Add a new y range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tbRemoveYRange->setToolTip(tr2i18n("remove the current selected y range", nullptr));
#endif // QT_CONFIG(tooltip)
        lNiceExtend->setText(tr2i18n("Extend:", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabTitle), tr2i18n("Title", nullptr));
        lBottomMargin->setText(tr2i18n("Width:", nullptr));
        lPaddingHorizontal->setText(tr2i18n("Horizontal:", nullptr));
#if QT_CONFIG(tooltip)
        sbTop->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbTop->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbTop->setSuffix(tr2i18n(" cm", nullptr));
        lGeometry->setText(tr2i18n("Geometry", nullptr));
#if QT_CONFIG(tooltip)
        sbPaddingHorizontal->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPaddingHorizontal->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbPaddingHorizontal->setSuffix(tr2i18n(" cm", nullptr));
        lPadding->setText(tr2i18n("Padding", nullptr));
        cbPaddingSymmetric->setText(QString());
        label_8->setText(tr2i18n("Symmetric:", nullptr));
        lPaddingVerticalDown->setText(tr2i18n("Bottom:", nullptr));
#if QT_CONFIG(tooltip)
        sbWidth->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbWidth->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbWidth->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        sbPaddingVertical->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPaddingVertical->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbPaddingVertical->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        sbPaddingRight->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPaddingRight->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbPaddingRight->setSuffix(tr2i18n(" cm", nullptr));
        lRightMargin->setText(tr2i18n("Height:", nullptr));
#if QT_CONFIG(tooltip)
        sbLeft->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLeft->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLeft->setSuffix(tr2i18n(" cm", nullptr));
        lTopMargin->setText(tr2i18n("Left:", nullptr));
        lLeftMargin->setText(tr2i18n("Top:", nullptr));
        lPaddingHorizontalRight->setText(tr2i18n("Right:", nullptr));
#if QT_CONFIG(tooltip)
        sbHeight->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbHeight->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbHeight->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        sbPaddingBottom->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPaddingBottom->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbPaddingBottom->setSuffix(tr2i18n(" cm", nullptr));
        lPaddingVertical->setText(tr2i18n("Vertical:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabLayout_2), tr2i18n("Layout", nullptr));
        lYBreakEnd->setText(tr2i18n("To:", nullptr));
        lXBreakEnd->setText(tr2i18n("To:", nullptr));
        chkXBreak->setText(QString());
#if QT_CONFIG(tooltip)
        bAddXBreak->setToolTip(tr2i18n("Add new scale breaking", nullptr));
#endif // QT_CONFIG(tooltip)
        bAddXBreak->setText(QString());
#if QT_CONFIG(tooltip)
        bRemoveXBreak->setToolTip(tr2i18n("Remove scale breaking", nullptr));
#endif // QT_CONFIG(tooltip)
        bRemoveXBreak->setText(QString());
#if QT_CONFIG(tooltip)
        cbXBreak->setToolTip(tr2i18n("Current scale breaking", nullptr));
#endif // QT_CONFIG(tooltip)
        lYBreakPosition->setText(tr2i18n("Position:", nullptr));
        lXBreakStyle->setText(tr2i18n("Style:", nullptr));
        sbYBreakPosition->setSuffix(tr2i18n(" %", nullptr));
        label_3->setText(tr2i18n("Y-Range", nullptr));
        label_2->setText(tr2i18n("Enabled:", nullptr));
        label_4->setText(tr2i18n("Enabled:", nullptr));
#if QT_CONFIG(tooltip)
        bAddYBreak->setToolTip(tr2i18n("Add new scale breaking", nullptr));
#endif // QT_CONFIG(tooltip)
        bAddYBreak->setText(QString());
#if QT_CONFIG(tooltip)
        bRemoveYBreak->setToolTip(tr2i18n("Remove scale breaking", nullptr));
#endif // QT_CONFIG(tooltip)
        bRemoveYBreak->setText(QString());
#if QT_CONFIG(tooltip)
        cbYBreak->setToolTip(tr2i18n("Current scale breaking", nullptr));
#endif // QT_CONFIG(tooltip)
        lXBreakStart->setText(tr2i18n("From:", nullptr));
        label->setText(tr2i18n("X-Range", nullptr));
        lYBreakStyle->setText(tr2i18n("Style:", nullptr));
        chkYBreak->setText(QString());
        sbXBreakPosition->setSuffix(tr2i18n(" %", nullptr));
        lXBreakPosition->setText(tr2i18n("Position:", nullptr));
        lYBreakStart->setText(tr2i18n("From:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabScales), tr2i18n("Range Breaks", nullptr));
        label_10->setText(tr2i18n("Type:", nullptr));
        lBorder->setText(tr2i18n("Border", nullptr));
#if QT_CONFIG(tooltip)
        sbBorderCornerRadius->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbBorderCornerRadius->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbBorderCornerRadius->setSuffix(tr2i18n(" cm", nullptr));
        lBackground->setText(tr2i18n("Background", nullptr));
        lBorderCornerRadius->setText(tr2i18n("Corner Radius:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabPlotArea), tr2i18n("Area", nullptr));
        label_9->setText(tr2i18n("Line", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabCursor), tr2i18n("Cursor", nullptr));
        (void)CartesianPlotDock;
    } // retranslateUi

};

namespace Ui {
    class CartesianPlotDock: public Ui_CartesianPlotDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CARTESIANPLOTDOCK_H

