/****************************************************************************
** Meta object code from reading C++ file 'CartesianPlotLegend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/plots/cartesian/CartesianPlotLegend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CartesianPlotLegend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19CartesianPlotLegendE_t {};
} // unnamed namespace

template <> constexpr inline auto CartesianPlotLegend::qt_create_metaobjectdata<qt_meta_tag_ZN19CartesianPlotLegendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CartesianPlotLegend",
        "labelFontChanged",
        "",
        "QFont&",
        "usePlotColorChanged",
        "labelColorChanged",
        "QColor&",
        "labelColumnMajorChanged",
        "lineSymbolWidthChanged",
        "borderCornerRadiusChanged",
        "layoutTopMarginChanged",
        "layoutBottomMarginChanged",
        "layoutLeftMarginChanged",
        "layoutRightMarginChanged",
        "layoutVerticalSpacingChanged",
        "layoutHorizontalSpacingChanged",
        "layoutColumnCountChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'labelFontChanged'
        QtMocHelpers::SignalData<void(QFont &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'usePlotColorChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'labelColorChanged'
        QtMocHelpers::SignalData<void(QColor &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'labelColumnMajorChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'lineSymbolWidthChanged'
        QtMocHelpers::SignalData<void(float)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'borderCornerRadiusChanged'
        QtMocHelpers::SignalData<void(float)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'layoutTopMarginChanged'
        QtMocHelpers::SignalData<void(float)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'layoutBottomMarginChanged'
        QtMocHelpers::SignalData<void(float)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'layoutLeftMarginChanged'
        QtMocHelpers::SignalData<void(float)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'layoutRightMarginChanged'
        QtMocHelpers::SignalData<void(float)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'layoutVerticalSpacingChanged'
        QtMocHelpers::SignalData<void(float)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'layoutHorizontalSpacingChanged'
        QtMocHelpers::SignalData<void(float)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'layoutColumnCountChanged'
        QtMocHelpers::SignalData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CartesianPlotLegend, qt_meta_tag_ZN19CartesianPlotLegendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CartesianPlotLegend::staticMetaObject = { {
    QMetaObject::SuperData::link<WorksheetElement::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CartesianPlotLegendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CartesianPlotLegendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19CartesianPlotLegendE_t>.metaTypes,
    nullptr
} };

void CartesianPlotLegend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CartesianPlotLegend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->labelFontChanged((*reinterpret_cast<std::add_pointer_t<QFont&>>(_a[1]))); break;
        case 1: _t->usePlotColorChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->labelColorChanged((*reinterpret_cast<std::add_pointer_t<QColor&>>(_a[1]))); break;
        case 3: _t->labelColumnMajorChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->lineSymbolWidthChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 5: _t->borderCornerRadiusChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 6: _t->layoutTopMarginChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 7: _t->layoutBottomMarginChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 8: _t->layoutLeftMarginChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 9: _t->layoutRightMarginChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 10: _t->layoutVerticalSpacingChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 11: _t->layoutHorizontalSpacingChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 12: _t->layoutColumnCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(QFont & )>(_a, &CartesianPlotLegend::labelFontChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(bool )>(_a, &CartesianPlotLegend::usePlotColorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(QColor & )>(_a, &CartesianPlotLegend::labelColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(bool )>(_a, &CartesianPlotLegend::labelColumnMajorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(float )>(_a, &CartesianPlotLegend::lineSymbolWidthChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(float )>(_a, &CartesianPlotLegend::borderCornerRadiusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(float )>(_a, &CartesianPlotLegend::layoutTopMarginChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(float )>(_a, &CartesianPlotLegend::layoutBottomMarginChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(float )>(_a, &CartesianPlotLegend::layoutLeftMarginChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(float )>(_a, &CartesianPlotLegend::layoutRightMarginChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(float )>(_a, &CartesianPlotLegend::layoutVerticalSpacingChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(float )>(_a, &CartesianPlotLegend::layoutHorizontalSpacingChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegend::*)(int )>(_a, &CartesianPlotLegend::layoutColumnCountChanged, 12))
            return;
    }
}

const QMetaObject *CartesianPlotLegend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CartesianPlotLegend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CartesianPlotLegendE_t>.strings))
        return static_cast<void*>(this);
    return WorksheetElement::qt_metacast(_clname);
}

int CartesianPlotLegend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WorksheetElement::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void CartesianPlotLegend::labelFontChanged(QFont & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void CartesianPlotLegend::usePlotColorChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void CartesianPlotLegend::labelColorChanged(QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void CartesianPlotLegend::labelColumnMajorChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void CartesianPlotLegend::lineSymbolWidthChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void CartesianPlotLegend::borderCornerRadiusChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void CartesianPlotLegend::layoutTopMarginChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void CartesianPlotLegend::layoutBottomMarginChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void CartesianPlotLegend::layoutLeftMarginChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void CartesianPlotLegend::layoutRightMarginChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void CartesianPlotLegend::layoutVerticalSpacingChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void CartesianPlotLegend::layoutHorizontalSpacingChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void CartesianPlotLegend::layoutColumnCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}
QT_WARNING_POP
