/********************************************************************************
** Form generated from reading UI file 'matrixfunctionwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MATRIXFUNCTIONWIDGET_H
#define UI_MATRIXFUNCTIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ExpressionTextEdit.h"

QT_BEGIN_NAMESPACE

class Ui_MatrixFunctionWidget
{
public:
    QGridLayout *gridLayout_2;
    QLabel *lXInfo;
    QLabel *lYInfo;
    QFrame *frame;
    QGridLayout *gridLayout;
    ExpressionTextEdit *teEquation;
    QToolButton *tbFunctions;
    QToolButton *tbConstants;
    QSpacerItem *verticalSpacer;
    QLabel *lY;
    QLabel *lX;
    QLabel *lZ;

    void setupUi(QWidget *MatrixFunctionWidget)
    {
        if (MatrixFunctionWidget->objectName().isEmpty())
            MatrixFunctionWidget->setObjectName("MatrixFunctionWidget");
        MatrixFunctionWidget->resize(273, 178);
        gridLayout_2 = new QGridLayout(MatrixFunctionWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        lXInfo = new QLabel(MatrixFunctionWidget);
        lXInfo->setObjectName("lXInfo");

        gridLayout_2->addWidget(lXInfo, 0, 2, 1, 1);

        lYInfo = new QLabel(MatrixFunctionWidget);
        lYInfo->setObjectName("lYInfo");

        gridLayout_2->addWidget(lYInfo, 1, 2, 1, 1);

        frame = new QFrame(MatrixFunctionWidget);
        frame->setObjectName("frame");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy);
        frame->setMaximumSize(QSize(16777215, 16777215));
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Raised);
        gridLayout = new QGridLayout(frame);
        gridLayout->setSpacing(0);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        teEquation = new ExpressionTextEdit(frame);
        teEquation->setObjectName("teEquation");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(teEquation->sizePolicy().hasHeightForWidth());
        teEquation->setSizePolicy(sizePolicy1);
        teEquation->setMaximumSize(QSize(16777215, 16777215));

        gridLayout->addWidget(teEquation, 0, 0, 3, 1);

        tbFunctions = new QToolButton(frame);
        tbFunctions->setObjectName("tbFunctions");

        gridLayout->addWidget(tbFunctions, 0, 1, 1, 1);

        tbConstants = new QToolButton(frame);
        tbConstants->setObjectName("tbConstants");

        gridLayout->addWidget(tbConstants, 1, 1, 1, 1);


        gridLayout_2->addWidget(frame, 2, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 60, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 3, 0, 1, 1);

        lY = new QLabel(MatrixFunctionWidget);
        lY->setObjectName("lY");
        QFont font;
        font.setBold(true);
        lY->setFont(font);
        lY->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(lY, 1, 0, 1, 2);

        lX = new QLabel(MatrixFunctionWidget);
        lX->setObjectName("lX");
        lX->setFont(font);
        lX->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(lX, 0, 0, 1, 2);

        lZ = new QLabel(MatrixFunctionWidget);
        lZ->setObjectName("lZ");
        lZ->setFont(font);
        lZ->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        gridLayout_2->addWidget(lZ, 2, 0, 1, 2);


        retranslateUi(MatrixFunctionWidget);

        QMetaObject::connectSlotsByName(MatrixFunctionWidget);
    } // setupUi

    void retranslateUi(QWidget *MatrixFunctionWidget)
    {
        lXInfo->setText(QString());
        lYInfo->setText(QString());
#if QT_CONFIG(tooltip)
        tbFunctions->setToolTip(tr2i18n("Functions", nullptr));
#endif // QT_CONFIG(tooltip)
        tbFunctions->setText(QString());
#if QT_CONFIG(tooltip)
        tbConstants->setToolTip(tr2i18n("Constants", nullptr));
#endif // QT_CONFIG(tooltip)
        tbConstants->setText(QString());
        lY->setText(tr2i18n("y = ", nullptr));
        lX->setText(tr2i18n("x = ", nullptr));
        lZ->setText(tr2i18n("f(x,y) = ", nullptr));
        (void)MatrixFunctionWidget;
    } // retranslateUi

};

namespace Ui {
    class MatrixFunctionWidget: public Ui_MatrixFunctionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MATRIXFUNCTIONWIDGET_H

