/********************************************************************************
** Form generated from reading UI file 'constantswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONSTANTSWIDGET_H
#define UI_CONSTANTSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConstantsWidget
{
public:
    QGridLayout *gridLayout;
    QFrame *line;
    QListWidget *lwConstants;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QLabel *lValue;
    QLineEdit *leValue;
    QLabel *lUnit;
    QPushButton *bInsert;
    QPushButton *bCancel;
    QSpacerItem *horizontalSpacer;
    QLineEdit *leFilter;
    QComboBox *cbGroup;

    void setupUi(QWidget *ConstantsWidget)
    {
        if (ConstantsWidget->objectName().isEmpty())
            ConstantsWidget->setObjectName("ConstantsWidget");
        ConstantsWidget->resize(296, 299);
        gridLayout = new QGridLayout(ConstantsWidget);
        gridLayout->setObjectName("gridLayout");
        line = new QFrame(ConstantsWidget);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 1, 0, 1, 4);

        lwConstants = new QListWidget(ConstantsWidget);
        lwConstants->setObjectName("lwConstants");

        gridLayout->addWidget(lwConstants, 3, 0, 1, 4);

        frame = new QFrame(ConstantsWidget);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        lValue = new QLabel(frame);
        lValue->setObjectName("lValue");
        QFont font;
        font.setBold(true);
        lValue->setFont(font);

        horizontalLayout->addWidget(lValue);

        leValue = new QLineEdit(frame);
        leValue->setObjectName("leValue");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(leValue->sizePolicy().hasHeightForWidth());
        leValue->setSizePolicy(sizePolicy);
        leValue->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        leValue->setReadOnly(true);

        horizontalLayout->addWidget(leValue);

        lUnit = new QLabel(frame);
        lUnit->setObjectName("lUnit");

        horizontalLayout->addWidget(lUnit);


        gridLayout->addWidget(frame, 4, 0, 1, 4);

        bInsert = new QPushButton(ConstantsWidget);
        bInsert->setObjectName("bInsert");

        gridLayout->addWidget(bInsert, 5, 2, 1, 1);

        bCancel = new QPushButton(ConstantsWidget);
        bCancel->setObjectName("bCancel");

        gridLayout->addWidget(bCancel, 5, 3, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 5, 0, 1, 2);

        leFilter = new QLineEdit(ConstantsWidget);
        leFilter->setObjectName("leFilter");
        leFilter->setClearButtonEnabled(true);

        gridLayout->addWidget(leFilter, 0, 0, 1, 4);

        cbGroup = new QComboBox(ConstantsWidget);
        cbGroup->setObjectName("cbGroup");

        gridLayout->addWidget(cbGroup, 2, 0, 1, 4);


        retranslateUi(ConstantsWidget);

        QMetaObject::connectSlotsByName(ConstantsWidget);
    } // setupUi

    void retranslateUi(QWidget *ConstantsWidget)
    {
        lValue->setText(tr2i18n("Value:", nullptr));
        lUnit->setText(QString());
        bInsert->setText(tr2i18n("Insert", nullptr));
        bCancel->setText(tr2i18n("Cancel", nullptr));
        leFilter->setPlaceholderText(tr2i18n("Enter search term here", nullptr));
        (void)ConstantsWidget;
    } // retranslateUi

};

namespace Ui {
    class ConstantsWidget: public Ui_ConstantsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONSTANTSWIDGET_H

