/****************************************************************************
** Meta object code from reading C++ file 'ProcessBehaviorChartDock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/dockwidgets/ProcessBehaviorChartDock.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ProcessBehaviorChartDock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24ProcessBehaviorChartDockE_t {};
} // unnamed namespace

template <> constexpr inline auto ProcessBehaviorChartDock::qt_create_metaobjectdata<qt_meta_tag_ZN24ProcessBehaviorChartDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProcessBehaviorChartDock",
        "info",
        "",
        "dataColumnChanged",
        "QModelIndex",
        "data2ColumnChanged",
        "typeChanged",
        "limitsMetricChanged",
        "sampleSizeChanged",
        "maxUpperLimitChanged",
        "minLowerLimitChanged",
        "exactLimitsEnabledChanged",
        "updateLowerLimitWidgets",
        "labelsEnabledChanged",
        "labelsPrecisionChanged",
        "labelsAutoPrecisionChanged",
        "labelsFontChanged",
        "QFont",
        "labelsFontColorChanged",
        "QColor",
        "labelsBackgroundColorChanged",
        "labelsBorderShapeChanged",
        "plotDataColumnChanged",
        "const AbstractColumn*",
        "plotData2ColumnChanged",
        "plotTypeChanged",
        "ProcessBehaviorChart::Type",
        "plotLimitsMetricChanged",
        "ProcessBehaviorChart::LimitsMetric",
        "plotSampleSizeChanged",
        "plotMaxUpperLimitChanged",
        "plotMinLowerLimitChanged",
        "plotExactLimitsEnabledChanged",
        "plotLabelsEnabledChanged",
        "plotLabelsAutoPrecisionChanged",
        "plotLabelsPrecisionChanged",
        "plotLabelsFontChanged",
        "plotLabelsFontColorChanged",
        "plotLabelsBackgroundColorChanged",
        "plotLabelsBorderShapeChanged",
        "TextLabel::BorderShape",
        "showStatusInfo",
        "loadConfigFromTemplate",
        "KConfig&",
        "saveConfigAsTemplate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'info'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'dataColumnChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'data2ColumnChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'typeChanged'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'limitsMetricChanged'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'sampleSizeChanged'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'maxUpperLimitChanged'
        QtMocHelpers::SlotData<void(const QString &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'minLowerLimitChanged'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'exactLimitsEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'updateLowerLimitWidgets'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'labelsEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'labelsPrecisionChanged'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'labelsAutoPrecisionChanged'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'labelsFontChanged'
        QtMocHelpers::SlotData<void(const QFont &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Slot 'labelsFontColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Slot 'labelsBackgroundColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Slot 'labelsBorderShapeChanged'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'plotDataColumnChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 2 },
        }}),
        // Slot 'plotData2ColumnChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 2 },
        }}),
        // Slot 'plotTypeChanged'
        QtMocHelpers::SlotData<void(ProcessBehaviorChart::Type)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
        // Slot 'plotLimitsMetricChanged'
        QtMocHelpers::SlotData<void(ProcessBehaviorChart::LimitsMetric)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 2 },
        }}),
        // Slot 'plotSampleSizeChanged'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'plotMaxUpperLimitChanged'
        QtMocHelpers::SlotData<void(double)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'plotMinLowerLimitChanged'
        QtMocHelpers::SlotData<void(double)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'plotExactLimitsEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'plotLabelsEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'plotLabelsAutoPrecisionChanged'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'plotLabelsPrecisionChanged'
        QtMocHelpers::SlotData<void(int)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'plotLabelsFontChanged'
        QtMocHelpers::SlotData<void(const QFont &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Slot 'plotLabelsFontColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Slot 'plotLabelsBackgroundColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Slot 'plotLabelsBorderShapeChanged'
        QtMocHelpers::SlotData<void(TextLabel::BorderShape)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 2 },
        }}),
        // Slot 'showStatusInfo'
        QtMocHelpers::SlotData<void(const QString &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'loadConfigFromTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 43, 2 },
        }}),
        // Slot 'saveConfigAsTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 43, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProcessBehaviorChartDock, qt_meta_tag_ZN24ProcessBehaviorChartDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProcessBehaviorChartDock::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseDock::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ProcessBehaviorChartDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ProcessBehaviorChartDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24ProcessBehaviorChartDockE_t>.metaTypes,
    nullptr
} };

void ProcessBehaviorChartDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProcessBehaviorChartDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->dataColumnChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 2: _t->data2ColumnChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 3: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->limitsMetricChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->sampleSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->maxUpperLimitChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->minLowerLimitChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->exactLimitsEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->updateLowerLimitWidgets(); break;
        case 10: _t->labelsEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->labelsPrecisionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->labelsAutoPrecisionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->labelsFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 14: _t->labelsFontColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 15: _t->labelsBackgroundColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 16: _t->labelsBorderShapeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->plotDataColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 18: _t->plotData2ColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 19: _t->plotTypeChanged((*reinterpret_cast<std::add_pointer_t<ProcessBehaviorChart::Type>>(_a[1]))); break;
        case 20: _t->plotLimitsMetricChanged((*reinterpret_cast<std::add_pointer_t<ProcessBehaviorChart::LimitsMetric>>(_a[1]))); break;
        case 21: _t->plotSampleSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->plotMaxUpperLimitChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 23: _t->plotMinLowerLimitChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 24: _t->plotExactLimitsEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->plotLabelsEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->plotLabelsAutoPrecisionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->plotLabelsPrecisionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->plotLabelsFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 29: _t->plotLabelsFontColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 30: _t->plotLabelsBackgroundColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 31: _t->plotLabelsBorderShapeChanged((*reinterpret_cast<std::add_pointer_t<TextLabel::BorderShape>>(_a[1]))); break;
        case 32: _t->showStatusInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: _t->loadConfigFromTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        case 34: _t->saveConfigAsTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChartDock::*)(const QString & )>(_a, &ProcessBehaviorChartDock::info, 0))
            return;
    }
}

const QMetaObject *ProcessBehaviorChartDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProcessBehaviorChartDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ProcessBehaviorChartDockE_t>.strings))
        return static_cast<void*>(this);
    return BaseDock::qt_metacast(_clname);
}

int ProcessBehaviorChartDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseDock::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void ProcessBehaviorChartDock::info(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
