/********************************************************************************
** Form generated from reading UI file 'axisdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AXISDOCK_H
#define UI_AXISDOCK_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcolorbutton.h"
#include "kcombobox.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_AxisDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout_4;
    QSpacerItem *horizontalSpacer;
    QCheckBox *chkVisible;
    QLabel *lPosition;
    QLabel *lStartDateTime;
    QCheckBox *chkShowScaleOffset;
    QSpacerItem *verticalSpacer;
    QComboBox *cbRangeType;
    QHBoxLayout *horizontalLayout_4;
    NumberSpinBox *sbScalingFactor;
    QToolButton *tbUnityScale;
    QToolButton *tbUnityRange;
    QComboBox *cbPlotRanges;
    QLabel *lScale;
    QSpacerItem *verticalSpacer_3;
    QLabel *lZeroOffset;
    QLabel *lComment;
    QLabel *lEndDateTime;
    QHBoxLayout *horizontalLayout;
    KComboBox *cbPosition;
    NumberSpinBox *sbPosition;
    NumberSpinBox *sbPositionLogical;
    QSpacerItem *verticalSpacer_2;
    KComboBox *cbOrientation;
    QLabel *lPlotRange;
    QLabel *lStart;
    ResizableTextEdit *teComment;
    QHBoxLayout *horizontalLayout_3;
    NumberSpinBox *sbZeroOffset;
    QToolButton *tbOffsetLeft;
    QToolButton *tbOffsetCenter;
    QToolButton *tbOffsetRight;
    QLabel *lName;
    UTCDateTimeEdit *dateTimeEditStart;
    UTCDateTimeEdit *dateTimeEditEnd;
    TimedLineEdit *leName;
    QLabel *lScalingFactor;
    QLabel *lRangeType;
    QLabel *lOrientation;
    QLabel *lEnd;
    NumberSpinBox *sbStart;
    NumberSpinBox *sbEnd;
    QLabel *label;
    KColorButton *kcbAxisColor;
    QHBoxLayout *horizontalLayout_5;
    KComboBox *cbScale;
    QCheckBox *cbRangeScale;
    QWidget *tabTitle;
    QWidget *tabLine;
    QGridLayout *gridLayout_3;
    QSpacerItem *verticalSpacer_5;
    QLabel *lArrow;
    KComboBox *cbArrowType;
    KComboBox *cbArrowPosition;
    QLabel *lArrowSize;
    QSpacerItem *horizontalSpacer_2;
    QSpinBox *sbArrowSize;
    QLabel *lArrowType;
    QSpacerItem *verticalSpacer_11;
    QLabel *lArrowPosition;
    QLabel *lLine;
    QSpacerItem *verticalSpacer_13;
    QWidget *tabTicks;
    QGridLayout *gridLayout_5;
    QHBoxLayout *horizontalLayout_7;
    QSpinBox *sbMajorTicksNumber;
    QCheckBox *cbMajorTicksAutoNumber;
    KComboBox *cbMajorTicksDirection;
    QComboBox *cbMajorTicksStartType;
    NumberSpinBox *sbMajorTicksSpacingNumeric;
    QLabel *lMinorTicksType;
    QLabel *lMajorTicksNumber;
    QLabel *lMajorTickStartValue;
    QLabel *lMajorTicksSpacingNumeric;
    QSpacerItem *verticalSpacer_6;
    QLabel *lMajorTicks;
    QLabel *lMajorTicksIncrementDateTime;
    QLabel *lLabelsTextType;
    QLabel *lLabelsTextColumn;
    QSpacerItem *verticalSpacer_12;
    QLabel *lMinorTicksColumn;
    NumberSpinBox *sbMajorTickStartValue;
    QSpacerItem *horizontalSpacer_3;
    QLabel *lMajorTicksDirection;
    KComboBox *cbMajorTicksType;
    KComboBox *cbMinorTicksType;
    NumberSpinBox *sbMinorTicksSpacingNumeric;
    QLabel *lMinorTicksIncrementDateTime;
    QHBoxLayout *horizontalLayout_8;
    QSpinBox *sbMinorTicksNumber;
    QCheckBox *cbMinorTicksAutoNumber;
    QHBoxLayout *layoutMajorTickStartOffset;
    NumberSpinBox *sbMajorTickStartOffset;
    QToolButton *tbFirstTickData;
    QToolButton *tbFirstTickAuto;
    QLabel *lMajorTicksLength;
    NumberSpinBox *sbMajorTicksLength;
    QLabel *lMinorTicks;
    QLabel *lMinorTicksSpacingNumeric;
    QLabel *lMinorTicksLength;
    QSpacerItem *verticalSpacer_19;
    KComboBox *cbMinorTicksDirection;
    QLabel *lMajorTickStartOffset;
    QSpacerItem *verticalSpacer_20;
    QSpacerItem *verticalSpacer_4;
    QComboBox *cbLabelsTextType;
    QLabel *lMinorTicksDirection;
    QSpacerItem *verticalSpacer_10;
    QLabel *lMajorTicksType;
    QLabel *lMajorTicksStartType;
    QLabel *lMajorTicksColumn;
    QLabel *lMinorTicksNumber;
    NumberSpinBox *sbMinorTicksLength;
    QLabel *lMajorTickStartDateTime;
    UTCDateTimeEdit *sbMajorTickStartDateTime;
    QWidget *tabLabels;
    QGridLayout *gridLayout;
    QLabel *lLabelsPrecision;
    QFrame *frameLabelsPrecision;
    QHBoxLayout *horizontalLayout_2;
    QSpinBox *sbLabelsPrecision;
    QCheckBox *chkLabelsAutoPrecision;
    QLineEdit *leLabelsPrefix;
    QLabel *lMajorGrid_2;
    QSpinBox *sbLabelsRotation;
    QLabel *lLabelsPosition;
    QLabel *lLabelsRotation;
    QLabel *lLabelsFont;
    KFontRequester *kfrLabelsFont;
    QSpacerItem *verticalSpacer_7;
    QLabel *lLabelsSuffix;
    QLineEdit *leLabelsSuffix;
    QLabel *lLabelsOffset;
    KComboBox *cbLabelsPosition;
    KColorButton *kcbLabelsBackgroundColor;
    KColorButton *kcbLabelsFontColor;
    QLabel *lLabelsOpacity;
    QLabel *lLabelsDateTimeFormat;
    QLabel *lLabelsBackgroundColor;
    QSpinBox *sbLabelsOpacity;
    QLabel *label_4;
    QLabel *lLabelsBackground;
    QSpacerItem *horizontalSpacer_7;
    KComboBox *cbLabelsDateTimeFormat;
    QSpacerItem *verticalSpacer_14;
    QLabel *lLabelsFormat;
    QSpacerItem *verticalSpacer_9;
    QLabel *lLabelsBackgroundType;
    QLabel *lLabelsPrefix;
    QLabel *lLabelsColor;
    QLabel *lLabelsText;
    QComboBox *cbLabelsBackgroundType;
    QSpacerItem *verticalSpacer_8;
    NumberSpinBox *sbLabelsOffset;
    QFrame *frameLabelsFormat;
    QHBoxLayout *horizontalLayout_9;
    KComboBox *cbLabelsFormat;
    QCheckBox *chkLabelsFormatAuto;
    QWidget *tabGrid;
    QGridLayout *gridLayout_2;
    QSpacerItem *verticalSpacer_17;
    QSpacerItem *verticalSpacer_18;
    QLabel *lMinorGrid;
    QLabel *lMajorGrid;
    QSpacerItem *verticalSpacer_16;
    QSpacerItem *verticalSpacer_15;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *horizontalSpacer_5;

    void setupUi(QWidget *AxisDock)
    {
        if (AxisDock->objectName().isEmpty())
            AxisDock->setObjectName("AxisDock");
        AxisDock->resize(437, 948);
        AxisDock->setMaximumSize(QSize(16777215, 16777215));
        verticalLayout = new QVBoxLayout(AxisDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(AxisDock);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setEnabled(true);
        tabWidget->setMaximumSize(QSize(16777215, 16777215));
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout_4 = new QGridLayout(tabGeneral);
        gridLayout_4->setObjectName("gridLayout_4");
        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer, 0, 1, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout_4->addWidget(chkVisible, 22, 0, 1, 1);

        lPosition = new QLabel(tabGeneral);
        lPosition->setObjectName("lPosition");

        gridLayout_4->addWidget(lPosition, 4, 0, 1, 1);

        lStartDateTime = new QLabel(tabGeneral);
        lStartDateTime->setObjectName("lStartDateTime");

        gridLayout_4->addWidget(lStartDateTime, 14, 0, 1, 1);

        chkShowScaleOffset = new QCheckBox(tabGeneral);
        chkShowScaleOffset->setObjectName("chkShowScaleOffset");

        gridLayout_4->addWidget(chkShowScaleOffset, 19, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 75, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer, 21, 0, 1, 1);

        cbRangeType = new QComboBox(tabGeneral);
        cbRangeType->setObjectName("cbRangeType");

        gridLayout_4->addWidget(cbRangeType, 11, 2, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        sbScalingFactor = new NumberSpinBox(tabGeneral);
        sbScalingFactor->setObjectName("sbScalingFactor");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(sbScalingFactor->sizePolicy().hasHeightForWidth());
        sbScalingFactor->setSizePolicy(sizePolicy);
        sbScalingFactor->setProperty("feedback", QVariant(true));

        horizontalLayout_4->addWidget(sbScalingFactor);

        tbUnityScale = new QToolButton(tabGeneral);
        tbUnityScale->setObjectName("tbUnityScale");

        horizontalLayout_4->addWidget(tbUnityScale);

        tbUnityRange = new QToolButton(tabGeneral);
        tbUnityRange->setObjectName("tbUnityRange");

        horizontalLayout_4->addWidget(tbUnityRange);


        gridLayout_4->addLayout(horizontalLayout_4, 18, 2, 1, 1);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout_4->addWidget(cbPlotRanges, 20, 2, 1, 1);

        lScale = new QLabel(tabGeneral);
        lScale->setObjectName("lScale");

        gridLayout_4->addWidget(lScale, 8, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_3, 2, 0, 1, 1);

        lZeroOffset = new QLabel(tabGeneral);
        lZeroOffset->setObjectName("lZeroOffset");

        gridLayout_4->addWidget(lZeroOffset, 16, 0, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(lComment, 1, 0, 1, 1);

        lEndDateTime = new QLabel(tabGeneral);
        lEndDateTime->setObjectName("lEndDateTime");

        gridLayout_4->addWidget(lEndDateTime, 15, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        cbPosition = new KComboBox(tabGeneral);
        cbPosition->setObjectName("cbPosition");

        horizontalLayout->addWidget(cbPosition);

        sbPosition = new NumberSpinBox(tabGeneral);
        sbPosition->setObjectName("sbPosition");
        sizePolicy.setHeightForWidth(sbPosition->sizePolicy().hasHeightForWidth());
        sbPosition->setSizePolicy(sizePolicy);
        sbPosition->setProperty("feedback", QVariant(true));

        horizontalLayout->addWidget(sbPosition);

        sbPositionLogical = new NumberSpinBox(tabGeneral);
        sbPositionLogical->setObjectName("sbPositionLogical");
        sizePolicy.setHeightForWidth(sbPositionLogical->sizePolicy().hasHeightForWidth());
        sbPositionLogical->setSizePolicy(sizePolicy);
        sbPositionLogical->setProperty("feedback", QVariant(true));

        horizontalLayout->addWidget(sbPositionLogical);


        gridLayout_4->addLayout(horizontalLayout, 4, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_2, 10, 0, 1, 1);

        cbOrientation = new KComboBox(tabGeneral);
        cbOrientation->setObjectName("cbOrientation");

        gridLayout_4->addWidget(cbOrientation, 3, 2, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout_4->addWidget(lPlotRange, 20, 0, 1, 1);

        lStart = new QLabel(tabGeneral);
        lStart->setObjectName("lStart");

        gridLayout_4->addWidget(lStart, 12, 0, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout_4->addWidget(teComment, 1, 2, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        sbZeroOffset = new NumberSpinBox(tabGeneral);
        sbZeroOffset->setObjectName("sbZeroOffset");
        sizePolicy.setHeightForWidth(sbZeroOffset->sizePolicy().hasHeightForWidth());
        sbZeroOffset->setSizePolicy(sizePolicy);
        sbZeroOffset->setProperty("feedback", QVariant(true));

        horizontalLayout_3->addWidget(sbZeroOffset);

        tbOffsetLeft = new QToolButton(tabGeneral);
        tbOffsetLeft->setObjectName("tbOffsetLeft");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("align-horizontal-left")));
        tbOffsetLeft->setIcon(icon);

        horizontalLayout_3->addWidget(tbOffsetLeft);

        tbOffsetCenter = new QToolButton(tabGeneral);
        tbOffsetCenter->setObjectName("tbOffsetCenter");
        tbOffsetCenter->setText(QString::fromUtf8(""));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("align-horizontal-center")));
        tbOffsetCenter->setIcon(icon1);

        horizontalLayout_3->addWidget(tbOffsetCenter);

        tbOffsetRight = new QToolButton(tabGeneral);
        tbOffsetRight->setObjectName("tbOffsetRight");
        tbOffsetRight->setText(QString::fromUtf8(""));
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("align-horizontal-right")));
        tbOffsetRight->setIcon(icon2);

        horizontalLayout_3->addWidget(tbOffsetRight);


        gridLayout_4->addLayout(horizontalLayout_3, 16, 2, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout_4->addWidget(lName, 0, 0, 1, 1);

        dateTimeEditStart = new UTCDateTimeEdit(tabGeneral);
        dateTimeEditStart->setObjectName("dateTimeEditStart");
        dateTimeEditStart->setCalendarPopup(true);

        gridLayout_4->addWidget(dateTimeEditStart, 14, 2, 1, 1);

        dateTimeEditEnd = new UTCDateTimeEdit(tabGeneral);
        dateTimeEditEnd->setObjectName("dateTimeEditEnd");
        dateTimeEditEnd->setCalendarPopup(true);

        gridLayout_4->addWidget(dateTimeEditEnd, 15, 2, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(leName->sizePolicy().hasHeightForWidth());
        leName->setSizePolicy(sizePolicy1);

        gridLayout_4->addWidget(leName, 0, 2, 1, 1);

        lScalingFactor = new QLabel(tabGeneral);
        lScalingFactor->setObjectName("lScalingFactor");

        gridLayout_4->addWidget(lScalingFactor, 18, 0, 1, 1);

        lRangeType = new QLabel(tabGeneral);
        lRangeType->setObjectName("lRangeType");

        gridLayout_4->addWidget(lRangeType, 11, 0, 1, 1);

        lOrientation = new QLabel(tabGeneral);
        lOrientation->setObjectName("lOrientation");

        gridLayout_4->addWidget(lOrientation, 3, 0, 1, 1);

        lEnd = new QLabel(tabGeneral);
        lEnd->setObjectName("lEnd");

        gridLayout_4->addWidget(lEnd, 13, 0, 1, 1);

        sbStart = new NumberSpinBox(tabGeneral);
        sbStart->setObjectName("sbStart");
        sizePolicy.setHeightForWidth(sbStart->sizePolicy().hasHeightForWidth());
        sbStart->setSizePolicy(sizePolicy);
        sbStart->setProperty("feedback", QVariant(true));

        gridLayout_4->addWidget(sbStart, 12, 2, 1, 1);

        sbEnd = new NumberSpinBox(tabGeneral);
        sbEnd->setObjectName("sbEnd");
        sizePolicy.setHeightForWidth(sbEnd->sizePolicy().hasHeightForWidth());
        sbEnd->setSizePolicy(sizePolicy);
        sbEnd->setProperty("feedback", QVariant(true));

        gridLayout_4->addWidget(sbEnd, 13, 2, 1, 1);

        label = new QLabel(tabGeneral);
        label->setObjectName("label");

        gridLayout_4->addWidget(label, 9, 0, 1, 1);

        kcbAxisColor = new KColorButton(tabGeneral);
        kcbAxisColor->setObjectName("kcbAxisColor");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kcbAxisColor->sizePolicy().hasHeightForWidth());
        kcbAxisColor->setSizePolicy(sizePolicy2);

        gridLayout_4->addWidget(kcbAxisColor, 9, 2, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        cbScale = new KComboBox(tabGeneral);
        cbScale->setObjectName("cbScale");
        sizePolicy.setHeightForWidth(cbScale->sizePolicy().hasHeightForWidth());
        cbScale->setSizePolicy(sizePolicy);

        horizontalLayout_5->addWidget(cbScale);

        cbRangeScale = new QCheckBox(tabGeneral);
        cbRangeScale->setObjectName("cbRangeScale");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(cbRangeScale->sizePolicy().hasHeightForWidth());
        cbRangeScale->setSizePolicy(sizePolicy3);

        horizontalLayout_5->addWidget(cbRangeScale);


        gridLayout_4->addLayout(horizontalLayout_5, 8, 2, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabTitle = new QWidget();
        tabTitle->setObjectName("tabTitle");
        tabWidget->addTab(tabTitle, QString());
        tabLine = new QWidget();
        tabLine->setObjectName("tabLine");
        gridLayout_3 = new QGridLayout(tabLine);
        gridLayout_3->setObjectName("gridLayout_3");
        verticalSpacer_5 = new QSpacerItem(18, 368, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_5, 7, 0, 1, 1);

        lArrow = new QLabel(tabLine);
        lArrow->setObjectName("lArrow");
        QFont font;
        font.setBold(true);
        lArrow->setFont(font);

        gridLayout_3->addWidget(lArrow, 3, 0, 1, 1);

        cbArrowType = new KComboBox(tabLine);
        cbArrowType->setObjectName("cbArrowType");
        sizePolicy.setHeightForWidth(cbArrowType->sizePolicy().hasHeightForWidth());
        cbArrowType->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(cbArrowType, 4, 2, 1, 1);

        cbArrowPosition = new KComboBox(tabLine);
        cbArrowPosition->setObjectName("cbArrowPosition");
        sizePolicy.setHeightForWidth(cbArrowPosition->sizePolicy().hasHeightForWidth());
        cbArrowPosition->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(cbArrowPosition, 5, 2, 1, 1);

        lArrowSize = new QLabel(tabLine);
        lArrowSize->setObjectName("lArrowSize");

        gridLayout_3->addWidget(lArrowSize, 6, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 4, 1, 1, 1);

        sbArrowSize = new QSpinBox(tabLine);
        sbArrowSize->setObjectName("sbArrowSize");
        sizePolicy2.setHeightForWidth(sbArrowSize->sizePolicy().hasHeightForWidth());
        sbArrowSize->setSizePolicy(sizePolicy2);
        sbArrowSize->setMinimum(0);
        sbArrowSize->setMaximum(100);
        sbArrowSize->setSingleStep(10);
        sbArrowSize->setValue(50);

        gridLayout_3->addWidget(sbArrowSize, 6, 2, 1, 1);

        lArrowType = new QLabel(tabLine);
        lArrowType->setObjectName("lArrowType");

        gridLayout_3->addWidget(lArrowType, 4, 0, 1, 1);

        verticalSpacer_11 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_11, 1, 0, 1, 1);

        lArrowPosition = new QLabel(tabLine);
        lArrowPosition->setObjectName("lArrowPosition");

        gridLayout_3->addWidget(lArrowPosition, 5, 0, 1, 1);

        lLine = new QLabel(tabLine);
        lLine->setObjectName("lLine");
        lLine->setFont(font);

        gridLayout_3->addWidget(lLine, 0, 0, 1, 1);

        verticalSpacer_13 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_13, 2, 0, 1, 1);

        tabWidget->addTab(tabLine, QString());
        tabTicks = new QWidget();
        tabTicks->setObjectName("tabTicks");
        gridLayout_5 = new QGridLayout(tabTicks);
        gridLayout_5->setObjectName("gridLayout_5");
        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        sbMajorTicksNumber = new QSpinBox(tabTicks);
        sbMajorTicksNumber->setObjectName("sbMajorTicksNumber");
        sizePolicy.setHeightForWidth(sbMajorTicksNumber->sizePolicy().hasHeightForWidth());
        sbMajorTicksNumber->setSizePolicy(sizePolicy);

        horizontalLayout_7->addWidget(sbMajorTicksNumber);

        cbMajorTicksAutoNumber = new QCheckBox(tabTicks);
        cbMajorTicksAutoNumber->setObjectName("cbMajorTicksAutoNumber");

        horizontalLayout_7->addWidget(cbMajorTicksAutoNumber);


        gridLayout_5->addLayout(horizontalLayout_7, 3, 2, 1, 1);

        cbMajorTicksDirection = new KComboBox(tabTicks);
        cbMajorTicksDirection->setObjectName("cbMajorTicksDirection");
        sizePolicy.setHeightForWidth(cbMajorTicksDirection->sizePolicy().hasHeightForWidth());
        cbMajorTicksDirection->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(cbMajorTicksDirection, 1, 2, 1, 1);

        cbMajorTicksStartType = new QComboBox(tabTicks);
        cbMajorTicksStartType->setObjectName("cbMajorTicksStartType");

        gridLayout_5->addWidget(cbMajorTicksStartType, 6, 2, 1, 1);

        sbMajorTicksSpacingNumeric = new NumberSpinBox(tabTicks);
        sbMajorTicksSpacingNumeric->setObjectName("sbMajorTicksSpacingNumeric");
        sizePolicy.setHeightForWidth(sbMajorTicksSpacingNumeric->sizePolicy().hasHeightForWidth());
        sbMajorTicksSpacingNumeric->setSizePolicy(sizePolicy);
        sbMajorTicksSpacingNumeric->setProperty("feedback", QVariant(true));

        gridLayout_5->addWidget(sbMajorTicksSpacingNumeric, 4, 2, 1, 1);

        lMinorTicksType = new QLabel(tabTicks);
        lMinorTicksType->setObjectName("lMinorTicksType");

        gridLayout_5->addWidget(lMinorTicksType, 19, 0, 1, 1);

        lMajorTicksNumber = new QLabel(tabTicks);
        lMajorTicksNumber->setObjectName("lMajorTicksNumber");

        gridLayout_5->addWidget(lMajorTicksNumber, 3, 0, 1, 1);

        lMajorTickStartValue = new QLabel(tabTicks);
        lMajorTickStartValue->setObjectName("lMajorTickStartValue");

        gridLayout_5->addWidget(lMajorTickStartValue, 7, 0, 1, 1);

        lMajorTicksSpacingNumeric = new QLabel(tabTicks);
        lMajorTicksSpacingNumeric->setObjectName("lMajorTicksSpacingNumeric");

        gridLayout_5->addWidget(lMajorTicksSpacingNumeric, 4, 0, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_5->addItem(verticalSpacer_6, 13, 0, 1, 1);

        lMajorTicks = new QLabel(tabTicks);
        lMajorTicks->setObjectName("lMajorTicks");
        lMajorTicks->setFont(font);

        gridLayout_5->addWidget(lMajorTicks, 0, 0, 1, 1);

        lMajorTicksIncrementDateTime = new QLabel(tabTicks);
        lMajorTicksIncrementDateTime->setObjectName("lMajorTicksIncrementDateTime");

        gridLayout_5->addWidget(lMajorTicksIncrementDateTime, 5, 0, 1, 1);

        lLabelsTextType = new QLabel(tabTicks);
        lLabelsTextType->setObjectName("lLabelsTextType");

        gridLayout_5->addWidget(lLabelsTextType, 11, 0, 1, 1);

        lLabelsTextColumn = new QLabel(tabTicks);
        lLabelsTextColumn->setObjectName("lLabelsTextColumn");

        gridLayout_5->addWidget(lLabelsTextColumn, 12, 0, 1, 1);

        verticalSpacer_12 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_5->addItem(verticalSpacer_12, 24, 0, 1, 1);

        lMinorTicksColumn = new QLabel(tabTicks);
        lMinorTicksColumn->setObjectName("lMinorTicksColumn");

        gridLayout_5->addWidget(lMinorTicksColumn, 23, 0, 1, 1);

        sbMajorTickStartValue = new NumberSpinBox(tabTicks);
        sbMajorTickStartValue->setObjectName("sbMajorTickStartValue");
        sizePolicy.setHeightForWidth(sbMajorTickStartValue->sizePolicy().hasHeightForWidth());
        sbMajorTickStartValue->setSizePolicy(sizePolicy);
        sbMajorTickStartValue->setProperty("feedback", QVariant(true));

        gridLayout_5->addWidget(sbMajorTickStartValue, 7, 2, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(10, 24, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_3, 1, 1, 1, 1);

        lMajorTicksDirection = new QLabel(tabTicks);
        lMajorTicksDirection->setObjectName("lMajorTicksDirection");

        gridLayout_5->addWidget(lMajorTicksDirection, 1, 0, 1, 1);

        cbMajorTicksType = new KComboBox(tabTicks);
        cbMajorTicksType->setObjectName("cbMajorTicksType");
        sizePolicy.setHeightForWidth(cbMajorTicksType->sizePolicy().hasHeightForWidth());
        cbMajorTicksType->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(cbMajorTicksType, 2, 2, 1, 1);

        cbMinorTicksType = new KComboBox(tabTicks);
        cbMinorTicksType->setObjectName("cbMinorTicksType");

        gridLayout_5->addWidget(cbMinorTicksType, 19, 2, 1, 1);

        sbMinorTicksSpacingNumeric = new NumberSpinBox(tabTicks);
        sbMinorTicksSpacingNumeric->setObjectName("sbMinorTicksSpacingNumeric");
        sizePolicy.setHeightForWidth(sbMinorTicksSpacingNumeric->sizePolicy().hasHeightForWidth());
        sbMinorTicksSpacingNumeric->setSizePolicy(sizePolicy);
        sbMinorTicksSpacingNumeric->setProperty("feedback", QVariant(true));

        gridLayout_5->addWidget(sbMinorTicksSpacingNumeric, 21, 2, 1, 1);

        lMinorTicksIncrementDateTime = new QLabel(tabTicks);
        lMinorTicksIncrementDateTime->setObjectName("lMinorTicksIncrementDateTime");

        gridLayout_5->addWidget(lMinorTicksIncrementDateTime, 22, 0, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        sbMinorTicksNumber = new QSpinBox(tabTicks);
        sbMinorTicksNumber->setObjectName("sbMinorTicksNumber");
        sizePolicy.setHeightForWidth(sbMinorTicksNumber->sizePolicy().hasHeightForWidth());
        sbMinorTicksNumber->setSizePolicy(sizePolicy);

        horizontalLayout_8->addWidget(sbMinorTicksNumber);

        cbMinorTicksAutoNumber = new QCheckBox(tabTicks);
        cbMinorTicksAutoNumber->setObjectName("cbMinorTicksAutoNumber");

        horizontalLayout_8->addWidget(cbMinorTicksAutoNumber);


        gridLayout_5->addLayout(horizontalLayout_8, 20, 2, 1, 1);

        layoutMajorTickStartOffset = new QHBoxLayout();
        layoutMajorTickStartOffset->setObjectName("layoutMajorTickStartOffset");
        sbMajorTickStartOffset = new NumberSpinBox(tabTicks);
        sbMajorTickStartOffset->setObjectName("sbMajorTickStartOffset");
        sizePolicy.setHeightForWidth(sbMajorTickStartOffset->sizePolicy().hasHeightForWidth());
        sbMajorTickStartOffset->setSizePolicy(sizePolicy);
        sbMajorTickStartOffset->setProperty("feedback", QVariant(true));

        layoutMajorTickStartOffset->addWidget(sbMajorTickStartOffset);

        tbFirstTickData = new QToolButton(tabTicks);
        tbFirstTickData->setObjectName("tbFirstTickData");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("application-vnd.oasis.opendocument.chart")));
        tbFirstTickData->setIcon(icon3);

        layoutMajorTickStartOffset->addWidget(tbFirstTickData);

        tbFirstTickAuto = new QToolButton(tabTicks);
        tbFirstTickAuto->setObjectName("tbFirstTickAuto");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("autocorrection")));
        tbFirstTickAuto->setIcon(icon4);

        layoutMajorTickStartOffset->addWidget(tbFirstTickAuto);


        gridLayout_5->addLayout(layoutMajorTickStartOffset, 9, 2, 1, 1);

        lMajorTicksLength = new QLabel(tabTicks);
        lMajorTicksLength->setObjectName("lMajorTicksLength");

        gridLayout_5->addWidget(lMajorTicksLength, 14, 0, 1, 1);

        sbMajorTicksLength = new NumberSpinBox(tabTicks);
        sbMajorTicksLength->setObjectName("sbMajorTicksLength");
        sizePolicy.setHeightForWidth(sbMajorTicksLength->sizePolicy().hasHeightForWidth());
        sbMajorTicksLength->setSizePolicy(sizePolicy);
        sbMajorTicksLength->setProperty("feedback", QVariant(true));

        gridLayout_5->addWidget(sbMajorTicksLength, 14, 2, 1, 1);

        lMinorTicks = new QLabel(tabTicks);
        lMinorTicks->setObjectName("lMinorTicks");
        lMinorTicks->setFont(font);

        gridLayout_5->addWidget(lMinorTicks, 17, 0, 1, 1);

        lMinorTicksSpacingNumeric = new QLabel(tabTicks);
        lMinorTicksSpacingNumeric->setObjectName("lMinorTicksSpacingNumeric");

        gridLayout_5->addWidget(lMinorTicksSpacingNumeric, 21, 0, 1, 1);

        lMinorTicksLength = new QLabel(tabTicks);
        lMinorTicksLength->setObjectName("lMinorTicksLength");

        gridLayout_5->addWidget(lMinorTicksLength, 25, 0, 1, 1);

        verticalSpacer_19 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_5->addItem(verticalSpacer_19, 15, 0, 1, 1);

        cbMinorTicksDirection = new KComboBox(tabTicks);
        cbMinorTicksDirection->setObjectName("cbMinorTicksDirection");

        gridLayout_5->addWidget(cbMinorTicksDirection, 18, 2, 1, 1);

        lMajorTickStartOffset = new QLabel(tabTicks);
        lMajorTickStartOffset->setObjectName("lMajorTickStartOffset");

        gridLayout_5->addWidget(lMajorTickStartOffset, 9, 0, 1, 1);

        verticalSpacer_20 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_5->addItem(verticalSpacer_20, 26, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(48, 301, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer_4, 27, 0, 1, 1);

        cbLabelsTextType = new QComboBox(tabTicks);
        cbLabelsTextType->setObjectName("cbLabelsTextType");

        gridLayout_5->addWidget(cbLabelsTextType, 11, 2, 1, 1);

        lMinorTicksDirection = new QLabel(tabTicks);
        lMinorTicksDirection->setObjectName("lMinorTicksDirection");

        gridLayout_5->addWidget(lMinorTicksDirection, 18, 0, 1, 1);

        verticalSpacer_10 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_5->addItem(verticalSpacer_10, 16, 0, 1, 1);

        lMajorTicksType = new QLabel(tabTicks);
        lMajorTicksType->setObjectName("lMajorTicksType");

        gridLayout_5->addWidget(lMajorTicksType, 2, 0, 1, 1);

        lMajorTicksStartType = new QLabel(tabTicks);
        lMajorTicksStartType->setObjectName("lMajorTicksStartType");

        gridLayout_5->addWidget(lMajorTicksStartType, 6, 0, 1, 1);

        lMajorTicksColumn = new QLabel(tabTicks);
        lMajorTicksColumn->setObjectName("lMajorTicksColumn");

        gridLayout_5->addWidget(lMajorTicksColumn, 10, 0, 1, 1);

        lMinorTicksNumber = new QLabel(tabTicks);
        lMinorTicksNumber->setObjectName("lMinorTicksNumber");

        gridLayout_5->addWidget(lMinorTicksNumber, 20, 0, 1, 1);

        sbMinorTicksLength = new NumberSpinBox(tabTicks);
        sbMinorTicksLength->setObjectName("sbMinorTicksLength");
        sizePolicy.setHeightForWidth(sbMinorTicksLength->sizePolicy().hasHeightForWidth());
        sbMinorTicksLength->setSizePolicy(sizePolicy);
        sbMinorTicksLength->setProperty("feedback", QVariant(true));

        gridLayout_5->addWidget(sbMinorTicksLength, 25, 2, 1, 1);

        lMajorTickStartDateTime = new QLabel(tabTicks);
        lMajorTickStartDateTime->setObjectName("lMajorTickStartDateTime");

        gridLayout_5->addWidget(lMajorTickStartDateTime, 8, 0, 1, 1);

        sbMajorTickStartDateTime = new UTCDateTimeEdit(tabTicks);
        sbMajorTickStartDateTime->setObjectName("sbMajorTickStartDateTime");

        gridLayout_5->addWidget(sbMajorTickStartDateTime, 8, 2, 1, 1);

        tabWidget->addTab(tabTicks, QString());
        tabLabels = new QWidget();
        tabLabels->setObjectName("tabLabels");
        gridLayout = new QGridLayout(tabLabels);
        gridLayout->setObjectName("gridLayout");
        lLabelsPrecision = new QLabel(tabLabels);
        lLabelsPrecision->setObjectName("lLabelsPrecision");

        gridLayout->addWidget(lLabelsPrecision, 7, 0, 1, 1);

        frameLabelsPrecision = new QFrame(tabLabels);
        frameLabelsPrecision->setObjectName("frameLabelsPrecision");
        frameLabelsPrecision->setFrameShape(QFrame::Shape::NoFrame);
        frameLabelsPrecision->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout_2 = new QHBoxLayout(frameLabelsPrecision);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        sbLabelsPrecision = new QSpinBox(frameLabelsPrecision);
        sbLabelsPrecision->setObjectName("sbLabelsPrecision");
        sizePolicy.setHeightForWidth(sbLabelsPrecision->sizePolicy().hasHeightForWidth());
        sbLabelsPrecision->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(sbLabelsPrecision);

        chkLabelsAutoPrecision = new QCheckBox(frameLabelsPrecision);
        chkLabelsAutoPrecision->setObjectName("chkLabelsAutoPrecision");

        horizontalLayout_2->addWidget(chkLabelsAutoPrecision);


        gridLayout->addWidget(frameLabelsPrecision, 7, 2, 1, 1);

        leLabelsPrefix = new QLineEdit(tabLabels);
        leLabelsPrefix->setObjectName("leLabelsPrefix");
        sizePolicy.setHeightForWidth(leLabelsPrefix->sizePolicy().hasHeightForWidth());
        leLabelsPrefix->setSizePolicy(sizePolicy);

        gridLayout->addWidget(leLabelsPrefix, 9, 2, 1, 1);

        lMajorGrid_2 = new QLabel(tabLabels);
        lMajorGrid_2->setObjectName("lMajorGrid_2");
        lMajorGrid_2->setFont(font);

        gridLayout->addWidget(lMajorGrid_2, 0, 0, 1, 1);

        sbLabelsRotation = new QSpinBox(tabLabels);
        sbLabelsRotation->setObjectName("sbLabelsRotation");
        sizePolicy2.setHeightForWidth(sbLabelsRotation->sizePolicy().hasHeightForWidth());
        sbLabelsRotation->setSizePolicy(sizePolicy2);
        sbLabelsRotation->setMinimum(-180);
        sbLabelsRotation->setMaximum(180);
        sbLabelsRotation->setSingleStep(10);
        sbLabelsRotation->setValue(0);

        gridLayout->addWidget(sbLabelsRotation, 3, 2, 1, 1);

        lLabelsPosition = new QLabel(tabLabels);
        lLabelsPosition->setObjectName("lLabelsPosition");

        gridLayout->addWidget(lLabelsPosition, 1, 0, 1, 1);

        lLabelsRotation = new QLabel(tabLabels);
        lLabelsRotation->setObjectName("lLabelsRotation");

        gridLayout->addWidget(lLabelsRotation, 3, 0, 1, 1);

        lLabelsFont = new QLabel(tabLabels);
        lLabelsFont->setObjectName("lLabelsFont");

        gridLayout->addWidget(lLabelsFont, 13, 0, 1, 1);

        kfrLabelsFont = new KFontRequester(tabLabels);
        kfrLabelsFont->setObjectName("kfrLabelsFont");

        gridLayout->addWidget(kfrLabelsFont, 13, 2, 1, 1);

        verticalSpacer_7 = new QSpacerItem(58, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_7, 4, 0, 1, 1);

        lLabelsSuffix = new QLabel(tabLabels);
        lLabelsSuffix->setObjectName("lLabelsSuffix");

        gridLayout->addWidget(lLabelsSuffix, 10, 0, 1, 1);

        leLabelsSuffix = new QLineEdit(tabLabels);
        leLabelsSuffix->setObjectName("leLabelsSuffix");
        sizePolicy2.setHeightForWidth(leLabelsSuffix->sizePolicy().hasHeightForWidth());
        leLabelsSuffix->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(leLabelsSuffix, 10, 2, 1, 1);

        lLabelsOffset = new QLabel(tabLabels);
        lLabelsOffset->setObjectName("lLabelsOffset");

        gridLayout->addWidget(lLabelsOffset, 2, 0, 1, 1);

        cbLabelsPosition = new KComboBox(tabLabels);
        cbLabelsPosition->setObjectName("cbLabelsPosition");
        sizePolicy.setHeightForWidth(cbLabelsPosition->sizePolicy().hasHeightForWidth());
        cbLabelsPosition->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbLabelsPosition, 1, 2, 1, 1);

        kcbLabelsBackgroundColor = new KColorButton(tabLabels);
        kcbLabelsBackgroundColor->setObjectName("kcbLabelsBackgroundColor");
        sizePolicy2.setHeightForWidth(kcbLabelsBackgroundColor->sizePolicy().hasHeightForWidth());
        kcbLabelsBackgroundColor->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(kcbLabelsBackgroundColor, 19, 2, 1, 1);

        kcbLabelsFontColor = new KColorButton(tabLabels);
        kcbLabelsFontColor->setObjectName("kcbLabelsFontColor");
        sizePolicy2.setHeightForWidth(kcbLabelsFontColor->sizePolicy().hasHeightForWidth());
        kcbLabelsFontColor->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(kcbLabelsFontColor, 14, 2, 1, 1);

        lLabelsOpacity = new QLabel(tabLabels);
        lLabelsOpacity->setObjectName("lLabelsOpacity");

        gridLayout->addWidget(lLabelsOpacity, 15, 0, 1, 1);

        lLabelsDateTimeFormat = new QLabel(tabLabels);
        lLabelsDateTimeFormat->setObjectName("lLabelsDateTimeFormat");

        gridLayout->addWidget(lLabelsDateTimeFormat, 8, 0, 1, 1);

        lLabelsBackgroundColor = new QLabel(tabLabels);
        lLabelsBackgroundColor->setObjectName("lLabelsBackgroundColor");

        gridLayout->addWidget(lLabelsBackgroundColor, 19, 0, 1, 1);

        sbLabelsOpacity = new QSpinBox(tabLabels);
        sbLabelsOpacity->setObjectName("sbLabelsOpacity");
        sizePolicy2.setHeightForWidth(sbLabelsOpacity->sizePolicy().hasHeightForWidth());
        sbLabelsOpacity->setSizePolicy(sizePolicy2);
        sbLabelsOpacity->setMinimum(0);
        sbLabelsOpacity->setMaximum(100);
        sbLabelsOpacity->setSingleStep(10);
        sbLabelsOpacity->setValue(100);

        gridLayout->addWidget(sbLabelsOpacity, 15, 2, 1, 1);

        label_4 = new QLabel(tabLabels);
        label_4->setObjectName("label_4");
        label_4->setFont(font);

        gridLayout->addWidget(label_4, 12, 0, 1, 1);

        lLabelsBackground = new QLabel(tabLabels);
        lLabelsBackground->setObjectName("lLabelsBackground");
        lLabelsBackground->setFont(font);

        gridLayout->addWidget(lLabelsBackground, 17, 0, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_7, 1, 1, 1, 1);

        cbLabelsDateTimeFormat = new KComboBox(tabLabels);
        cbLabelsDateTimeFormat->setObjectName("cbLabelsDateTimeFormat");
        cbLabelsDateTimeFormat->setEditable(true);

        gridLayout->addWidget(cbLabelsDateTimeFormat, 8, 2, 1, 1);

        verticalSpacer_14 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_14, 16, 0, 1, 1);

        lLabelsFormat = new QLabel(tabLabels);
        lLabelsFormat->setObjectName("lLabelsFormat");

        gridLayout->addWidget(lLabelsFormat, 6, 0, 1, 1);

        verticalSpacer_9 = new QSpacerItem(20, 83, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_9, 20, 0, 1, 1);

        lLabelsBackgroundType = new QLabel(tabLabels);
        lLabelsBackgroundType->setObjectName("lLabelsBackgroundType");

        gridLayout->addWidget(lLabelsBackgroundType, 18, 0, 1, 1);

        lLabelsPrefix = new QLabel(tabLabels);
        lLabelsPrefix->setObjectName("lLabelsPrefix");

        gridLayout->addWidget(lLabelsPrefix, 9, 0, 1, 1);

        lLabelsColor = new QLabel(tabLabels);
        lLabelsColor->setObjectName("lLabelsColor");

        gridLayout->addWidget(lLabelsColor, 14, 0, 1, 1);

        lLabelsText = new QLabel(tabLabels);
        lLabelsText->setObjectName("lLabelsText");
        lLabelsText->setFont(font);

        gridLayout->addWidget(lLabelsText, 5, 0, 1, 1);

        cbLabelsBackgroundType = new QComboBox(tabLabels);
        cbLabelsBackgroundType->setObjectName("cbLabelsBackgroundType");

        gridLayout->addWidget(cbLabelsBackgroundType, 18, 2, 1, 1);

        verticalSpacer_8 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_8, 11, 0, 1, 1);

        sbLabelsOffset = new NumberSpinBox(tabLabels);
        sbLabelsOffset->setObjectName("sbLabelsOffset");
        sizePolicy.setHeightForWidth(sbLabelsOffset->sizePolicy().hasHeightForWidth());
        sbLabelsOffset->setSizePolicy(sizePolicy);
        sbLabelsOffset->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbLabelsOffset, 2, 2, 1, 1);

        frameLabelsFormat = new QFrame(tabLabels);
        frameLabelsFormat->setObjectName("frameLabelsFormat");
        frameLabelsFormat->setFrameShape(QFrame::Shape::NoFrame);
        frameLabelsFormat->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout_9 = new QHBoxLayout(frameLabelsFormat);
        horizontalLayout_9->setSpacing(0);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        horizontalLayout_9->setContentsMargins(0, 0, 0, 0);
        cbLabelsFormat = new KComboBox(frameLabelsFormat);
        cbLabelsFormat->setObjectName("cbLabelsFormat");
        sizePolicy.setHeightForWidth(cbLabelsFormat->sizePolicy().hasHeightForWidth());
        cbLabelsFormat->setSizePolicy(sizePolicy);

        horizontalLayout_9->addWidget(cbLabelsFormat);

        chkLabelsFormatAuto = new QCheckBox(frameLabelsFormat);
        chkLabelsFormatAuto->setObjectName("chkLabelsFormatAuto");

        horizontalLayout_9->addWidget(chkLabelsFormatAuto);


        gridLayout->addWidget(frameLabelsFormat, 6, 2, 1, 1);

        tabWidget->addTab(tabLabels, QString());
        tabGrid = new QWidget();
        tabGrid->setObjectName("tabGrid");
        tabGrid->setEnabled(true);
        gridLayout_2 = new QGridLayout(tabGrid);
        gridLayout_2->setObjectName("gridLayout_2");
        verticalSpacer_17 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_17, 4, 0, 1, 1);

        verticalSpacer_18 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_18, 2, 0, 1, 1);

        lMinorGrid = new QLabel(tabGrid);
        lMinorGrid->setObjectName("lMinorGrid");
        lMinorGrid->setFont(font);

        gridLayout_2->addWidget(lMinorGrid, 3, 0, 1, 1);

        lMajorGrid = new QLabel(tabGrid);
        lMajorGrid->setObjectName("lMajorGrid");
        lMajorGrid->setFont(font);

        gridLayout_2->addWidget(lMajorGrid, 0, 0, 1, 1);

        verticalSpacer_16 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_16, 5, 0, 1, 1);

        verticalSpacer_15 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_15, 1, 0, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(13, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_4, 0, 1, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(289, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_5, 0, 2, 1, 1);

        tabWidget->addTab(tabGrid, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbOrientation);
        QWidget::setTabOrder(cbOrientation, cbPosition);
        QWidget::setTabOrder(cbPosition, sbPosition);
        QWidget::setTabOrder(sbPosition, sbPositionLogical);
        QWidget::setTabOrder(sbPositionLogical, cbScale);
        QWidget::setTabOrder(cbScale, cbRangeScale);
        QWidget::setTabOrder(cbRangeScale, kcbAxisColor);
        QWidget::setTabOrder(kcbAxisColor, cbRangeType);
        QWidget::setTabOrder(cbRangeType, sbStart);
        QWidget::setTabOrder(sbStart, sbEnd);
        QWidget::setTabOrder(sbEnd, dateTimeEditStart);
        QWidget::setTabOrder(dateTimeEditStart, dateTimeEditEnd);
        QWidget::setTabOrder(dateTimeEditEnd, sbZeroOffset);
        QWidget::setTabOrder(sbZeroOffset, tbOffsetLeft);
        QWidget::setTabOrder(tbOffsetLeft, tbOffsetCenter);
        QWidget::setTabOrder(tbOffsetCenter, tbOffsetRight);
        QWidget::setTabOrder(tbOffsetRight, sbScalingFactor);
        QWidget::setTabOrder(sbScalingFactor, tbUnityScale);
        QWidget::setTabOrder(tbUnityScale, tbUnityRange);
        QWidget::setTabOrder(tbUnityRange, chkShowScaleOffset);
        QWidget::setTabOrder(chkShowScaleOffset, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkVisible);
        QWidget::setTabOrder(chkVisible, cbArrowType);
        QWidget::setTabOrder(cbArrowType, cbArrowPosition);
        QWidget::setTabOrder(cbArrowPosition, sbArrowSize);
        QWidget::setTabOrder(sbArrowSize, sbMajorTicksNumber);
        QWidget::setTabOrder(sbMajorTicksNumber, cbMajorTicksAutoNumber);
        QWidget::setTabOrder(cbMajorTicksAutoNumber, cbMajorTicksDirection);
        QWidget::setTabOrder(cbMajorTicksDirection, cbMajorTicksStartType);
        QWidget::setTabOrder(cbMajorTicksStartType, sbMajorTicksSpacingNumeric);
        QWidget::setTabOrder(sbMajorTicksSpacingNumeric, sbMajorTickStartValue);
        QWidget::setTabOrder(sbMajorTickStartValue, cbMajorTicksType);
        QWidget::setTabOrder(cbMajorTicksType, cbMinorTicksType);
        QWidget::setTabOrder(cbMinorTicksType, sbMinorTicksSpacingNumeric);
        QWidget::setTabOrder(sbMinorTicksSpacingNumeric, sbMinorTicksNumber);
        QWidget::setTabOrder(sbMinorTicksNumber, cbMinorTicksAutoNumber);
        QWidget::setTabOrder(cbMinorTicksAutoNumber, sbMajorTickStartOffset);
        QWidget::setTabOrder(sbMajorTickStartOffset, tbFirstTickData);
        QWidget::setTabOrder(tbFirstTickData, tbFirstTickAuto);
        QWidget::setTabOrder(tbFirstTickAuto, sbMajorTicksLength);
        QWidget::setTabOrder(sbMajorTicksLength, cbMinorTicksDirection);
        QWidget::setTabOrder(cbMinorTicksDirection, cbLabelsTextType);
        QWidget::setTabOrder(cbLabelsTextType, sbMinorTicksLength);
        QWidget::setTabOrder(sbMinorTicksLength, sbMajorTickStartDateTime);
        QWidget::setTabOrder(sbMajorTickStartDateTime, sbLabelsPrecision);
        QWidget::setTabOrder(sbLabelsPrecision, chkLabelsAutoPrecision);
        QWidget::setTabOrder(chkLabelsAutoPrecision, leLabelsPrefix);
        QWidget::setTabOrder(leLabelsPrefix, sbLabelsRotation);
        QWidget::setTabOrder(sbLabelsRotation, kfrLabelsFont);
        QWidget::setTabOrder(kfrLabelsFont, leLabelsSuffix);
        QWidget::setTabOrder(leLabelsSuffix, cbLabelsPosition);
        QWidget::setTabOrder(cbLabelsPosition, kcbLabelsBackgroundColor);
        QWidget::setTabOrder(kcbLabelsBackgroundColor, kcbLabelsFontColor);
        QWidget::setTabOrder(kcbLabelsFontColor, sbLabelsOpacity);
        QWidget::setTabOrder(sbLabelsOpacity, cbLabelsDateTimeFormat);
        QWidget::setTabOrder(cbLabelsDateTimeFormat, cbLabelsBackgroundType);
        QWidget::setTabOrder(cbLabelsBackgroundType, sbLabelsOffset);
        QWidget::setTabOrder(sbLabelsOffset, cbLabelsFormat);
        QWidget::setTabOrder(cbLabelsFormat, chkLabelsFormatAuto);

        retranslateUi(AxisDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AxisDock);
    } // setupUi

    void retranslateUi(QWidget *AxisDock)
    {
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lPosition->setText(tr2i18n("Position:", nullptr));
        lStartDateTime->setText(tr2i18n("Start:", nullptr));
#if QT_CONFIG(tooltip)
        chkShowScaleOffset->setToolTip(tr2i18n("Show scale and offset beside axis", nullptr));
#endif // QT_CONFIG(tooltip)
        chkShowScaleOffset->setText(tr2i18n("Show scale and offset", nullptr));
#if QT_CONFIG(tooltip)
        sbScalingFactor->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbScalingFactor->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        tbUnityScale->setToolTip(tr2i18n("Set factor to unity scale", nullptr));
#endif // QT_CONFIG(tooltip)
        tbUnityScale->setText(tr2i18n("1", nullptr));
#if QT_CONFIG(tooltip)
        tbUnityRange->setToolTip(tr2i18n("Set factor and offset to get 0 .. 1", nullptr));
#endif // QT_CONFIG(tooltip)
        tbUnityRange->setText(tr2i18n("0 .. 1", nullptr));
        lScale->setText(tr2i18n("Scale:", nullptr));
        lZeroOffset->setText(tr2i18n("Zero Offset:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lEndDateTime->setText(tr2i18n("End:", nullptr));
#if QT_CONFIG(tooltip)
        sbPosition->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPosition->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        sbPositionLogical->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionLogical->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        lStart->setText(tr2i18n("Start:", nullptr));
#if QT_CONFIG(tooltip)
        sbZeroOffset->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbZeroOffset->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        tbOffsetLeft->setToolTip(tr2i18n("Set offset to start at zero", nullptr));
#endif // QT_CONFIG(tooltip)
        tbOffsetLeft->setText(QString());
#if QT_CONFIG(tooltip)
        tbOffsetCenter->setToolTip(tr2i18n("Set offset to center around zero", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tbOffsetRight->setToolTip(tr2i18n("Set offset to end at zero", nullptr));
#endif // QT_CONFIG(tooltip)
        lName->setText(tr2i18n("Name:", nullptr));
        lScalingFactor->setText(tr2i18n("Scaling Factor:", nullptr));
        lRangeType->setText(tr2i18n("Range:", nullptr));
        lOrientation->setText(tr2i18n("Orientation:", nullptr));
        lEnd->setText(tr2i18n("End:", nullptr));
#if QT_CONFIG(tooltip)
        sbStart->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbStart->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        sbEnd->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbEnd->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Color:", nullptr));
        cbRangeScale->setText(tr2i18n("Auto", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabTitle), tr2i18n("Title", nullptr));
        lArrow->setText(tr2i18n("Arrow", nullptr));
        lArrowSize->setText(tr2i18n("Size:", nullptr));
#if QT_CONFIG(tooltip)
        sbArrowSize->setToolTip(tr2i18n("The opacity ranges from 0 to 100, where 0 is fully transparent and 100 is fully opaque.", nullptr));
#endif // QT_CONFIG(tooltip)
        sbArrowSize->setSuffix(tr2i18n(" pt", nullptr));
        sbArrowSize->setPrefix(QString());
        lArrowType->setText(tr2i18n("Type:", nullptr));
        lArrowPosition->setText(tr2i18n("Position:", nullptr));
        lLine->setText(tr2i18n("Line", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabLine), tr2i18n("Line", nullptr));
        cbMajorTicksAutoNumber->setText(tr2i18n("Auto", nullptr));
#if QT_CONFIG(tooltip)
        sbMajorTicksSpacingNumeric->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbMajorTicksSpacingNumeric->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lMinorTicksType->setText(tr2i18n("Type:", nullptr));
        lMajorTicksNumber->setText(tr2i18n("Number:", nullptr));
        lMajorTickStartValue->setText(tr2i18n("1st Tick Value:", nullptr));
        lMajorTicksSpacingNumeric->setText(tr2i18n("Spacing:", nullptr));
        lMajorTicks->setText(tr2i18n("Major Ticks", nullptr));
        lMajorTicksIncrementDateTime->setText(tr2i18n("Increment:", nullptr));
        lLabelsTextType->setText(tr2i18n("Label Type:", nullptr));
        lLabelsTextColumn->setText(tr2i18n("Label Column:", nullptr));
        lMinorTicksColumn->setText(tr2i18n("Column:", nullptr));
#if QT_CONFIG(tooltip)
        sbMajorTickStartValue->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbMajorTickStartValue->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lMajorTicksDirection->setText(tr2i18n("Direction:", nullptr));
#if QT_CONFIG(tooltip)
        sbMinorTicksSpacingNumeric->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbMinorTicksSpacingNumeric->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lMinorTicksIncrementDateTime->setText(tr2i18n("Increment:", nullptr));
        cbMinorTicksAutoNumber->setText(tr2i18n("Auto", nullptr));
#if QT_CONFIG(tooltip)
        sbMajorTickStartOffset->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbMajorTickStartOffset->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        tbFirstTickData->setToolTip(tr2i18n("<html><head/><body><p>Set offset to start ticks at first data point</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tbFirstTickAuto->setToolTip(tr2i18n("<html><head/><body><p>Set offset to start ticks at round value before first data point</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        tbFirstTickAuto->setText(QString());
        lMajorTicksLength->setText(tr2i18n("Length:", nullptr));
#if QT_CONFIG(tooltip)
        sbMajorTicksLength->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbMajorTicksLength->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbMajorTicksLength->setSuffix(tr2i18n(" pt", nullptr));
        lMinorTicks->setText(tr2i18n("Minor Ticks", nullptr));
        lMinorTicksSpacingNumeric->setText(tr2i18n("Spacing:", nullptr));
        lMinorTicksLength->setText(tr2i18n("Length:", nullptr));
#if QT_CONFIG(tooltip)
        lMajorTickStartOffset->setToolTip(tr2i18n("<html><head/><body><p>Offset of the first tick from the start of the axis</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        lMajorTickStartOffset->setText(tr2i18n("1st Tick Offset:", nullptr));
        lMinorTicksDirection->setText(tr2i18n("Direction:", nullptr));
        lMajorTicksType->setText(tr2i18n("Type:", nullptr));
        lMajorTicksStartType->setText(tr2i18n("1st Tick at:", nullptr));
        lMajorTicksColumn->setText(tr2i18n("Column:", nullptr));
        lMinorTicksNumber->setText(tr2i18n("Number:", nullptr));
#if QT_CONFIG(tooltip)
        sbMinorTicksLength->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbMinorTicksLength->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbMinorTicksLength->setSuffix(tr2i18n(" pt", nullptr));
        lMajorTickStartDateTime->setText(tr2i18n("1st Tick Value:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabTicks), tr2i18n("Ticks", nullptr));
#if QT_CONFIG(tooltip)
        lLabelsPrecision->setToolTip(tr2i18n("Number of digits after the decimal point", nullptr));
#endif // QT_CONFIG(tooltip)
        lLabelsPrecision->setText(tr2i18n("Precision:", nullptr));
#if QT_CONFIG(tooltip)
        sbLabelsPrecision->setToolTip(tr2i18n("Number of digits after the decimal point", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        chkLabelsAutoPrecision->setToolTip(tr2i18n("Automatically determine the optimal number of digits after the decimal point", nullptr));
#endif // QT_CONFIG(tooltip)
        chkLabelsAutoPrecision->setText(tr2i18n("Auto", nullptr));
        lMajorGrid_2->setText(tr2i18n("Position", nullptr));
#if QT_CONFIG(tooltip)
        sbLabelsRotation->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        sbLabelsRotation->setSuffix(tr2i18n("\302\260", nullptr));
        lLabelsPosition->setText(tr2i18n("Position:", nullptr));
        lLabelsRotation->setText(tr2i18n("Rotation:", nullptr));
        lLabelsFont->setText(tr2i18n("Font:", nullptr));
        lLabelsSuffix->setText(tr2i18n("Suffix:", nullptr));
        lLabelsOffset->setText(tr2i18n("Offset:", nullptr));
        lLabelsOpacity->setText(tr2i18n("Opacity:", nullptr));
        lLabelsDateTimeFormat->setText(tr2i18n("Format:", nullptr));
        lLabelsBackgroundColor->setText(tr2i18n("Color:", nullptr));
#if QT_CONFIG(tooltip)
        sbLabelsOpacity->setToolTip(tr2i18n("The opacity ranges from 0 to 100, where 0 is fully transparent and 100 is fully opaque.", nullptr));
#endif // QT_CONFIG(tooltip)
        sbLabelsOpacity->setSuffix(tr2i18n(" %", nullptr));
        label_4->setText(tr2i18n("Font:", nullptr));
        lLabelsBackground->setText(tr2i18n("Background", nullptr));
        lLabelsFormat->setText(tr2i18n("Format:", nullptr));
        lLabelsBackgroundType->setText(tr2i18n("Type:", nullptr));
        lLabelsPrefix->setText(tr2i18n("Prefix:", nullptr));
        lLabelsColor->setText(tr2i18n("Font Color:", nullptr));
        lLabelsText->setText(tr2i18n("Text", nullptr));
#if QT_CONFIG(tooltip)
        sbLabelsOffset->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbLabelsOffset->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbLabelsOffset->setSuffix(tr2i18n(" pt", nullptr));
        chkLabelsFormatAuto->setText(tr2i18n("Auto", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabLabels), tr2i18n("Labels", nullptr));
        lMinorGrid->setText(tr2i18n("Minor Grid", nullptr));
        lMajorGrid->setText(tr2i18n("Major Grid", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGrid), tr2i18n("Grid", nullptr));
        (void)AxisDock;
    } // retranslateUi

};

namespace Ui {
    class AxisDock: public Ui_AxisDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // AXISDOCK_H

