/****************************************************************************
** Meta object code from reading C++ file 'WorksheetView.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/worksheet/WorksheetView.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'WorksheetView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13WorksheetViewE_t {};
} // unnamed namespace

template <> constexpr inline auto WorksheetView::qt_create_metaobjectdata<qt_meta_tag_ZN13WorksheetViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WorksheetView",
        "statusInfo",
        "",
        "propertiesExplorerRequested",
        "createContextMenu",
        "QMenu*",
        "fillToolBar",
        "QToolBar*",
        "fillCartesianPlotToolBar",
        "fillCartesianPlotNavigationToolBar",
        "enableCursor",
        "print",
        "QPrinter*",
        "selectItem",
        "QGraphicsItem*",
        "presenterMode",
        "cartesianPlotMouseModeChangedSlot",
        "CartesianPlot::MouseMode",
        "childContextMenuRequested",
        "AspectType",
        "cartesianPlotMouseModeChanged",
        "QAction*",
        "addNew",
        "aspectAboutToBeRemoved",
        "const AbstractAspect*",
        "selectAllElements",
        "deleteElement",
        "mouseModeChanged",
        "useViewSizeChanged",
        "changeZoom",
        "fitChanged",
        "updateFit",
        "magnificationChanged",
        "changeLayout",
        "changeGrid",
        "changeSnapToGrid",
        "plotsInteractiveActionChanged",
        "checked",
        "deselectItem",
        "selectionChanged",
        "updateBackground",
        "layoutChanged",
        "Worksheet::Layout",
        "fadeIn",
        "fadeOut",
        "zoom",
        "scalingTime",
        "animFinished",
        "cartesianPlotActionModeChanged",
        "cartesianPlotCursorModeChanged",
        "cartesianPlotNavigationChanged",
        "handleCartesianPlotActions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusInfo'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'propertiesExplorerRequested'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createContextMenu'
        QtMocHelpers::SlotData<void(QMenu *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'fillToolBar'
        QtMocHelpers::SlotData<void(QToolBar *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'fillCartesianPlotToolBar'
        QtMocHelpers::SlotData<void(QToolBar *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'fillCartesianPlotNavigationToolBar'
        QtMocHelpers::SlotData<void(QToolBar *, bool) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'fillCartesianPlotNavigationToolBar'
        QtMocHelpers::SlotData<void(QToolBar *) const>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'print'
        QtMocHelpers::SlotData<void(QPrinter *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Slot 'selectItem'
        QtMocHelpers::SlotData<void(QGraphicsItem *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'presenterMode'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cartesianPlotMouseModeChangedSlot'
        QtMocHelpers::SlotData<void(CartesianPlot::MouseMode)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Slot 'childContextMenuRequested'
        QtMocHelpers::SlotData<void(AspectType, QMenu *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 2 }, { 0x80000000 | 5, 2 },
        }}),
        // Slot 'cartesianPlotMouseModeChanged'
        QtMocHelpers::SlotData<void(QAction *)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'addNew'
        QtMocHelpers::SlotData<void(QAction *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'aspectAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 2 },
        }}),
        // Slot 'selectAllElements'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteElement'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'mouseModeChanged'
        QtMocHelpers::SlotData<void(QAction *)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'useViewSizeChanged'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'changeZoom'
        QtMocHelpers::SlotData<void(QAction *)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'fitChanged'
        QtMocHelpers::SlotData<void(QAction *)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'updateFit'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'magnificationChanged'
        QtMocHelpers::SlotData<void(QAction *)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'changeLayout'
        QtMocHelpers::SlotData<void(QAction *)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'changeGrid'
        QtMocHelpers::SlotData<void(QAction *)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'changeSnapToGrid'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'plotsInteractiveActionChanged'
        QtMocHelpers::SlotData<void(bool)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'deselectItem'
        QtMocHelpers::SlotData<void(QGraphicsItem *)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateBackground'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'layoutChanged'
        QtMocHelpers::SlotData<void(Worksheet::Layout)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 2 },
        }}),
        // Slot 'fadeIn'
        QtMocHelpers::SlotData<void(qreal)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'fadeOut'
        QtMocHelpers::SlotData<void(qreal)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'zoom'
        QtMocHelpers::SlotData<void(int)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'scalingTime'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'animFinished'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cartesianPlotActionModeChanged'
        QtMocHelpers::SlotData<void(QAction *)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'cartesianPlotCursorModeChanged'
        QtMocHelpers::SlotData<void(QAction *)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'cartesianPlotNavigationChanged'
        QtMocHelpers::SlotData<void(QAction *)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'handleCartesianPlotActions'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WorksheetView, qt_meta_tag_ZN13WorksheetViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WorksheetView::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13WorksheetViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13WorksheetViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13WorksheetViewE_t>.metaTypes,
    nullptr
} };

void WorksheetView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WorksheetView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->propertiesExplorerRequested(); break;
        case 2: _t->createContextMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 3: _t->fillToolBar((*reinterpret_cast<std::add_pointer_t<QToolBar*>>(_a[1]))); break;
        case 4: _t->fillCartesianPlotToolBar((*reinterpret_cast<std::add_pointer_t<QToolBar*>>(_a[1]))); break;
        case 5: _t->fillCartesianPlotNavigationToolBar((*reinterpret_cast<std::add_pointer_t<QToolBar*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->fillCartesianPlotNavigationToolBar((*reinterpret_cast<std::add_pointer_t<QToolBar*>>(_a[1]))); break;
        case 7: _t->print((*reinterpret_cast<std::add_pointer_t<QPrinter*>>(_a[1]))); break;
        case 8: _t->selectItem((*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[1]))); break;
        case 9: _t->presenterMode(); break;
        case 10: _t->cartesianPlotMouseModeChangedSlot((*reinterpret_cast<std::add_pointer_t<CartesianPlot::MouseMode>>(_a[1]))); break;
        case 11: _t->childContextMenuRequested((*reinterpret_cast<std::add_pointer_t<AspectType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2]))); break;
        case 12: _t->cartesianPlotMouseModeChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 13: _t->addNew((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 14: _t->aspectAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 15: _t->selectAllElements(); break;
        case 16: _t->deleteElement(); break;
        case 17: _t->mouseModeChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 18: _t->useViewSizeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->changeZoom((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 20: _t->fitChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 21: _t->updateFit(); break;
        case 22: _t->magnificationChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 23: _t->changeLayout((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 24: _t->changeGrid((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 25: _t->changeSnapToGrid(); break;
        case 26: _t->plotsInteractiveActionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->deselectItem((*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[1]))); break;
        case 28: _t->selectionChanged(); break;
        case 29: _t->updateBackground(); break;
        case 30: _t->layoutChanged((*reinterpret_cast<std::add_pointer_t<Worksheet::Layout>>(_a[1]))); break;
        case 31: _t->fadeIn((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 32: _t->fadeOut((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 33: _t->zoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->scalingTime(); break;
        case 35: _t->animFinished(); break;
        case 36: _t->cartesianPlotActionModeChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 37: _t->cartesianPlotCursorModeChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 38: _t->cartesianPlotNavigationChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 39: _t->handleCartesianPlotActions(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WorksheetView::*)(const QString & )>(_a, &WorksheetView::statusInfo, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetView::*)()>(_a, &WorksheetView::propertiesExplorerRequested, 1))
            return;
    }
}

const QMetaObject *WorksheetView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorksheetView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13WorksheetViewE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int WorksheetView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
    return _id;
}

// SIGNAL 0
void WorksheetView::statusInfo(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void WorksheetView::propertiesExplorerRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
