/****************************************************************************
** Meta object code from reading C++ file 'AbstractColumn.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/core/AbstractColumn.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbstractColumn.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14AbstractColumnE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractColumn::qt_create_metaobjectdata<qt_meta_tag_ZN14AbstractColumnE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractColumn",
        "plotDesignationAboutToChange",
        "",
        "const AbstractColumn*",
        "source",
        "plotDesignationChanged",
        "modeAboutToChange",
        "modeChanged",
        "dataAboutToChange",
        "dataChanged",
        "formatChanged",
        "rowsAboutToBeInserted",
        "before",
        "count",
        "rowsInserted",
        "rowsAboutToBeRemoved",
        "first",
        "rowsRemoved",
        "maskingAboutToChange",
        "maskingChanged",
        "aboutToBeDestroyed",
        "aboutToReset",
        "PlotDesignation",
        "NoDesignation",
        "X",
        "Y",
        "Z",
        "XError",
        "XErrorPlus",
        "XErrorMinus",
        "YError",
        "YErrorPlus",
        "YErrorMinus",
        "TimeUnit",
        "Milliseconds",
        "Seconds",
        "Minutes",
        "Hours",
        "Days",
        "ColumnMode",
        "Double",
        "Text",
        "Month",
        "Day",
        "DateTime",
        "Integer",
        "BigInt",
        "Properties",
        "No",
        "Constant",
        "MonotonicIncreasing",
        "MonotonicDecreasing",
        "NonMonotonic"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'plotDesignationAboutToChange'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'plotDesignationChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'modeAboutToChange'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'dataAboutToChange'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'formatChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'rowsAboutToBeInserted'
        QtMocHelpers::SignalData<void(const AbstractColumn *, int, int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 12 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'rowsInserted'
        QtMocHelpers::SignalData<void(const AbstractColumn *, int, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 12 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'rowsAboutToBeRemoved'
        QtMocHelpers::SignalData<void(const AbstractColumn *, int, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 16 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'rowsRemoved'
        QtMocHelpers::SignalData<void(const AbstractColumn *, int, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 16 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'maskingAboutToChange'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'maskingChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'aboutToBeDestroyed'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'aboutToReset'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PlotDesignation'
        QtMocHelpers::EnumData<enum PlotDesignation>(22, 22, QMC::EnumIsScoped).add({
            {   23, PlotDesignation::NoDesignation },
            {   24, PlotDesignation::X },
            {   25, PlotDesignation::Y },
            {   26, PlotDesignation::Z },
            {   27, PlotDesignation::XError },
            {   28, PlotDesignation::XErrorPlus },
            {   29, PlotDesignation::XErrorMinus },
            {   30, PlotDesignation::YError },
            {   31, PlotDesignation::YErrorPlus },
            {   32, PlotDesignation::YErrorMinus },
        }),
        // enum 'TimeUnit'
        QtMocHelpers::EnumData<enum TimeUnit>(33, 33, QMC::EnumIsScoped).add({
            {   34, TimeUnit::Milliseconds },
            {   35, TimeUnit::Seconds },
            {   36, TimeUnit::Minutes },
            {   37, TimeUnit::Hours },
            {   38, TimeUnit::Days },
        }),
        // enum 'ColumnMode'
        QtMocHelpers::EnumData<enum ColumnMode>(39, 39, QMC::EnumIsScoped).add({
            {   40, ColumnMode::Double },
            {   41, ColumnMode::Text },
            {   42, ColumnMode::Month },
            {   43, ColumnMode::Day },
            {   44, ColumnMode::DateTime },
            {   45, ColumnMode::Integer },
            {   46, ColumnMode::BigInt },
        }),
        // enum 'Properties'
        QtMocHelpers::EnumData<enum Properties>(47, 47, QMC::EnumIsScoped).add({
            {   48, Properties::No },
            {   49, Properties::Constant },
            {   50, Properties::MonotonicIncreasing },
            {   51, Properties::MonotonicDecreasing },
            {   52, Properties::NonMonotonic },
        }),
    };
    return QtMocHelpers::metaObjectData<AbstractColumn, qt_meta_tag_ZN14AbstractColumnE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractColumn::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractAspect::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AbstractColumnE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AbstractColumnE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AbstractColumnE_t>.metaTypes,
    nullptr
} };

void AbstractColumn::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractColumn *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->plotDesignationAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 1: _t->plotDesignationChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 2: _t->modeAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 3: _t->modeChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 4: _t->dataAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 5: _t->dataChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 6: _t->formatChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 7: _t->rowsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 8: _t->rowsInserted((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 9: _t->rowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 10: _t->rowsRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->maskingAboutToChange((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 12: _t->maskingChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 13: _t->aboutToBeDestroyed((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 14: _t->aboutToReset((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * )>(_a, &AbstractColumn::plotDesignationAboutToChange, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * )>(_a, &AbstractColumn::plotDesignationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * )>(_a, &AbstractColumn::modeAboutToChange, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * )>(_a, &AbstractColumn::modeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * )>(_a, &AbstractColumn::dataAboutToChange, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * )>(_a, &AbstractColumn::dataChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * )>(_a, &AbstractColumn::formatChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * , int , int )>(_a, &AbstractColumn::rowsAboutToBeInserted, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * , int , int )>(_a, &AbstractColumn::rowsInserted, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * , int , int )>(_a, &AbstractColumn::rowsAboutToBeRemoved, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * , int , int )>(_a, &AbstractColumn::rowsRemoved, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * )>(_a, &AbstractColumn::maskingAboutToChange, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * )>(_a, &AbstractColumn::maskingChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * )>(_a, &AbstractColumn::aboutToBeDestroyed, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractColumn::*)(const AbstractColumn * )>(_a, &AbstractColumn::aboutToReset, 14))
            return;
    }
}

const QMetaObject *AbstractColumn::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractColumn::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AbstractColumnE_t>.strings))
        return static_cast<void*>(this);
    return AbstractAspect::qt_metacast(_clname);
}

int AbstractColumn::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractAspect::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void AbstractColumn::plotDesignationAboutToChange(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractColumn::plotDesignationChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AbstractColumn::modeAboutToChange(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AbstractColumn::modeChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AbstractColumn::dataAboutToChange(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AbstractColumn::dataChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void AbstractColumn::formatChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void AbstractColumn::rowsAboutToBeInserted(const AbstractColumn * _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void AbstractColumn::rowsInserted(const AbstractColumn * _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void AbstractColumn::rowsAboutToBeRemoved(const AbstractColumn * _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3);
}

// SIGNAL 10
void AbstractColumn::rowsRemoved(const AbstractColumn * _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3);
}

// SIGNAL 11
void AbstractColumn::maskingAboutToChange(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void AbstractColumn::maskingChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void AbstractColumn::aboutToBeDestroyed(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void AbstractColumn::aboutToReset(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}
QT_WARNING_POP
