/********************************************************************************
** Form generated from reading UI file 'lollipopplotdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOLLIPOPPLOTDOCK_H
#define UI_LOLLIPOPPLOTDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_LollipopPlotDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout_3;
    QSpacerItem *hsName;
    QLabel *lXColumn;
    QLabel *lDataColumn;
    QSpacerItem *verticalSpacerST_2;
    QSpacerItem *verticalSpacer_2;
    QLabel *lComment;
    QLabel *lXData;
    TimedLineEdit *leName;
    QLabel *lName;
    QSpacerItem *verticalSpacerGeneral;
    ResizableTextEdit *teComment;
    QComboBox *cbOrientation;
    QFrame *frameXColumn;
    QHBoxLayout *horizontalLayout;
    QPushButton *bRemoveXColumn;
    QComboBox *cbPlotRanges;
    QFrame *frameDataColumns;
    QLabel *lPlotRange;
    QSpacerItem *verticalSpacerST;
    QCheckBox *chkVisible;
    QLabel *lOrientation;
    QCheckBox *chkLegendVisible;
    QWidget *tabLine;
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer_3;
    QComboBox *cbNumberLine;
    QSpacerItem *verticalSpacer;
    QSpacerItem *horizontalSpacer;
    QLabel *lNumberLine;
    QSpacerItem *verticalSpacer_7;
    QWidget *tabSymbol;
    QGridLayout *gridLayout_2;
    QSpacerItem *verticalSpacer_4;
    QSpacerItem *verticalSpacer_5;
    QComboBox *cbNumberSymbol;
    QLabel *lNumberSymbol;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_6;
    QWidget *tabValues;

    void setupUi(QWidget *LollipopPlotDock)
    {
        if (LollipopPlotDock->objectName().isEmpty())
            LollipopPlotDock->setObjectName("LollipopPlotDock");
        LollipopPlotDock->resize(393, 670);
        verticalLayout = new QVBoxLayout(LollipopPlotDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(LollipopPlotDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout_3 = new QGridLayout(tabGeneral);
        gridLayout_3->setObjectName("gridLayout_3");
        hsName = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(hsName, 0, 1, 1, 1);

        lXColumn = new QLabel(tabGeneral);
        lXColumn->setObjectName("lXColumn");

        gridLayout_3->addWidget(lXColumn, 3, 0, 1, 1);

        lDataColumn = new QLabel(tabGeneral);
        lDataColumn->setObjectName("lDataColumn");
        lDataColumn->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout_3->addWidget(lDataColumn, 5, 0, 1, 1);

        verticalSpacerST_2 = new QSpacerItem(32, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacerST_2, 6, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_2, 12, 0, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(lComment, 1, 0, 1, 1);

        lXData = new QLabel(tabGeneral);
        lXData->setObjectName("lXData");

        gridLayout_3->addWidget(lXData, 4, 0, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");

        gridLayout_3->addWidget(leName, 0, 2, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout_3->addWidget(lName, 0, 0, 1, 1);

        verticalSpacerGeneral = new QSpacerItem(24, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout_3->addItem(verticalSpacerGeneral, 14, 0, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout_3->addWidget(teComment, 1, 2, 1, 1);

        cbOrientation = new QComboBox(tabGeneral);
        cbOrientation->setObjectName("cbOrientation");

        gridLayout_3->addWidget(cbOrientation, 7, 2, 1, 1);

        frameXColumn = new QFrame(tabGeneral);
        frameXColumn->setObjectName("frameXColumn");
        frameXColumn->setFrameShape(QFrame::Shape::NoFrame);
        frameXColumn->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout = new QHBoxLayout(frameXColumn);
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        bRemoveXColumn = new QPushButton(frameXColumn);
        bRemoveXColumn->setObjectName("bRemoveXColumn");

        horizontalLayout->addWidget(bRemoveXColumn);


        gridLayout_3->addWidget(frameXColumn, 4, 2, 1, 1);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout_3->addWidget(cbPlotRanges, 13, 2, 1, 1);

        frameDataColumns = new QFrame(tabGeneral);
        frameDataColumns->setObjectName("frameDataColumns");
        frameDataColumns->setFrameShape(QFrame::Shape::NoFrame);
        frameDataColumns->setFrameShadow(QFrame::Shadow::Raised);

        gridLayout_3->addWidget(frameDataColumns, 5, 2, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout_3->addWidget(lPlotRange, 13, 0, 1, 1);

        verticalSpacerST = new QSpacerItem(32, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacerST, 2, 0, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout_3->addWidget(chkVisible, 16, 0, 1, 1);

        lOrientation = new QLabel(tabGeneral);
        lOrientation->setObjectName("lOrientation");

        gridLayout_3->addWidget(lOrientation, 7, 0, 1, 1);

        chkLegendVisible = new QCheckBox(tabGeneral);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout_3->addWidget(chkLegendVisible, 15, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabLine = new QWidget();
        tabLine->setObjectName("tabLine");
        gridLayout = new QGridLayout(tabLine);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_3, 3, 0, 1, 1);

        cbNumberLine = new QComboBox(tabLine);
        cbNumberLine->setObjectName("cbNumberLine");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbNumberLine->sizePolicy().hasHeightForWidth());
        cbNumberLine->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbNumberLine, 0, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 1, 1, 1);

        lNumberLine = new QLabel(tabLine);
        lNumberLine->setObjectName("lNumberLine");

        gridLayout->addWidget(lNumberLine, 0, 0, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_7, 2, 0, 1, 1);

        tabWidget->addTab(tabLine, QString());
        tabSymbol = new QWidget();
        tabSymbol->setObjectName("tabSymbol");
        gridLayout_2 = new QGridLayout(tabSymbol);
        gridLayout_2->setObjectName("gridLayout_2");
        verticalSpacer_4 = new QSpacerItem(20, 541, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_4, 3, 0, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_5, 1, 0, 1, 1);

        cbNumberSymbol = new QComboBox(tabSymbol);
        cbNumberSymbol->setObjectName("cbNumberSymbol");
        sizePolicy.setHeightForWidth(cbNumberSymbol->sizePolicy().hasHeightForWidth());
        cbNumberSymbol->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(cbNumberSymbol, 0, 2, 1, 1);

        lNumberSymbol = new QLabel(tabSymbol);
        lNumberSymbol->setObjectName("lNumberSymbol");

        gridLayout_2->addWidget(lNumberSymbol, 0, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 0, 1, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_6, 2, 0, 1, 1);

        tabWidget->addTab(tabSymbol, QString());
        tabValues = new QWidget();
        tabValues->setObjectName("tabValues");
        tabWidget->addTab(tabValues, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, bRemoveXColumn);
        QWidget::setTabOrder(bRemoveXColumn, cbOrientation);
        QWidget::setTabOrder(cbOrientation, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);
        QWidget::setTabOrder(chkVisible, cbNumberLine);
        QWidget::setTabOrder(cbNumberLine, cbNumberSymbol);

        retranslateUi(LollipopPlotDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(LollipopPlotDock);
    } // setupUi

    void retranslateUi(QWidget *LollipopPlotDock)
    {
        lXColumn->setText(tr2i18n("Data:", nullptr));
        lDataColumn->setText(tr2i18n("y:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lXData->setText(tr2i18n("x:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        bRemoveXColumn->setText(QString());
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        chkVisible->setText(tr2i18n("visible", nullptr));
        lOrientation->setText(tr2i18n("Orientation:", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        lNumberLine->setText(tr2i18n("Column", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabLine), tr2i18n("Line", nullptr));
        lNumberSymbol->setText(tr2i18n("Column", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabSymbol), tr2i18n("Symbol", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabValues), tr2i18n("Values", nullptr));
        (void)LollipopPlotDock;
    } // retranslateUi

};

namespace Ui {
    class LollipopPlotDock: public Ui_LollipopPlotDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LOLLIPOPPLOTDOCK_H

