/****************************************************************************
** Meta object code from reading C++ file 'SpreadsheetView.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/spreadsheet/SpreadsheetView.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SpreadsheetView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SpreadsheetViewE_t {};
} // unnamed namespace

template <> constexpr inline auto SpreadsheetView::qt_create_metaobjectdata<qt_meta_tag_ZN15SpreadsheetViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SpreadsheetView",
        "handleAspectsAdded",
        "",
        "first",
        "last",
        "createContextMenu",
        "QMenu*",
        "fillColumnContextMenu",
        "Column*",
        "fillToolBar",
        "QToolBar*",
        "print",
        "QPrinter*",
        "pasteIntoSelection",
        "fillWithRowNumbers",
        "selectAll",
        "selectColumn",
        "deselectColumn",
        "goToCell",
        "row",
        "col",
        "selectCell",
        "clearSelection",
        "searchReplace",
        "toggleComments",
        "toggleSparklines",
        "goToNextColumn",
        "goToPreviousColumn",
        "formatHeatmap",
        "removeFormat",
        "cutSelection",
        "copySelection",
        "clearSelectedCells",
        "maskSelection",
        "unmaskSelection",
        "reverseSelection",
        "plotData",
        "QAction*",
        "plotAnalysisData",
        "plotDataDistributionFit",
        "fillSelectedCellsWithRowNumbers",
        "fillSelectedCellsWithRandomNumbers",
        "fillWithRandomValues",
        "fillWithEquidistantValues",
        "fillWithFunctionValues",
        "fillSelectedCellsWithConstValues",
        "insertRowAbove",
        "insertRowBelow",
        "insertRowsAbove",
        "insertRowsBelow",
        "removeSelectedRows",
        "insertColumnLeft",
        "insertColumnRight",
        "insertColumnsLeft",
        "insertColumnsRight",
        "removeSelectedColumns",
        "clearSelectedColumns",
        "toggleFreezeColumn",
        "modifyValues",
        "reverseColumns",
        "dropColumnValues",
        "maskColumnValues",
        "sampleColumnValues",
        "flattenColumns",
        "normalizeSelectedColumns",
        "powerTransformSelectedColumns",
        "sortCustom",
        "sortAscending",
        "sortDescending",
        "setSelectionAs",
        "activateFormulaMode",
        "on",
        "showColumnStatistics",
        "forAll",
        "showAllColumnsStatistics",
        "showRowStatistics",
        "handleHorizontalSectionResized",
        "logicalIndex",
        "oldSize",
        "newSize",
        "handleHorizontalSectionMoved",
        "index",
        "from",
        "to",
        "handleHorizontalHeaderDoubleClicked",
        "handleHeaderDataChanged",
        "Qt::Orientation",
        "handleAspectAboutToBeRemoved",
        "updateHeaderGeometry",
        "columnClicked",
        "selectionChanged",
        "QItemSelection",
        "selected",
        "deselected",
        "advanceCell"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleAspectsAdded'
        QtMocHelpers::SlotData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'createContextMenu'
        QtMocHelpers::SlotData<void(QMenu *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'fillColumnContextMenu'
        QtMocHelpers::SlotData<void(QMenu *, Column *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { 0x80000000 | 8, 2 },
        }}),
        // Slot 'fillToolBar'
        QtMocHelpers::SlotData<void(QToolBar *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'print'
        QtMocHelpers::SlotData<void(QPrinter *) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Slot 'pasteIntoSelection'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fillWithRowNumbers'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectColumn'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'deselectColumn'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'goToCell'
        QtMocHelpers::SlotData<void(int, int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 20 },
        }}),
        // Slot 'selectCell'
        QtMocHelpers::SlotData<void(int, int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 20 },
        }}),
        // Slot 'clearSelection'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'searchReplace'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleComments'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleSparklines'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goToNextColumn'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goToPreviousColumn'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goToCell'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'formatHeatmap'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeFormat'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cutSelection'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'copySelection'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearSelectedCells'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'maskSelection'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'unmaskSelection'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reverseSelection'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'plotData'
        QtMocHelpers::SlotData<void(QAction *)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 2 },
        }}),
        // Slot 'plotAnalysisData'
        QtMocHelpers::SlotData<void(QAction *)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 2 },
        }}),
        // Slot 'plotDataDistributionFit'
        QtMocHelpers::SlotData<void(QAction *)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 2 },
        }}),
        // Slot 'fillSelectedCellsWithRowNumbers'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fillSelectedCellsWithRandomNumbers'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fillWithRandomValues'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fillWithEquidistantValues'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fillWithFunctionValues'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fillSelectedCellsWithConstValues'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'insertRowAbove'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'insertRowBelow'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'insertRowsAbove'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'insertRowsBelow'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeSelectedRows'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'insertColumnLeft'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'insertColumnRight'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'insertColumnsLeft'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'insertColumnsRight'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeSelectedColumns'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearSelectedColumns'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleFreezeColumn'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'modifyValues'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reverseColumns'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'dropColumnValues'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'maskColumnValues'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sampleColumnValues'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'flattenColumns'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'normalizeSelectedColumns'
        QtMocHelpers::SlotData<void(QAction *)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 2 },
        }}),
        // Slot 'powerTransformSelectedColumns'
        QtMocHelpers::SlotData<void(QAction *)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 2 },
        }}),
        // Slot 'sortCustom'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sortAscending'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sortDescending'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setSelectionAs'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'activateFormulaMode'
        QtMocHelpers::SlotData<void(bool)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 71 },
        }}),
        // Slot 'showColumnStatistics'
        QtMocHelpers::SlotData<void(bool)>(72, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 73 },
        }}),
        // Slot 'showColumnStatistics'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'showAllColumnsStatistics'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showRowStatistics'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleHorizontalSectionResized'
        QtMocHelpers::SlotData<void(int, int, int)>(76, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 77 }, { QMetaType::Int, 78 }, { QMetaType::Int, 79 },
        }}),
        // Slot 'handleHorizontalSectionMoved'
        QtMocHelpers::SlotData<void(int, int, int)>(80, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 81 }, { QMetaType::Int, 82 }, { QMetaType::Int, 83 },
        }}),
        // Slot 'handleHorizontalHeaderDoubleClicked'
        QtMocHelpers::SlotData<void(int)>(84, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 81 },
        }}),
        // Slot 'handleHeaderDataChanged'
        QtMocHelpers::SlotData<void(Qt::Orientation, int, int)>(85, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 86, 2 }, { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'handleAspectAboutToBeRemoved'
        QtMocHelpers::SlotData<void(int, int)>(87, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'updateHeaderGeometry'
        QtMocHelpers::SlotData<void(Qt::Orientation, int, int)>(88, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 86, 2 }, { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'columnClicked'
        QtMocHelpers::SlotData<void(int)>(89, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(90, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 91, 92 }, { 0x80000000 | 91, 93 },
        }}),
        // Slot 'advanceCell'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SpreadsheetView, qt_meta_tag_ZN15SpreadsheetViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SpreadsheetView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SpreadsheetViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SpreadsheetViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SpreadsheetViewE_t>.metaTypes,
    nullptr
} };

void SpreadsheetView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SpreadsheetView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleAspectsAdded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->createContextMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 2: _t->fillColumnContextMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Column*>>(_a[2]))); break;
        case 3: _t->fillToolBar((*reinterpret_cast<std::add_pointer_t<QToolBar*>>(_a[1]))); break;
        case 4: _t->print((*reinterpret_cast<std::add_pointer_t<QPrinter*>>(_a[1]))); break;
        case 5: _t->pasteIntoSelection(); break;
        case 6: _t->fillWithRowNumbers(); break;
        case 7: _t->selectAll(); break;
        case 8: _t->selectColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->deselectColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->goToCell((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->selectCell((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->clearSelection(); break;
        case 13: _t->searchReplace(); break;
        case 14: _t->toggleComments(); break;
        case 15: _t->toggleSparklines(); break;
        case 16: _t->goToNextColumn(); break;
        case 17: _t->goToPreviousColumn(); break;
        case 18: _t->goToCell(); break;
        case 19: _t->formatHeatmap(); break;
        case 20: _t->removeFormat(); break;
        case 21: _t->cutSelection(); break;
        case 22: _t->copySelection(); break;
        case 23: _t->clearSelectedCells(); break;
        case 24: _t->maskSelection(); break;
        case 25: _t->unmaskSelection(); break;
        case 26: _t->reverseSelection(); break;
        case 27: _t->plotData((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 28: _t->plotAnalysisData((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 29: _t->plotDataDistributionFit((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 30: _t->fillSelectedCellsWithRowNumbers(); break;
        case 31: _t->fillSelectedCellsWithRandomNumbers(); break;
        case 32: _t->fillWithRandomValues(); break;
        case 33: _t->fillWithEquidistantValues(); break;
        case 34: _t->fillWithFunctionValues(); break;
        case 35: _t->fillSelectedCellsWithConstValues(); break;
        case 36: _t->insertRowAbove(); break;
        case 37: _t->insertRowBelow(); break;
        case 38: _t->insertRowsAbove(); break;
        case 39: _t->insertRowsBelow(); break;
        case 40: _t->removeSelectedRows(); break;
        case 41: _t->insertColumnLeft(); break;
        case 42: _t->insertColumnRight(); break;
        case 43: _t->insertColumnsLeft(); break;
        case 44: _t->insertColumnsRight(); break;
        case 45: _t->removeSelectedColumns(); break;
        case 46: _t->clearSelectedColumns(); break;
        case 47: _t->toggleFreezeColumn(); break;
        case 48: _t->modifyValues(); break;
        case 49: _t->reverseColumns(); break;
        case 50: _t->dropColumnValues(); break;
        case 51: _t->maskColumnValues(); break;
        case 52: _t->sampleColumnValues(); break;
        case 53: _t->flattenColumns(); break;
        case 54: _t->normalizeSelectedColumns((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 55: _t->powerTransformSelectedColumns((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 56: _t->sortCustom(); break;
        case 57: _t->sortAscending(); break;
        case 58: _t->sortDescending(); break;
        case 59: _t->setSelectionAs(); break;
        case 60: _t->activateFormulaMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 61: _t->showColumnStatistics((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 62: _t->showColumnStatistics(); break;
        case 63: _t->showAllColumnsStatistics(); break;
        case 64: _t->showRowStatistics(); break;
        case 65: _t->handleHorizontalSectionResized((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 66: _t->handleHorizontalSectionMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 67: _t->handleHorizontalHeaderDoubleClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 68: _t->handleHeaderDataChanged((*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 69: _t->handleAspectAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 70: _t->updateHeaderGeometry((*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 71: _t->columnClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 72: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 73: _t->advanceCell(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 54:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 55:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *SpreadsheetView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SpreadsheetView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SpreadsheetViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int SpreadsheetView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 74)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 74;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 74)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 74;
    }
    return _id;
}
QT_WARNING_POP
