/********************************************************************************
** Form generated from reading UI file 'runchartdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RUNCHARTDOCK_H
#define UI_RUNCHARTDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_RunChartDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    QCheckBox *chkVisible;
    TimedLineEdit *leName;
    ResizableTextEdit *teComment;
    QSpacerItem *verticalSpacerGeneral;
    QCheckBox *chkLegendVisible;
    QSpacerItem *verticalSpacer;
    QLabel *lYDataColumn;
    QLabel *lPlotRange;
    QSpacerItem *horizontalSpacer_5;
    QLabel *lName;
    QComboBox *cbPlotRanges;
    QSpacerItem *verticalSpacer_4;
    QLabel *lComment;
    QLabel *lCenterMetric;
    QComboBox *cbCenterMetric;
    QWidget *tabDataLine;
    QVBoxLayout *verticalLayout_2;
    QLabel *lLine;
    QSpacerItem *verticalSpacer_10;
    QSpacerItem *verticalSpacer_11;
    QSpacerItem *verticalSpacer_2;
    QWidget *tabCenterLine;
    QVBoxLayout *verticalLayout_3;
    QLabel *lCenter;
    QSpacerItem *verticalSpacer_5;
    QSpacerItem *verticalSpacer_6;
    QSpacerItem *verticalSpacer_3;

    void setupUi(QWidget *RunChartDock)
    {
        if (RunChartDock->objectName().isEmpty())
            RunChartDock->setObjectName("RunChartDock");
        RunChartDock->resize(323, 609);
        verticalLayout = new QVBoxLayout(RunChartDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(RunChartDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setObjectName("gridLayout");
        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout->addWidget(chkVisible, 10, 0, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        verticalSpacerGeneral = new QSpacerItem(24, 214, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout->addItem(verticalSpacerGeneral, 8, 0, 1, 1);

        chkLegendVisible = new QCheckBox(tabGeneral);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout->addWidget(chkLegendVisible, 9, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        lYDataColumn = new QLabel(tabGeneral);
        lYDataColumn->setObjectName("lYDataColumn");

        gridLayout->addWidget(lYDataColumn, 3, 0, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout->addWidget(lPlotRange, 7, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout->addWidget(cbPlotRanges, 7, 2, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 5, 0, 2, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        lCenterMetric = new QLabel(tabGeneral);
        lCenterMetric->setObjectName("lCenterMetric");

        gridLayout->addWidget(lCenterMetric, 4, 0, 1, 1);

        cbCenterMetric = new QComboBox(tabGeneral);
        cbCenterMetric->setObjectName("cbCenterMetric");

        gridLayout->addWidget(cbCenterMetric, 4, 2, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabDataLine = new QWidget();
        tabDataLine->setObjectName("tabDataLine");
        verticalLayout_2 = new QVBoxLayout(tabDataLine);
        verticalLayout_2->setObjectName("verticalLayout_2");
        lLine = new QLabel(tabDataLine);
        lLine->setObjectName("lLine");
        QFont font;
        font.setBold(true);
        lLine->setFont(font);

        verticalLayout_2->addWidget(lLine);

        verticalSpacer_10 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_10);

        verticalSpacer_11 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_11);

        verticalSpacer_2 = new QSpacerItem(20, 654, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        tabWidget->addTab(tabDataLine, QString());
        tabCenterLine = new QWidget();
        tabCenterLine->setObjectName("tabCenterLine");
        verticalLayout_3 = new QVBoxLayout(tabCenterLine);
        verticalLayout_3->setObjectName("verticalLayout_3");
        lCenter = new QLabel(tabCenterLine);
        lCenter->setObjectName("lCenter");
        lCenter->setFont(font);

        verticalLayout_3->addWidget(lCenter);

        verticalSpacer_5 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_5);

        verticalSpacer_6 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_6);

        verticalSpacer_3 = new QSpacerItem(20, 654, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);

        tabWidget->addTab(tabCenterLine, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbCenterMetric);
        QWidget::setTabOrder(cbCenterMetric, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);

        retranslateUi(RunChartDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(RunChartDock);
    } // setupUi

    void retranslateUi(QWidget *RunChartDock)
    {
        RunChartDock->setWindowTitle(tr2i18n("Form", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        lYDataColumn->setText(tr2i18n("Data:", nullptr));
        lPlotRange->setText(tr2i18n("Plot range:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lCenterMetric->setText(tr2i18n("Center:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        lLine->setText(tr2i18n("Line", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDataLine), tr2i18n("Data Line", nullptr));
        lCenter->setText(tr2i18n("Line", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabCenterLine), tr2i18n("Center Line", nullptr));
    } // retranslateUi

};

namespace Ui {
    class RunChartDock: public Ui_RunChartDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RUNCHARTDOCK_H

