/****************************************************************************
** Meta object code from reading C++ file 'Worksheet.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/Worksheet.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Worksheet.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9WorksheetE_t {};
} // unnamed namespace

template <> constexpr inline auto Worksheet::qt_create_metaobjectdata<qt_meta_tag_ZN9WorksheetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Worksheet",
        "requestProjectContextMenu",
        "",
        "QMenu*",
        "itemSelected",
        "QGraphicsItem*",
        "itemDeselected",
        "requestUpdate",
        "cartesianPlotMouseModeChanged",
        "CartesianPlot::MouseMode",
        "showCursorDock",
        "TreeModel*",
        "QList<CartesianPlot*>",
        "propertiesExplorerRequested",
        "childContextMenuRequested",
        "AspectType",
        "scaleContentChanged",
        "useViewSizeChanged",
        "pageRectChanged",
        "QRectF",
        "layoutChanged",
        "Worksheet::Layout",
        "layoutTopMarginChanged",
        "layoutBottomMarginChanged",
        "layoutLeftMarginChanged",
        "layoutRightMarginChanged",
        "layoutVerticalSpacingChanged",
        "layoutHorizontalSpacingChanged",
        "layoutRowCountChanged",
        "layoutColumnCountChanged",
        "changed",
        "themeChanged",
        "setTheme",
        "cartesianPlotAxisShift",
        "delta",
        "Dimension",
        "dim",
        "index",
        "cartesianPlotWheelEvent",
        "QPointF",
        "sceneRelPos",
        "xIndex",
        "yIndex",
        "considerDimension",
        "cartesianPlotMousePressZoomSelectionMode",
        "logicPos",
        "cartesianPlotMousePressCursorMode",
        "cursorNumber",
        "cartesianPlotMouseMoveZoomSelectionMode",
        "cartesianPlotMouseMoveSelectionMode",
        "logicStart",
        "logicEnd",
        "cartesianPlotMouseMoveCursorMode",
        "cartesianPlotMouseReleaseZoomSelectionMode",
        "cartesianPlotMouseHoverZoomSelectionMode",
        "cartesianPlotMouseHoverOutsideDataRect",
        "cartesianPlotMouseModeChangedSlot",
        "updateCurveBackground",
        "QColor",
        "curveName",
        "updateCompleteCursorTreeModel",
        "cursorPosChanged",
        "xPos",
        "curveAdded",
        "const XYCurve*",
        "curve",
        "curveRemoved",
        "curveDataChanged",
        "handleAspectAdded",
        "const AbstractAspect*",
        "handleAspectAboutToBeRemoved",
        "handleAspectRemoved",
        "parent",
        "before",
        "child",
        "handleAspectMoved",
        "childSelected",
        "childDeselected"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestProjectContextMenu'
        QtMocHelpers::SignalData<void(QMenu *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'itemSelected'
        QtMocHelpers::SignalData<void(QGraphicsItem *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'itemDeselected'
        QtMocHelpers::SignalData<void(QGraphicsItem *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'requestUpdate'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cartesianPlotMouseModeChanged'
        QtMocHelpers::SignalData<void(CartesianPlot::MouseMode)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'showCursorDock'
        QtMocHelpers::SignalData<void(TreeModel *, QVector<CartesianPlot*>)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 }, { 0x80000000 | 12, 2 },
        }}),
        // Signal 'propertiesExplorerRequested'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'childContextMenuRequested'
        QtMocHelpers::SignalData<void(AspectType, QMenu *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Signal 'scaleContentChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'useViewSizeChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'pageRectChanged'
        QtMocHelpers::SignalData<void(const QRectF &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Signal 'layoutChanged'
        QtMocHelpers::SignalData<void(Worksheet::Layout)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Signal 'layoutTopMarginChanged'
        QtMocHelpers::SignalData<void(double)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'layoutBottomMarginChanged'
        QtMocHelpers::SignalData<void(double)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'layoutLeftMarginChanged'
        QtMocHelpers::SignalData<void(double)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'layoutRightMarginChanged'
        QtMocHelpers::SignalData<void(double)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'layoutVerticalSpacingChanged'
        QtMocHelpers::SignalData<void(double)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'layoutHorizontalSpacingChanged'
        QtMocHelpers::SignalData<void(double)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'layoutRowCountChanged'
        QtMocHelpers::SignalData<void(int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'layoutColumnCountChanged'
        QtMocHelpers::SignalData<void(int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'themeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'setTheme'
        QtMocHelpers::SlotData<void(const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'cartesianPlotAxisShift'
        QtMocHelpers::SlotData<void(int, Dimension, int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { 0x80000000 | 35, 36 }, { QMetaType::Int, 37 },
        }}),
        // Slot 'cartesianPlotWheelEvent'
        QtMocHelpers::SlotData<void(const QPointF &, int, int, int, bool, Dimension)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 40 }, { QMetaType::Int, 34 }, { QMetaType::Int, 41 }, { QMetaType::Int, 42 },
            { QMetaType::Bool, 43 }, { 0x80000000 | 35, 36 },
        }}),
        // Slot 'cartesianPlotMousePressZoomSelectionMode'
        QtMocHelpers::SlotData<void(QPointF)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 45 },
        }}),
        // Slot 'cartesianPlotMousePressCursorMode'
        QtMocHelpers::SlotData<void(int, QPointF)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 47 }, { 0x80000000 | 39, 45 },
        }}),
        // Slot 'cartesianPlotMouseMoveZoomSelectionMode'
        QtMocHelpers::SlotData<void(QPointF)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 45 },
        }}),
        // Slot 'cartesianPlotMouseMoveSelectionMode'
        QtMocHelpers::SlotData<void(QPointF, QPointF)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 50 }, { 0x80000000 | 39, 51 },
        }}),
        // Slot 'cartesianPlotMouseMoveCursorMode'
        QtMocHelpers::SlotData<void(int, QPointF)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 47 }, { 0x80000000 | 39, 45 },
        }}),
        // Slot 'cartesianPlotMouseReleaseZoomSelectionMode'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cartesianPlotMouseHoverZoomSelectionMode'
        QtMocHelpers::SlotData<void(QPointF)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 45 },
        }}),
        // Slot 'cartesianPlotMouseHoverOutsideDataRect'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cartesianPlotMouseModeChangedSlot'
        QtMocHelpers::SlotData<void(CartesianPlot::MouseMode)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Slot 'updateCurveBackground'
        QtMocHelpers::SlotData<void(QColor, const QString &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 2 }, { QMetaType::QString, 59 },
        }}),
        // Slot 'updateCompleteCursorTreeModel'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cursorPosChanged'
        QtMocHelpers::SlotData<void(int, double)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 47 }, { QMetaType::Double, 62 },
        }}),
        // Slot 'curveAdded'
        QtMocHelpers::SlotData<void(const XYCurve *)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Slot 'curveRemoved'
        QtMocHelpers::SlotData<void(const XYCurve *)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Slot 'curveDataChanged'
        QtMocHelpers::SlotData<void(const XYCurve *)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Slot 'handleAspectAdded'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 69, 2 },
        }}),
        // Slot 'handleAspectAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 69, 2 },
        }}),
        // Slot 'handleAspectRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *, const AbstractAspect *, const AbstractAspect *)>(71, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 69, 72 }, { 0x80000000 | 69, 73 }, { 0x80000000 | 69, 74 },
        }}),
        // Slot 'handleAspectMoved'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'childSelected'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(76, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 69, 2 },
        }}),
        // Slot 'childDeselected'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(77, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 69, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Worksheet, qt_meta_tag_ZN9WorksheetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Worksheet::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractPart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9WorksheetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9WorksheetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9WorksheetE_t>.metaTypes,
    nullptr
} };

void Worksheet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Worksheet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestProjectContextMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 1: _t->itemSelected((*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[1]))); break;
        case 2: _t->itemDeselected((*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[1]))); break;
        case 3: _t->requestUpdate(); break;
        case 4: _t->cartesianPlotMouseModeChanged((*reinterpret_cast<std::add_pointer_t<CartesianPlot::MouseMode>>(_a[1]))); break;
        case 5: _t->showCursorDock((*reinterpret_cast<std::add_pointer_t<TreeModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<CartesianPlot*>>>(_a[2]))); break;
        case 6: _t->propertiesExplorerRequested(); break;
        case 7: _t->childContextMenuRequested((*reinterpret_cast<std::add_pointer_t<AspectType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2]))); break;
        case 8: _t->scaleContentChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->useViewSizeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->pageRectChanged((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 11: _t->layoutChanged((*reinterpret_cast<std::add_pointer_t<Worksheet::Layout>>(_a[1]))); break;
        case 12: _t->layoutTopMarginChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 13: _t->layoutBottomMarginChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 14: _t->layoutLeftMarginChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: _t->layoutRightMarginChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 16: _t->layoutVerticalSpacingChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: _t->layoutHorizontalSpacingChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 18: _t->layoutRowCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->layoutColumnCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->changed(); break;
        case 21: _t->themeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->setTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->cartesianPlotAxisShift((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 24: _t->cartesianPlotWheelEvent((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<Dimension>>(_a[6]))); break;
        case 25: _t->cartesianPlotMousePressZoomSelectionMode((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 26: _t->cartesianPlotMousePressCursorMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 27: _t->cartesianPlotMouseMoveZoomSelectionMode((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 28: _t->cartesianPlotMouseMoveSelectionMode((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 29: _t->cartesianPlotMouseMoveCursorMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 30: _t->cartesianPlotMouseReleaseZoomSelectionMode(); break;
        case 31: _t->cartesianPlotMouseHoverZoomSelectionMode((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 32: _t->cartesianPlotMouseHoverOutsideDataRect(); break;
        case 33: _t->cartesianPlotMouseModeChangedSlot((*reinterpret_cast<std::add_pointer_t<CartesianPlot::MouseMode>>(_a[1]))); break;
        case 34: _t->updateCurveBackground((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 35: _t->updateCompleteCursorTreeModel(); break;
        case 36: _t->cursorPosChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 37: _t->curveAdded((*reinterpret_cast<std::add_pointer_t<const XYCurve*>>(_a[1]))); break;
        case 38: _t->curveRemoved((*reinterpret_cast<std::add_pointer_t<const XYCurve*>>(_a[1]))); break;
        case 39: _t->curveDataChanged((*reinterpret_cast<std::add_pointer_t<const XYCurve*>>(_a[1]))); break;
        case 40: _t->handleAspectAdded((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 41: _t->handleAspectAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 42: _t->handleAspectRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[3]))); break;
        case 43: _t->handleAspectMoved(); break;
        case 44: _t->childSelected((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 45: _t->childDeselected((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<CartesianPlot*> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(QMenu * )>(_a, &Worksheet::requestProjectContextMenu, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(QGraphicsItem * )>(_a, &Worksheet::itemSelected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(QGraphicsItem * )>(_a, &Worksheet::itemDeselected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)()>(_a, &Worksheet::requestUpdate, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(CartesianPlot::MouseMode )>(_a, &Worksheet::cartesianPlotMouseModeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(TreeModel * , QVector<CartesianPlot*> )>(_a, &Worksheet::showCursorDock, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)()>(_a, &Worksheet::propertiesExplorerRequested, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(AspectType , QMenu * )>(_a, &Worksheet::childContextMenuRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(bool )>(_a, &Worksheet::scaleContentChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(bool )>(_a, &Worksheet::useViewSizeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(const QRectF & )>(_a, &Worksheet::pageRectChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(Worksheet::Layout )>(_a, &Worksheet::layoutChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(double )>(_a, &Worksheet::layoutTopMarginChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(double )>(_a, &Worksheet::layoutBottomMarginChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(double )>(_a, &Worksheet::layoutLeftMarginChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(double )>(_a, &Worksheet::layoutRightMarginChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(double )>(_a, &Worksheet::layoutVerticalSpacingChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(double )>(_a, &Worksheet::layoutHorizontalSpacingChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(int )>(_a, &Worksheet::layoutRowCountChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(int )>(_a, &Worksheet::layoutColumnCountChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)()>(_a, &Worksheet::changed, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Worksheet::*)(const QString & )>(_a, &Worksheet::themeChanged, 21))
            return;
    }
}

const QMetaObject *Worksheet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Worksheet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9WorksheetE_t>.strings))
        return static_cast<void*>(this);
    return AbstractPart::qt_metacast(_clname);
}

int Worksheet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractPart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 46)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 46;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 46)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 46;
    }
    return _id;
}

// SIGNAL 0
void Worksheet::requestProjectContextMenu(QMenu * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Worksheet::itemSelected(QGraphicsItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Worksheet::itemDeselected(QGraphicsItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Worksheet::requestUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Worksheet::cartesianPlotMouseModeChanged(CartesianPlot::MouseMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Worksheet::showCursorDock(TreeModel * _t1, QVector<CartesianPlot*> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Worksheet::propertiesExplorerRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Worksheet::childContextMenuRequested(AspectType _t1, QMenu * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Worksheet::scaleContentChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Worksheet::useViewSizeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Worksheet::pageRectChanged(const QRectF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Worksheet::layoutChanged(Worksheet::Layout _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Worksheet::layoutTopMarginChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Worksheet::layoutBottomMarginChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Worksheet::layoutLeftMarginChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Worksheet::layoutRightMarginChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Worksheet::layoutVerticalSpacingChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Worksheet::layoutHorizontalSpacingChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Worksheet::layoutRowCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Worksheet::layoutColumnCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void Worksheet::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Worksheet::themeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}
QT_WARNING_POP
