/********************************************************************************
** Form generated from reading UI file 'binaryoptionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BINARYOPTIONSWIDGET_H
#define UI_BINARYOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_BinaryOptionsWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *lSkipBytes;
    QSpinBox *niVectors;
    QSpacerItem *horizontalSpacer;
    QLabel *lDataType;
    QComboBox *cbDataType;
    QSpinBox *sbSkipStartBytes;
    QSpinBox *sbSkipBytes;
    QLabel *lVectors;
    QLabel *lSkipStartBytes;
    QLabel *lByteOrder;
    QComboBox *cbByteOrder;
    QSpacerItem *verticalSpacer;
    QCheckBox *chbCreateIndex;

    void setupUi(QWidget *BinaryOptionsWidget)
    {
        if (BinaryOptionsWidget->objectName().isEmpty())
            BinaryOptionsWidget->setObjectName("BinaryOptionsWidget");
        BinaryOptionsWidget->resize(295, 240);
        gridLayout = new QGridLayout(BinaryOptionsWidget);
        gridLayout->setObjectName("gridLayout");
        lSkipBytes = new QLabel(BinaryOptionsWidget);
        lSkipBytes->setObjectName("lSkipBytes");

        gridLayout->addWidget(lSkipBytes, 4, 0, 1, 1);

        niVectors = new QSpinBox(BinaryOptionsWidget);
        niVectors->setObjectName("niVectors");
        niVectors->setMinimum(1);
        niVectors->setValue(2);

        gridLayout->addWidget(niVectors, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(80, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        lDataType = new QLabel(BinaryOptionsWidget);
        lDataType->setObjectName("lDataType");

        gridLayout->addWidget(lDataType, 1, 0, 1, 1);

        cbDataType = new QComboBox(BinaryOptionsWidget);
        cbDataType->setObjectName("cbDataType");

        gridLayout->addWidget(cbDataType, 1, 1, 1, 1);

        sbSkipStartBytes = new QSpinBox(BinaryOptionsWidget);
        sbSkipStartBytes->setObjectName("sbSkipStartBytes");
        sbSkipStartBytes->setMaximum(2147483647);

        gridLayout->addWidget(sbSkipStartBytes, 3, 1, 1, 1);

        sbSkipBytes = new QSpinBox(BinaryOptionsWidget);
        sbSkipBytes->setObjectName("sbSkipBytes");
        sbSkipBytes->setMaximum(2147483647);

        gridLayout->addWidget(sbSkipBytes, 4, 1, 1, 1);

        lVectors = new QLabel(BinaryOptionsWidget);
        lVectors->setObjectName("lVectors");

        gridLayout->addWidget(lVectors, 0, 0, 1, 1);

        lSkipStartBytes = new QLabel(BinaryOptionsWidget);
        lSkipStartBytes->setObjectName("lSkipStartBytes");

        gridLayout->addWidget(lSkipStartBytes, 3, 0, 1, 1);

        lByteOrder = new QLabel(BinaryOptionsWidget);
        lByteOrder->setObjectName("lByteOrder");

        gridLayout->addWidget(lByteOrder, 2, 0, 1, 1);

        cbByteOrder = new QComboBox(BinaryOptionsWidget);
        cbByteOrder->setObjectName("cbByteOrder");

        gridLayout->addWidget(cbByteOrder, 2, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 74, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 6, 0, 1, 1);

        chbCreateIndex = new QCheckBox(BinaryOptionsWidget);
        chbCreateIndex->setObjectName("chbCreateIndex");

        gridLayout->addWidget(chbCreateIndex, 5, 0, 1, 1);


        retranslateUi(BinaryOptionsWidget);

        QMetaObject::connectSlotsByName(BinaryOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *BinaryOptionsWidget)
    {
        lSkipBytes->setText(tr2i18n("Skip Bytes:", nullptr));
#if QT_CONFIG(tooltip)
        niVectors->setToolTip(tr2i18n("The number of vectors in the file", nullptr));
#endif // QT_CONFIG(tooltip)
        lDataType->setText(tr2i18n("Data type:", nullptr));
#if QT_CONFIG(tooltip)
        sbSkipStartBytes->setToolTip(tr2i18n("Skip bytes at start of file", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        sbSkipBytes->setToolTip(tr2i18n("Skip bytes after each value", nullptr));
#endif // QT_CONFIG(tooltip)
        lVectors->setText(tr2i18n("Vectors:", nullptr));
#if QT_CONFIG(tooltip)
        lSkipStartBytes->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        lSkipStartBytes->setText(tr2i18n("Skip start bytes:", nullptr));
        lByteOrder->setText(tr2i18n("Byte order:", nullptr));
        chbCreateIndex->setText(tr2i18n("Create index column", nullptr));
        (void)BinaryOptionsWidget;
    } // retranslateUi

};

namespace Ui {
    class BinaryOptionsWidget: public Ui_BinaryOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BINARYOPTIONSWIDGET_H

