/****************************************************************************
** Meta object code from reading C++ file 'ErrorBar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/plots/cartesian/ErrorBar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ErrorBar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8ErrorBarE_t {};
} // unnamed namespace

template <> constexpr inline auto ErrorBar::qt_create_metaobjectdata<qt_meta_tag_ZN8ErrorBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ErrorBar",
        "updateRequested",
        "",
        "updatePixmapRequested",
        "xErrorTypeChanged",
        "ErrorBar::ErrorType",
        "xPlusDataChanged",
        "xPlusColumnChanged",
        "const AbstractColumn*",
        "xMinusDataChanged",
        "xMinusColumnChanged",
        "yErrorTypeChanged",
        "yPlusDataChanged",
        "yPlusColumnChanged",
        "yMinusDataChanged",
        "yMinusColumnChanged",
        "typeChanged",
        "ErrorBar::Type",
        "capSizeChanged",
        "xPlusColumnAboutToBeRemoved",
        "const AbstractAspect*",
        "xMinusColumnAboutToBeRemoved",
        "yPlusColumnAboutToBeRemoved",
        "yMinusColumnAboutToBeRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'updateRequested'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updatePixmapRequested'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xErrorTypeChanged'
        QtMocHelpers::SignalData<void(ErrorBar::ErrorType)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'xPlusDataChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xPlusColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'xMinusDataChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xMinusColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'yErrorTypeChanged'
        QtMocHelpers::SignalData<void(ErrorBar::ErrorType)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'yPlusDataChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yPlusColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'yMinusDataChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yMinusColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(ErrorBar::Type)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Signal 'capSizeChanged'
        QtMocHelpers::SignalData<void(double)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'xPlusColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 2 },
        }}),
        // Slot 'xMinusColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 2 },
        }}),
        // Slot 'yPlusColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 2 },
        }}),
        // Slot 'yMinusColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ErrorBar, qt_meta_tag_ZN8ErrorBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ErrorBar::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractAspect::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ErrorBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ErrorBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8ErrorBarE_t>.metaTypes,
    nullptr
} };

void ErrorBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ErrorBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateRequested(); break;
        case 1: _t->updatePixmapRequested(); break;
        case 2: _t->xErrorTypeChanged((*reinterpret_cast<std::add_pointer_t<ErrorBar::ErrorType>>(_a[1]))); break;
        case 3: _t->xPlusDataChanged(); break;
        case 4: _t->xPlusColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 5: _t->xMinusDataChanged(); break;
        case 6: _t->xMinusColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 7: _t->yErrorTypeChanged((*reinterpret_cast<std::add_pointer_t<ErrorBar::ErrorType>>(_a[1]))); break;
        case 8: _t->yPlusDataChanged(); break;
        case 9: _t->yPlusColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 10: _t->yMinusDataChanged(); break;
        case 11: _t->yMinusColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 12: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<ErrorBar::Type>>(_a[1]))); break;
        case 13: _t->capSizeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 14: _t->xPlusColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 15: _t->xMinusColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 16: _t->yPlusColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 17: _t->yMinusColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)()>(_a, &ErrorBar::updateRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)()>(_a, &ErrorBar::updatePixmapRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)(ErrorBar::ErrorType )>(_a, &ErrorBar::xErrorTypeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)()>(_a, &ErrorBar::xPlusDataChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)(const AbstractColumn * )>(_a, &ErrorBar::xPlusColumnChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)()>(_a, &ErrorBar::xMinusDataChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)(const AbstractColumn * )>(_a, &ErrorBar::xMinusColumnChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)(ErrorBar::ErrorType )>(_a, &ErrorBar::yErrorTypeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)()>(_a, &ErrorBar::yPlusDataChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)(const AbstractColumn * )>(_a, &ErrorBar::yPlusColumnChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)()>(_a, &ErrorBar::yMinusDataChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)(const AbstractColumn * )>(_a, &ErrorBar::yMinusColumnChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)(ErrorBar::Type )>(_a, &ErrorBar::typeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ErrorBar::*)(double )>(_a, &ErrorBar::capSizeChanged, 13))
            return;
    }
}

const QMetaObject *ErrorBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ErrorBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ErrorBarE_t>.strings))
        return static_cast<void*>(this);
    return AbstractAspect::qt_metacast(_clname);
}

int ErrorBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractAspect::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void ErrorBar::updateRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ErrorBar::updatePixmapRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ErrorBar::xErrorTypeChanged(ErrorBar::ErrorType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ErrorBar::xPlusDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ErrorBar::xPlusColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ErrorBar::xMinusDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ErrorBar::xMinusColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ErrorBar::yErrorTypeChanged(ErrorBar::ErrorType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ErrorBar::yPlusDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ErrorBar::yPlusColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ErrorBar::yMinusDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ErrorBar::yMinusColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ErrorBar::typeChanged(ErrorBar::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void ErrorBar::capSizeChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
