/********************************************************************************
** Form generated from reading UI file 'equidistantvalueswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EQUIDISTANTVALUESWIDGET_H
#define UI_EQUIDISTANTVALUESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "UTCDateTimeEdit.h"

QT_BEGIN_NAMESPACE

class Ui_EquidistantValuesWidget
{
public:
    QGridLayout *gridLayout;
    UTCDateTimeEdit *dteFrom;
    QLabel *lTo;
    QLabel *lIncrementDateTime;
    UTCDateTimeEdit *dteTo;
    QLineEdit *leNumber;
    QLabel *lNumeric;
    QLabel *lFrom;
    QFrame *frameIncrementDateTime;
    QHBoxLayout *horizontalLayout;
    QLineEdit *leIncrementDateTime;
    QComboBox *cbIncrementDateTimeUnit;
    QLabel *label;
    QLineEdit *leIncrement;
    QLabel *lFromDateTime;
    QLabel *lDateTime;
    QComboBox *cbType;
    QLabel *lIncrement;
    QLabel *lToDateTime;
    QLineEdit *leTo;
    QLineEdit *leFrom;
    QLabel *lNumber;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *EquidistantValuesWidget)
    {
        if (EquidistantValuesWidget->objectName().isEmpty())
            EquidistantValuesWidget->setObjectName("EquidistantValuesWidget");
        EquidistantValuesWidget->resize(320, 382);
        gridLayout = new QGridLayout(EquidistantValuesWidget);
        gridLayout->setObjectName("gridLayout");
        dteFrom = new UTCDateTimeEdit(EquidistantValuesWidget);
        dteFrom->setObjectName("dteFrom");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(dteFrom->sizePolicy().hasHeightForWidth());
        dteFrom->setSizePolicy(sizePolicy);

        gridLayout->addWidget(dteFrom, 9, 2, 1, 1);

        lTo = new QLabel(EquidistantValuesWidget);
        lTo->setObjectName("lTo");

        gridLayout->addWidget(lTo, 5, 0, 1, 1);

        lIncrementDateTime = new QLabel(EquidistantValuesWidget);
        lIncrementDateTime->setObjectName("lIncrementDateTime");

        gridLayout->addWidget(lIncrementDateTime, 8, 0, 1, 1);

        dteTo = new UTCDateTimeEdit(EquidistantValuesWidget);
        dteTo->setObjectName("dteTo");

        gridLayout->addWidget(dteTo, 10, 2, 1, 1);

        leNumber = new QLineEdit(EquidistantValuesWidget);
        leNumber->setObjectName("leNumber");

        gridLayout->addWidget(leNumber, 1, 2, 1, 1);

        lNumeric = new QLabel(EquidistantValuesWidget);
        lNumeric->setObjectName("lNumeric");
        QFont font;
        font.setBold(true);
        lNumeric->setFont(font);

        gridLayout->addWidget(lNumeric, 2, 0, 1, 1);

        lFrom = new QLabel(EquidistantValuesWidget);
        lFrom->setObjectName("lFrom");

        gridLayout->addWidget(lFrom, 4, 0, 1, 1);

        frameIncrementDateTime = new QFrame(EquidistantValuesWidget);
        frameIncrementDateTime->setObjectName("frameIncrementDateTime");
        frameIncrementDateTime->setFrameShape(QFrame::NoFrame);
        frameIncrementDateTime->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(frameIncrementDateTime);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        leIncrementDateTime = new QLineEdit(frameIncrementDateTime);
        leIncrementDateTime->setObjectName("leIncrementDateTime");

        horizontalLayout->addWidget(leIncrementDateTime);

        cbIncrementDateTimeUnit = new QComboBox(frameIncrementDateTime);
        cbIncrementDateTimeUnit->setObjectName("cbIncrementDateTimeUnit");

        horizontalLayout->addWidget(cbIncrementDateTimeUnit);


        gridLayout->addWidget(frameIncrementDateTime, 8, 2, 1, 1);

        label = new QLabel(EquidistantValuesWidget);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        leIncrement = new QLineEdit(EquidistantValuesWidget);
        leIncrement->setObjectName("leIncrement");

        gridLayout->addWidget(leIncrement, 3, 2, 1, 1);

        lFromDateTime = new QLabel(EquidistantValuesWidget);
        lFromDateTime->setObjectName("lFromDateTime");

        gridLayout->addWidget(lFromDateTime, 9, 0, 1, 1);

        lDateTime = new QLabel(EquidistantValuesWidget);
        lDateTime->setObjectName("lDateTime");
        lDateTime->setFont(font);

        gridLayout->addWidget(lDateTime, 6, 0, 2, 2);

        cbType = new QComboBox(EquidistantValuesWidget);
        cbType->setObjectName("cbType");
        sizePolicy.setHeightForWidth(cbType->sizePolicy().hasHeightForWidth());
        cbType->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbType, 0, 2, 1, 1);

        lIncrement = new QLabel(EquidistantValuesWidget);
        lIncrement->setObjectName("lIncrement");

        gridLayout->addWidget(lIncrement, 3, 0, 1, 1);

        lToDateTime = new QLabel(EquidistantValuesWidget);
        lToDateTime->setObjectName("lToDateTime");

        gridLayout->addWidget(lToDateTime, 10, 0, 1, 1);

        leTo = new QLineEdit(EquidistantValuesWidget);
        leTo->setObjectName("leTo");

        gridLayout->addWidget(leTo, 5, 2, 1, 1);

        leFrom = new QLineEdit(EquidistantValuesWidget);
        leFrom->setObjectName("leFrom");

        gridLayout->addWidget(leFrom, 4, 2, 1, 1);

        lNumber = new QLabel(EquidistantValuesWidget);
        lNumber->setObjectName("lNumber");

        gridLayout->addWidget(lNumber, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 27, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 11, 0, 1, 1);

        QWidget::setTabOrder(cbType, leNumber);
        QWidget::setTabOrder(leNumber, leIncrement);
        QWidget::setTabOrder(leIncrement, leFrom);
        QWidget::setTabOrder(leFrom, leTo);
        QWidget::setTabOrder(leTo, leIncrementDateTime);
        QWidget::setTabOrder(leIncrementDateTime, cbIncrementDateTimeUnit);
        QWidget::setTabOrder(cbIncrementDateTimeUnit, dteFrom);
        QWidget::setTabOrder(dteFrom, dteTo);

        retranslateUi(EquidistantValuesWidget);

        QMetaObject::connectSlotsByName(EquidistantValuesWidget);
    } // setupUi

    void retranslateUi(QWidget *EquidistantValuesWidget)
    {
        lTo->setText(tr2i18n("To:", nullptr));
        lIncrementDateTime->setText(tr2i18n("Increment:", nullptr));
        lNumeric->setText(tr2i18n("Numeric", nullptr));
        lFrom->setText(tr2i18n("From:", nullptr));
        label->setText(tr2i18n("Fix:", nullptr));
        lFromDateTime->setText(tr2i18n("From:", nullptr));
        lDateTime->setText(tr2i18n("Date & Time", nullptr));
        lIncrement->setText(tr2i18n("Increment:", nullptr));
        lToDateTime->setText(tr2i18n("To:", nullptr));
        lNumber->setText(tr2i18n("Number:", nullptr));
        (void)EquidistantValuesWidget;
    } // retranslateUi

};

namespace Ui {
    class EquidistantValuesWidget: public Ui_EquidistantValuesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EQUIDISTANTVALUESWIDGET_H

