/********************************************************************************
** Form generated from reading UI file 'settingsworksheetpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSWORKSHEETPAGE_H
#define UI_SETTINGSWORKSHEETPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SettingsWorksheetPage
{
public:
    QGridLayout *gridLayout;
    QLabel *lLatexWarning;
    QLabel *lPresenterMode_2;
    QLabel *lPerformance;
    QComboBox *cbPreviewThumbnailSize;
    QLabel *lTex;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer;
    QLabel *lPresenterMode;
    QSpacerItem *verticalSpacer_5;
    QLabel *lPreview;
    QLabel *lPreviewThumbnailSize;
    QSpacerItem *spacerItem;
    QCheckBox *chkDoubleBuffering;
    QLabel *lTheme;
    QCheckBox *chkPresenterModeInteractive;
    QLabel *lTexEngine;
    QSpacerItem *verticalSpacer_4;
    QComboBox *cbTexEngine;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *SettingsWorksheetPage)
    {
        if (SettingsWorksheetPage->objectName().isEmpty())
            SettingsWorksheetPage->setObjectName("SettingsWorksheetPage");
        SettingsWorksheetPage->resize(487, 482);
        gridLayout = new QGridLayout(SettingsWorksheetPage);
        gridLayout->setObjectName("gridLayout");
        lLatexWarning = new QLabel(SettingsWorksheetPage);
        lLatexWarning->setObjectName("lLatexWarning");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lLatexWarning->sizePolicy().hasHeightForWidth());
        lLatexWarning->setSizePolicy(sizePolicy);
        lLatexWarning->setFrameShape(QFrame::Shape::Box);

        gridLayout->addWidget(lLatexWarning, 13, 5, 1, 1);

        lPresenterMode_2 = new QLabel(SettingsWorksheetPage);
        lPresenterMode_2->setObjectName("lPresenterMode_2");
        QFont font;
        font.setBold(true);
        lPresenterMode_2->setFont(font);

        gridLayout->addWidget(lPresenterMode_2, 0, 0, 1, 3);

        lPerformance = new QLabel(SettingsWorksheetPage);
        lPerformance->setObjectName("lPerformance");
        lPerformance->setFont(font);

        gridLayout->addWidget(lPerformance, 9, 0, 1, 3);

        cbPreviewThumbnailSize = new QComboBox(SettingsWorksheetPage);
        cbPreviewThumbnailSize->setObjectName("cbPreviewThumbnailSize");

        gridLayout->addWidget(cbPreviewThumbnailSize, 4, 4, 1, 1);

        lTex = new QLabel(SettingsWorksheetPage);
        lTex->setObjectName("lTex");
        lTex->setFont(font);

        gridLayout->addWidget(lTex, 12, 0, 1, 3);

        verticalSpacer_3 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 156, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 14, 1, 1, 1);

        lPresenterMode = new QLabel(SettingsWorksheetPage);
        lPresenterMode->setObjectName("lPresenterMode");
        lPresenterMode->setFont(font);

        gridLayout->addWidget(lPresenterMode, 6, 0, 1, 3);

        verticalSpacer_5 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_5, 11, 0, 1, 1);

        lPreview = new QLabel(SettingsWorksheetPage);
        lPreview->setObjectName("lPreview");
        lPreview->setFont(font);

        gridLayout->addWidget(lPreview, 3, 0, 1, 3);

        lPreviewThumbnailSize = new QLabel(SettingsWorksheetPage);
        lPreviewThumbnailSize->setObjectName("lPreviewThumbnailSize");

        gridLayout->addWidget(lPreviewThumbnailSize, 4, 0, 1, 3);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 1, 3, 1, 1);

        chkDoubleBuffering = new QCheckBox(SettingsWorksheetPage);
        chkDoubleBuffering->setObjectName("chkDoubleBuffering");

        gridLayout->addWidget(chkDoubleBuffering, 10, 0, 1, 3);

        lTheme = new QLabel(SettingsWorksheetPage);
        lTheme->setObjectName("lTheme");

        gridLayout->addWidget(lTheme, 1, 0, 1, 1);

        chkPresenterModeInteractive = new QCheckBox(SettingsWorksheetPage);
        chkPresenterModeInteractive->setObjectName("chkPresenterModeInteractive");

        gridLayout->addWidget(chkPresenterModeInteractive, 7, 0, 1, 3);

        lTexEngine = new QLabel(SettingsWorksheetPage);
        lTexEngine->setObjectName("lTexEngine");

        gridLayout->addWidget(lTexEngine, 13, 0, 1, 3);

        verticalSpacer_4 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 8, 0, 1, 1);

        cbTexEngine = new QComboBox(SettingsWorksheetPage);
        cbTexEngine->setObjectName("cbTexEngine");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbTexEngine->sizePolicy().hasHeightForWidth());
        cbTexEngine->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbTexEngine, 13, 4, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 5, 0, 1, 1);


        retranslateUi(SettingsWorksheetPage);

        QMetaObject::connectSlotsByName(SettingsWorksheetPage);
    } // setupUi

    void retranslateUi(QWidget *SettingsWorksheetPage)
    {
        lLatexWarning->setText(QString());
        lPresenterMode_2->setText(tr2i18n("Appearance", nullptr));
        lPerformance->setText(tr2i18n("Performance", nullptr));
        lTex->setText(tr2i18n("LaTeX", nullptr));
        lPresenterMode->setText(tr2i18n("Presenter Mode", nullptr));
        lPreview->setText(tr2i18n("Preview", nullptr));
        lPreviewThumbnailSize->setText(tr2i18n("Thumbnail Size:", nullptr));
        chkDoubleBuffering->setText(tr2i18n("Double buffering", nullptr));
        lTheme->setText(tr2i18n("Theme:", nullptr));
        chkPresenterModeInteractive->setText(tr2i18n("Interactive", nullptr));
        lTexEngine->setText(tr2i18n("Typesetting engine:", nullptr));
        (void)SettingsWorksheetPage;
    } // retranslateUi

};

namespace Ui {
    class SettingsWorksheetPage: public Ui_SettingsWorksheetPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGSWORKSHEETPAGE_H

