/****************************************************************************
** Meta object code from reading C++ file 'BoxPlotDock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/dockwidgets/BoxPlotDock.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'BoxPlotDock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11BoxPlotDockE_t {};
} // unnamed namespace

template <> constexpr inline auto BoxPlotDock::qt_create_metaobjectdata<qt_meta_tag_ZN11BoxPlotDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BoxPlotDock",
        "info",
        "",
        "addDataColumn",
        "removeDataColumn",
        "dataColumnChanged",
        "QModelIndex",
        "orderingChanged",
        "orientationChanged",
        "variableWidthChanged",
        "notchesEnabledChanged",
        "currentBoxChanged",
        "widthFactorChanged",
        "symbolCategoryChanged",
        "jitteringEnabledChanged",
        "whiskersTypeChanged",
        "whiskersRangeParameterChanged",
        "whiskersCapSizeChanged",
        "rugEnabledChanged",
        "rugLengthChanged",
        "rugWidthChanged",
        "rugOffsetChanged",
        "plotDescriptionChanged",
        "const AbstractAspect*",
        "plotDataColumnsChanged",
        "QList<const AbstractColumn*>",
        "plotOrderingChanged",
        "BoxPlot::Ordering",
        "plotOrientationChanged",
        "BoxPlot::Orientation",
        "plotVariableWidthChanged",
        "plotWidthFactorChanged",
        "plotNotchesEnabledChanged",
        "plotJitteringEnabledChanged",
        "plotWhiskersTypeChanged",
        "BoxPlot::WhiskersType",
        "plotWhiskersRangeParameterChanged",
        "plotWhiskersCapSizeChanged",
        "plotRugEnabledChanged",
        "plotRugLengthChanged",
        "plotRugWidthChanged",
        "plotRugOffsetChanged",
        "loadConfigFromTemplate",
        "KConfig&",
        "saveConfigAsTemplate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'info'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'addDataColumn'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeDataColumn'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'dataColumnChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'orderingChanged'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'orientationChanged'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'variableWidthChanged'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'notchesEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'currentBoxChanged'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'widthFactorChanged'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'symbolCategoryChanged'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'jitteringEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'whiskersTypeChanged'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'whiskersRangeParameterChanged'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'whiskersCapSizeChanged'
        QtMocHelpers::SlotData<void(double) const>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'rugEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'rugLengthChanged'
        QtMocHelpers::SlotData<void(double) const>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'rugWidthChanged'
        QtMocHelpers::SlotData<void(double) const>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'rugOffsetChanged'
        QtMocHelpers::SlotData<void(double) const>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'plotDescriptionChanged'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 2 },
        }}),
        // Slot 'plotDataColumnsChanged'
        QtMocHelpers::SlotData<void(const QVector<const AbstractColumn*> &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 2 },
        }}),
        // Slot 'plotOrderingChanged'
        QtMocHelpers::SlotData<void(BoxPlot::Ordering)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 2 },
        }}),
        // Slot 'plotOrientationChanged'
        QtMocHelpers::SlotData<void(BoxPlot::Orientation)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'plotVariableWidthChanged'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'plotWidthFactorChanged'
        QtMocHelpers::SlotData<void(double)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'plotNotchesEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'plotJitteringEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'plotWhiskersTypeChanged'
        QtMocHelpers::SlotData<void(BoxPlot::WhiskersType)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 2 },
        }}),
        // Slot 'plotWhiskersRangeParameterChanged'
        QtMocHelpers::SlotData<void(double)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'plotWhiskersCapSizeChanged'
        QtMocHelpers::SlotData<void(double)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'plotRugEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'plotRugLengthChanged'
        QtMocHelpers::SlotData<void(double)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'plotRugWidthChanged'
        QtMocHelpers::SlotData<void(double)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'plotRugOffsetChanged'
        QtMocHelpers::SlotData<void(double)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'loadConfigFromTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 43, 2 },
        }}),
        // Slot 'saveConfigAsTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 43, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BoxPlotDock, qt_meta_tag_ZN11BoxPlotDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BoxPlotDock::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseDock::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11BoxPlotDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11BoxPlotDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11BoxPlotDockE_t>.metaTypes,
    nullptr
} };

void BoxPlotDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BoxPlotDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->addDataColumn(); break;
        case 2: _t->removeDataColumn(); break;
        case 3: _t->dataColumnChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 4: _t->orderingChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->orientationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->variableWidthChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->notchesEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->currentBoxChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->widthFactorChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->symbolCategoryChanged(); break;
        case 11: _t->jitteringEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->whiskersTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->whiskersRangeParameterChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->whiskersCapSizeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: _t->rugEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->rugLengthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: _t->rugWidthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 18: _t->rugOffsetChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 19: _t->plotDescriptionChanged((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 20: _t->plotDataColumnsChanged((*reinterpret_cast<std::add_pointer_t<QList<const AbstractColumn*>>>(_a[1]))); break;
        case 21: _t->plotOrderingChanged((*reinterpret_cast<std::add_pointer_t<BoxPlot::Ordering>>(_a[1]))); break;
        case 22: _t->plotOrientationChanged((*reinterpret_cast<std::add_pointer_t<BoxPlot::Orientation>>(_a[1]))); break;
        case 23: _t->plotVariableWidthChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->plotWidthFactorChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 25: _t->plotNotchesEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->plotJitteringEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->plotWhiskersTypeChanged((*reinterpret_cast<std::add_pointer_t<BoxPlot::WhiskersType>>(_a[1]))); break;
        case 28: _t->plotWhiskersRangeParameterChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 29: _t->plotWhiskersCapSizeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 30: _t->plotRugEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->plotRugLengthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 32: _t->plotRugWidthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 33: _t->plotRugOffsetChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 34: _t->loadConfigFromTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        case 35: _t->saveConfigAsTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BoxPlotDock::*)(const QString & )>(_a, &BoxPlotDock::info, 0))
            return;
    }
}

const QMetaObject *BoxPlotDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BoxPlotDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11BoxPlotDockE_t>.strings))
        return static_cast<void*>(this);
    return BaseDock::qt_metacast(_clname);
}

int BoxPlotDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseDock::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void BoxPlotDock::info(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
