/********************************************************************************
** Form generated from reading UI file 'xyfitcurvedockgeneraltab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XYFITCURVEDOCKGENERALTAB_H
#define UI_XYFITCURVEDOCKGENERALTAB_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ExpressionTextEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_XYFitCurveDockGeneralTab
{
public:
    QGridLayout *gridLayout_2;
    QSpacerItem *verticalSpacer;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *pbOptions;
    QLabel *lName;
    QComboBox *cbPlotRanges;
    QSpacerItem *horizontalSpacer_5;
    QHBoxLayout *hlYWeight;
    QComboBox *cbYWeight;
    QLabel *lYErrorCol;
    QLabel *lYWeight;
    QLabel *lXWeight;
    QComboBox *cbCategory;
    QSpacerItem *verticalSpacer_5;
    QLabel *lCategory;
    QToolButton *tbData;
    QSpinBox *sbDegree;
    QLabel *lComment;
    QSpacerItem *verticalSpacer_7;
    QLabel *lAlgorithm;
    QLabel *lDataSourceType;
    QSpacerItem *verticalSpacer_6;
    QSpacerItem *verticalSpacer_3;
    QLabel *lDataSourceCurve;
    QLabel *lYColumn;
    QHBoxLayout *hlXError;
    QComboBox *cbXWeight;
    QLabel *lXErrorCol;
    QToolButton *tbWeights;
    QCheckBox *chkVisible;
    QCheckBox *chkLegendVisible;
    QFrame *frameParameters;
    QToolButton *tbResults;
    QSpacerItem *verticalSpacerGeneral;
    QLabel *lDegree;
    QFrame *frameEquation;
    QGridLayout *gridLayout;
    QLabel *lFuncPic;
    ExpressionTextEdit *teEquation;
    QToolButton *tbFunctions;
    QToolButton *tbConstants;
    KComboBox *cbModel;
    QToolButton *tbFit;
    TimedLineEdit *leName;
    ResizableTextEdit *teComment;
    QFrame *frame_2;
    QHBoxLayout *horizontalLayout_2;
    KComboBox *cbAlgorithm;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *pbRecalculate;
    QToolButton *tbParameters;
    QLabel *lModel;
    QSpacerItem *verticalSpacer_4;
    QFrame *line_2;
    QComboBox *cbDataSourceType;
    QSpacerItem *verticalSpacer_2;
    QLabel *lEquation;
    QLabel *lPlotRange;
    QLabel *lXColumn;
    QTabWidget *twResults;
    QWidget *tab_3;
    QVBoxLayout *verticalLayout_3;
    QTableWidget *twParameters;
    QWidget *tab_4;
    QHBoxLayout *horizontalLayout_4;
    QTableWidget *twGoodness;
    QWidget *tab;
    QVBoxLayout *verticalLayout_2;
    QTableWidget *twLog;
    QSpacerItem *verticalSpacer_8;

    void setupUi(QWidget *XYFitCurveDockGeneralTab)
    {
        if (XYFitCurveDockGeneralTab->objectName().isEmpty())
            XYFitCurveDockGeneralTab->setObjectName("XYFitCurveDockGeneralTab");
        XYFitCurveDockGeneralTab->resize(494, 1243);
        XYFitCurveDockGeneralTab->setAutoFillBackground(true);
        gridLayout_2 = new QGridLayout(XYFitCurveDockGeneralTab);
        gridLayout_2->setObjectName("gridLayout_2");
        verticalSpacer = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer, 8, 0, 1, 1);

        frame = new QFrame(XYFitCurveDockGeneralTab);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::Shape::StyledPanel);
        frame->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(41, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pbOptions = new QPushButton(frame);
        pbOptions->setObjectName("pbOptions");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(pbOptions->sizePolicy().hasHeightForWidth());
        pbOptions->setSizePolicy(sizePolicy);
        pbOptions->setLayoutDirection(Qt::LayoutDirection::LeftToRight);
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("configure")));
        pbOptions->setIcon(icon);

        horizontalLayout->addWidget(pbOptions);


        gridLayout_2->addWidget(frame, 12, 2, 2, 2);

        lName = new QLabel(XYFitCurveDockGeneralTab);
        lName->setObjectName("lName");

        gridLayout_2->addWidget(lName, 0, 0, 1, 1);

        cbPlotRanges = new QComboBox(XYFitCurveDockGeneralTab);
        cbPlotRanges->setObjectName("cbPlotRanges");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbPlotRanges->sizePolicy().hasHeightForWidth());
        cbPlotRanges->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(cbPlotRanges, 31, 2, 1, 2);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        hlYWeight = new QHBoxLayout();
        hlYWeight->setObjectName("hlYWeight");
        cbYWeight = new QComboBox(XYFitCurveDockGeneralTab);
        cbYWeight->setObjectName("cbYWeight");

        hlYWeight->addWidget(cbYWeight);

        lYErrorCol = new QLabel(XYFitCurveDockGeneralTab);
        lYErrorCol->setObjectName("lYErrorCol");
        lYErrorCol->setEnabled(false);
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(lYErrorCol->sizePolicy().hasHeightForWidth());
        lYErrorCol->setSizePolicy(sizePolicy2);
        lYErrorCol->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        hlYWeight->addWidget(lYErrorCol);


        gridLayout_2->addLayout(hlYWeight, 11, 2, 1, 2);

        lYWeight = new QLabel(XYFitCurveDockGeneralTab);
        lYWeight->setObjectName("lYWeight");

        gridLayout_2->addWidget(lYWeight, 11, 0, 1, 1);

        lXWeight = new QLabel(XYFitCurveDockGeneralTab);
        lXWeight->setObjectName("lXWeight");

        gridLayout_2->addWidget(lXWeight, 10, 0, 1, 1);

        cbCategory = new QComboBox(XYFitCurveDockGeneralTab);
        cbCategory->setObjectName("cbCategory");
        sizePolicy1.setHeightForWidth(cbCategory->sizePolicy().hasHeightForWidth());
        cbCategory->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(cbCategory, 14, 2, 1, 2);

        verticalSpacer_5 = new QSpacerItem(20, 230, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_5, 26, 0, 1, 1);

        lCategory = new QLabel(XYFitCurveDockGeneralTab);
        lCategory->setObjectName("lCategory");

        gridLayout_2->addWidget(lCategory, 14, 0, 1, 1);

        tbData = new QToolButton(XYFitCurveDockGeneralTab);
        tbData->setObjectName("tbData");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(tbData->sizePolicy().hasHeightForWidth());
        tbData->setSizePolicy(sizePolicy3);
        QFont font;
        font.setBold(true);
        tbData->setFont(font);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("arrow-down")));
        tbData->setIcon(icon1);
        tbData->setCheckable(true);
        tbData->setChecked(true);
        tbData->setToolButtonStyle(Qt::ToolButtonStyle::ToolButtonTextBesideIcon);
        tbData->setAutoRaise(true);

        gridLayout_2->addWidget(tbData, 3, 0, 1, 1);

        sbDegree = new QSpinBox(XYFitCurveDockGeneralTab);
        sbDegree->setObjectName("sbDegree");
        sizePolicy1.setHeightForWidth(sbDegree->sizePolicy().hasHeightForWidth());
        sbDegree->setSizePolicy(sizePolicy1);
        sbDegree->setMinimum(1);
        sbDegree->setMaximum(50);
        sbDegree->setValue(1);

        gridLayout_2->addWidget(sbDegree, 16, 2, 1, 2);

        lComment = new QLabel(XYFitCurveDockGeneralTab);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(lComment, 1, 0, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(verticalSpacer_7, 20, 0, 1, 1);

        lAlgorithm = new QLabel(XYFitCurveDockGeneralTab);
        lAlgorithm->setObjectName("lAlgorithm");

        gridLayout_2->addWidget(lAlgorithm, 22, 0, 1, 1);

        lDataSourceType = new QLabel(XYFitCurveDockGeneralTab);
        lDataSourceType->setObjectName("lDataSourceType");

        gridLayout_2->addWidget(lDataSourceType, 4, 0, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_6, 18, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_3, 2, 0, 1, 1);

        lDataSourceCurve = new QLabel(XYFitCurveDockGeneralTab);
        lDataSourceCurve->setObjectName("lDataSourceCurve");

        gridLayout_2->addWidget(lDataSourceCurve, 5, 0, 1, 1);

        lYColumn = new QLabel(XYFitCurveDockGeneralTab);
        lYColumn->setObjectName("lYColumn");

        gridLayout_2->addWidget(lYColumn, 7, 0, 1, 1);

        hlXError = new QHBoxLayout();
        hlXError->setObjectName("hlXError");
        cbXWeight = new QComboBox(XYFitCurveDockGeneralTab);
        cbXWeight->setObjectName("cbXWeight");

        hlXError->addWidget(cbXWeight);

        lXErrorCol = new QLabel(XYFitCurveDockGeneralTab);
        lXErrorCol->setObjectName("lXErrorCol");
        lXErrorCol->setEnabled(false);
        sizePolicy2.setHeightForWidth(lXErrorCol->sizePolicy().hasHeightForWidth());
        lXErrorCol->setSizePolicy(sizePolicy2);
        lXErrorCol->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        hlXError->addWidget(lXErrorCol);


        gridLayout_2->addLayout(hlXError, 10, 2, 1, 2);

        tbWeights = new QToolButton(XYFitCurveDockGeneralTab);
        tbWeights->setObjectName("tbWeights");
        sizePolicy3.setHeightForWidth(tbWeights->sizePolicy().hasHeightForWidth());
        tbWeights->setSizePolicy(sizePolicy3);
        tbWeights->setFont(font);
        tbWeights->setLayoutDirection(Qt::LayoutDirection::LeftToRight);
        tbWeights->setIcon(icon1);
        tbWeights->setCheckable(true);
        tbWeights->setChecked(true);
        tbWeights->setToolButtonStyle(Qt::ToolButtonStyle::ToolButtonTextBesideIcon);
        tbWeights->setAutoRaise(true);

        gridLayout_2->addWidget(tbWeights, 9, 0, 1, 1);

        chkVisible = new QCheckBox(XYFitCurveDockGeneralTab);
        chkVisible->setObjectName("chkVisible");

        gridLayout_2->addWidget(chkVisible, 34, 0, 1, 1);

        chkLegendVisible = new QCheckBox(XYFitCurveDockGeneralTab);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout_2->addWidget(chkLegendVisible, 33, 0, 1, 1);

        frameParameters = new QFrame(XYFitCurveDockGeneralTab);
        frameParameters->setObjectName("frameParameters");
        frameParameters->setMinimumSize(QSize(0, 0));
        frameParameters->setFrameShape(QFrame::Shape::NoFrame);
        frameParameters->setFrameShadow(QFrame::Shadow::Raised);

        gridLayout_2->addWidget(frameParameters, 19, 2, 2, 2);

        tbResults = new QToolButton(XYFitCurveDockGeneralTab);
        tbResults->setObjectName("tbResults");
        sizePolicy3.setHeightForWidth(tbResults->sizePolicy().hasHeightForWidth());
        tbResults->setSizePolicy(sizePolicy3);
        tbResults->setFont(font);
        tbResults->setIcon(icon1);
        tbResults->setCheckable(true);
        tbResults->setChecked(true);
        tbResults->setToolButtonStyle(Qt::ToolButtonStyle::ToolButtonTextBesideIcon);
        tbResults->setAutoRaise(true);

        gridLayout_2->addWidget(tbResults, 25, 0, 1, 1);

        verticalSpacerGeneral = new QSpacerItem(24, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacerGeneral, 32, 0, 1, 1);

        lDegree = new QLabel(XYFitCurveDockGeneralTab);
        lDegree->setObjectName("lDegree");

        gridLayout_2->addWidget(lDegree, 16, 0, 1, 1);

        frameEquation = new QFrame(XYFitCurveDockGeneralTab);
        frameEquation->setObjectName("frameEquation");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(frameEquation->sizePolicy().hasHeightForWidth());
        frameEquation->setSizePolicy(sizePolicy4);
        frameEquation->setMaximumSize(QSize(16777215, 16777215));
        frameEquation->setFrameShape(QFrame::Shape::NoFrame);
        frameEquation->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout = new QGridLayout(frameEquation);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        lFuncPic = new QLabel(frameEquation);
        lFuncPic->setObjectName("lFuncPic");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(lFuncPic->sizePolicy().hasHeightForWidth());
        lFuncPic->setSizePolicy(sizePolicy5);

        gridLayout->addWidget(lFuncPic, 2, 0, 1, 2);

        teEquation = new ExpressionTextEdit(frameEquation);
        teEquation->setObjectName("teEquation");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(teEquation->sizePolicy().hasHeightForWidth());
        teEquation->setSizePolicy(sizePolicy6);
        teEquation->setMaximumSize(QSize(16777215, 16777215));

        gridLayout->addWidget(teEquation, 0, 0, 2, 2);

        tbFunctions = new QToolButton(frameEquation);
        tbFunctions->setObjectName("tbFunctions");

        gridLayout->addWidget(tbFunctions, 0, 2, 1, 1);

        tbConstants = new QToolButton(frameEquation);
        tbConstants->setObjectName("tbConstants");

        gridLayout->addWidget(tbConstants, 1, 2, 1, 1);


        gridLayout_2->addWidget(frameEquation, 17, 2, 1, 2);

        cbModel = new KComboBox(XYFitCurveDockGeneralTab);
        cbModel->setObjectName("cbModel");
        sizePolicy1.setHeightForWidth(cbModel->sizePolicy().hasHeightForWidth());
        cbModel->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(cbModel, 15, 2, 1, 2);

        tbFit = new QToolButton(XYFitCurveDockGeneralTab);
        tbFit->setObjectName("tbFit");
        sizePolicy3.setHeightForWidth(tbFit->sizePolicy().hasHeightForWidth());
        tbFit->setSizePolicy(sizePolicy3);
        tbFit->setFont(font);
        tbFit->setAutoFillBackground(false);
        tbFit->setStyleSheet(QString::fromUtf8(""));
        tbFit->setIcon(icon1);
        tbFit->setCheckable(true);
        tbFit->setChecked(true);
        tbFit->setToolButtonStyle(Qt::ToolButtonStyle::ToolButtonTextBesideIcon);
        tbFit->setAutoRaise(true);
        tbFit->setArrowType(Qt::ArrowType::NoArrow);

        gridLayout_2->addWidget(tbFit, 13, 0, 1, 1);

        leName = new TimedLineEdit(XYFitCurveDockGeneralTab);
        leName->setObjectName("leName");

        gridLayout_2->addWidget(leName, 0, 2, 1, 2);

        teComment = new ResizableTextEdit(XYFitCurveDockGeneralTab);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout_2->addWidget(teComment, 1, 2, 1, 2);

        frame_2 = new QFrame(XYFitCurveDockGeneralTab);
        frame_2->setObjectName("frame_2");
        frame_2->setMinimumSize(QSize(0, 0));
        frame_2->setFrameShape(QFrame::Shape::StyledPanel);
        frame_2->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout_2 = new QHBoxLayout(frame_2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        cbAlgorithm = new KComboBox(frame_2);
        cbAlgorithm->setObjectName("cbAlgorithm");
        sizePolicy1.setHeightForWidth(cbAlgorithm->sizePolicy().hasHeightForWidth());
        cbAlgorithm->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(cbAlgorithm);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        pbRecalculate = new QPushButton(frame_2);
        pbRecalculate->setObjectName("pbRecalculate");
        sizePolicy4.setHeightForWidth(pbRecalculate->sizePolicy().hasHeightForWidth());
        pbRecalculate->setSizePolicy(sizePolicy4);
        pbRecalculate->setFont(font);

        horizontalLayout_2->addWidget(pbRecalculate);


        gridLayout_2->addWidget(frame_2, 22, 3, 1, 1);

        tbParameters = new QToolButton(XYFitCurveDockGeneralTab);
        tbParameters->setObjectName("tbParameters");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(tbParameters->sizePolicy().hasHeightForWidth());
        tbParameters->setSizePolicy(sizePolicy7);
        tbParameters->setMinimumSize(QSize(0, 0));
        tbParameters->setFont(font);
        tbParameters->setIcon(icon1);
        tbParameters->setCheckable(true);
        tbParameters->setChecked(true);
        tbParameters->setToolButtonStyle(Qt::ToolButtonStyle::ToolButtonTextBesideIcon);
        tbParameters->setAutoRaise(true);

        gridLayout_2->addWidget(tbParameters, 19, 0, 1, 1);

        lModel = new QLabel(XYFitCurveDockGeneralTab);
        lModel->setObjectName("lModel");

        gridLayout_2->addWidget(lModel, 15, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_4, 12, 0, 1, 1);

        line_2 = new QFrame(XYFitCurveDockGeneralTab);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(line_2, 28, 0, 1, 4);

        cbDataSourceType = new QComboBox(XYFitCurveDockGeneralTab);
        cbDataSourceType->setObjectName("cbDataSourceType");
        sizePolicy1.setHeightForWidth(cbDataSourceType->sizePolicy().hasHeightForWidth());
        cbDataSourceType->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(cbDataSourceType, 4, 2, 1, 2);

        verticalSpacer_2 = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);

        gridLayout_2->addItem(verticalSpacer_2, 24, 0, 1, 1);

        lEquation = new QLabel(XYFitCurveDockGeneralTab);
        lEquation->setObjectName("lEquation");
        lEquation->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout_2->addWidget(lEquation, 17, 0, 1, 1);

        lPlotRange = new QLabel(XYFitCurveDockGeneralTab);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout_2->addWidget(lPlotRange, 31, 0, 1, 1);

        lXColumn = new QLabel(XYFitCurveDockGeneralTab);
        lXColumn->setObjectName("lXColumn");

        gridLayout_2->addWidget(lXColumn, 6, 0, 1, 1);

        twResults = new QTabWidget(XYFitCurveDockGeneralTab);
        twResults->setObjectName("twResults");
        twResults->setAutoFillBackground(true);
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        verticalLayout_3 = new QVBoxLayout(tab_3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        twParameters = new QTableWidget(tab_3);
        if (twParameters->columnCount() < 8)
            twParameters->setColumnCount(8);
        twParameters->setObjectName("twParameters");
        twParameters->setAlternatingRowColors(true);
        twParameters->setColumnCount(8);
        twParameters->horizontalHeader()->setCascadingSectionResizes(true);
        twParameters->horizontalHeader()->setDefaultSectionSize(80);
        twParameters->horizontalHeader()->setStretchLastSection(true);
        twParameters->verticalHeader()->setVisible(false);

        verticalLayout_3->addWidget(twParameters);

        twResults->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        horizontalLayout_4 = new QHBoxLayout(tab_4);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        twGoodness = new QTableWidget(tab_4);
        if (twGoodness->columnCount() < 2)
            twGoodness->setColumnCount(2);
        if (twGoodness->rowCount() < 11)
            twGoodness->setRowCount(11);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        twGoodness->setItem(0, 0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        twGoodness->setItem(0, 1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        twGoodness->setItem(1, 0, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        twGoodness->setItem(1, 1, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        twGoodness->setItem(2, 0, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        twGoodness->setItem(2, 1, __qtablewidgetitem5);
        QTableWidgetItem *__qtablewidgetitem6 = new QTableWidgetItem();
        twGoodness->setItem(3, 0, __qtablewidgetitem6);
        QTableWidgetItem *__qtablewidgetitem7 = new QTableWidgetItem();
        twGoodness->setItem(3, 1, __qtablewidgetitem7);
        QTableWidgetItem *__qtablewidgetitem8 = new QTableWidgetItem();
        twGoodness->setItem(4, 0, __qtablewidgetitem8);
        QTableWidgetItem *__qtablewidgetitem9 = new QTableWidgetItem();
        twGoodness->setItem(4, 1, __qtablewidgetitem9);
        QTableWidgetItem *__qtablewidgetitem10 = new QTableWidgetItem();
        twGoodness->setItem(5, 0, __qtablewidgetitem10);
        QTableWidgetItem *__qtablewidgetitem11 = new QTableWidgetItem();
        twGoodness->setItem(5, 1, __qtablewidgetitem11);
        QTableWidgetItem *__qtablewidgetitem12 = new QTableWidgetItem();
        twGoodness->setItem(6, 0, __qtablewidgetitem12);
        QTableWidgetItem *__qtablewidgetitem13 = new QTableWidgetItem();
        twGoodness->setItem(6, 1, __qtablewidgetitem13);
        QTableWidgetItem *__qtablewidgetitem14 = new QTableWidgetItem();
        twGoodness->setItem(7, 0, __qtablewidgetitem14);
        QTableWidgetItem *__qtablewidgetitem15 = new QTableWidgetItem();
        twGoodness->setItem(7, 1, __qtablewidgetitem15);
        QTableWidgetItem *__qtablewidgetitem16 = new QTableWidgetItem();
        twGoodness->setItem(8, 0, __qtablewidgetitem16);
        QTableWidgetItem *__qtablewidgetitem17 = new QTableWidgetItem();
        twGoodness->setItem(8, 1, __qtablewidgetitem17);
        QTableWidgetItem *__qtablewidgetitem18 = new QTableWidgetItem();
        twGoodness->setItem(9, 0, __qtablewidgetitem18);
        QTableWidgetItem *__qtablewidgetitem19 = new QTableWidgetItem();
        twGoodness->setItem(9, 1, __qtablewidgetitem19);
        QTableWidgetItem *__qtablewidgetitem20 = new QTableWidgetItem();
        twGoodness->setItem(10, 0, __qtablewidgetitem20);
        QTableWidgetItem *__qtablewidgetitem21 = new QTableWidgetItem();
        twGoodness->setItem(10, 1, __qtablewidgetitem21);
        twGoodness->setObjectName("twGoodness");
        twGoodness->setAlternatingRowColors(true);
        twGoodness->setRowCount(11);
        twGoodness->setColumnCount(2);
        twGoodness->horizontalHeader()->setVisible(false);
        twGoodness->horizontalHeader()->setCascadingSectionResizes(true);
        twGoodness->horizontalHeader()->setDefaultSectionSize(75);
        twGoodness->horizontalHeader()->setStretchLastSection(true);
        twGoodness->verticalHeader()->setVisible(false);

        horizontalLayout_4->addWidget(twGoodness);

        twResults->addTab(tab_4, QString());
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_2 = new QVBoxLayout(tab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        twLog = new QTableWidget(tab);
        if (twLog->columnCount() < 2)
            twLog->setColumnCount(2);
        if (twLog->rowCount() < 9)
            twLog->setRowCount(9);
        QTableWidgetItem *__qtablewidgetitem22 = new QTableWidgetItem();
        twLog->setItem(0, 0, __qtablewidgetitem22);
        QTableWidgetItem *__qtablewidgetitem23 = new QTableWidgetItem();
        twLog->setItem(0, 1, __qtablewidgetitem23);
        QTableWidgetItem *__qtablewidgetitem24 = new QTableWidgetItem();
        twLog->setItem(1, 0, __qtablewidgetitem24);
        QTableWidgetItem *__qtablewidgetitem25 = new QTableWidgetItem();
        twLog->setItem(1, 1, __qtablewidgetitem25);
        QTableWidgetItem *__qtablewidgetitem26 = new QTableWidgetItem();
        twLog->setItem(2, 0, __qtablewidgetitem26);
        QTableWidgetItem *__qtablewidgetitem27 = new QTableWidgetItem();
        twLog->setItem(2, 1, __qtablewidgetitem27);
        QTableWidgetItem *__qtablewidgetitem28 = new QTableWidgetItem();
        twLog->setItem(3, 0, __qtablewidgetitem28);
        QTableWidgetItem *__qtablewidgetitem29 = new QTableWidgetItem();
        twLog->setItem(3, 1, __qtablewidgetitem29);
        QTableWidgetItem *__qtablewidgetitem30 = new QTableWidgetItem();
        twLog->setItem(4, 0, __qtablewidgetitem30);
        QTableWidgetItem *__qtablewidgetitem31 = new QTableWidgetItem();
        twLog->setItem(4, 1, __qtablewidgetitem31);
        QTableWidgetItem *__qtablewidgetitem32 = new QTableWidgetItem();
        twLog->setItem(5, 0, __qtablewidgetitem32);
        QTableWidgetItem *__qtablewidgetitem33 = new QTableWidgetItem();
        twLog->setItem(5, 1, __qtablewidgetitem33);
        QTableWidgetItem *__qtablewidgetitem34 = new QTableWidgetItem();
        twLog->setItem(6, 0, __qtablewidgetitem34);
        QTableWidgetItem *__qtablewidgetitem35 = new QTableWidgetItem();
        twLog->setItem(6, 1, __qtablewidgetitem35);
        QTableWidgetItem *__qtablewidgetitem36 = new QTableWidgetItem();
        twLog->setItem(7, 0, __qtablewidgetitem36);
        QTableWidgetItem *__qtablewidgetitem37 = new QTableWidgetItem();
        twLog->setItem(7, 1, __qtablewidgetitem37);
        QTableWidgetItem *__qtablewidgetitem38 = new QTableWidgetItem();
        twLog->setItem(8, 0, __qtablewidgetitem38);
        QTableWidgetItem *__qtablewidgetitem39 = new QTableWidgetItem();
        twLog->setItem(8, 1, __qtablewidgetitem39);
        twLog->setObjectName("twLog");
        twLog->setAlternatingRowColors(true);
        twLog->setRowCount(9);
        twLog->setColumnCount(2);
        twLog->horizontalHeader()->setVisible(false);
        twLog->horizontalHeader()->setCascadingSectionResizes(true);
        twLog->horizontalHeader()->setDefaultSectionSize(150);
        twLog->horizontalHeader()->setStretchLastSection(true);
        twLog->verticalHeader()->setVisible(false);

        verticalLayout_2->addWidget(twLog);

        twResults->addTab(tab, QString());

        gridLayout_2->addWidget(twResults, 25, 2, 2, 2);

        verticalSpacer_8 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_8, 23, 3, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, tbData);
        QWidget::setTabOrder(tbData, cbDataSourceType);
        QWidget::setTabOrder(cbDataSourceType, tbWeights);
        QWidget::setTabOrder(tbWeights, cbXWeight);
        QWidget::setTabOrder(cbXWeight, cbYWeight);
        QWidget::setTabOrder(cbYWeight, tbFit);
        QWidget::setTabOrder(tbFit, pbOptions);
        QWidget::setTabOrder(pbOptions, cbCategory);
        QWidget::setTabOrder(cbCategory, cbModel);
        QWidget::setTabOrder(cbModel, sbDegree);
        QWidget::setTabOrder(sbDegree, teEquation);
        QWidget::setTabOrder(teEquation, tbFunctions);
        QWidget::setTabOrder(tbFunctions, tbConstants);
        QWidget::setTabOrder(tbConstants, tbParameters);
        QWidget::setTabOrder(tbParameters, cbAlgorithm);
        QWidget::setTabOrder(cbAlgorithm, pbRecalculate);
        QWidget::setTabOrder(pbRecalculate, tbResults);
        QWidget::setTabOrder(tbResults, twResults);
        QWidget::setTabOrder(twResults, twLog);
        QWidget::setTabOrder(twLog, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);
        QWidget::setTabOrder(chkVisible, twGoodness);
        QWidget::setTabOrder(twGoodness, twParameters);

        retranslateUi(XYFitCurveDockGeneralTab);

        twResults->setCurrentIndex(2);


        QMetaObject::connectSlotsByName(XYFitCurveDockGeneralTab);
    } // setupUi

    void retranslateUi(QWidget *XYFitCurveDockGeneralTab)
    {
#if QT_CONFIG(tooltip)
        pbOptions->setToolTip(tr2i18n("Advanced fit options", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        pbOptions->setWhatsThis(tr2i18n("Opens a dialog to change advanced fit options", nullptr));
#endif // QT_CONFIG(whatsthis)
        pbOptions->setText(tr2i18n("Options", nullptr));
#if QT_CONFIG(tooltip)
        lName->setToolTip(tr2i18n("Name of the fit curve", nullptr));
#endif // QT_CONFIG(tooltip)
        lName->setText(tr2i18n("Name:", nullptr));
        lYErrorCol->setText(tr2i18n("col =", nullptr));
#if QT_CONFIG(tooltip)
        lYWeight->setToolTip(tr2i18n("Weight for y data", nullptr));
#endif // QT_CONFIG(tooltip)
        lYWeight->setText(tr2i18n("Y-Weight:", nullptr));
#if QT_CONFIG(tooltip)
        lXWeight->setToolTip(tr2i18n("Weight for x data", nullptr));
#endif // QT_CONFIG(tooltip)
        lXWeight->setText(tr2i18n("X-Weight:", nullptr));
#if QT_CONFIG(tooltip)
        lCategory->setToolTip(tr2i18n("Fit model category", nullptr));
#endif // QT_CONFIG(tooltip)
        lCategory->setText(tr2i18n("Category:", nullptr));
#if QT_CONFIG(tooltip)
        tbData->setToolTip(tr2i18n("Data to fit", nullptr));
#endif // QT_CONFIG(tooltip)
        tbData->setText(tr2i18n("Data:", nullptr));
#if QT_CONFIG(tooltip)
        lComment->setToolTip(tr2i18n("Optional comment", nullptr));
#endif // QT_CONFIG(tooltip)
        lComment->setText(tr2i18n("Comment:", nullptr));
        lAlgorithm->setText(tr2i18n("Algorithm:", nullptr));
#if QT_CONFIG(tooltip)
        lDataSourceType->setToolTip(tr2i18n("Type of data source", nullptr));
#endif // QT_CONFIG(tooltip)
        lDataSourceType->setText(tr2i18n("Source:", nullptr));
#if QT_CONFIG(tooltip)
        lDataSourceCurve->setToolTip(tr2i18n("Source curve", nullptr));
#endif // QT_CONFIG(tooltip)
        lDataSourceCurve->setText(tr2i18n("Curve:", nullptr));
#if QT_CONFIG(tooltip)
        lYColumn->setToolTip(tr2i18n("Source of y data", nullptr));
#endif // QT_CONFIG(tooltip)
        lYColumn->setText(tr2i18n("Y-Data:", nullptr));
        lXErrorCol->setText(tr2i18n("col =", nullptr));
#if QT_CONFIG(tooltip)
        tbWeights->setToolTip(tr2i18n("How to weight the data points", nullptr));
#endif // QT_CONFIG(tooltip)
        tbWeights->setText(tr2i18n("Weights:", nullptr));
#if QT_CONFIG(tooltip)
        chkVisible->setToolTip(tr2i18n("Show fit curve", nullptr));
#endif // QT_CONFIG(tooltip)
        chkVisible->setText(tr2i18n("Visible", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
#if QT_CONFIG(tooltip)
        tbResults->setToolTip(tr2i18n("Fit results", nullptr));
#endif // QT_CONFIG(tooltip)
        tbResults->setText(tr2i18n("Results:", nullptr));
#if QT_CONFIG(tooltip)
        lDegree->setToolTip(tr2i18n("Degree of fit model", nullptr));
#endif // QT_CONFIG(tooltip)
        lDegree->setText(tr2i18n("Degree:", nullptr));
        lFuncPic->setText(QString());
#if QT_CONFIG(tooltip)
        tbFunctions->setToolTip(tr2i18n("Functions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        tbFunctions->setWhatsThis(tr2i18n("Select predefined function", nullptr));
#endif // QT_CONFIG(whatsthis)
        tbFunctions->setText(QString());
#if QT_CONFIG(tooltip)
        tbConstants->setToolTip(tr2i18n("Constants", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        tbConstants->setWhatsThis(tr2i18n("Select predefined constants", nullptr));
#endif // QT_CONFIG(whatsthis)
        tbConstants->setText(QString());
#if QT_CONFIG(tooltip)
        tbFit->setToolTip(tr2i18n("Function to fit and options", nullptr));
#endif // QT_CONFIG(tooltip)
        tbFit->setText(tr2i18n("Fit:", nullptr));
#if QT_CONFIG(tooltip)
        pbRecalculate->setToolTip(tr2i18n("Run fit", nullptr));
#endif // QT_CONFIG(tooltip)
        pbRecalculate->setText(tr2i18n("Run", nullptr));
#if QT_CONFIG(tooltip)
        tbParameters->setToolTip(tr2i18n("Specify parameters and their properties", nullptr));
#endif // QT_CONFIG(tooltip)
        tbParameters->setText(tr2i18n("Parameters:", nullptr));
#if QT_CONFIG(tooltip)
        lModel->setToolTip(tr2i18n("Fit model type", nullptr));
#endif // QT_CONFIG(tooltip)
        lModel->setText(tr2i18n("Model:", nullptr));
#if QT_CONFIG(tooltip)
        lEquation->setToolTip(tr2i18n("Function of fit model", nullptr));
#endif // QT_CONFIG(tooltip)
        lEquation->setText(tr2i18n("f(x) =", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
#if QT_CONFIG(tooltip)
        lXColumn->setToolTip(tr2i18n("Source of x data", nullptr));
#endif // QT_CONFIG(tooltip)
        lXColumn->setText(tr2i18n("X-Data:", nullptr));
#if QT_CONFIG(tooltip)
        twResults->setToolTip(tr2i18n("Resulting fit parameter and properties", nullptr));
#endif // QT_CONFIG(tooltip)
        twResults->setTabText(twResults->indexOf(tab_3), tr2i18n("Parameters", nullptr));

        const bool __sortingEnabled = twGoodness->isSortingEnabled();
        twGoodness->setSortingEnabled(false);
        QTableWidgetItem *___qtablewidgetitem = twGoodness->item(0, 0);
        ___qtablewidgetitem->setText(tr2i18n("Sum of squared residuals", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = twGoodness->item(1, 0);
        ___qtablewidgetitem1->setText(tr2i18n("Residual mean square", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = twGoodness->item(2, 0);
        ___qtablewidgetitem2->setText(tr2i18n("Root mean square deviation (RMSD, SD)", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = twGoodness->item(3, 0);
        ___qtablewidgetitem3->setText(tr2i18n("Coefficient of determination", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = twGoodness->item(4, 0);
        ___qtablewidgetitem4->setText(tr2i18n("Adj. coefficient of determination", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = twGoodness->item(6, 0);
        ___qtablewidgetitem5->setText(tr2i18n("F test", nullptr));
        QTableWidgetItem *___qtablewidgetitem6 = twGoodness->item(7, 0);
        ___qtablewidgetitem6->setText(tr2i18n("P > F", nullptr));
        QTableWidgetItem *___qtablewidgetitem7 = twGoodness->item(8, 0);
        ___qtablewidgetitem7->setText(tr2i18n("Mean absolute error (MAE)", nullptr));
        QTableWidgetItem *___qtablewidgetitem8 = twGoodness->item(9, 0);
        ___qtablewidgetitem8->setText(tr2i18n("Akaike information criterion (AIC)", nullptr));
        QTableWidgetItem *___qtablewidgetitem9 = twGoodness->item(10, 0);
        ___qtablewidgetitem9->setText(tr2i18n("Bayesian information criterion (BIC)", nullptr));
        twGoodness->setSortingEnabled(__sortingEnabled);

        twResults->setTabText(twResults->indexOf(tab_4), tr2i18n("Goodness of fit", nullptr));

        const bool __sortingEnabled1 = twLog->isSortingEnabled();
        twLog->setSortingEnabled(false);
        QTableWidgetItem *___qtablewidgetitem10 = twLog->item(0, 0);
        ___qtablewidgetitem10->setText(tr2i18n("Status", nullptr));
        QTableWidgetItem *___qtablewidgetitem11 = twLog->item(1, 0);
        ___qtablewidgetitem11->setText(tr2i18n("Iterations", nullptr));
        QTableWidgetItem *___qtablewidgetitem12 = twLog->item(2, 0);
        ___qtablewidgetitem12->setText(tr2i18n("Tolerance", nullptr));
        QTableWidgetItem *___qtablewidgetitem13 = twLog->item(3, 0);
        ___qtablewidgetitem13->setText(tr2i18n("Calculation time", nullptr));
        QTableWidgetItem *___qtablewidgetitem14 = twLog->item(4, 0);
        ___qtablewidgetitem14->setText(tr2i18n("Degrees of Freedom", nullptr));
        QTableWidgetItem *___qtablewidgetitem15 = twLog->item(5, 0);
        ___qtablewidgetitem15->setText(tr2i18n("Parameters", nullptr));
        QTableWidgetItem *___qtablewidgetitem16 = twLog->item(6, 0);
        ___qtablewidgetitem16->setText(tr2i18n("X range", nullptr));
        QTableWidgetItem *___qtablewidgetitem17 = twLog->item(7, 0);
        ___qtablewidgetitem17->setText(tr2i18n("Correlation", nullptr));
        QTableWidgetItem *___qtablewidgetitem18 = twLog->item(8, 0);
        ___qtablewidgetitem18->setText(tr2i18n("Iterations", nullptr));
        twLog->setSortingEnabled(__sortingEnabled1);

        twResults->setTabText(twResults->indexOf(tab), tr2i18n("Log", nullptr));
        (void)XYFitCurveDockGeneralTab;
    } // retranslateUi

};

namespace Ui {
    class XYFitCurveDockGeneralTab: public Ui_XYFitCurveDockGeneralTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // XYFITCURVEDOCKGENERALTAB_H

