/********************************************************************************
** Form generated from reading UI file 'referencerangedock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REFERENCERANGEDOCK_H
#define UI_REFERENCERANGEDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ReferenceRangeDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout_2;
    NumberSpinBox *sbPositionEnd;
    QLabel *lPositionDateTimeEnd;
    QLabel *lComment;
    QSpacerItem *horizontalSpacer_2;
    QLabel *lPosition;
    QCheckBox *chkVisible;
    QLabel *lPositionEnd;
    QLabel *lName;
    QSpacerItem *verticalSpacer_2;
    QLabel *lPlotRange;
    QSpacerItem *verticalSpacer_18;
    ResizableTextEdit *teComment;
    QComboBox *cbPlotRanges;
    QLabel *lOrientation;
    UTCDateTimeEdit *dtePositionStart;
    NumberSpinBox *sbPositionStart;
    QSpacerItem *verticalSpacer_17;
    QLabel *lBackground;
    QSpacerItem *verticalSpacer_5;
    QSpacerItem *verticalSpacer_16;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer;
    UTCDateTimeEdit *dtePositionEnd;
    QLabel *lPositionDateTimeStart;
    QLabel *lBorder;
    QLabel *lPositionStart;
    KComboBox *cbOrientation;
    TimedLineEdit *leName;
    QCheckBox *chbLock;

    void setupUi(QWidget *ReferenceRangeDock)
    {
        if (ReferenceRangeDock->objectName().isEmpty())
            ReferenceRangeDock->setObjectName("ReferenceRangeDock");
        ReferenceRangeDock->resize(352, 706);
        verticalLayout = new QVBoxLayout(ReferenceRangeDock);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(ReferenceRangeDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout_2 = new QGridLayout(tabGeneral);
        gridLayout_2->setObjectName("gridLayout_2");
        sbPositionEnd = new NumberSpinBox(tabGeneral);
        sbPositionEnd->setObjectName("sbPositionEnd");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(sbPositionEnd->sizePolicy().hasHeightForWidth());
        sbPositionEnd->setSizePolicy(sizePolicy);
        sbPositionEnd->setProperty("feedback", QVariant(false));

        gridLayout_2->addWidget(sbPositionEnd, 6, 2, 1, 1);

        lPositionDateTimeEnd = new QLabel(tabGeneral);
        lPositionDateTimeEnd->setObjectName("lPositionDateTimeEnd");

        gridLayout_2->addWidget(lPositionDateTimeEnd, 8, 0, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(lComment, 1, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(13, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 0, 1, 1, 1);

        lPosition = new QLabel(tabGeneral);
        lPosition->setObjectName("lPosition");
        QFont font;
        font.setBold(true);
        lPosition->setFont(font);

        gridLayout_2->addWidget(lPosition, 3, 0, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout_2->addWidget(chkVisible, 18, 0, 1, 1);

        lPositionEnd = new QLabel(tabGeneral);
        lPositionEnd->setObjectName("lPositionEnd");

        gridLayout_2->addWidget(lPositionEnd, 6, 0, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout_2->addWidget(lName, 0, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_2, 15, 0, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout_2->addWidget(lPlotRange, 9, 0, 1, 1);

        verticalSpacer_18 = new QSpacerItem(72, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_18, 13, 0, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(teComment->sizePolicy().hasHeightForWidth());
        teComment->setSizePolicy(sizePolicy1);
        teComment->setTabChangesFocus(true);

        gridLayout_2->addWidget(teComment, 1, 2, 1, 1);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout_2->addWidget(cbPlotRanges, 9, 2, 1, 1);

        lOrientation = new QLabel(tabGeneral);
        lOrientation->setObjectName("lOrientation");

        gridLayout_2->addWidget(lOrientation, 4, 0, 1, 1);

        dtePositionStart = new UTCDateTimeEdit(tabGeneral);
        dtePositionStart->setObjectName("dtePositionStart");

        gridLayout_2->addWidget(dtePositionStart, 7, 2, 1, 1);

        sbPositionStart = new NumberSpinBox(tabGeneral);
        sbPositionStart->setObjectName("sbPositionStart");
        sizePolicy.setHeightForWidth(sbPositionStart->sizePolicy().hasHeightForWidth());
        sbPositionStart->setSizePolicy(sizePolicy);
        sbPositionStart->setProperty("feedback", QVariant(false));

        gridLayout_2->addWidget(sbPositionStart, 5, 2, 1, 1);

        verticalSpacer_17 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_17, 19, 0, 1, 1);

        lBackground = new QLabel(tabGeneral);
        lBackground->setObjectName("lBackground");
        lBackground->setFont(font);

        gridLayout_2->addWidget(lBackground, 11, 0, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_5, 2, 0, 1, 1);

        verticalSpacer_16 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_16, 10, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_3, 12, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 694, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 16, 0, 1, 1);

        dtePositionEnd = new UTCDateTimeEdit(tabGeneral);
        dtePositionEnd->setObjectName("dtePositionEnd");

        gridLayout_2->addWidget(dtePositionEnd, 8, 2, 1, 1);

        lPositionDateTimeStart = new QLabel(tabGeneral);
        lPositionDateTimeStart->setObjectName("lPositionDateTimeStart");

        gridLayout_2->addWidget(lPositionDateTimeStart, 7, 0, 1, 1);

        lBorder = new QLabel(tabGeneral);
        lBorder->setObjectName("lBorder");
        lBorder->setFont(font);

        gridLayout_2->addWidget(lBorder, 14, 0, 1, 1);

        lPositionStart = new QLabel(tabGeneral);
        lPositionStart->setObjectName("lPositionStart");

        gridLayout_2->addWidget(lPositionStart, 5, 0, 1, 1);

        cbOrientation = new KComboBox(tabGeneral);
        cbOrientation->setObjectName("cbOrientation");

        gridLayout_2->addWidget(cbOrientation, 4, 2, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");
        sizePolicy1.setHeightForWidth(leName->sizePolicy().hasHeightForWidth());
        leName->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(leName, 0, 2, 1, 1);

        chbLock = new QCheckBox(tabGeneral);
        chbLock->setObjectName("chbLock");

        gridLayout_2->addWidget(chbLock, 17, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbOrientation);
        QWidget::setTabOrder(cbOrientation, sbPositionStart);
        QWidget::setTabOrder(sbPositionStart, sbPositionEnd);
        QWidget::setTabOrder(sbPositionEnd, dtePositionStart);
        QWidget::setTabOrder(dtePositionStart, dtePositionEnd);
        QWidget::setTabOrder(dtePositionEnd, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chbLock);
        QWidget::setTabOrder(chbLock, chkVisible);

        retranslateUi(ReferenceRangeDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ReferenceRangeDock);
    } // setupUi

    void retranslateUi(QWidget *ReferenceRangeDock)
    {
#if QT_CONFIG(tooltip)
        sbPositionEnd->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionEnd->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lPositionDateTimeEnd->setText(tr2i18n("End x:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lPosition->setText(tr2i18n("Position", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
#if QT_CONFIG(tooltip)
        lPositionEnd->setToolTip(tr2i18n("Horizontal position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
        lPositionEnd->setText(tr2i18n("End x:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lPlotRange->setText(tr2i18n("Plot range:", nullptr));
        lOrientation->setText(tr2i18n("Orientation:", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionStart->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionStart->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lBackground->setText(tr2i18n("Background", nullptr));
        lPositionDateTimeStart->setText(tr2i18n("Start x:", nullptr));
        lBorder->setText(tr2i18n("Border", nullptr));
#if QT_CONFIG(tooltip)
        lPositionStart->setToolTip(tr2i18n("Horizontal position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
        lPositionStart->setText(tr2i18n("Start x:", nullptr));
        chbLock->setText(tr2i18n("Locked", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        (void)ReferenceRangeDock;
    } // retranslateUi

};

namespace Ui {
    class ReferenceRangeDock: public Ui_ReferenceRangeDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // REFERENCERANGEDOCK_H

