/********************************************************************************
** Form generated from reading UI file 'functionvalueswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FUNCTIONVALUESWIDGET_H
#define UI_FUNCTIONVALUESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ExpressionTextEdit.h"

QT_BEGIN_NAMESPACE

class Ui_FunctionValuesWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *lVariable;
    QGridLayout *gridLayoutVariables;
    QToolButton *bAddVariable;
    QSpacerItem *verticalSpacer_1;
    QLabel *lFunc;
    QFrame *frame;
    QGridLayout *gridLayout;
    ExpressionTextEdit *teEquation;
    QLabel *lFunction;
    QToolButton *tbConstants;
    QToolButton *tbFunctions;
    QCheckBox *chkAutoUpdate;
    QCheckBox *chkAutoResize;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *FunctionValuesWidget)
    {
        if (FunctionValuesWidget->objectName().isEmpty())
            FunctionValuesWidget->setObjectName("FunctionValuesWidget");
        FunctionValuesWidget->resize(631, 324);
        verticalLayout = new QVBoxLayout(FunctionValuesWidget);
        verticalLayout->setObjectName("verticalLayout");
        lVariable = new QLabel(FunctionValuesWidget);
        lVariable->setObjectName("lVariable");
        QFont font;
        font.setBold(true);
        lVariable->setFont(font);

        verticalLayout->addWidget(lVariable);

        gridLayoutVariables = new QGridLayout();
        gridLayoutVariables->setObjectName("gridLayoutVariables");
        bAddVariable = new QToolButton(FunctionValuesWidget);
        bAddVariable->setObjectName("bAddVariable");

        gridLayoutVariables->addWidget(bAddVariable, 0, 0, 1, 1);


        verticalLayout->addLayout(gridLayoutVariables);

        verticalSpacer_1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_1);

        lFunc = new QLabel(FunctionValuesWidget);
        lFunc->setObjectName("lFunc");
        lFunc->setFont(font);

        verticalLayout->addWidget(lFunc);

        frame = new QFrame(FunctionValuesWidget);
        frame->setObjectName("frame");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy);
        frame->setMaximumSize(QSize(16777215, 16777215));
        frame->setFrameShape(QFrame::Shape::NoFrame);
        frame->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout = new QGridLayout(frame);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        teEquation = new ExpressionTextEdit(frame);
        teEquation->setObjectName("teEquation");
        teEquation->setMaximumSize(QSize(16777215, 50));

        gridLayout->addWidget(teEquation, 0, 1, 3, 1);

        lFunction = new QLabel(frame);
        lFunction->setObjectName("lFunction");
        QFont font1;
        font1.setBold(false);
        lFunction->setFont(font1);
        lFunction->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout->addWidget(lFunction, 0, 0, 1, 1);

        tbConstants = new QToolButton(frame);
        tbConstants->setObjectName("tbConstants");

        gridLayout->addWidget(tbConstants, 1, 2, 1, 1);

        tbFunctions = new QToolButton(frame);
        tbFunctions->setObjectName("tbFunctions");

        gridLayout->addWidget(tbFunctions, 0, 2, 1, 1);


        verticalLayout->addWidget(frame);

        chkAutoUpdate = new QCheckBox(FunctionValuesWidget);
        chkAutoUpdate->setObjectName("chkAutoUpdate");
        chkAutoUpdate->setChecked(true);

        verticalLayout->addWidget(chkAutoUpdate);

        chkAutoResize = new QCheckBox(FunctionValuesWidget);
        chkAutoResize->setObjectName("chkAutoResize");
        chkAutoResize->setChecked(true);

        verticalLayout->addWidget(chkAutoResize);

        verticalSpacer_2 = new QSpacerItem(20, 60, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        retranslateUi(FunctionValuesWidget);

        QMetaObject::connectSlotsByName(FunctionValuesWidget);
    } // setupUi

    void retranslateUi(QWidget *FunctionValuesWidget)
    {
        lVariable->setText(tr2i18n("Variable:", nullptr));
        bAddVariable->setText(QString());
        lFunc->setText(tr2i18n("Function:", nullptr));
        lFunction->setText(tr2i18n("f(x) = ", nullptr));
#if QT_CONFIG(tooltip)
        tbConstants->setToolTip(tr2i18n("Constants", nullptr));
#endif // QT_CONFIG(tooltip)
        tbConstants->setText(QString());
#if QT_CONFIG(tooltip)
        tbFunctions->setToolTip(tr2i18n("Functions", nullptr));
#endif // QT_CONFIG(tooltip)
        tbFunctions->setText(QString());
        chkAutoUpdate->setText(tr2i18n("auto update the values", nullptr));
        chkAutoResize->setText(tr2i18n("auto resize the column", nullptr));
        (void)FunctionValuesWidget;
    } // retranslateUi

};

namespace Ui {
    class FunctionValuesWidget: public Ui_FunctionValuesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FUNCTIONVALUESWIDGET_H

