/****************************************************************************
** Meta object code from reading C++ file 'Project.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/core/Project.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Project.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7ProjectE_t {};
} // unnamed namespace

template <> constexpr inline auto Project::qt_create_metaobjectdata<qt_meta_tag_ZN7ProjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Project",
        "authorChanged",
        "",
        "saveDefaultDockWidgetStateChanged",
        "saveCalculationsChanged",
        "requestSaveState",
        "QXmlStreamWriter*",
        "requestLoadState",
        "XmlStreamReader*",
        "requestProjectContextMenu",
        "QMenu*",
        "requestFolderContextMenu",
        "const Folder*",
        "mdiWindowVisibilityChanged",
        "changed",
        "requestNavigateTo",
        "path",
        "closeRequested",
        "saved",
        "loaded",
        "aboutToClose",
        "descriptionChanged",
        "const AbstractAspect*",
        "aspectAddedSlot"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'authorChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'saveDefaultDockWidgetStateChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'saveCalculationsChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'requestSaveState'
        QtMocHelpers::SignalData<void(QXmlStreamWriter *) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'requestLoadState'
        QtMocHelpers::SignalData<void(XmlStreamReader *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'requestProjectContextMenu'
        QtMocHelpers::SignalData<void(QMenu *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'requestFolderContextMenu'
        QtMocHelpers::SignalData<void(const Folder *, QMenu *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 }, { 0x80000000 | 10, 2 },
        }}),
        // Signal 'mdiWindowVisibilityChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestNavigateTo'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Signal 'closeRequested'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'saved'
        QtMocHelpers::SignalData<void() const>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loaded'
        QtMocHelpers::SignalData<void() const>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToClose'
        QtMocHelpers::SignalData<void() const>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'descriptionChanged'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Slot 'aspectAddedSlot'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Project, qt_meta_tag_ZN7ProjectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Project::staticMetaObject = { {
    QMetaObject::SuperData::link<Folder::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ProjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ProjectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7ProjectE_t>.metaTypes,
    nullptr
} };

void Project::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Project *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->authorChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->saveDefaultDockWidgetStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->saveCalculationsChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->requestSaveState((*reinterpret_cast<std::add_pointer_t<QXmlStreamWriter*>>(_a[1]))); break;
        case 4: _t->requestLoadState((*reinterpret_cast<std::add_pointer_t<XmlStreamReader*>>(_a[1]))); break;
        case 5: _t->requestProjectContextMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 6: _t->requestFolderContextMenu((*reinterpret_cast<std::add_pointer_t<const Folder*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2]))); break;
        case 7: _t->mdiWindowVisibilityChanged(); break;
        case 8: _t->changed(); break;
        case 9: _t->requestNavigateTo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->closeRequested(); break;
        case 11: _t->saved(); break;
        case 12: _t->loaded(); break;
        case 13: _t->aboutToClose(); break;
        case 14: _t->descriptionChanged((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 15: _t->aspectAddedSlot((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Project::*)(const QString & )>(_a, &Project::authorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(bool )>(_a, &Project::saveDefaultDockWidgetStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(bool )>(_a, &Project::saveCalculationsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(QXmlStreamWriter * ) const>(_a, &Project::requestSaveState, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(XmlStreamReader * )>(_a, &Project::requestLoadState, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(QMenu * )>(_a, &Project::requestProjectContextMenu, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(const Folder * , QMenu * )>(_a, &Project::requestFolderContextMenu, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)()>(_a, &Project::mdiWindowVisibilityChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)()>(_a, &Project::changed, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(const QString & )>(_a, &Project::requestNavigateTo, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)()>(_a, &Project::closeRequested, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)() const>(_a, &Project::saved, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)() const>(_a, &Project::loaded, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)() const>(_a, &Project::aboutToClose, 13))
            return;
    }
}

const QMetaObject *Project::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Project::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ProjectE_t>.strings))
        return static_cast<void*>(this);
    return Folder::qt_metacast(_clname);
}

int Project::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Folder::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void Project::authorChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Project::saveDefaultDockWidgetStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Project::saveCalculationsChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Project::requestSaveState(QXmlStreamWriter * _t1)const
{
    QMetaObject::activate<void>(const_cast< Project *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Project::requestLoadState(XmlStreamReader * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Project::requestProjectContextMenu(QMenu * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Project::requestFolderContextMenu(const Folder * _t1, QMenu * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void Project::mdiWindowVisibilityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Project::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Project::requestNavigateTo(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Project::closeRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Project::saved()const
{
    QMetaObject::activate(const_cast< Project *>(this), &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Project::loaded()const
{
    QMetaObject::activate(const_cast< Project *>(this), &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Project::aboutToClose()const
{
    QMetaObject::activate(const_cast< Project *>(this), &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
