/********************************************************************************
** Form generated from reading UI file 'fitoptionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FITOPTIONSWIDGET_H
#define UI_FITOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "kseparator.h"

QT_BEGIN_NAMESPACE

class Ui_FitOptionsWidget
{
public:
    QGridLayout *gridLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *pbApply;
    QPushButton *pbCancel;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLineEdit *leEps;
    QCheckBox *cbPreview;
    QLabel *lEps;
    QCheckBox *cbUseDataErrors;
    QLineEdit *leMin;
    QLineEdit *leMax;
    QLabel *lEvaluatedPoints;
    QLabel *lEvalRange;
    QLabel *lMaxIterations;
    QLineEdit *leMaxIterations;
    QLabel *lXRange;
    QLineEdit *leEvalMax;
    QComboBox *cbRobust;
    QLineEdit *leEvaluatedPoints;
    QCheckBox *cbAutoRange;
    QCheckBox *cbAutoEvalRange;
    QCheckBox *cbUseResults;
    QLabel *lRobust;
    QLineEdit *leEvalMin;
    UTCDateTimeEdit *dateTimeEditMin;
    UTCDateTimeEdit *dateTimeEditMax;
    UTCDateTimeEdit *dateTimeEditEvalMin;
    UTCDateTimeEdit *dateTimeEditEvalMax;
    QLabel *lXRangeDateTime;
    QLabel *lEvalRangeDateTime;
    QLabel *label;
    KSeparator *kseparator;
    NumberSpinBox *sbConfidenceInterval;

    void setupUi(QWidget *FitOptionsWidget)
    {
        if (FitOptionsWidget->objectName().isEmpty())
            FitOptionsWidget->setObjectName("FitOptionsWidget");
        FitOptionsWidget->resize(474, 640);
        gridLayout_2 = new QGridLayout(FitOptionsWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        horizontalSpacer = new QSpacerItem(129, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 1, 0, 1, 1);

        pbApply = new QPushButton(FitOptionsWidget);
        pbApply->setObjectName("pbApply");

        gridLayout_2->addWidget(pbApply, 1, 1, 1, 1);

        pbCancel = new QPushButton(FitOptionsWidget);
        pbCancel->setObjectName("pbCancel");

        gridLayout_2->addWidget(pbCancel, 1, 2, 1, 1);

        groupBox = new QGroupBox(FitOptionsWidget);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        leEps = new QLineEdit(groupBox);
        leEps->setObjectName("leEps");

        gridLayout->addWidget(leEps, 2, 3, 1, 1);

        cbPreview = new QCheckBox(groupBox);
        cbPreview->setObjectName("cbPreview");
        cbPreview->setChecked(true);

        gridLayout->addWidget(cbPreview, 12, 0, 1, 3);

        lEps = new QLabel(groupBox);
        lEps->setObjectName("lEps");

        gridLayout->addWidget(lEps, 2, 0, 1, 1);

        cbUseDataErrors = new QCheckBox(groupBox);
        cbUseDataErrors->setObjectName("cbUseDataErrors");
        cbUseDataErrors->setChecked(true);

        gridLayout->addWidget(cbUseDataErrors, 10, 0, 1, 4);

        leMin = new QLineEdit(groupBox);
        leMin->setObjectName("leMin");

        gridLayout->addWidget(leMin, 5, 0, 1, 1);

        leMax = new QLineEdit(groupBox);
        leMax->setObjectName("leMax");

        gridLayout->addWidget(leMax, 5, 3, 1, 1);

        lEvaluatedPoints = new QLabel(groupBox);
        lEvaluatedPoints->setObjectName("lEvaluatedPoints");

        gridLayout->addWidget(lEvaluatedPoints, 3, 0, 1, 1);

        lEvalRange = new QLabel(groupBox);
        lEvalRange->setObjectName("lEvalRange");

        gridLayout->addWidget(lEvalRange, 8, 2, 1, 1);

        lMaxIterations = new QLabel(groupBox);
        lMaxIterations->setObjectName("lMaxIterations");

        gridLayout->addWidget(lMaxIterations, 1, 0, 1, 1);

        leMaxIterations = new QLineEdit(groupBox);
        leMaxIterations->setObjectName("leMaxIterations");

        gridLayout->addWidget(leMaxIterations, 1, 3, 1, 1);

        lXRange = new QLabel(groupBox);
        lXRange->setObjectName("lXRange");

        gridLayout->addWidget(lXRange, 5, 2, 1, 1);

        leEvalMax = new QLineEdit(groupBox);
        leEvalMax->setObjectName("leEvalMax");

        gridLayout->addWidget(leEvalMax, 8, 3, 1, 1);

        cbRobust = new QComboBox(groupBox);
        cbRobust->setObjectName("cbRobust");

        gridLayout->addWidget(cbRobust, 0, 3, 1, 1);

        leEvaluatedPoints = new QLineEdit(groupBox);
        leEvaluatedPoints->setObjectName("leEvaluatedPoints");

        gridLayout->addWidget(leEvaluatedPoints, 3, 3, 1, 1);

        cbAutoRange = new QCheckBox(groupBox);
        cbAutoRange->setObjectName("cbAutoRange");
        cbAutoRange->setChecked(true);

        gridLayout->addWidget(cbAutoRange, 4, 0, 1, 1);

        cbAutoEvalRange = new QCheckBox(groupBox);
        cbAutoEvalRange->setObjectName("cbAutoEvalRange");
        cbAutoEvalRange->setChecked(true);

        gridLayout->addWidget(cbAutoEvalRange, 7, 0, 1, 4);

        cbUseResults = new QCheckBox(groupBox);
        cbUseResults->setObjectName("cbUseResults");
        cbUseResults->setChecked(true);

        gridLayout->addWidget(cbUseResults, 11, 0, 1, 4);

        lRobust = new QLabel(groupBox);
        lRobust->setObjectName("lRobust");
        lRobust->setEnabled(false);

        gridLayout->addWidget(lRobust, 0, 0, 1, 1);

        leEvalMin = new QLineEdit(groupBox);
        leEvalMin->setObjectName("leEvalMin");

        gridLayout->addWidget(leEvalMin, 8, 0, 1, 1);

        dateTimeEditMin = new UTCDateTimeEdit(groupBox);
        dateTimeEditMin->setObjectName("dateTimeEditMin");
        dateTimeEditMin->setCalendarPopup(true);

        gridLayout->addWidget(dateTimeEditMin, 6, 0, 1, 1);

        dateTimeEditMax = new UTCDateTimeEdit(groupBox);
        dateTimeEditMax->setObjectName("dateTimeEditMax");
        dateTimeEditMax->setCalendarPopup(true);

        gridLayout->addWidget(dateTimeEditMax, 6, 3, 1, 1);

        dateTimeEditEvalMin = new UTCDateTimeEdit(groupBox);
        dateTimeEditEvalMin->setObjectName("dateTimeEditEvalMin");
        dateTimeEditEvalMin->setCalendarPopup(true);

        gridLayout->addWidget(dateTimeEditEvalMin, 9, 0, 1, 1);

        dateTimeEditEvalMax = new UTCDateTimeEdit(groupBox);
        dateTimeEditEvalMax->setObjectName("dateTimeEditEvalMax");
        dateTimeEditEvalMax->setCalendarPopup(true);

        gridLayout->addWidget(dateTimeEditEvalMax, 9, 3, 1, 1);

        lXRangeDateTime = new QLabel(groupBox);
        lXRangeDateTime->setObjectName("lXRangeDateTime");

        gridLayout->addWidget(lXRangeDateTime, 6, 2, 1, 1);

        lEvalRangeDateTime = new QLabel(groupBox);
        lEvalRangeDateTime->setObjectName("lEvalRangeDateTime");

        gridLayout->addWidget(lEvalRangeDateTime, 9, 2, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 14, 0, 1, 1);

        kseparator = new KSeparator(groupBox);
        kseparator->setObjectName("kseparator");

        gridLayout->addWidget(kseparator, 13, 0, 1, 1);

        sbConfidenceInterval = new NumberSpinBox(groupBox);
        sbConfidenceInterval->setObjectName("sbConfidenceInterval");
        sbConfidenceInterval->setProperty("feedback", QVariant(false));

        gridLayout->addWidget(sbConfidenceInterval, 14, 3, 1, 1);


        gridLayout_2->addWidget(groupBox, 0, 0, 1, 3);


        retranslateUi(FitOptionsWidget);

        QMetaObject::connectSlotsByName(FitOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *FitOptionsWidget)
    {
        pbApply->setText(tr2i18n("Apply", nullptr));
        pbCancel->setText(tr2i18n("Cancel", nullptr));
        groupBox->setTitle(QString());
#if QT_CONFIG(tooltip)
        cbPreview->setToolTip(tr2i18n("show the fit function with the given start parameters", nullptr));
#endif // QT_CONFIG(tooltip)
        cbPreview->setText(tr2i18n("Preview fit function", nullptr));
#if QT_CONFIG(tooltip)
        lEps->setToolTip(tr2i18n("Specify the tolerance for the fit algorithm convergence", nullptr));
#endif // QT_CONFIG(tooltip)
        lEps->setText(tr2i18n("Tolerance:", nullptr));
#if QT_CONFIG(tooltip)
        cbUseDataErrors->setToolTip(tr2i18n("This option can be used to turn on and off the usage of given data uncertainties when fitting.", nullptr));
#endif // QT_CONFIG(tooltip)
        cbUseDataErrors->setText(tr2i18n("Use given data uncertainties", nullptr));
#if QT_CONFIG(tooltip)
        lEvaluatedPoints->setToolTip(tr2i18n("Number of points to use when evaluating the final fit function", nullptr));
#endif // QT_CONFIG(tooltip)
        lEvaluatedPoints->setText(tr2i18n("Evaluated points:", nullptr));
        lEvalRange->setText(tr2i18n("..", nullptr));
#if QT_CONFIG(tooltip)
        lMaxIterations->setToolTip(tr2i18n("Specify maximum number of iterations for the fit algorithm", nullptr));
#endif // QT_CONFIG(tooltip)
        lMaxIterations->setText(tr2i18n("Max. iterations:", nullptr));
        lXRange->setText(tr2i18n("..", nullptr));
#if QT_CONFIG(tooltip)
        cbAutoRange->setToolTip(tr2i18n("Select range of data to use for fitting", nullptr));
#endif // QT_CONFIG(tooltip)
        cbAutoRange->setText(tr2i18n("Auto fit range", nullptr));
#if QT_CONFIG(tooltip)
        cbAutoEvalRange->setToolTip(tr2i18n("Select the range to evaluate the resulting fit function", nullptr));
#endif // QT_CONFIG(tooltip)
        cbAutoEvalRange->setText(tr2i18n("Auto evaluation range", nullptr));
#if QT_CONFIG(tooltip)
        cbUseResults->setToolTip(tr2i18n("If selected, the resulting fit parameter are set as new start values.", nullptr));
#endif // QT_CONFIG(tooltip)
        cbUseResults->setText(tr2i18n("Use results as new start values", nullptr));
        lRobust->setText(tr2i18n("Robust fit:", nullptr));
        lXRangeDateTime->setText(tr2i18n("..", nullptr));
        lEvalRangeDateTime->setText(tr2i18n("..", nullptr));
        label->setText(tr2i18n("Confidence Interval", nullptr));
#if QT_CONFIG(tooltip)
        sbConfidenceInterval->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbConfidenceInterval->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        (void)FitOptionsWidget;
    } // retranslateUi

};

namespace Ui {
    class FitOptionsWidget: public Ui_FitOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FITOPTIONSWIDGET_H

