/********************************************************************************
** Form generated from reading UI file 'colormapswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORMAPSWIDGET_H
#define UI_COLORMAPSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ColorMapsWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *lCollections;
    QComboBox *cbCollections;
    QPushButton *bInfo;
    QSpacerItem *horizontalSpacer;
    QToolButton *bViewMode;
    QLabel *lColormap;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QVBoxLayout *verticalLayout;
    QListView *lvColorMaps;
    QWidget *page_2;
    QHBoxLayout *horizontalLayout_2;
    QListWidget *lwColorMaps;
    QLabel *lPreview;
    QWidget *page_3;
    QHBoxLayout *horizontalLayout_3;
    QListWidget *lwColorMapsDetails;
    QTableWidget *twColorMapDetails;
    QHBoxLayout *horizontalLayout;
    QLabel *lSearch;
    QLineEdit *leSearch;

    void setupUi(QWidget *ColorMapsWidget)
    {
        if (ColorMapsWidget->objectName().isEmpty())
            ColorMapsWidget->setObjectName("ColorMapsWidget");
        ColorMapsWidget->resize(493, 345);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ColorMapsWidget->sizePolicy().hasHeightForWidth());
        ColorMapsWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(ColorMapsWidget);
        gridLayout->setObjectName("gridLayout");
        lCollections = new QLabel(ColorMapsWidget);
        lCollections->setObjectName("lCollections");

        gridLayout->addWidget(lCollections, 0, 0, 1, 1);

        cbCollections = new QComboBox(ColorMapsWidget);
        cbCollections->setObjectName("cbCollections");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbCollections->sizePolicy().hasHeightForWidth());
        cbCollections->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbCollections, 0, 1, 1, 1);

        bInfo = new QPushButton(ColorMapsWidget);
        bInfo->setObjectName("bInfo");

        gridLayout->addWidget(bInfo, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(148, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);

        bViewMode = new QToolButton(ColorMapsWidget);
        bViewMode->setObjectName("bViewMode");
        bViewMode->setCheckable(false);
        bViewMode->setChecked(false);

        gridLayout->addWidget(bViewMode, 0, 4, 1, 1);

        lColormap = new QLabel(ColorMapsWidget);
        lColormap->setObjectName("lColormap");
        lColormap->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout->addWidget(lColormap, 1, 0, 1, 1);

        stackedWidget = new QStackedWidget(ColorMapsWidget);
        stackedWidget->setObjectName("stackedWidget");
        page = new QWidget();
        page->setObjectName("page");
        verticalLayout = new QVBoxLayout(page);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, -1, 0);
        lvColorMaps = new QListView(page);
        lvColorMaps->setObjectName("lvColorMaps");

        verticalLayout->addWidget(lvColorMaps);

        stackedWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        horizontalLayout_2 = new QHBoxLayout(page_2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        lwColorMaps = new QListWidget(page_2);
        lwColorMaps->setObjectName("lwColorMaps");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(lwColorMaps->sizePolicy().hasHeightForWidth());
        lwColorMaps->setSizePolicy(sizePolicy2);

        horizontalLayout_2->addWidget(lwColorMaps);

        lPreview = new QLabel(page_2);
        lPreview->setObjectName("lPreview");
        sizePolicy.setHeightForWidth(lPreview->sizePolicy().hasHeightForWidth());
        lPreview->setSizePolicy(sizePolicy);
        lPreview->setFrameShape(QFrame::Shape::StyledPanel);
        lPreview->setFrameShadow(QFrame::Shadow::Sunken);
        lPreview->setScaledContents(true);
        lPreview->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        horizontalLayout_2->addWidget(lPreview);

        stackedWidget->addWidget(page_2);
        page_3 = new QWidget();
        page_3->setObjectName("page_3");
        horizontalLayout_3 = new QHBoxLayout(page_3);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        lwColorMapsDetails = new QListWidget(page_3);
        lwColorMapsDetails->setObjectName("lwColorMapsDetails");
        sizePolicy2.setHeightForWidth(lwColorMapsDetails->sizePolicy().hasHeightForWidth());
        lwColorMapsDetails->setSizePolicy(sizePolicy2);

        horizontalLayout_3->addWidget(lwColorMapsDetails);

        twColorMapDetails = new QTableWidget(page_3);
        if (twColorMapDetails->columnCount() < 8)
            twColorMapDetails->setColumnCount(8);
        twColorMapDetails->setObjectName("twColorMapDetails");
        twColorMapDetails->setColumnCount(8);
        twColorMapDetails->horizontalHeader()->setStretchLastSection(true);

        horizontalLayout_3->addWidget(twColorMapDetails);

        stackedWidget->addWidget(page_3);

        gridLayout->addWidget(stackedWidget, 1, 1, 1, 4);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        lSearch = new QLabel(ColorMapsWidget);
        lSearch->setObjectName("lSearch");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(lSearch->sizePolicy().hasHeightForWidth());
        lSearch->setSizePolicy(sizePolicy3);

        horizontalLayout->addWidget(lSearch);

        leSearch = new QLineEdit(ColorMapsWidget);
        leSearch->setObjectName("leSearch");
        sizePolicy1.setHeightForWidth(leSearch->sizePolicy().hasHeightForWidth());
        leSearch->setSizePolicy(sizePolicy1);
        leSearch->setClearButtonEnabled(true);

        horizontalLayout->addWidget(leSearch);


        gridLayout->addLayout(horizontalLayout, 2, 1, 1, 4);

        QWidget::setTabOrder(cbCollections, leSearch);

        retranslateUi(ColorMapsWidget);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ColorMapsWidget);
    } // setupUi

    void retranslateUi(QWidget *ColorMapsWidget)
    {
        lCollections->setText(tr2i18n("Collection:", nullptr));
        bInfo->setText(QString());
        bViewMode->setText(tr2i18n("View", nullptr));
        lColormap->setText(tr2i18n("Colormaps:", nullptr));
        lPreview->setText(QString());
        lSearch->setText(QString());
        (void)ColorMapsWidget;
    } // retranslateUi

};

namespace Ui {
    class ColorMapsWidget: public Ui_ColorMapsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COLORMAPSWIDGET_H

