/********************************************************************************
** Form generated from reading UI file 'worksheetpreviewwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WORKSHEETPREVIEWWIDGET_H
#define UI_WORKSHEETPREVIEWWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WorksheetPreviewWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QListWidget *lwPreview;

    void setupUi(QWidget *WorksheetPreviewWidget)
    {
        if (WorksheetPreviewWidget->objectName().isEmpty())
            WorksheetPreviewWidget->setObjectName("WorksheetPreviewWidget");
        WorksheetPreviewWidget->resize(533, 248);
        horizontalLayout = new QHBoxLayout(WorksheetPreviewWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        lwPreview = new QListWidget(WorksheetPreviewWidget);
        lwPreview->setObjectName("lwPreview");
        lwPreview->setMovement(QListView::Static);
        lwPreview->setProperty("isWrapping", QVariant(true));
        lwPreview->setViewMode(QListView::IconMode);

        horizontalLayout->addWidget(lwPreview);


        retranslateUi(WorksheetPreviewWidget);

        QMetaObject::connectSlotsByName(WorksheetPreviewWidget);
    } // setupUi

    void retranslateUi(QWidget *WorksheetPreviewWidget)
    {
        WorksheetPreviewWidget->setWindowTitle(tr2i18n("Form", nullptr));
    } // retranslateUi

};

namespace Ui {
    class WorksheetPreviewWidget: public Ui_WorksheetPreviewWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WORKSHEETPREVIEWWIDGET_H

