/********************************************************************************
** Form generated from reading UI file 'custompointdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMPOINTDOCK_H
#define UI_CUSTOMPOINTDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_CustomPointDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    QLabel *lBindLogicalPos;
    QCheckBox *chbBindLogicalPos;
    QSpacerItem *verticalSpacer_5;
    QLabel *lPositionXLogicalDateTime;
    QSpacerItem *horizontalSpacer;
    TimedLineEdit *leName;
    UTCDateTimeEdit *dtePositionYLogical;
    QLabel *lPositionXLogical;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacer_6;
    UTCDateTimeEdit *dtePositionXLogical;
    QComboBox *cbPlotRanges;
    NumberSpinBox *sbPositionXLogical;
    QLabel *lPlotRange;
    QLabel *lPositionYLogical;
    QHBoxLayout *horizontalLayout;
    KComboBox *cbPositionX;
    NumberSpinBox *sbPositionX;
    QLabel *lPositionX;
    QLabel *lName;
    QHBoxLayout *horizontalLayout_2;
    KComboBox *cbPositionY;
    NumberSpinBox *sbPositionY;
    NumberSpinBox *sbPositionYLogical;
    QCheckBox *chkVisible;
    QLabel *lComment;
    QLabel *lPositionYLogicalDateTime;
    QLabel *lPositionY;
    ResizableTextEdit *teComment;
    QLabel *lPosition;
    QCheckBox *chbLock;
    QWidget *tabSymbol;

    void setupUi(QWidget *CustomPointDock)
    {
        if (CustomPointDock->objectName().isEmpty())
            CustomPointDock->setObjectName("CustomPointDock");
        CustomPointDock->resize(349, 620);
        verticalLayout = new QVBoxLayout(CustomPointDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(CustomPointDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setObjectName("gridLayout");
        lBindLogicalPos = new QLabel(tabGeneral);
        lBindLogicalPos->setObjectName("lBindLogicalPos");

        gridLayout->addWidget(lBindLogicalPos, 4, 0, 1, 1);

        chbBindLogicalPos = new QCheckBox(tabGeneral);
        chbBindLogicalPos->setObjectName("chbBindLogicalPos");

        gridLayout->addWidget(chbBindLogicalPos, 4, 2, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_5, 2, 0, 1, 1);

        lPositionXLogicalDateTime = new QLabel(tabGeneral);
        lPositionXLogicalDateTime->setObjectName("lPositionXLogicalDateTime");

        gridLayout->addWidget(lPositionXLogicalDateTime, 6, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 1, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(leName->sizePolicy().hasHeightForWidth());
        leName->setSizePolicy(sizePolicy);

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        dtePositionYLogical = new UTCDateTimeEdit(tabGeneral);
        dtePositionYLogical->setObjectName("dtePositionYLogical");

        gridLayout->addWidget(dtePositionYLogical, 9, 2, 1, 1);

        lPositionXLogical = new QLabel(tabGeneral);
        lPositionXLogical->setObjectName("lPositionXLogical");

        gridLayout->addWidget(lPositionXLogical, 7, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 694, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 13, 0, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_6, 11, 0, 1, 1);

        dtePositionXLogical = new UTCDateTimeEdit(tabGeneral);
        dtePositionXLogical->setObjectName("dtePositionXLogical");
        dtePositionXLogical->setCalendarPopup(true);

        gridLayout->addWidget(dtePositionXLogical, 6, 2, 1, 1);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout->addWidget(cbPlotRanges, 12, 2, 1, 1);

        sbPositionXLogical = new NumberSpinBox(tabGeneral);
        sbPositionXLogical->setObjectName("sbPositionXLogical");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sbPositionXLogical->sizePolicy().hasHeightForWidth());
        sbPositionXLogical->setSizePolicy(sizePolicy1);
        sbPositionXLogical->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionXLogical, 7, 2, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout->addWidget(lPlotRange, 12, 0, 1, 1);

        lPositionYLogical = new QLabel(tabGeneral);
        lPositionYLogical->setObjectName("lPositionYLogical");

        gridLayout->addWidget(lPositionYLogical, 10, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        cbPositionX = new KComboBox(tabGeneral);
        cbPositionX->setObjectName("cbPositionX");

        horizontalLayout->addWidget(cbPositionX);

        sbPositionX = new NumberSpinBox(tabGeneral);
        sbPositionX->setObjectName("sbPositionX");
        sizePolicy1.setHeightForWidth(sbPositionX->sizePolicy().hasHeightForWidth());
        sbPositionX->setSizePolicy(sizePolicy1);
        sbPositionX->setProperty("feedback", QVariant(true));

        horizontalLayout->addWidget(sbPositionX);


        gridLayout->addLayout(horizontalLayout, 5, 2, 1, 1);

        lPositionX = new QLabel(tabGeneral);
        lPositionX->setObjectName("lPositionX");

        gridLayout->addWidget(lPositionX, 5, 0, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        cbPositionY = new KComboBox(tabGeneral);
        cbPositionY->setObjectName("cbPositionY");

        horizontalLayout_2->addWidget(cbPositionY);

        sbPositionY = new NumberSpinBox(tabGeneral);
        sbPositionY->setObjectName("sbPositionY");
        sizePolicy1.setHeightForWidth(sbPositionY->sizePolicy().hasHeightForWidth());
        sbPositionY->setSizePolicy(sizePolicy1);
        sbPositionY->setProperty("feedback", QVariant(true));

        horizontalLayout_2->addWidget(sbPositionY);


        gridLayout->addLayout(horizontalLayout_2, 8, 2, 1, 1);

        sbPositionYLogical = new NumberSpinBox(tabGeneral);
        sbPositionYLogical->setObjectName("sbPositionYLogical");
        sizePolicy1.setHeightForWidth(sbPositionYLogical->sizePolicy().hasHeightForWidth());
        sbPositionYLogical->setSizePolicy(sizePolicy1);
        sbPositionYLogical->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPositionYLogical, 10, 2, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout->addWidget(chkVisible, 15, 0, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        lPositionYLogicalDateTime = new QLabel(tabGeneral);
        lPositionYLogicalDateTime->setObjectName("lPositionYLogicalDateTime");

        gridLayout->addWidget(lPositionYLogicalDateTime, 9, 0, 1, 1);

        lPositionY = new QLabel(tabGeneral);
        lPositionY->setObjectName("lPositionY");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(lPositionY->sizePolicy().hasHeightForWidth());
        lPositionY->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(lPositionY, 8, 0, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        sizePolicy.setHeightForWidth(teComment->sizePolicy().hasHeightForWidth());
        teComment->setSizePolicy(sizePolicy);
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        lPosition = new QLabel(tabGeneral);
        lPosition->setObjectName("lPosition");
        QFont font;
        font.setBold(true);
        lPosition->setFont(font);

        gridLayout->addWidget(lPosition, 3, 0, 1, 1);

        chbLock = new QCheckBox(tabGeneral);
        chbLock->setObjectName("chbLock");

        gridLayout->addWidget(chbLock, 14, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabSymbol = new QWidget();
        tabSymbol->setObjectName("tabSymbol");
        tabWidget->addTab(tabSymbol, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, chbBindLogicalPos);
        QWidget::setTabOrder(chbBindLogicalPos, cbPositionX);
        QWidget::setTabOrder(cbPositionX, sbPositionX);
        QWidget::setTabOrder(sbPositionX, dtePositionXLogical);
        QWidget::setTabOrder(dtePositionXLogical, sbPositionXLogical);
        QWidget::setTabOrder(sbPositionXLogical, cbPositionY);
        QWidget::setTabOrder(cbPositionY, sbPositionY);
        QWidget::setTabOrder(sbPositionY, dtePositionYLogical);
        QWidget::setTabOrder(dtePositionYLogical, sbPositionYLogical);
        QWidget::setTabOrder(sbPositionYLogical, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chbLock);
        QWidget::setTabOrder(chbLock, chkVisible);

        retranslateUi(CustomPointDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(CustomPointDock);
    } // setupUi

    void retranslateUi(QWidget *CustomPointDock)
    {
        lBindLogicalPos->setText(tr2i18n("Logical coordinates", nullptr));
        chbBindLogicalPos->setText(QString());
        lPositionXLogicalDateTime->setText(tr2i18n("x:", nullptr));
        lPositionXLogical->setText(tr2i18n("x:", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionXLogical->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionXLogical->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        lPositionYLogical->setText(tr2i18n("y:", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionX->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionX->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        lPositionX->setToolTip(tr2i18n("Horizontal position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
        lPositionX->setText(tr2i18n("x:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionY->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionY->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        sbPositionYLogical->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionYLogical->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lPositionYLogicalDateTime->setText(tr2i18n("y:", nullptr));
#if QT_CONFIG(tooltip)
        lPositionY->setToolTip(tr2i18n("Vertical position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
        lPositionY->setText(tr2i18n("y:", nullptr));
        lPosition->setText(tr2i18n("Position", nullptr));
        chbLock->setText(tr2i18n("Locked", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabSymbol), tr2i18n("Symbol", nullptr));
        (void)CustomPointDock;
    } // retranslateUi

};

namespace Ui {
    class CustomPointDock: public Ui_CustomPointDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUSTOMPOINTDOCK_H

