/****************************************************************************
** Meta object code from reading C++ file 'InfoElement.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/InfoElement.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'InfoElement.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11InfoElementE_t {};
} // unnamed namespace

template <> constexpr inline auto InfoElement::qt_create_metaobjectdata<qt_meta_tag_ZN11InfoElementE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InfoElement",
        "gluePointIndexChanged",
        "",
        "connectionLineCurveNameChanged",
        "positionLogicalChanged",
        "labelBorderShapeChangedSignal",
        "curveRemoved",
        "labelPositionChanged",
        "TextLabel::PositionWrapper",
        "labelVisibleChanged",
        "pointPositionChanged",
        "PositionWrapper",
        "childRemoved",
        "const AbstractAspect*",
        "parent",
        "before",
        "child",
        "childAdded",
        "labelBorderShapeChanged",
        "labelTextWrapperChanged",
        "TextLabel::TextWrapper",
        "curveVisibilityChanged",
        "curveDataChanged",
        "curveCoordinateSystemIndexChanged",
        "pointVisibleChanged",
        "visible"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'gluePointIndexChanged'
        QtMocHelpers::SignalData<void(const int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'connectionLineCurveNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'positionLogicalChanged'
        QtMocHelpers::SignalData<void(const double)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'labelBorderShapeChangedSignal'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'curveRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'labelPositionChanged'
        QtMocHelpers::SlotData<void(TextLabel::PositionWrapper)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'labelVisibleChanged'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'pointPositionChanged'
        QtMocHelpers::SlotData<void(const PositionWrapper &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'childRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *, const AbstractAspect *, const AbstractAspect *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 15 }, { 0x80000000 | 13, 16 },
        }}),
        // Slot 'childAdded'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'labelBorderShapeChanged'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'labelTextWrapperChanged'
        QtMocHelpers::SlotData<void(TextLabel::TextWrapper)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 2 },
        }}),
        // Slot 'curveVisibilityChanged'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'curveDataChanged'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'curveCoordinateSystemIndexChanged'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'pointVisibleChanged'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InfoElement, qt_meta_tag_ZN11InfoElementE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject InfoElement::staticMetaObject = { {
    QMetaObject::SuperData::link<WorksheetElement::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11InfoElementE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11InfoElementE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11InfoElementE_t>.metaTypes,
    nullptr
} };

void InfoElement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InfoElement *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->gluePointIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->connectionLineCurveNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->positionLogicalChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 3: _t->labelBorderShapeChangedSignal(); break;
        case 4: _t->curveRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->labelPositionChanged((*reinterpret_cast<std::add_pointer_t<TextLabel::PositionWrapper>>(_a[1]))); break;
        case 6: _t->labelVisibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->pointPositionChanged((*reinterpret_cast<std::add_pointer_t<PositionWrapper>>(_a[1]))); break;
        case 8: _t->childRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[3]))); break;
        case 9: _t->childAdded((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 10: _t->labelBorderShapeChanged(); break;
        case 11: _t->labelTextWrapperChanged((*reinterpret_cast<std::add_pointer_t<TextLabel::TextWrapper>>(_a[1]))); break;
        case 12: _t->curveVisibilityChanged(); break;
        case 13: _t->curveDataChanged(); break;
        case 14: _t->curveCoordinateSystemIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->pointVisibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InfoElement::*)(const int )>(_a, &InfoElement::gluePointIndexChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InfoElement::*)(const QString & )>(_a, &InfoElement::connectionLineCurveNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InfoElement::*)(const double )>(_a, &InfoElement::positionLogicalChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InfoElement::*)()>(_a, &InfoElement::labelBorderShapeChangedSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (InfoElement::*)(const QString & )>(_a, &InfoElement::curveRemoved, 4))
            return;
    }
}

const QMetaObject *InfoElement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InfoElement::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11InfoElementE_t>.strings))
        return static_cast<void*>(this);
    return WorksheetElement::qt_metacast(_clname);
}

int InfoElement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WorksheetElement::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void InfoElement::gluePointIndexChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void InfoElement::connectionLineCurveNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void InfoElement::positionLogicalChanged(const double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void InfoElement::labelBorderShapeChangedSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void InfoElement::curveRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
