/********************************************************************************
** Form generated from reading UI file 'matrixdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MATRIXDOCK_H
#define UI_MATRIXDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_MatrixDock
{
public:
    QGridLayout *gridLayout;
    QLabel *lName;
    QSpacerItem *horizontalSpacer_4;
    TimedLineEdit *leName;
    QLabel *lComment;
    ResizableTextEdit *teComment;
    QSpacerItem *verticalSpacer_3;
    QLabel *lDimensions;
    QLabel *lRowCount;
    QSpinBox *sbRowCount;
    QLabel *lColumnCount;
    QSpinBox *sbColumnCount;
    QSpacerItem *verticalSpacer_4;
    QLabel *lMapping;
    QLabel *lXStart;
    QLineEdit *leXStart;
    QLabel *lXMax;
    QLineEdit *leXEnd;
    QSpacerItem *verticalSpacer_5;
    QLabel *lYStart;
    QLineEdit *leYStart;
    QLabel *lYEnd;
    QLineEdit *leYEnd;
    QSpacerItem *verticalSpacer_7;
    QLabel *lFormat;
    QLabel *lType;
    KComboBox *cbFormat;
    QLabel *lPrecision;
    QSpinBox *sbPrecision;
    QLabel *lHeader;
    KComboBox *cbHeader;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *MatrixDock)
    {
        if (MatrixDock->objectName().isEmpty())
            MatrixDock->setObjectName("MatrixDock");
        MatrixDock->resize(305, 649);
        gridLayout = new QGridLayout(MatrixDock);
        gridLayout->setObjectName("gridLayout");
        lName = new QLabel(MatrixDock);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 0, 1, 1, 1);

        leName = new TimedLineEdit(MatrixDock);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        lComment = new QLabel(MatrixDock);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        teComment = new ResizableTextEdit(MatrixDock);
        teComment->setObjectName("teComment");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(teComment->sizePolicy().hasHeightForWidth());
        teComment->setSizePolicy(sizePolicy);
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        verticalSpacer_3 = new QSpacerItem(58, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 2, 0, 1, 1);

        lDimensions = new QLabel(MatrixDock);
        lDimensions->setObjectName("lDimensions");
        QFont font;
        font.setBold(true);
        lDimensions->setFont(font);

        gridLayout->addWidget(lDimensions, 3, 0, 1, 1);

        lRowCount = new QLabel(MatrixDock);
        lRowCount->setObjectName("lRowCount");

        gridLayout->addWidget(lRowCount, 4, 0, 1, 1);

        sbRowCount = new QSpinBox(MatrixDock);
        sbRowCount->setObjectName("sbRowCount");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sbRowCount->sizePolicy().hasHeightForWidth());
        sbRowCount->setSizePolicy(sizePolicy1);
        sbRowCount->setMinimum(0);
        sbRowCount->setMaximum(16777215);

        gridLayout->addWidget(sbRowCount, 4, 2, 1, 1);

        lColumnCount = new QLabel(MatrixDock);
        lColumnCount->setObjectName("lColumnCount");

        gridLayout->addWidget(lColumnCount, 5, 0, 1, 1);

        sbColumnCount = new QSpinBox(MatrixDock);
        sbColumnCount->setObjectName("sbColumnCount");
        sizePolicy1.setHeightForWidth(sbColumnCount->sizePolicy().hasHeightForWidth());
        sbColumnCount->setSizePolicy(sizePolicy1);
        sbColumnCount->setMinimum(0);
        sbColumnCount->setMaximum(16777215);

        gridLayout->addWidget(sbColumnCount, 5, 2, 1, 1);

        verticalSpacer_4 = new QSpacerItem(58, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 6, 0, 1, 1);

        lMapping = new QLabel(MatrixDock);
        lMapping->setObjectName("lMapping");
        lMapping->setFont(font);

        gridLayout->addWidget(lMapping, 7, 0, 1, 1);

        lXStart = new QLabel(MatrixDock);
        lXStart->setObjectName("lXStart");

        gridLayout->addWidget(lXStart, 8, 0, 1, 1);

        leXStart = new QLineEdit(MatrixDock);
        leXStart->setObjectName("leXStart");
        leXStart->setClearButtonEnabled(true);

        gridLayout->addWidget(leXStart, 8, 2, 1, 1);

        lXMax = new QLabel(MatrixDock);
        lXMax->setObjectName("lXMax");

        gridLayout->addWidget(lXMax, 9, 0, 1, 1);

        leXEnd = new QLineEdit(MatrixDock);
        leXEnd->setObjectName("leXEnd");
        leXEnd->setClearButtonEnabled(true);

        gridLayout->addWidget(leXEnd, 9, 2, 1, 1);

        verticalSpacer_5 = new QSpacerItem(58, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_5, 10, 0, 1, 1);

        lYStart = new QLabel(MatrixDock);
        lYStart->setObjectName("lYStart");

        gridLayout->addWidget(lYStart, 11, 0, 1, 1);

        leYStart = new QLineEdit(MatrixDock);
        leYStart->setObjectName("leYStart");
        leYStart->setClearButtonEnabled(true);

        gridLayout->addWidget(leYStart, 11, 2, 1, 1);

        lYEnd = new QLabel(MatrixDock);
        lYEnd->setObjectName("lYEnd");

        gridLayout->addWidget(lYEnd, 12, 0, 1, 1);

        leYEnd = new QLineEdit(MatrixDock);
        leYEnd->setObjectName("leYEnd");
        leYEnd->setClearButtonEnabled(true);

        gridLayout->addWidget(leYEnd, 12, 2, 1, 1);

        verticalSpacer_7 = new QSpacerItem(58, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_7, 13, 0, 1, 1);

        lFormat = new QLabel(MatrixDock);
        lFormat->setObjectName("lFormat");
        lFormat->setFont(font);

        gridLayout->addWidget(lFormat, 14, 0, 1, 1);

        lType = new QLabel(MatrixDock);
        lType->setObjectName("lType");

        gridLayout->addWidget(lType, 15, 0, 1, 1);

        cbFormat = new KComboBox(MatrixDock);
        cbFormat->setObjectName("cbFormat");
        sizePolicy1.setHeightForWidth(cbFormat->sizePolicy().hasHeightForWidth());
        cbFormat->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbFormat, 15, 2, 1, 1);

        lPrecision = new QLabel(MatrixDock);
        lPrecision->setObjectName("lPrecision");

        gridLayout->addWidget(lPrecision, 16, 0, 1, 1);

        sbPrecision = new QSpinBox(MatrixDock);
        sbPrecision->setObjectName("sbPrecision");
        sizePolicy1.setHeightForWidth(sbPrecision->sizePolicy().hasHeightForWidth());
        sbPrecision->setSizePolicy(sizePolicy1);
        sbPrecision->setMaximum(16);

        gridLayout->addWidget(sbPrecision, 16, 2, 1, 1);

        lHeader = new QLabel(MatrixDock);
        lHeader->setObjectName("lHeader");

        gridLayout->addWidget(lHeader, 17, 0, 1, 1);

        cbHeader = new KComboBox(MatrixDock);
        cbHeader->setObjectName("cbHeader");
        sizePolicy1.setHeightForWidth(cbHeader->sizePolicy().hasHeightForWidth());
        cbHeader->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbHeader, 17, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 18, 0, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, sbRowCount);
        QWidget::setTabOrder(sbRowCount, sbColumnCount);
        QWidget::setTabOrder(sbColumnCount, leXStart);
        QWidget::setTabOrder(leXStart, leXEnd);
        QWidget::setTabOrder(leXEnd, leYStart);
        QWidget::setTabOrder(leYStart, leYEnd);
        QWidget::setTabOrder(leYEnd, cbFormat);
        QWidget::setTabOrder(cbFormat, sbPrecision);
        QWidget::setTabOrder(sbPrecision, cbHeader);

        retranslateUi(MatrixDock);

        QMetaObject::connectSlotsByName(MatrixDock);
    } // setupUi

    void retranslateUi(QWidget *MatrixDock)
    {
        lName->setText(tr2i18n("Name:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lDimensions->setText(tr2i18n("Dimensions", nullptr));
        lRowCount->setText(tr2i18n("Rows:", nullptr));
        lColumnCount->setText(tr2i18n("Columns:", nullptr));
        lMapping->setText(tr2i18n("Mapping", nullptr));
        lXStart->setText(tr2i18n("X-Start:", nullptr));
        lXMax->setText(tr2i18n("X-End:", nullptr));
        lYStart->setText(tr2i18n("Y-Start:", nullptr));
        lYEnd->setText(tr2i18n("Y-End:", nullptr));
        lFormat->setText(tr2i18n("Format", nullptr));
        lType->setText(tr2i18n("Type:", nullptr));
        lPrecision->setText(tr2i18n("Precision:", nullptr));
        lHeader->setText(tr2i18n("Header:", nullptr));
        (void)MatrixDock;
    } // retranslateUi

};

namespace Ui {
    class MatrixDock: public Ui_MatrixDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MATRIXDOCK_H

