/****************************************************************************
** Meta object code from reading C++ file 'XYFourierTransformCurveDock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/dockwidgets/XYFourierTransformCurveDock.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'XYFourierTransformCurveDock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN27XYFourierTransformCurveDockE_t {};
} // unnamed namespace

template <> constexpr inline auto XYFourierTransformCurveDock::qt_create_metaobjectdata<qt_meta_tag_ZN27XYFourierTransformCurveDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XYFourierTransformCurveDock",
        "xDataColumnChanged",
        "",
        "QModelIndex",
        "autoRangeChanged",
        "xRangeMinChanged",
        "xRangeMaxChanged",
        "windowTypeChanged",
        "typeChanged",
        "twoSidedChanged",
        "shiftedChanged",
        "xScaleChanged",
        "recalculateClicked",
        "curveTransformDataChanged",
        "XYFourierTransformCurve::TransformData"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'xDataColumnChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'autoRangeChanged'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'xRangeMinChanged'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'xRangeMaxChanged'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'windowTypeChanged'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'typeChanged'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'twoSidedChanged'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'shiftedChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'xScaleChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'recalculateClicked'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'curveTransformDataChanged'
        QtMocHelpers::SlotData<void(const XYFourierTransformCurve::TransformData &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XYFourierTransformCurveDock, qt_meta_tag_ZN27XYFourierTransformCurveDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XYFourierTransformCurveDock::staticMetaObject = { {
    QMetaObject::SuperData::link<XYAnalysisCurveDock::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27XYFourierTransformCurveDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27XYFourierTransformCurveDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27XYFourierTransformCurveDockE_t>.metaTypes,
    nullptr
} };

void XYFourierTransformCurveDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XYFourierTransformCurveDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->xDataColumnChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 1: _t->autoRangeChanged(); break;
        case 2: _t->xRangeMinChanged(); break;
        case 3: _t->xRangeMaxChanged(); break;
        case 4: _t->windowTypeChanged(); break;
        case 5: _t->typeChanged(); break;
        case 6: _t->twoSidedChanged(); break;
        case 7: _t->shiftedChanged(); break;
        case 8: _t->xScaleChanged(); break;
        case 9: _t->recalculateClicked(); break;
        case 10: _t->curveTransformDataChanged((*reinterpret_cast<std::add_pointer_t<XYFourierTransformCurve::TransformData>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *XYFourierTransformCurveDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XYFourierTransformCurveDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27XYFourierTransformCurveDockE_t>.strings))
        return static_cast<void*>(this);
    return XYAnalysisCurveDock::qt_metacast(_clname);
}

int XYFourierTransformCurveDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XYAnalysisCurveDock::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
