/********************************************************************************
** Form generated from reading UI file 'jsonoptionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JSONOPTIONSWIDGET_H
#define UI_JSONOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_JsonOptionsWidget
{
public:
    QGridLayout *gridLayout;
    QCheckBox *chbCreateIndex;
    QCheckBox *chbConvertNaNToZero;
    QLabel *lDateTimeFormat;
    QComboBox *cbDecimalSeparator;
    QSpacerItem *horizontalSpacer;
    KComboBox *cbDateTimeFormat;
    QLabel *lDecimalSeparator;
    QSpacerItem *verticalSpacer_4;
    QCheckBox *chbImportObjectNames;

    void setupUi(QWidget *JsonOptionsWidget)
    {
        if (JsonOptionsWidget->objectName().isEmpty())
            JsonOptionsWidget->setObjectName("JsonOptionsWidget");
        JsonOptionsWidget->resize(632, 227);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(JsonOptionsWidget->sizePolicy().hasHeightForWidth());
        JsonOptionsWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(JsonOptionsWidget);
        gridLayout->setObjectName("gridLayout");
        chbCreateIndex = new QCheckBox(JsonOptionsWidget);
        chbCreateIndex->setObjectName("chbCreateIndex");

        gridLayout->addWidget(chbCreateIndex, 2, 0, 1, 1);

        chbConvertNaNToZero = new QCheckBox(JsonOptionsWidget);
        chbConvertNaNToZero->setObjectName("chbConvertNaNToZero");
        chbConvertNaNToZero->setChecked(false);

        gridLayout->addWidget(chbConvertNaNToZero, 2, 2, 1, 1);

        lDateTimeFormat = new QLabel(JsonOptionsWidget);
        lDateTimeFormat->setObjectName("lDateTimeFormat");

        gridLayout->addWidget(lDateTimeFormat, 1, 0, 1, 2);

        cbDecimalSeparator = new QComboBox(JsonOptionsWidget);
        cbDecimalSeparator->setObjectName("cbDecimalSeparator");

        gridLayout->addWidget(cbDecimalSeparator, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);

        cbDateTimeFormat = new KComboBox(JsonOptionsWidget);
        cbDateTimeFormat->setObjectName("cbDateTimeFormat");
        sizePolicy.setHeightForWidth(cbDateTimeFormat->sizePolicy().hasHeightForWidth());
        cbDateTimeFormat->setSizePolicy(sizePolicy);
        cbDateTimeFormat->setEditable(true);

        gridLayout->addWidget(cbDateTimeFormat, 1, 2, 1, 1);

        lDecimalSeparator = new QLabel(JsonOptionsWidget);
        lDecimalSeparator->setObjectName("lDecimalSeparator");

        gridLayout->addWidget(lDecimalSeparator, 0, 0, 1, 2);

        verticalSpacer_4 = new QSpacerItem(20, 44, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_4, 5, 0, 1, 1);

        chbImportObjectNames = new QCheckBox(JsonOptionsWidget);
        chbImportObjectNames->setObjectName("chbImportObjectNames");

        gridLayout->addWidget(chbImportObjectNames, 3, 0, 1, 1);


        retranslateUi(JsonOptionsWidget);

        QMetaObject::connectSlotsByName(JsonOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *JsonOptionsWidget)
    {
        chbCreateIndex->setText(tr2i18n("Create index column", nullptr));
        chbConvertNaNToZero->setText(tr2i18n("Convert NaN to 0", nullptr));
        lDateTimeFormat->setText(tr2i18n("DateTime format:", nullptr));
        lDecimalSeparator->setText(tr2i18n("Decimal separator:", nullptr));
        chbImportObjectNames->setText(tr2i18n("Import object names", nullptr));
        (void)JsonOptionsWidget;
    } // retranslateUi

};

namespace Ui {
    class JsonOptionsWidget: public Ui_JsonOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // JSONOPTIONSWIDGET_H

