/********************************************************************************
** Form generated from reading UI file 'mqttwillsettingswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MQTTWILLSETTINGSWIDGET_H
#define UI_MQTTWILLSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MQTTWillSettingsWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *lWillQoS;
    QListWidget *lwWillStatistics;
    QComboBox *cbWillQoS;
    QLabel *lWillOwnMessage;
    QLabel *lWillMessageType;
    QComboBox *cbWillUpdate;
    QLineEdit *leWillOwnMessage;
    QLabel *lWillUpdateInterval;
    QLineEdit *leWillUpdateInterval;
    QComboBox *cbWillMessageType;
    QCheckBox *chbWillRetain;
    QLabel *lUseRetainMessage;
    QLabel *lWillStatistics;
    QLabel *lWillUpdateType;
    QPushButton *bApply;
    QComboBox *cbWillTopic;
    QLabel *lWillTopic;
    QLabel *lEnabled;
    QCheckBox *chbEnabled;

    void setupUi(QWidget *MQTTWillSettingsWidget)
    {
        if (MQTTWillSettingsWidget->objectName().isEmpty())
            MQTTWillSettingsWidget->setObjectName("MQTTWillSettingsWidget");
        MQTTWillSettingsWidget->resize(424, 600);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MQTTWillSettingsWidget->sizePolicy().hasHeightForWidth());
        MQTTWillSettingsWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(MQTTWillSettingsWidget);
        gridLayout->setObjectName("gridLayout");
        lWillQoS = new QLabel(MQTTWillSettingsWidget);
        lWillQoS->setObjectName("lWillQoS");

        gridLayout->addWidget(lWillQoS, 5, 0, 1, 1);

        lwWillStatistics = new QListWidget(MQTTWillSettingsWidget);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem->setCheckState(Qt::Unchecked);
        __qlistwidgetitem->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem1->setCheckState(Qt::Unchecked);
        __qlistwidgetitem1->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem2->setCheckState(Qt::Unchecked);
        __qlistwidgetitem2->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem3->setCheckState(Qt::Unchecked);
        __qlistwidgetitem3->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem4->setCheckState(Qt::Unchecked);
        __qlistwidgetitem4->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem5 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem5->setCheckState(Qt::Unchecked);
        __qlistwidgetitem5->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem6 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem6->setCheckState(Qt::Unchecked);
        __qlistwidgetitem6->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem7 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem7->setCheckState(Qt::Unchecked);
        __qlistwidgetitem7->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem8 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem8->setCheckState(Qt::Unchecked);
        __qlistwidgetitem8->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem9 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem9->setCheckState(Qt::Unchecked);
        __qlistwidgetitem9->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem10 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem10->setCheckState(Qt::Unchecked);
        __qlistwidgetitem10->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem11 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem11->setCheckState(Qt::Unchecked);
        __qlistwidgetitem11->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem12 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem12->setCheckState(Qt::Unchecked);
        __qlistwidgetitem12->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem13 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem13->setCheckState(Qt::Unchecked);
        __qlistwidgetitem13->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem14 = new QListWidgetItem(lwWillStatistics);
        __qlistwidgetitem14->setCheckState(Qt::Unchecked);
        __qlistwidgetitem14->setFlags(Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        lwWillStatistics->setObjectName("lwWillStatistics");

        gridLayout->addWidget(lwWillStatistics, 3, 1, 1, 1);

        cbWillQoS = new QComboBox(MQTTWillSettingsWidget);
        cbWillQoS->addItem(QString());
        cbWillQoS->addItem(QString());
        cbWillQoS->addItem(QString());
        cbWillQoS->setObjectName("cbWillQoS");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbWillQoS->sizePolicy().hasHeightForWidth());
        cbWillQoS->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbWillQoS, 5, 1, 1, 1);

        lWillOwnMessage = new QLabel(MQTTWillSettingsWidget);
        lWillOwnMessage->setObjectName("lWillOwnMessage");

        gridLayout->addWidget(lWillOwnMessage, 2, 0, 1, 1);

        lWillMessageType = new QLabel(MQTTWillSettingsWidget);
        lWillMessageType->setObjectName("lWillMessageType");

        gridLayout->addWidget(lWillMessageType, 1, 0, 1, 1);

        cbWillUpdate = new QComboBox(MQTTWillSettingsWidget);
        cbWillUpdate->addItem(QString());
        cbWillUpdate->addItem(QString());
        cbWillUpdate->setObjectName("cbWillUpdate");

        gridLayout->addWidget(cbWillUpdate, 7, 1, 1, 1);

        leWillOwnMessage = new QLineEdit(MQTTWillSettingsWidget);
        leWillOwnMessage->setObjectName("leWillOwnMessage");

        gridLayout->addWidget(leWillOwnMessage, 2, 1, 1, 1);

        lWillUpdateInterval = new QLabel(MQTTWillSettingsWidget);
        lWillUpdateInterval->setObjectName("lWillUpdateInterval");

        gridLayout->addWidget(lWillUpdateInterval, 8, 0, 1, 1);

        leWillUpdateInterval = new QLineEdit(MQTTWillSettingsWidget);
        leWillUpdateInterval->setObjectName("leWillUpdateInterval");

        gridLayout->addWidget(leWillUpdateInterval, 8, 1, 1, 1);

        cbWillMessageType = new QComboBox(MQTTWillSettingsWidget);
        cbWillMessageType->addItem(QString());
        cbWillMessageType->addItem(QString());
        cbWillMessageType->addItem(QString());
        cbWillMessageType->setObjectName("cbWillMessageType");
        sizePolicy1.setHeightForWidth(cbWillMessageType->sizePolicy().hasHeightForWidth());
        cbWillMessageType->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbWillMessageType, 1, 1, 1, 1);

        chbWillRetain = new QCheckBox(MQTTWillSettingsWidget);
        chbWillRetain->setObjectName("chbWillRetain");

        gridLayout->addWidget(chbWillRetain, 6, 1, 1, 1);

        lUseRetainMessage = new QLabel(MQTTWillSettingsWidget);
        lUseRetainMessage->setObjectName("lUseRetainMessage");

        gridLayout->addWidget(lUseRetainMessage, 6, 0, 1, 1);

        lWillStatistics = new QLabel(MQTTWillSettingsWidget);
        lWillStatistics->setObjectName("lWillStatistics");

        gridLayout->addWidget(lWillStatistics, 3, 0, 1, 1);

        lWillUpdateType = new QLabel(MQTTWillSettingsWidget);
        lWillUpdateType->setObjectName("lWillUpdateType");

        gridLayout->addWidget(lWillUpdateType, 7, 0, 1, 1);

        bApply = new QPushButton(MQTTWillSettingsWidget);
        bApply->setObjectName("bApply");

        gridLayout->addWidget(bApply, 9, 0, 1, 2);

        cbWillTopic = new QComboBox(MQTTWillSettingsWidget);
        cbWillTopic->setObjectName("cbWillTopic");
        sizePolicy1.setHeightForWidth(cbWillTopic->sizePolicy().hasHeightForWidth());
        cbWillTopic->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbWillTopic, 4, 1, 1, 1);

        lWillTopic = new QLabel(MQTTWillSettingsWidget);
        lWillTopic->setObjectName("lWillTopic");

        gridLayout->addWidget(lWillTopic, 4, 0, 1, 1);

        lEnabled = new QLabel(MQTTWillSettingsWidget);
        lEnabled->setObjectName("lEnabled");

        gridLayout->addWidget(lEnabled, 0, 0, 1, 1);

        chbEnabled = new QCheckBox(MQTTWillSettingsWidget);
        chbEnabled->setObjectName("chbEnabled");

        gridLayout->addWidget(chbEnabled, 0, 1, 1, 1);


        retranslateUi(MQTTWillSettingsWidget);

        QMetaObject::connectSlotsByName(MQTTWillSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *MQTTWillSettingsWidget)
    {
        lWillQoS->setText(tr2i18n("QoS", nullptr));

        const bool __sortingEnabled = lwWillStatistics->isSortingEnabled();
        lwWillStatistics->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = lwWillStatistics->item(0);
        ___qlistwidgetitem->setText(tr2i18n("Minimum", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = lwWillStatistics->item(1);
        ___qlistwidgetitem1->setText(tr2i18n("Maximum", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = lwWillStatistics->item(2);
        ___qlistwidgetitem2->setText(tr2i18n("Arithmetic mean", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = lwWillStatistics->item(3);
        ___qlistwidgetitem3->setText(tr2i18n("Geometric mean", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = lwWillStatistics->item(4);
        ___qlistwidgetitem4->setText(tr2i18n("Harmonic mean", nullptr));
        QListWidgetItem *___qlistwidgetitem5 = lwWillStatistics->item(5);
        ___qlistwidgetitem5->setText(tr2i18n("Contraharmonic mean", nullptr));
        QListWidgetItem *___qlistwidgetitem6 = lwWillStatistics->item(6);
        ___qlistwidgetitem6->setText(tr2i18n("Median", nullptr));
        QListWidgetItem *___qlistwidgetitem7 = lwWillStatistics->item(7);
        ___qlistwidgetitem7->setText(tr2i18n("Variance", nullptr));
        QListWidgetItem *___qlistwidgetitem8 = lwWillStatistics->item(8);
        ___qlistwidgetitem8->setText(tr2i18n("Standard deviation", nullptr));
        QListWidgetItem *___qlistwidgetitem9 = lwWillStatistics->item(9);
        ___qlistwidgetitem9->setText(tr2i18n("Mean deviation", nullptr));
        QListWidgetItem *___qlistwidgetitem10 = lwWillStatistics->item(10);
        ___qlistwidgetitem10->setText(tr2i18n("Mean deviation around median", nullptr));
        QListWidgetItem *___qlistwidgetitem11 = lwWillStatistics->item(11);
        ___qlistwidgetitem11->setText(tr2i18n("Median deviation", nullptr));
        QListWidgetItem *___qlistwidgetitem12 = lwWillStatistics->item(12);
        ___qlistwidgetitem12->setText(tr2i18n("Skewness", nullptr));
        QListWidgetItem *___qlistwidgetitem13 = lwWillStatistics->item(13);
        ___qlistwidgetitem13->setText(tr2i18n("Kurtosis", nullptr));
        QListWidgetItem *___qlistwidgetitem14 = lwWillStatistics->item(14);
        ___qlistwidgetitem14->setText(tr2i18n("Entropy", nullptr));
        lwWillStatistics->setSortingEnabled(__sortingEnabled);

        cbWillQoS->setItemText(0, tr2i18n("0", nullptr));
        cbWillQoS->setItemText(1, tr2i18n("1", nullptr));
        cbWillQoS->setItemText(2, tr2i18n("2", nullptr));

        lWillOwnMessage->setText(tr2i18n("Own message:", nullptr));
        lWillMessageType->setText(tr2i18n("Message type:", nullptr));
        cbWillUpdate->setItemText(0, tr2i18n("Time Interval", nullptr));
        cbWillUpdate->setItemText(1, tr2i18n("On Click", nullptr));

        lWillUpdateInterval->setText(tr2i18n("Time interval:", nullptr));
        leWillUpdateInterval->setText(tr2i18n("10000", nullptr));
        cbWillMessageType->setItemText(0, tr2i18n("Own Message", nullptr));
        cbWillMessageType->setItemText(1, tr2i18n("Statistics", nullptr));
        cbWillMessageType->setItemText(2, tr2i18n("Last Message Received", nullptr));

        chbWillRetain->setText(QString());
        lUseRetainMessage->setText(tr2i18n("Retain:", nullptr));
        lWillStatistics->setText(tr2i18n("Will statistics:", nullptr));
        lWillUpdateType->setText(tr2i18n("Update type:", nullptr));
        bApply->setText(tr2i18n("Apply", nullptr));
        lWillTopic->setText(tr2i18n("Topic:", nullptr));
        lEnabled->setText(tr2i18n("Enabled:", nullptr));
        chbEnabled->setText(QString());
        (void)MQTTWillSettingsWidget;
    } // retranslateUi

};

namespace Ui {
    class MQTTWillSettingsWidget: public Ui_MQTTWillSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MQTTWILLSETTINGSWIDGET_H

