/********************************************************************************
** Form generated from reading UI file 'kdeplotdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KDEPLOTDOCK_H
#define UI_KDEPLOTDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_KDEPlotDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacerGeneral;
    QSpacerItem *horizontalSpacer_5;
    QSpacerItem *verticalSpacer;
    QCheckBox *chkVisible;
    QLabel *lKernelType;
    TimedLineEdit *leName;
    QComboBox *cbPlotRanges;
    QLabel *lBandwidth;
    QLabel *lBandwidthType;
    ResizableTextEdit *teComment;
    QComboBox *cbKernelType;
    NumberSpinBox *sbBandwidth;
    QLabel *lName;
    QLabel *lDataColumn;
    QLabel *lPlotRange;
    QComboBox *cbBandwidthType;
    QLabel *lFuncPic;
    QLabel *lComment;
    QSpacerItem *verticalSpacer_4;
    QCheckBox *chkLegendVisible;
    QWidget *tabKDE;
    QVBoxLayout *verticalLayout_2;
    QLabel *lEstimationLine;
    QSpacerItem *verticalSpacer_6;
    QSpacerItem *verticalSpacer_7;
    QLabel *lEstimationFilling;
    QSpacerItem *verticalSpacer_8;
    QSpacerItem *verticalSpacer_3;
    QWidget *tabMargins;
    QGridLayout *gridLayout_2;
    QLabel *lRug;
    QLabel *lRugEnabled;
    QSpacerItem *horizontalSpacer_6;
    QCheckBox *chkRugEnabled;
    QLabel *lRugLength;
    NumberSpinBox *sbRugLength;
    QLabel *lRugWidth;
    NumberSpinBox *sbRugWidth;
    QLabel *lRugOffset;
    NumberSpinBox *sbRugOffset;
    QSpacerItem *verticalSpacer_13;

    void setupUi(QWidget *KDEPlotDock)
    {
        if (KDEPlotDock->objectName().isEmpty())
            KDEPlotDock->setObjectName("KDEPlotDock");
        KDEPlotDock->resize(350, 691);
        verticalLayout = new QVBoxLayout(KDEPlotDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(KDEPlotDock);
        tabWidget->setObjectName("tabWidget");
        QFont font;
        font.setBold(false);
        tabWidget->setFont(font);
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setObjectName("gridLayout");
        verticalSpacerGeneral = new QSpacerItem(24, 214, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout->addItem(verticalSpacerGeneral, 11, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout->addWidget(chkVisible, 13, 0, 1, 1);

        lKernelType = new QLabel(tabGeneral);
        lKernelType->setObjectName("lKernelType");

        gridLayout->addWidget(lKernelType, 4, 0, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout->addWidget(cbPlotRanges, 9, 2, 1, 1);

        lBandwidth = new QLabel(tabGeneral);
        lBandwidth->setObjectName("lBandwidth");

        gridLayout->addWidget(lBandwidth, 6, 0, 1, 1);

        lBandwidthType = new QLabel(tabGeneral);
        lBandwidthType->setObjectName("lBandwidthType");
        lBandwidthType->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lBandwidthType, 5, 0, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        cbKernelType = new QComboBox(tabGeneral);
        cbKernelType->setObjectName("cbKernelType");

        gridLayout->addWidget(cbKernelType, 4, 2, 1, 1);

        sbBandwidth = new NumberSpinBox(tabGeneral);
        sbBandwidth->setObjectName("sbBandwidth");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(sbBandwidth->sizePolicy().hasHeightForWidth());
        sbBandwidth->setSizePolicy(sizePolicy);
        sbBandwidth->setMinimum(0.000000000000000);
        sbBandwidth->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbBandwidth, 6, 2, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        lDataColumn = new QLabel(tabGeneral);
        lDataColumn->setObjectName("lDataColumn");

        gridLayout->addWidget(lDataColumn, 3, 0, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout->addWidget(lPlotRange, 9, 0, 1, 1);

        cbBandwidthType = new QComboBox(tabGeneral);
        cbBandwidthType->setObjectName("cbBandwidthType");

        gridLayout->addWidget(cbBandwidthType, 5, 2, 1, 1);

        lFuncPic = new QLabel(tabGeneral);
        lFuncPic->setObjectName("lFuncPic");

        gridLayout->addWidget(lFuncPic, 8, 2, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 7, 0, 2, 1);

        chkLegendVisible = new QCheckBox(tabGeneral);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout->addWidget(chkLegendVisible, 12, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabKDE = new QWidget();
        tabKDE->setObjectName("tabKDE");
        verticalLayout_2 = new QVBoxLayout(tabKDE);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(2, 2, 2, 2);
        lEstimationLine = new QLabel(tabKDE);
        lEstimationLine->setObjectName("lEstimationLine");
        QFont font1;
        font1.setBold(true);
        lEstimationLine->setFont(font1);

        verticalLayout_2->addWidget(lEstimationLine);

        verticalSpacer_6 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_6);

        verticalSpacer_7 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_7);

        lEstimationFilling = new QLabel(tabKDE);
        lEstimationFilling->setObjectName("lEstimationFilling");
        lEstimationFilling->setFont(font1);

        verticalLayout_2->addWidget(lEstimationFilling);

        verticalSpacer_8 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_8);

        verticalSpacer_3 = new QSpacerItem(20, 654, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_3);

        tabWidget->addTab(tabKDE, QString());
        tabMargins = new QWidget();
        tabMargins->setObjectName("tabMargins");
        gridLayout_2 = new QGridLayout(tabMargins);
        gridLayout_2->setObjectName("gridLayout_2");
        lRug = new QLabel(tabMargins);
        lRug->setObjectName("lRug");
        lRug->setFont(font1);

        gridLayout_2->addWidget(lRug, 0, 0, 1, 1);

        lRugEnabled = new QLabel(tabMargins);
        lRugEnabled->setObjectName("lRugEnabled");

        gridLayout_2->addWidget(lRugEnabled, 1, 0, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_6, 1, 1, 1, 1);

        chkRugEnabled = new QCheckBox(tabMargins);
        chkRugEnabled->setObjectName("chkRugEnabled");
        sizePolicy.setHeightForWidth(chkRugEnabled->sizePolicy().hasHeightForWidth());
        chkRugEnabled->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(chkRugEnabled, 1, 2, 1, 1);

        lRugLength = new QLabel(tabMargins);
        lRugLength->setObjectName("lRugLength");

        gridLayout_2->addWidget(lRugLength, 2, 0, 1, 1);

        sbRugLength = new NumberSpinBox(tabMargins);
        sbRugLength->setObjectName("sbRugLength");
        sizePolicy.setHeightForWidth(sbRugLength->sizePolicy().hasHeightForWidth());
        sbRugLength->setSizePolicy(sizePolicy);
        sbRugLength->setMinimum(0.000000000000000);
        sbRugLength->setProperty("feedback", QVariant(true));

        gridLayout_2->addWidget(sbRugLength, 2, 2, 1, 1);

        lRugWidth = new QLabel(tabMargins);
        lRugWidth->setObjectName("lRugWidth");

        gridLayout_2->addWidget(lRugWidth, 3, 0, 1, 1);

        sbRugWidth = new NumberSpinBox(tabMargins);
        sbRugWidth->setObjectName("sbRugWidth");
        sizePolicy.setHeightForWidth(sbRugWidth->sizePolicy().hasHeightForWidth());
        sbRugWidth->setSizePolicy(sizePolicy);
        sbRugWidth->setMinimum(0.000000000000000);
        sbRugWidth->setProperty("feedback", QVariant(true));

        gridLayout_2->addWidget(sbRugWidth, 3, 2, 1, 1);

        lRugOffset = new QLabel(tabMargins);
        lRugOffset->setObjectName("lRugOffset");

        gridLayout_2->addWidget(lRugOffset, 4, 0, 1, 1);

        sbRugOffset = new NumberSpinBox(tabMargins);
        sbRugOffset->setObjectName("sbRugOffset");
        sizePolicy.setHeightForWidth(sbRugOffset->sizePolicy().hasHeightForWidth());
        sbRugOffset->setSizePolicy(sizePolicy);
        sbRugOffset->setProperty("feedback", QVariant(true));

        gridLayout_2->addWidget(sbRugOffset, 4, 2, 1, 1);

        verticalSpacer_13 = new QSpacerItem(18, 543, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_13, 5, 0, 1, 1);

        tabWidget->addTab(tabMargins, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbKernelType);
        QWidget::setTabOrder(cbKernelType, cbBandwidthType);
        QWidget::setTabOrder(cbBandwidthType, sbBandwidth);
        QWidget::setTabOrder(sbBandwidth, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);
        QWidget::setTabOrder(chkVisible, chkRugEnabled);
        QWidget::setTabOrder(chkRugEnabled, sbRugLength);
        QWidget::setTabOrder(sbRugLength, sbRugWidth);
        QWidget::setTabOrder(sbRugWidth, sbRugOffset);

        retranslateUi(KDEPlotDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(KDEPlotDock);
    } // setupUi

    void retranslateUi(QWidget *KDEPlotDock)
    {
        KDEPlotDock->setWindowTitle(tr2i18n("Form", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lKernelType->setText(tr2i18n("Kernel:", nullptr));
        lBandwidth->setText(tr2i18n("Value:", nullptr));
        lBandwidthType->setText(tr2i18n("Bandwidth:", nullptr));
#if QT_CONFIG(tooltip)
        sbBandwidth->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        lName->setText(tr2i18n("Name:", nullptr));
        lDataColumn->setText(tr2i18n("Data:", nullptr));
        lPlotRange->setText(tr2i18n("Plot range:", nullptr));
        lFuncPic->setText(QString());
        lComment->setText(tr2i18n("Comment:", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        lEstimationLine->setText(tr2i18n("Line", nullptr));
        lEstimationFilling->setText(tr2i18n("Filling", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabKDE), tr2i18n("Estimation Line", nullptr));
        lRug->setText(tr2i18n("Rug Plot", nullptr));
        lRugEnabled->setText(tr2i18n("Enabled:", nullptr));
        chkRugEnabled->setText(QString());
        lRugLength->setText(tr2i18n("Length:", nullptr));
#if QT_CONFIG(tooltip)
        sbRugLength->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRugLength->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbRugLength->setSuffix(tr2i18n(" pt", nullptr));
        lRugWidth->setText(tr2i18n("Width:", nullptr));
#if QT_CONFIG(tooltip)
        sbRugWidth->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRugWidth->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbRugWidth->setSuffix(tr2i18n(" pt", nullptr));
        lRugOffset->setText(tr2i18n("Offset:", nullptr));
#if QT_CONFIG(tooltip)
        sbRugOffset->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbRugOffset->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbRugOffset->setSuffix(tr2i18n(" pt", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabMargins), tr2i18n("Margins", nullptr));
    } // retranslateUi

};

namespace Ui {
    class KDEPlotDock: public Ui_KDEPlotDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KDEPLOTDOCK_H

