/****************************************************************************
** Meta object code from reading C++ file 'MainWin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/MainWin.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MainWin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7MainWinE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWin::qt_create_metaobjectdata<qt_meta_tag_ZN7MainWinE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWin",
        "initGUI",
        "",
        "customAboutDialog",
        "activateNextDock",
        "activatePreviousDock",
        "dockWidgetRemoved",
        "ads::CDockWidget*",
        "dockFocusChanged",
        "old",
        "now",
        "updateGUI",
        "updateGUIOnProjectChanges",
        "undo",
        "redo",
        "newProject",
        "createInitialContent",
        "openProject",
        "openRecentProject",
        "QUrl",
        "closeProject",
        "saveProject",
        "saveProjectAs",
        "autoSaveProject",
        "updateTitleBar",
        "print",
        "printPreview",
        "historyDialog",
        "importFileDialog",
        "fileName",
        "importKaggleDatasetDialog",
        "importSqlDialog",
        "importProjectDialog",
        "importDatasetDialog",
        "exportDialog",
        "editFitsFileDialog",
        "settingsDialog",
        "projectChanged",
        "colorSchemeChanged",
        "QAction*",
        "openDatasetExample",
        "newNotebook",
        "settingsNotebookDialog",
        "updateNotebookActions",
        "newFolder",
        "newWorkbook",
        "newSpreadsheet",
        "newMatrix",
        "newWorksheet",
        "newNotes",
        "newDatapicker",
        "newLiveDataSource",
        "createContextMenu",
        "QMenu*",
        "createFolderContextMenu",
        "const Folder*",
        "handleAspectAdded",
        "const AbstractAspect*",
        "handleAspectAboutToBeRemoved",
        "handleAspectRemoved",
        "handleCurrentAspectChanged",
        "AbstractAspect*",
        "handleShowSubWindowRequested",
        "handleSettingsChanges",
        "QList<Settings::Type>",
        "setDockVisibility",
        "updateDockWindowVisibility",
        "toggleDockWidget",
        "toggleStatusBar",
        "toggleMenuBar",
        "toggleMemoryInfo",
        "toggleFullScreen",
        "projectExplorerDockVisibilityChanged",
        "propertiesDockVisibilityChanged",
        "worksheetPreviewDockVisibilityChanged",
        "cursorDockVisibilityChanged",
        "propertiesExplorerRequested",
        "focusCursorDock",
        "cartesianPlotMouseModeChanged",
        "CartesianPlot::MouseMode",
        "shareActionFinished",
        "QJsonObject",
        "output",
        "error",
        "message"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'initGUI'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'customAboutDialog'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'activateNextDock'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'activatePreviousDock'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'dockWidgetRemoved'
        QtMocHelpers::SlotData<void(ads::CDockWidget *)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'dockFocusChanged'
        QtMocHelpers::SlotData<void(ads::CDockWidget *, ads::CDockWidget *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 9 }, { 0x80000000 | 7, 10 },
        }}),
        // Slot 'updateGUI'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateGUIOnProjectChanges'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'undo'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'redo'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newProject'
        QtMocHelpers::SlotData<bool(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'newProject'
        QtMocHelpers::SlotData<bool()>(15, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'openProject'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openProject'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'openRecentProject'
        QtMocHelpers::SlotData<void(const QUrl &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Slot 'closeProject'
        QtMocHelpers::SlotData<bool()>(20, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'saveProject'
        QtMocHelpers::SlotData<bool()>(21, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'saveProjectAs'
        QtMocHelpers::SlotData<bool()>(22, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'autoSaveProject'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateTitleBar'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'print'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'printPreview'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'historyDialog'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importFileDialog'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'importFileDialog'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'importKaggleDatasetDialog'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importSqlDialog'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importProjectDialog'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importDatasetDialog'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'exportDialog'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editFitsFileDialog'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'settingsDialog'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'projectChanged'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'colorSchemeChanged'
        QtMocHelpers::SlotData<void(QAction *)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 2 },
        }}),
        // Slot 'openDatasetExample'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newNotebook'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'settingsNotebookDialog'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateNotebookActions'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newFolder'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newWorkbook'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newSpreadsheet'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newMatrix'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newWorksheet'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newNotes'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newDatapicker'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newLiveDataSource'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createContextMenu'
        QtMocHelpers::SlotData<void(QMenu *) const>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 53, 2 },
        }}),
        // Slot 'createFolderContextMenu'
        QtMocHelpers::SlotData<void(const Folder *, QMenu *) const>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 55, 2 }, { 0x80000000 | 53, 2 },
        }}),
        // Slot 'handleAspectAdded'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 2 },
        }}),
        // Slot 'handleAspectAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 2 },
        }}),
        // Slot 'handleAspectRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *, const AbstractAspect *, const AbstractAspect *)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 2 }, { 0x80000000 | 57, 2 }, { 0x80000000 | 57, 2 },
        }}),
        // Slot 'handleCurrentAspectChanged'
        QtMocHelpers::SlotData<void(AbstractAspect *)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 61, 2 },
        }}),
        // Slot 'handleShowSubWindowRequested'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleSettingsChanges'
        QtMocHelpers::SlotData<void(QList<Settings::Type>)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 64, 2 },
        }}),
        // Slot 'setDockVisibility'
        QtMocHelpers::SlotData<void(QAction *)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 2 },
        }}),
        // Slot 'updateDockWindowVisibility'
        QtMocHelpers::SlotData<void() const>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleDockWidget'
        QtMocHelpers::SlotData<void(QAction *)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 2 },
        }}),
        // Slot 'toggleStatusBar'
        QtMocHelpers::SlotData<void(bool)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleMenuBar'
        QtMocHelpers::SlotData<void(bool)>(69, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleMemoryInfo'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleFullScreen'
        QtMocHelpers::SlotData<void(bool)>(71, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'projectExplorerDockVisibilityChanged'
        QtMocHelpers::SlotData<void(bool)>(72, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'propertiesDockVisibilityChanged'
        QtMocHelpers::SlotData<void(bool)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'worksheetPreviewDockVisibilityChanged'
        QtMocHelpers::SlotData<void(bool)>(74, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'cursorDockVisibilityChanged'
        QtMocHelpers::SlotData<void(bool)>(75, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'propertiesExplorerRequested'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'focusCursorDock'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cartesianPlotMouseModeChanged'
        QtMocHelpers::SlotData<void(CartesianPlot::MouseMode)>(78, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 79, 2 },
        }}),
        // Slot 'shareActionFinished'
        QtMocHelpers::SlotData<void(const QJsonObject &, int, const QString &)>(80, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 81, 82 }, { QMetaType::Int, 83 }, { QMetaType::QString, 84 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWin, qt_meta_tag_ZN7MainWinE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWin::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7MainWinE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7MainWinE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7MainWinE_t>.metaTypes,
    nullptr
} };

void MainWin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->initGUI((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->customAboutDialog(); break;
        case 2: _t->activateNextDock(); break;
        case 3: _t->activatePreviousDock(); break;
        case 4: _t->dockWidgetRemoved((*reinterpret_cast<std::add_pointer_t<ads::CDockWidget*>>(_a[1]))); break;
        case 5: _t->dockFocusChanged((*reinterpret_cast<std::add_pointer_t<ads::CDockWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ads::CDockWidget*>>(_a[2]))); break;
        case 6: _t->updateGUI(); break;
        case 7: _t->updateGUIOnProjectChanges(); break;
        case 8: _t->undo(); break;
        case 9: _t->redo(); break;
        case 10: { bool _r = _t->newProject((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->newProject();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->openProject(); break;
        case 13: _t->openProject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->openRecentProject((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 15: { bool _r = _t->closeProject();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->saveProject();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->saveProjectAs();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->autoSaveProject(); break;
        case 19: _t->updateTitleBar(); break;
        case 20: _t->print(); break;
        case 21: _t->printPreview(); break;
        case 22: _t->historyDialog(); break;
        case 23: _t->importFileDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->importFileDialog(); break;
        case 25: _t->importKaggleDatasetDialog(); break;
        case 26: _t->importSqlDialog(); break;
        case 27: _t->importProjectDialog(); break;
        case 28: _t->importDatasetDialog(); break;
        case 29: _t->exportDialog(); break;
        case 30: _t->editFitsFileDialog(); break;
        case 31: _t->settingsDialog(); break;
        case 32: _t->projectChanged(); break;
        case 33: _t->colorSchemeChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 34: _t->openDatasetExample(); break;
        case 35: _t->newNotebook(); break;
        case 36: _t->settingsNotebookDialog(); break;
        case 37: _t->updateNotebookActions(); break;
        case 38: _t->newFolder(); break;
        case 39: _t->newWorkbook(); break;
        case 40: _t->newSpreadsheet(); break;
        case 41: _t->newMatrix(); break;
        case 42: _t->newWorksheet(); break;
        case 43: _t->newNotes(); break;
        case 44: _t->newDatapicker(); break;
        case 45: _t->newLiveDataSource(); break;
        case 46: _t->createContextMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 47: _t->createFolderContextMenu((*reinterpret_cast<std::add_pointer_t<const Folder*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2]))); break;
        case 48: _t->handleAspectAdded((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 49: _t->handleAspectAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 50: _t->handleAspectRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[3]))); break;
        case 51: _t->handleCurrentAspectChanged((*reinterpret_cast<std::add_pointer_t<AbstractAspect*>>(_a[1]))); break;
        case 52: _t->handleShowSubWindowRequested(); break;
        case 53: _t->handleSettingsChanges((*reinterpret_cast<std::add_pointer_t<QList<Settings::Type>>>(_a[1]))); break;
        case 54: _t->setDockVisibility((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 55: _t->updateDockWindowVisibility(); break;
        case 56: _t->toggleDockWidget((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 57: _t->toggleStatusBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 58: _t->toggleMenuBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 59: _t->toggleMemoryInfo(); break;
        case 60: _t->toggleFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 61: _t->projectExplorerDockVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 62: _t->propertiesDockVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 63: _t->worksheetPreviewDockVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 64: _t->cursorDockVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 65: _t->propertiesExplorerRequested(); break;
        case 66: _t->focusCursorDock(); break;
        case 67: _t->cartesianPlotMouseModeChanged((*reinterpret_cast<std::add_pointer_t<CartesianPlot::MouseMode>>(_a[1]))); break;
        case 68: _t->shareActionFinished((*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 51:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAspect* >(); break;
            }
            break;
        case 54:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 56:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *MainWin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7MainWinE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int MainWin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 69)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 69;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 69)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 69;
    }
    return _id;
}
QT_WARNING_POP
