/********************************************************************************
** Form generated from reading UI file 'backgroundwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BACKGROUNDWIDGET_H
#define UI_BACKGROUNDWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_BackgroundWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *lPosition;
    QLabel *lEnabled;
    QCheckBox *chkEnabled;
    QLabel *lType;
    QSpacerItem *horizontalSpacer_6;
    KComboBox *cbType;
    QLabel *lFileName;
    QLineEdit *leFileName;
    QPushButton *bOpen;
    QLabel *lColorStyle;
    KComboBox *cbColorStyle;
    QLabel *lImageStyle;
    KComboBox *cbImageStyle;
    QLabel *lBrushStyle;
    KComboBox *cbBrushStyle;
    QLabel *lFirstColor;
    KColorButton *kcbFirstColor;
    KColorButton *kcbSecondColor;
    QLabel *lOpacity;
    QSpinBox *sbOpacity;
    KComboBox *cbPosition;
    QLabel *lSecondColor;

    void setupUi(QWidget *BackgroundWidget)
    {
        if (BackgroundWidget->objectName().isEmpty())
            BackgroundWidget->setObjectName("BackgroundWidget");
        BackgroundWidget->resize(300, 374);
        gridLayout = new QGridLayout(BackgroundWidget);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        lPosition = new QLabel(BackgroundWidget);
        lPosition->setObjectName("lPosition");

        gridLayout->addWidget(lPosition, 0, 0, 1, 1);

        lEnabled = new QLabel(BackgroundWidget);
        lEnabled->setObjectName("lEnabled");

        gridLayout->addWidget(lEnabled, 1, 0, 1, 1);

        chkEnabled = new QCheckBox(BackgroundWidget);
        chkEnabled->setObjectName("chkEnabled");

        gridLayout->addWidget(chkEnabled, 1, 2, 1, 1);

        lType = new QLabel(BackgroundWidget);
        lType->setObjectName("lType");
        lType->setFrameShape(QFrame::NoFrame);

        gridLayout->addWidget(lType, 2, 0, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_6, 2, 1, 1, 1);

        cbType = new KComboBox(BackgroundWidget);
        cbType->setObjectName("cbType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbType->sizePolicy().hasHeightForWidth());
        cbType->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbType, 2, 2, 1, 1);

        lFileName = new QLabel(BackgroundWidget);
        lFileName->setObjectName("lFileName");

        gridLayout->addWidget(lFileName, 3, 0, 1, 1);

        leFileName = new QLineEdit(BackgroundWidget);
        leFileName->setObjectName("leFileName");
        leFileName->setClearButtonEnabled(true);

        gridLayout->addWidget(leFileName, 3, 2, 1, 1);

        bOpen = new QPushButton(BackgroundWidget);
        bOpen->setObjectName("bOpen");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(bOpen->sizePolicy().hasHeightForWidth());
        bOpen->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(bOpen, 3, 3, 1, 1);

        lColorStyle = new QLabel(BackgroundWidget);
        lColorStyle->setObjectName("lColorStyle");

        gridLayout->addWidget(lColorStyle, 4, 0, 1, 1);

        cbColorStyle = new KComboBox(BackgroundWidget);
        cbColorStyle->setObjectName("cbColorStyle");

        gridLayout->addWidget(cbColorStyle, 4, 2, 1, 1);

        lImageStyle = new QLabel(BackgroundWidget);
        lImageStyle->setObjectName("lImageStyle");

        gridLayout->addWidget(lImageStyle, 5, 0, 1, 1);

        cbImageStyle = new KComboBox(BackgroundWidget);
        cbImageStyle->setObjectName("cbImageStyle");

        gridLayout->addWidget(cbImageStyle, 5, 2, 1, 1);

        lBrushStyle = new QLabel(BackgroundWidget);
        lBrushStyle->setObjectName("lBrushStyle");

        gridLayout->addWidget(lBrushStyle, 6, 0, 1, 1);

        cbBrushStyle = new KComboBox(BackgroundWidget);
        cbBrushStyle->setObjectName("cbBrushStyle");

        gridLayout->addWidget(cbBrushStyle, 6, 2, 1, 1);

        lFirstColor = new QLabel(BackgroundWidget);
        lFirstColor->setObjectName("lFirstColor");

        gridLayout->addWidget(lFirstColor, 7, 0, 1, 1);

        kcbFirstColor = new KColorButton(BackgroundWidget);
        kcbFirstColor->setObjectName("kcbFirstColor");

        gridLayout->addWidget(kcbFirstColor, 7, 2, 1, 1);

        kcbSecondColor = new KColorButton(BackgroundWidget);
        kcbSecondColor->setObjectName("kcbSecondColor");

        gridLayout->addWidget(kcbSecondColor, 8, 2, 1, 1);

        lOpacity = new QLabel(BackgroundWidget);
        lOpacity->setObjectName("lOpacity");

        gridLayout->addWidget(lOpacity, 9, 0, 1, 1);

        sbOpacity = new QSpinBox(BackgroundWidget);
        sbOpacity->setObjectName("sbOpacity");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(sbOpacity->sizePolicy().hasHeightForWidth());
        sbOpacity->setSizePolicy(sizePolicy2);
        sbOpacity->setMinimum(0);
        sbOpacity->setMaximum(100);
        sbOpacity->setSingleStep(10);
        sbOpacity->setValue(100);

        gridLayout->addWidget(sbOpacity, 9, 2, 1, 1);

        cbPosition = new KComboBox(BackgroundWidget);
        cbPosition->setObjectName("cbPosition");
        sizePolicy.setHeightForWidth(cbPosition->sizePolicy().hasHeightForWidth());
        cbPosition->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbPosition, 0, 2, 1, 1);

        lSecondColor = new QLabel(BackgroundWidget);
        lSecondColor->setObjectName("lSecondColor");

        gridLayout->addWidget(lSecondColor, 8, 0, 1, 1);

        QWidget::setTabOrder(cbPosition, chkEnabled);
        QWidget::setTabOrder(chkEnabled, cbType);
        QWidget::setTabOrder(cbType, leFileName);
        QWidget::setTabOrder(leFileName, bOpen);
        QWidget::setTabOrder(bOpen, cbColorStyle);
        QWidget::setTabOrder(cbColorStyle, cbImageStyle);
        QWidget::setTabOrder(cbImageStyle, cbBrushStyle);
        QWidget::setTabOrder(cbBrushStyle, kcbFirstColor);
        QWidget::setTabOrder(kcbFirstColor, kcbSecondColor);
        QWidget::setTabOrder(kcbSecondColor, sbOpacity);

        retranslateUi(BackgroundWidget);

        QMetaObject::connectSlotsByName(BackgroundWidget);
    } // setupUi

    void retranslateUi(QWidget *BackgroundWidget)
    {
        BackgroundWidget->setWindowTitle(tr2i18n("Form", nullptr));
        lPosition->setText(tr2i18n("Direction:", nullptr));
        lEnabled->setText(tr2i18n("Enabled:", nullptr));
        chkEnabled->setText(QString());
        lType->setText(tr2i18n("Type:", nullptr));
        lFileName->setText(tr2i18n("File name:", nullptr));
#if QT_CONFIG(tooltip)
        leFileName->setToolTip(tr2i18n("Specify the name of the image file.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        bOpen->setToolTip(tr2i18n(" Select the file to import", nullptr));
#endif // QT_CONFIG(tooltip)
        bOpen->setText(QString());
        lColorStyle->setText(tr2i18n("Style:", nullptr));
        lImageStyle->setText(tr2i18n("Style:", nullptr));
        lBrushStyle->setText(tr2i18n("Style:", nullptr));
        lFirstColor->setText(tr2i18n("First color:", nullptr));
        lOpacity->setText(tr2i18n("Opacity:", nullptr));
#if QT_CONFIG(tooltip)
        sbOpacity->setToolTip(tr2i18n("The opacity ranges from 0 to 100, where 0 is fully transparent and 100 is fully opaque.", nullptr));
#endif // QT_CONFIG(tooltip)
        sbOpacity->setSuffix(tr2i18n(" %", nullptr));
        lSecondColor->setText(tr2i18n("Second color:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BackgroundWidget: public Ui_BackgroundWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BACKGROUNDWIDGET_H

