/****************************************************************************
** Meta object code from reading C++ file 'Matrix.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/matrix/Matrix.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Matrix.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6MatrixE_t {};
} // unnamed namespace

template <> constexpr inline auto Matrix::qt_create_metaobjectdata<qt_meta_tag_ZN6MatrixE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Matrix",
        "requestProjectContextMenu",
        "",
        "QMenu*",
        "columnsAboutToBeInserted",
        "before",
        "count",
        "columnsInserted",
        "first",
        "columnsAboutToBeRemoved",
        "columnsRemoved",
        "rowsAboutToBeInserted",
        "rowsInserted",
        "rowsAboutToBeRemoved",
        "rowsRemoved",
        "dataChanged",
        "top",
        "left",
        "bottom",
        "right",
        "coordinatesChanged",
        "rowCountChanged",
        "columnCountChanged",
        "xStartChanged",
        "xEndChanged",
        "yStartChanged",
        "yEndChanged",
        "numericFormatChanged",
        "precisionChanged",
        "headerFormatChanged",
        "Matrix::HeaderFormat",
        "clear",
        "transpose",
        "mirrorVertically",
        "mirrorHorizontally",
        "addColumns",
        "addRows",
        "HeaderFormat",
        "HeaderRowsColumns",
        "HeaderValues",
        "HeaderRowsColumnsValues"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestProjectContextMenu'
        QtMocHelpers::SignalData<void(QMenu *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'columnsAboutToBeInserted'
        QtMocHelpers::SignalData<void(int, int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'columnsInserted'
        QtMocHelpers::SignalData<void(int, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'columnsAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'columnsRemoved'
        QtMocHelpers::SignalData<void(int, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'rowsAboutToBeInserted'
        QtMocHelpers::SignalData<void(int, int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'rowsInserted'
        QtMocHelpers::SignalData<void(int, int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'rowsAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'rowsRemoved'
        QtMocHelpers::SignalData<void(int, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void(int, int, int, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 19 },
        }}),
        // Signal 'coordinatesChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rowCountChanged'
        QtMocHelpers::SignalData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'columnCountChanged'
        QtMocHelpers::SignalData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'xStartChanged'
        QtMocHelpers::SignalData<void(double)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'xEndChanged'
        QtMocHelpers::SignalData<void(double)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'yStartChanged'
        QtMocHelpers::SignalData<void(double)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'yEndChanged'
        QtMocHelpers::SignalData<void(double)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'numericFormatChanged'
        QtMocHelpers::SignalData<void(char)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Char, 2 },
        }}),
        // Signal 'precisionChanged'
        QtMocHelpers::SignalData<void(int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'headerFormatChanged'
        QtMocHelpers::SignalData<void(Matrix::HeaderFormat)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 2 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'transpose'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mirrorVertically'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mirrorHorizontally'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addColumns'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addRows'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'HeaderFormat'
        QtMocHelpers::EnumData<enum HeaderFormat>(37, 37, QMC::EnumIsScoped).add({
            {   38, HeaderFormat::HeaderRowsColumns },
            {   39, HeaderFormat::HeaderValues },
            {   40, HeaderFormat::HeaderRowsColumnsValues },
        }),
    };
    return QtMocHelpers::metaObjectData<Matrix, qt_meta_tag_ZN6MatrixE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Matrix::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6MatrixE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6MatrixE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6MatrixE_t>.metaTypes,
    nullptr
} };

void Matrix::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Matrix *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestProjectContextMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 1: _t->columnsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->columnsInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->columnsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->columnsRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->rowsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->rowsInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->rowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->rowsRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->dataChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 10: _t->coordinatesChanged(); break;
        case 11: _t->rowCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->columnCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->xStartChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 14: _t->xEndChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: _t->yStartChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 16: _t->yEndChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: _t->numericFormatChanged((*reinterpret_cast<std::add_pointer_t<char>>(_a[1]))); break;
        case 18: _t->precisionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->headerFormatChanged((*reinterpret_cast<std::add_pointer_t<Matrix::HeaderFormat>>(_a[1]))); break;
        case 20: _t->clear(); break;
        case 21: _t->transpose(); break;
        case 22: _t->mirrorVertically(); break;
        case 23: _t->mirrorHorizontally(); break;
        case 24: _t->addColumns(); break;
        case 25: _t->addRows(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(QMenu * )>(_a, &Matrix::requestProjectContextMenu, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(int , int )>(_a, &Matrix::columnsAboutToBeInserted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(int , int )>(_a, &Matrix::columnsInserted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(int , int )>(_a, &Matrix::columnsAboutToBeRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(int , int )>(_a, &Matrix::columnsRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(int , int )>(_a, &Matrix::rowsAboutToBeInserted, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(int , int )>(_a, &Matrix::rowsInserted, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(int , int )>(_a, &Matrix::rowsAboutToBeRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(int , int )>(_a, &Matrix::rowsRemoved, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(int , int , int , int )>(_a, &Matrix::dataChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)()>(_a, &Matrix::coordinatesChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(int )>(_a, &Matrix::rowCountChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(int )>(_a, &Matrix::columnCountChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(double )>(_a, &Matrix::xStartChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(double )>(_a, &Matrix::xEndChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(double )>(_a, &Matrix::yStartChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(double )>(_a, &Matrix::yEndChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(char )>(_a, &Matrix::numericFormatChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(int )>(_a, &Matrix::precisionChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Matrix::*)(Matrix::HeaderFormat )>(_a, &Matrix::headerFormatChanged, 19))
            return;
    }
}

const QMetaObject *Matrix::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Matrix::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6MatrixE_t>.strings))
        return static_cast<void*>(this);
    return AbstractDataSource::qt_metacast(_clname);
}

int Matrix::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractDataSource::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void Matrix::requestProjectContextMenu(QMenu * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Matrix::columnsAboutToBeInserted(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Matrix::columnsInserted(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Matrix::columnsAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Matrix::columnsRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Matrix::rowsAboutToBeInserted(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Matrix::rowsInserted(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void Matrix::rowsAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Matrix::rowsRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void Matrix::dataChanged(int _t1, int _t2, int _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 10
void Matrix::coordinatesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Matrix::rowCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Matrix::columnCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Matrix::xStartChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Matrix::xEndChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Matrix::yStartChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Matrix::yEndChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Matrix::numericFormatChanged(char _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Matrix::precisionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Matrix::headerFormatChanged(Matrix::HeaderFormat _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}
QT_WARNING_POP
