/****************************************************************************
** Meta object code from reading C++ file 'DatapickerCurve.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/datapicker/DatapickerCurve.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DatapickerCurve.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15DatapickerCurveE_t {};
} // unnamed namespace

template <> constexpr inline auto DatapickerCurve::qt_create_metaobjectdata<qt_meta_tag_ZN15DatapickerCurveE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DatapickerCurve",
        "curveErrorTypesChanged",
        "",
        "DatapickerCurve::Errors",
        "posXColumnChanged",
        "const AbstractColumn*",
        "posYColumnChanged",
        "posZColumnChanged",
        "plusDeltaXColumnChanged",
        "minusDeltaXColumnChanged",
        "plusDeltaYColumnChanged",
        "minusDeltaYColumnChanged",
        "pointStyleChanged",
        "Symbol::Style",
        "pointSizeChanged",
        "pointRotationAngleChanged",
        "pointOpacityChanged",
        "pointBrushChanged",
        "QBrush",
        "pointPenChanged",
        "QPen",
        "pointErrorBarSizeChanged",
        "pointErrorBarBrushChanged",
        "pointErrorBarPenChanged",
        "pointVisibilityChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'curveErrorTypesChanged'
        QtMocHelpers::SignalData<void(const DatapickerCurve::Errors &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'posXColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'posYColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'posZColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'plusDeltaXColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'minusDeltaXColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'plusDeltaYColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'minusDeltaYColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'pointStyleChanged'
        QtMocHelpers::SignalData<void(Symbol::Style)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Signal 'pointSizeChanged'
        QtMocHelpers::SignalData<void(qreal)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'pointRotationAngleChanged'
        QtMocHelpers::SignalData<void(qreal)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'pointOpacityChanged'
        QtMocHelpers::SignalData<void(qreal)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'pointBrushChanged'
        QtMocHelpers::SignalData<void(QBrush)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Signal 'pointPenChanged'
        QtMocHelpers::SignalData<void(const QPen &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 2 },
        }}),
        // Signal 'pointErrorBarSizeChanged'
        QtMocHelpers::SignalData<void(qreal)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'pointErrorBarBrushChanged'
        QtMocHelpers::SignalData<void(QBrush)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Signal 'pointErrorBarPenChanged'
        QtMocHelpers::SignalData<void(const QPen &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 2 },
        }}),
        // Signal 'pointVisibilityChanged'
        QtMocHelpers::SignalData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DatapickerCurve, qt_meta_tag_ZN15DatapickerCurveE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DatapickerCurve::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractAspect::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DatapickerCurveE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DatapickerCurveE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DatapickerCurveE_t>.metaTypes,
    nullptr
} };

void DatapickerCurve::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DatapickerCurve *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->curveErrorTypesChanged((*reinterpret_cast<std::add_pointer_t<DatapickerCurve::Errors>>(_a[1]))); break;
        case 1: _t->posXColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 2: _t->posYColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 3: _t->posZColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 4: _t->plusDeltaXColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 5: _t->minusDeltaXColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 6: _t->plusDeltaYColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 7: _t->minusDeltaYColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 8: _t->pointStyleChanged((*reinterpret_cast<std::add_pointer_t<Symbol::Style>>(_a[1]))); break;
        case 9: _t->pointSizeChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 10: _t->pointRotationAngleChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 11: _t->pointOpacityChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 12: _t->pointBrushChanged((*reinterpret_cast<std::add_pointer_t<QBrush>>(_a[1]))); break;
        case 13: _t->pointPenChanged((*reinterpret_cast<std::add_pointer_t<QPen>>(_a[1]))); break;
        case 14: _t->pointErrorBarSizeChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 15: _t->pointErrorBarBrushChanged((*reinterpret_cast<std::add_pointer_t<QBrush>>(_a[1]))); break;
        case 16: _t->pointErrorBarPenChanged((*reinterpret_cast<std::add_pointer_t<QPen>>(_a[1]))); break;
        case 17: _t->pointVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(const DatapickerCurve::Errors & )>(_a, &DatapickerCurve::curveErrorTypesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(const AbstractColumn * )>(_a, &DatapickerCurve::posXColumnChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(const AbstractColumn * )>(_a, &DatapickerCurve::posYColumnChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(const AbstractColumn * )>(_a, &DatapickerCurve::posZColumnChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(const AbstractColumn * )>(_a, &DatapickerCurve::plusDeltaXColumnChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(const AbstractColumn * )>(_a, &DatapickerCurve::minusDeltaXColumnChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(const AbstractColumn * )>(_a, &DatapickerCurve::plusDeltaYColumnChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(const AbstractColumn * )>(_a, &DatapickerCurve::minusDeltaYColumnChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(Symbol::Style )>(_a, &DatapickerCurve::pointStyleChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(qreal )>(_a, &DatapickerCurve::pointSizeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(qreal )>(_a, &DatapickerCurve::pointRotationAngleChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(qreal )>(_a, &DatapickerCurve::pointOpacityChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(QBrush )>(_a, &DatapickerCurve::pointBrushChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(const QPen & )>(_a, &DatapickerCurve::pointPenChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(qreal )>(_a, &DatapickerCurve::pointErrorBarSizeChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(QBrush )>(_a, &DatapickerCurve::pointErrorBarBrushChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(const QPen & )>(_a, &DatapickerCurve::pointErrorBarPenChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatapickerCurve::*)(bool )>(_a, &DatapickerCurve::pointVisibilityChanged, 17))
            return;
    }
}

const QMetaObject *DatapickerCurve::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DatapickerCurve::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DatapickerCurveE_t>.strings))
        return static_cast<void*>(this);
    return AbstractAspect::qt_metacast(_clname);
}

int DatapickerCurve::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractAspect::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void DatapickerCurve::curveErrorTypesChanged(const DatapickerCurve::Errors & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DatapickerCurve::posXColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DatapickerCurve::posYColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DatapickerCurve::posZColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DatapickerCurve::plusDeltaXColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DatapickerCurve::minusDeltaXColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DatapickerCurve::plusDeltaYColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DatapickerCurve::minusDeltaYColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DatapickerCurve::pointStyleChanged(Symbol::Style _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DatapickerCurve::pointSizeChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DatapickerCurve::pointRotationAngleChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DatapickerCurve::pointOpacityChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DatapickerCurve::pointBrushChanged(QBrush _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DatapickerCurve::pointPenChanged(const QPen & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void DatapickerCurve::pointErrorBarSizeChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DatapickerCurve::pointErrorBarBrushChanged(QBrush _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DatapickerCurve::pointErrorBarPenChanged(const QPen & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void DatapickerCurve::pointVisibilityChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}
QT_WARNING_POP
