/****************************************************************************
** Meta object code from reading C++ file 'XYCorrelationCurveDock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/dockwidgets/XYCorrelationCurveDock.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'XYCorrelationCurveDock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22XYCorrelationCurveDockE_t {};
} // unnamed namespace

template <> constexpr inline auto XYCorrelationCurveDock::qt_create_metaobjectdata<qt_meta_tag_ZN22XYCorrelationCurveDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XYCorrelationCurveDock",
        "dataSourceTypeChanged",
        "",
        "xDataColumnChanged",
        "QModelIndex",
        "samplingIntervalChanged",
        "autoRangeChanged",
        "xRangeMinChanged",
        "xRangeMaxChanged",
        "typeChanged",
        "normChanged",
        "recalculateClicked",
        "curveXDataColumnChanged",
        "const AbstractColumn*",
        "curveY2DataColumnChanged",
        "curveCorrelationDataChanged",
        "XYCorrelationCurve::CorrelationData"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'dataSourceTypeChanged'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'xDataColumnChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'samplingIntervalChanged'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'autoRangeChanged'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'xRangeMinChanged'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'xRangeMaxChanged'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'typeChanged'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'normChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'recalculateClicked'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'curveXDataColumnChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'curveY2DataColumnChanged'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'curveCorrelationDataChanged'
        QtMocHelpers::SlotData<void(const XYCorrelationCurve::CorrelationData &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XYCorrelationCurveDock, qt_meta_tag_ZN22XYCorrelationCurveDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XYCorrelationCurveDock::staticMetaObject = { {
    QMetaObject::SuperData::link<XYAnalysisCurveDock::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22XYCorrelationCurveDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22XYCorrelationCurveDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22XYCorrelationCurveDockE_t>.metaTypes,
    nullptr
} };

void XYCorrelationCurveDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XYCorrelationCurveDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataSourceTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->xDataColumnChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 2: _t->samplingIntervalChanged(); break;
        case 3: _t->autoRangeChanged(); break;
        case 4: _t->xRangeMinChanged(); break;
        case 5: _t->xRangeMaxChanged(); break;
        case 6: _t->typeChanged(); break;
        case 7: _t->normChanged(); break;
        case 8: _t->recalculateClicked(); break;
        case 9: _t->curveXDataColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 10: _t->curveY2DataColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 11: _t->curveCorrelationDataChanged((*reinterpret_cast<std::add_pointer_t<XYCorrelationCurve::CorrelationData>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *XYCorrelationCurveDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XYCorrelationCurveDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22XYCorrelationCurveDockE_t>.strings))
        return static_cast<void*>(this);
    return XYAnalysisCurveDock::qt_metacast(_clname);
}

int XYCorrelationCurveDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XYAnalysisCurveDock::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
