/********************************************************************************
** Form generated from reading UI file 'datasetmetadatamanagerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DATASETMETADATAMANAGERWIDGET_H
#define UI_DATASETMETADATAMANAGERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_DatasetMetadataManagerWidget
{
public:
    QGridLayout *gridLayout;
    QComboBox *cbSubcategory;
    QLabel *lCategory;
    QTextEdit *teDescription;
    QGroupBox *gbColumnDescriptions;
    QGridLayout *columnLayout;
    QPushButton *bDelete;
    QPushButton *bNewColumn;
    QSpacerItem *horizontalSpacer;
    QLineEdit *leDatasetName;
    QGroupBox *gbFilter;
    QGridLayout *gridLayout_2;
    QLabel *lComment;
    QLabel *lSeparatingCharacter;
    QLabel *lNumberFormat;
    QLabel *lDateTimeFormat;
    QCheckBox *chbHeader;
    QCheckBox *chbCreateIndex;
    QCheckBox *chbSimplifyWhitespaces;
    QCheckBox *chbSkipEmptyParts;
    QCheckBox *chbRemoveQuotes;
    KComboBox *cbCommentCharacter;
    KComboBox *cbSeparatingCharacter;
    QComboBox *cbNumberFormat;
    KComboBox *cbDateTimeFormat;
    QLineEdit *leFileName;
    QLabel *lFileName;
    QLineEdit *leDownloadURL;
    QLabel *lDownloadUrl;
    QLabel *lDescription;
    QLabel *lSubcategory;
    QComboBox *cbCategory;
    QLabel *lDatasetName;
    QLabel *lCollection;
    QComboBox *cbCollection;

    void setupUi(QWidget *DatasetMetadataManagerWidget)
    {
        if (DatasetMetadataManagerWidget->objectName().isEmpty())
            DatasetMetadataManagerWidget->setObjectName("DatasetMetadataManagerWidget");
        DatasetMetadataManagerWidget->resize(457, 575);
        gridLayout = new QGridLayout(DatasetMetadataManagerWidget);
        gridLayout->setObjectName("gridLayout");
        cbSubcategory = new QComboBox(DatasetMetadataManagerWidget);
        cbSubcategory->setObjectName("cbSubcategory");
        cbSubcategory->setEditable(true);

        gridLayout->addWidget(cbSubcategory, 2, 1, 1, 1);

        lCategory = new QLabel(DatasetMetadataManagerWidget);
        lCategory->setObjectName("lCategory");

        gridLayout->addWidget(lCategory, 1, 0, 1, 1);

        teDescription = new QTextEdit(DatasetMetadataManagerWidget);
        teDescription->setObjectName("teDescription");

        gridLayout->addWidget(teDescription, 6, 1, 1, 1);

        gbColumnDescriptions = new QGroupBox(DatasetMetadataManagerWidget);
        gbColumnDescriptions->setObjectName("gbColumnDescriptions");
        columnLayout = new QGridLayout(gbColumnDescriptions);
        columnLayout->setObjectName("columnLayout");
        bDelete = new QPushButton(gbColumnDescriptions);
        bDelete->setObjectName("bDelete");

        columnLayout->addWidget(bDelete, 0, 1, 1, 1);

        bNewColumn = new QPushButton(gbColumnDescriptions);
        bNewColumn->setObjectName("bNewColumn");

        columnLayout->addWidget(bNewColumn, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        columnLayout->addItem(horizontalSpacer, 0, 2, 1, 1);


        gridLayout->addWidget(gbColumnDescriptions, 7, 0, 1, 2);

        leDatasetName = new QLineEdit(DatasetMetadataManagerWidget);
        leDatasetName->setObjectName("leDatasetName");

        gridLayout->addWidget(leDatasetName, 4, 1, 1, 1);

        gbFilter = new QGroupBox(DatasetMetadataManagerWidget);
        gbFilter->setObjectName("gbFilter");
        gridLayout_2 = new QGridLayout(gbFilter);
        gridLayout_2->setObjectName("gridLayout_2");
        lComment = new QLabel(gbFilter);
        lComment->setObjectName("lComment");

        gridLayout_2->addWidget(lComment, 0, 0, 1, 1);

        lSeparatingCharacter = new QLabel(gbFilter);
        lSeparatingCharacter->setObjectName("lSeparatingCharacter");

        gridLayout_2->addWidget(lSeparatingCharacter, 1, 0, 1, 1);

        lNumberFormat = new QLabel(gbFilter);
        lNumberFormat->setObjectName("lNumberFormat");

        gridLayout_2->addWidget(lNumberFormat, 2, 0, 1, 1);

        lDateTimeFormat = new QLabel(gbFilter);
        lDateTimeFormat->setObjectName("lDateTimeFormat");

        gridLayout_2->addWidget(lDateTimeFormat, 3, 0, 1, 1);

        chbHeader = new QCheckBox(gbFilter);
        chbHeader->setObjectName("chbHeader");
        chbHeader->setChecked(true);

        gridLayout_2->addWidget(chbHeader, 6, 1, 1, 2);

        chbCreateIndex = new QCheckBox(gbFilter);
        chbCreateIndex->setObjectName("chbCreateIndex");

        gridLayout_2->addWidget(chbCreateIndex, 4, 0, 1, 1);

        chbSimplifyWhitespaces = new QCheckBox(gbFilter);
        chbSimplifyWhitespaces->setObjectName("chbSimplifyWhitespaces");
        chbSimplifyWhitespaces->setChecked(true);

        gridLayout_2->addWidget(chbSimplifyWhitespaces, 4, 1, 1, 1);

        chbSkipEmptyParts = new QCheckBox(gbFilter);
        chbSkipEmptyParts->setObjectName("chbSkipEmptyParts");

        gridLayout_2->addWidget(chbSkipEmptyParts, 4, 2, 1, 1);

        chbRemoveQuotes = new QCheckBox(gbFilter);
        chbRemoveQuotes->setObjectName("chbRemoveQuotes");

        gridLayout_2->addWidget(chbRemoveQuotes, 6, 0, 1, 1);

        cbCommentCharacter = new KComboBox(gbFilter);
        cbCommentCharacter->setObjectName("cbCommentCharacter");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbCommentCharacter->sizePolicy().hasHeightForWidth());
        cbCommentCharacter->setSizePolicy(sizePolicy);
        cbCommentCharacter->setEditable(true);

        gridLayout_2->addWidget(cbCommentCharacter, 0, 1, 1, 2);

        cbSeparatingCharacter = new KComboBox(gbFilter);
        cbSeparatingCharacter->setObjectName("cbSeparatingCharacter");
        cbSeparatingCharacter->setEditable(true);

        gridLayout_2->addWidget(cbSeparatingCharacter, 1, 1, 1, 2);

        cbNumberFormat = new QComboBox(gbFilter);
        cbNumberFormat->setObjectName("cbNumberFormat");

        gridLayout_2->addWidget(cbNumberFormat, 2, 1, 1, 2);

        cbDateTimeFormat = new KComboBox(gbFilter);
        cbDateTimeFormat->setObjectName("cbDateTimeFormat");
        sizePolicy.setHeightForWidth(cbDateTimeFormat->sizePolicy().hasHeightForWidth());
        cbDateTimeFormat->setSizePolicy(sizePolicy);
        cbDateTimeFormat->setEditable(true);

        gridLayout_2->addWidget(cbDateTimeFormat, 3, 1, 1, 2);


        gridLayout->addWidget(gbFilter, 8, 0, 1, 2);

        leFileName = new QLineEdit(DatasetMetadataManagerWidget);
        leFileName->setObjectName("leFileName");

        gridLayout->addWidget(leFileName, 3, 1, 1, 1);

        lFileName = new QLabel(DatasetMetadataManagerWidget);
        lFileName->setObjectName("lFileName");

        gridLayout->addWidget(lFileName, 3, 0, 1, 1);

        leDownloadURL = new QLineEdit(DatasetMetadataManagerWidget);
        leDownloadURL->setObjectName("leDownloadURL");

        gridLayout->addWidget(leDownloadURL, 5, 1, 1, 1);

        lDownloadUrl = new QLabel(DatasetMetadataManagerWidget);
        lDownloadUrl->setObjectName("lDownloadUrl");

        gridLayout->addWidget(lDownloadUrl, 5, 0, 1, 1);

        lDescription = new QLabel(DatasetMetadataManagerWidget);
        lDescription->setObjectName("lDescription");

        gridLayout->addWidget(lDescription, 6, 0, 1, 1);

        lSubcategory = new QLabel(DatasetMetadataManagerWidget);
        lSubcategory->setObjectName("lSubcategory");

        gridLayout->addWidget(lSubcategory, 2, 0, 1, 1);

        cbCategory = new QComboBox(DatasetMetadataManagerWidget);
        cbCategory->setObjectName("cbCategory");
        cbCategory->setEditable(true);

        gridLayout->addWidget(cbCategory, 1, 1, 1, 1);

        lDatasetName = new QLabel(DatasetMetadataManagerWidget);
        lDatasetName->setObjectName("lDatasetName");

        gridLayout->addWidget(lDatasetName, 4, 0, 1, 1);

        lCollection = new QLabel(DatasetMetadataManagerWidget);
        lCollection->setObjectName("lCollection");

        gridLayout->addWidget(lCollection, 0, 0, 1, 1);

        cbCollection = new QComboBox(DatasetMetadataManagerWidget);
        cbCollection->setObjectName("cbCollection");
        cbCollection->setEditable(true);

        gridLayout->addWidget(cbCollection, 0, 1, 1, 1);

        QWidget::setTabOrder(cbCollection, cbCategory);
        QWidget::setTabOrder(cbCategory, cbSubcategory);
        QWidget::setTabOrder(cbSubcategory, leFileName);
        QWidget::setTabOrder(leFileName, leDatasetName);
        QWidget::setTabOrder(leDatasetName, leDownloadURL);
        QWidget::setTabOrder(leDownloadURL, teDescription);
        QWidget::setTabOrder(teDescription, bNewColumn);
        QWidget::setTabOrder(bNewColumn, bDelete);
        QWidget::setTabOrder(bDelete, cbCommentCharacter);
        QWidget::setTabOrder(cbCommentCharacter, cbSeparatingCharacter);
        QWidget::setTabOrder(cbSeparatingCharacter, cbNumberFormat);
        QWidget::setTabOrder(cbNumberFormat, cbDateTimeFormat);
        QWidget::setTabOrder(cbDateTimeFormat, chbCreateIndex);
        QWidget::setTabOrder(chbCreateIndex, chbSimplifyWhitespaces);
        QWidget::setTabOrder(chbSimplifyWhitespaces, chbSkipEmptyParts);
        QWidget::setTabOrder(chbSkipEmptyParts, chbRemoveQuotes);
        QWidget::setTabOrder(chbRemoveQuotes, chbHeader);

        retranslateUi(DatasetMetadataManagerWidget);

        QMetaObject::connectSlotsByName(DatasetMetadataManagerWidget);
    } // setupUi

    void retranslateUi(QWidget *DatasetMetadataManagerWidget)
    {
        lCategory->setText(tr2i18n("Category", nullptr));
        gbColumnDescriptions->setTitle(tr2i18n("Column Descriptions", nullptr));
        bDelete->setText(tr2i18n("Delete Description", nullptr));
        bNewColumn->setText(tr2i18n("Add new description", nullptr));
        gbFilter->setTitle(tr2i18n("Filter Options", nullptr));
        lComment->setText(tr2i18n("Comment character:", nullptr));
        lSeparatingCharacter->setText(tr2i18n("Separating string:", nullptr));
        lNumberFormat->setText(tr2i18n("Number format:", nullptr));
        lDateTimeFormat->setText(tr2i18n("DateTime format:", nullptr));
        chbHeader->setText(tr2i18n("Use the first row to name the vectors", nullptr));
        chbCreateIndex->setText(tr2i18n("Create index column", nullptr));
#if QT_CONFIG(tooltip)
        chbSimplifyWhitespaces->setToolTip(tr2i18n("Removes the whitespaces from the start and the end, and replaces each sequence of internal whitespaces with a single space.", nullptr));
#endif // QT_CONFIG(tooltip)
        chbSimplifyWhitespaces->setText(tr2i18n("Simplify whitespaces", nullptr));
        chbSkipEmptyParts->setText(tr2i18n("Skip empty parts", nullptr));
        chbRemoveQuotes->setText(tr2i18n("Remove quotes", nullptr));
        lFileName->setText(tr2i18n("Short name", nullptr));
        lDownloadUrl->setText(tr2i18n("Download URL", nullptr));
        lDescription->setText(tr2i18n("Description", nullptr));
        lSubcategory->setText(tr2i18n("Subcategory", nullptr));
        lDatasetName->setText(tr2i18n("Full name", nullptr));
        lCollection->setText(tr2i18n("Collection", nullptr));
        (void)DatasetMetadataManagerWidget;
    } // retranslateUi

};

namespace Ui {
    class DatasetMetadataManagerWidget: public Ui_DatasetMetadataManagerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DATASETMETADATAMANAGERWIDGET_H

