/********************************************************************************
** Form generated from reading UI file 'processbehaviorchartdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROCESSBEHAVIORCHARTDOCK_H
#define UI_PROCESSBEHAVIORCHARTDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcolorbutton.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ProcessBehaviorChartDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    QLabel *lSampleSize;
    QLabel *lExactLimits;
    QSpinBox *sbSampleSize;
    QCheckBox *chkVisible;
    QSpacerItem *verticalSpacer_16;
    QLabel *lData2Column;
    QLineEdit *leMinLowerLimit;
    QLabel *lComment;
    QComboBox *cbPlotRanges;
    QComboBox *cbLimitsMetric;
    QLabel *lPlotRange;
    QSpacerItem *verticalSpacer_4;
    QSpacerItem *verticalSpacer;
    QCheckBox *chbExactLimits;
    QLabel *lDataColumn;
    QCheckBox *chkLegendVisible;
    QSpacerItem *horizontalSpacer_5;
    TimedLineEdit *leName;
    QLabel *lType;
    QLabel *lMinLowerLimit;
    QSpacerItem *verticalSpacerGeneral;
    QLabel *lLimitsMetric;
    QLabel *lName;
    QComboBox *cbType;
    ResizableTextEdit *teComment;
    QLabel *lMaxUpperLimit;
    QLineEdit *leMaxUpperLimit;
    QWidget *tabDataLine;
    QVBoxLayout *verticalLayout_2;
    QLabel *lLine;
    QSpacerItem *verticalSpacer_10;
    QSpacerItem *verticalSpacer_11;
    QSpacerItem *verticalSpacer_2;
    QWidget *tabControlLimitLines;
    QVBoxLayout *verticalLayout_3;
    QLabel *lCenter;
    QSpacerItem *verticalSpacer_5;
    QSpacerItem *verticalSpacer_6;
    QLabel *lUpperLimit;
    QSpacerItem *verticalSpacer_7;
    QSpacerItem *verticalSpacer_8;
    QLabel *lLowerLimit;
    QSpacerItem *verticalSpacer_9;
    QSpacerItem *verticalSpacer_3;
    QWidget *tabControlLimitLabels;
    QGridLayout *gridLayout_2;
    KColorButton *kcbLabelsFontColor;
    QLabel *lLabelsBorderShape;
    QSpacerItem *verticalSpacer_15;
    QComboBox *cbLabelsBorderShape;
    QSpacerItem *horizontalSpacer_6;
    QLabel *lLabelsFont;
    QLabel *lLabelsBackgroundColor;
    KColorButton *kcbLabelsBackgroundColor;
    KFontRequester *kfrLabelsFont;
    QSpacerItem *verticalSpacer_12;
    QSpacerItem *verticalSpacer_14;
    QSpacerItem *verticalSpacer_13;
    QLabel *lLabelsText;
    QLabel *lLabelsEnabled;
    QCheckBox *chbLabelsEnabled;
    QLabel *lLabelsFontColor;
    QLabel *lLabelsBorder;
    QLabel *lLabelsPrecision;
    QFrame *frameLabelsPrecision;
    QHBoxLayout *horizontalLayout_2;
    QSpinBox *sbLabelsPrecision;
    QCheckBox *chkLabelsAutoPrecision;

    void setupUi(QWidget *ProcessBehaviorChartDock)
    {
        if (ProcessBehaviorChartDock->objectName().isEmpty())
            ProcessBehaviorChartDock->setObjectName("ProcessBehaviorChartDock");
        ProcessBehaviorChartDock->resize(447, 835);
        verticalLayout = new QVBoxLayout(ProcessBehaviorChartDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(ProcessBehaviorChartDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setObjectName("gridLayout");
        lSampleSize = new QLabel(tabGeneral);
        lSampleSize->setObjectName("lSampleSize");

        gridLayout->addWidget(lSampleSize, 7, 0, 1, 1);

        lExactLimits = new QLabel(tabGeneral);
        lExactLimits->setObjectName("lExactLimits");

        gridLayout->addWidget(lExactLimits, 12, 0, 1, 1);

        sbSampleSize = new QSpinBox(tabGeneral);
        sbSampleSize->setObjectName("sbSampleSize");
        sbSampleSize->setMinimum(2);
        sbSampleSize->setMaximum(100);

        gridLayout->addWidget(sbSampleSize, 7, 2, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout->addWidget(chkVisible, 20, 0, 1, 1);

        verticalSpacer_16 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_16, 8, 0, 1, 1);

        lData2Column = new QLabel(tabGeneral);
        lData2Column->setObjectName("lData2Column");

        gridLayout->addWidget(lData2Column, 5, 0, 1, 1);

        leMinLowerLimit = new QLineEdit(tabGeneral);
        leMinLowerLimit->setObjectName("leMinLowerLimit");

        gridLayout->addWidget(leMinLowerLimit, 10, 2, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout->addWidget(cbPlotRanges, 17, 2, 1, 1);

        cbLimitsMetric = new QComboBox(tabGeneral);
        cbLimitsMetric->setObjectName("cbLimitsMetric");

        gridLayout->addWidget(cbLimitsMetric, 6, 2, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout->addWidget(lPlotRange, 17, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 14, 0, 2, 1);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        chbExactLimits = new QCheckBox(tabGeneral);
        chbExactLimits->setObjectName("chbExactLimits");

        gridLayout->addWidget(chbExactLimits, 12, 2, 1, 1);

        lDataColumn = new QLabel(tabGeneral);
        lDataColumn->setObjectName("lDataColumn");

        gridLayout->addWidget(lDataColumn, 4, 0, 1, 1);

        chkLegendVisible = new QCheckBox(tabGeneral);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout->addWidget(chkLegendVisible, 19, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        lType = new QLabel(tabGeneral);
        lType->setObjectName("lType");

        gridLayout->addWidget(lType, 3, 0, 1, 1);

        lMinLowerLimit = new QLabel(tabGeneral);
        lMinLowerLimit->setObjectName("lMinLowerLimit");

        gridLayout->addWidget(lMinLowerLimit, 10, 0, 1, 1);

        verticalSpacerGeneral = new QSpacerItem(24, 214, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout->addItem(verticalSpacerGeneral, 18, 0, 1, 1);

        lLimitsMetric = new QLabel(tabGeneral);
        lLimitsMetric->setObjectName("lLimitsMetric");

        gridLayout->addWidget(lLimitsMetric, 6, 0, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        cbType = new QComboBox(tabGeneral);
        cbType->setObjectName("cbType");

        gridLayout->addWidget(cbType, 3, 2, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        lMaxUpperLimit = new QLabel(tabGeneral);
        lMaxUpperLimit->setObjectName("lMaxUpperLimit");

        gridLayout->addWidget(lMaxUpperLimit, 9, 0, 1, 1);

        leMaxUpperLimit = new QLineEdit(tabGeneral);
        leMaxUpperLimit->setObjectName("leMaxUpperLimit");

        gridLayout->addWidget(leMaxUpperLimit, 9, 2, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabDataLine = new QWidget();
        tabDataLine->setObjectName("tabDataLine");
        verticalLayout_2 = new QVBoxLayout(tabDataLine);
        verticalLayout_2->setObjectName("verticalLayout_2");
        lLine = new QLabel(tabDataLine);
        lLine->setObjectName("lLine");
        QFont font;
        font.setBold(true);
        lLine->setFont(font);

        verticalLayout_2->addWidget(lLine);

        verticalSpacer_10 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_10);

        verticalSpacer_11 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_11);

        verticalSpacer_2 = new QSpacerItem(20, 654, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        tabWidget->addTab(tabDataLine, QString());
        tabControlLimitLines = new QWidget();
        tabControlLimitLines->setObjectName("tabControlLimitLines");
        verticalLayout_3 = new QVBoxLayout(tabControlLimitLines);
        verticalLayout_3->setObjectName("verticalLayout_3");
        lCenter = new QLabel(tabControlLimitLines);
        lCenter->setObjectName("lCenter");
        lCenter->setFont(font);

        verticalLayout_3->addWidget(lCenter);

        verticalSpacer_5 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_5);

        verticalSpacer_6 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_6);

        lUpperLimit = new QLabel(tabControlLimitLines);
        lUpperLimit->setObjectName("lUpperLimit");
        lUpperLimit->setFont(font);

        verticalLayout_3->addWidget(lUpperLimit);

        verticalSpacer_7 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_7);

        verticalSpacer_8 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_8);

        lLowerLimit = new QLabel(tabControlLimitLines);
        lLowerLimit->setObjectName("lLowerLimit");
        lLowerLimit->setFont(font);

        verticalLayout_3->addWidget(lLowerLimit);

        verticalSpacer_9 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_9);

        verticalSpacer_3 = new QSpacerItem(20, 654, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);

        tabWidget->addTab(tabControlLimitLines, QString());
        tabControlLimitLabels = new QWidget();
        tabControlLimitLabels->setObjectName("tabControlLimitLabels");
        gridLayout_2 = new QGridLayout(tabControlLimitLabels);
        gridLayout_2->setObjectName("gridLayout_2");
        kcbLabelsFontColor = new KColorButton(tabControlLimitLabels);
        kcbLabelsFontColor->setObjectName("kcbLabelsFontColor");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcbLabelsFontColor->sizePolicy().hasHeightForWidth());
        kcbLabelsFontColor->setSizePolicy(sizePolicy);
        kcbLabelsFontColor->setIconSize(QSize(20, 20));

        gridLayout_2->addWidget(kcbLabelsFontColor, 6, 2, 1, 1);

        lLabelsBorderShape = new QLabel(tabControlLimitLabels);
        lLabelsBorderShape->setObjectName("lLabelsBorderShape");

        gridLayout_2->addWidget(lLabelsBorderShape, 10, 0, 1, 1);

        verticalSpacer_15 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_15, 2, 0, 1, 1);

        cbLabelsBorderShape = new QComboBox(tabControlLimitLabels);
        cbLabelsBorderShape->setObjectName("cbLabelsBorderShape");

        gridLayout_2->addWidget(cbLabelsBorderShape, 10, 2, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_6, 0, 1, 1, 1);

        lLabelsFont = new QLabel(tabControlLimitLabels);
        lLabelsFont->setObjectName("lLabelsFont");

        gridLayout_2->addWidget(lLabelsFont, 5, 0, 1, 1);

        lLabelsBackgroundColor = new QLabel(tabControlLimitLabels);
        lLabelsBackgroundColor->setObjectName("lLabelsBackgroundColor");

        gridLayout_2->addWidget(lLabelsBackgroundColor, 7, 0, 1, 1);

        kcbLabelsBackgroundColor = new KColorButton(tabControlLimitLabels);
        kcbLabelsBackgroundColor->setObjectName("kcbLabelsBackgroundColor");
        sizePolicy.setHeightForWidth(kcbLabelsBackgroundColor->sizePolicy().hasHeightForWidth());
        kcbLabelsBackgroundColor->setSizePolicy(sizePolicy);
        kcbLabelsBackgroundColor->setIconSize(QSize(20, 20));

        gridLayout_2->addWidget(kcbLabelsBackgroundColor, 7, 2, 1, 1);

        kfrLabelsFont = new KFontRequester(tabControlLimitLabels);
        kfrLabelsFont->setObjectName("kfrLabelsFont");

        gridLayout_2->addWidget(kfrLabelsFont, 5, 2, 1, 1);

        verticalSpacer_12 = new QSpacerItem(118, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_12, 11, 0, 1, 1);

        verticalSpacer_14 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_14, 8, 0, 1, 1);

        verticalSpacer_13 = new QSpacerItem(118, 495, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_13, 12, 0, 1, 1);

        lLabelsText = new QLabel(tabControlLimitLabels);
        lLabelsText->setObjectName("lLabelsText");
        lLabelsText->setFont(font);

        gridLayout_2->addWidget(lLabelsText, 3, 0, 1, 1);

        lLabelsEnabled = new QLabel(tabControlLimitLabels);
        lLabelsEnabled->setObjectName("lLabelsEnabled");

        gridLayout_2->addWidget(lLabelsEnabled, 0, 0, 1, 1);

        chbLabelsEnabled = new QCheckBox(tabControlLimitLabels);
        chbLabelsEnabled->setObjectName("chbLabelsEnabled");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(chbLabelsEnabled->sizePolicy().hasHeightForWidth());
        chbLabelsEnabled->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(chbLabelsEnabled, 0, 2, 1, 1);

        lLabelsFontColor = new QLabel(tabControlLimitLabels);
        lLabelsFontColor->setObjectName("lLabelsFontColor");

        gridLayout_2->addWidget(lLabelsFontColor, 6, 0, 1, 1);

        lLabelsBorder = new QLabel(tabControlLimitLabels);
        lLabelsBorder->setObjectName("lLabelsBorder");
        lLabelsBorder->setFont(font);

        gridLayout_2->addWidget(lLabelsBorder, 9, 0, 1, 1);

        lLabelsPrecision = new QLabel(tabControlLimitLabels);
        lLabelsPrecision->setObjectName("lLabelsPrecision");

        gridLayout_2->addWidget(lLabelsPrecision, 4, 0, 1, 1);

        frameLabelsPrecision = new QFrame(tabControlLimitLabels);
        frameLabelsPrecision->setObjectName("frameLabelsPrecision");
        frameLabelsPrecision->setFrameShape(QFrame::Shape::NoFrame);
        frameLabelsPrecision->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout_2 = new QHBoxLayout(frameLabelsPrecision);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        sbLabelsPrecision = new QSpinBox(frameLabelsPrecision);
        sbLabelsPrecision->setObjectName("sbLabelsPrecision");
        sizePolicy1.setHeightForWidth(sbLabelsPrecision->sizePolicy().hasHeightForWidth());
        sbLabelsPrecision->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(sbLabelsPrecision);

        chkLabelsAutoPrecision = new QCheckBox(frameLabelsPrecision);
        chkLabelsAutoPrecision->setObjectName("chkLabelsAutoPrecision");

        horizontalLayout_2->addWidget(chkLabelsAutoPrecision);


        gridLayout_2->addWidget(frameLabelsPrecision, 4, 2, 1, 1);

        tabWidget->addTab(tabControlLimitLabels, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbType);
        QWidget::setTabOrder(cbType, cbLimitsMetric);
        QWidget::setTabOrder(cbLimitsMetric, sbSampleSize);
        QWidget::setTabOrder(sbSampleSize, leMaxUpperLimit);
        QWidget::setTabOrder(leMaxUpperLimit, leMinLowerLimit);
        QWidget::setTabOrder(leMinLowerLimit, chbExactLimits);
        QWidget::setTabOrder(chbExactLimits, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);
        QWidget::setTabOrder(chkVisible, kcbLabelsFontColor);
        QWidget::setTabOrder(kcbLabelsFontColor, cbLabelsBorderShape);
        QWidget::setTabOrder(cbLabelsBorderShape, kcbLabelsBackgroundColor);
        QWidget::setTabOrder(kcbLabelsBackgroundColor, kfrLabelsFont);
        QWidget::setTabOrder(kfrLabelsFont, chbLabelsEnabled);
        QWidget::setTabOrder(chbLabelsEnabled, sbLabelsPrecision);
        QWidget::setTabOrder(sbLabelsPrecision, chkLabelsAutoPrecision);

        retranslateUi(ProcessBehaviorChartDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ProcessBehaviorChartDock);
    } // setupUi

    void retranslateUi(QWidget *ProcessBehaviorChartDock)
    {
        ProcessBehaviorChartDock->setWindowTitle(tr2i18n("Form", nullptr));
        lSampleSize->setText(tr2i18n("Sample Size:", nullptr));
        lExactLimits->setText(tr2i18n("Exact Limits:", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lData2Column->setText(tr2i18n("Sample Sizes:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lPlotRange->setText(tr2i18n("Plot range:", nullptr));
        chbExactLimits->setText(QString());
        lDataColumn->setText(tr2i18n("Variables:", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        lType->setText(tr2i18n("Type:", nullptr));
        lMinLowerLimit->setText(tr2i18n("Min. Lower Limit:", nullptr));
        lLimitsMetric->setText(tr2i18n("Limits based on:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lMaxUpperLimit->setText(tr2i18n("Max. Upper Limit:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        lLine->setText(tr2i18n("Line", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDataLine), tr2i18n("Data Line", nullptr));
        lCenter->setText(tr2i18n("Center", nullptr));
        lUpperLimit->setText(tr2i18n("Upper Limit", nullptr));
        lLowerLimit->setText(tr2i18n("Lower Limit", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabControlLimitLines), tr2i18n("Center/Limits Lines", nullptr));
        lLabelsBorderShape->setText(tr2i18n("Shape:", nullptr));
        lLabelsFont->setText(tr2i18n("Font:", nullptr));
        lLabelsBackgroundColor->setText(tr2i18n("Background Color:", nullptr));
        lLabelsText->setText(tr2i18n("Text", nullptr));
        lLabelsEnabled->setText(tr2i18n("Enabled:", nullptr));
        chbLabelsEnabled->setText(QString());
        lLabelsFontColor->setText(tr2i18n("Font Color:", nullptr));
        lLabelsBorder->setText(tr2i18n("Border", nullptr));
#if QT_CONFIG(tooltip)
        lLabelsPrecision->setToolTip(tr2i18n("Number of digits after the decimal point", nullptr));
#endif // QT_CONFIG(tooltip)
        lLabelsPrecision->setText(tr2i18n("Precision:", nullptr));
#if QT_CONFIG(tooltip)
        sbLabelsPrecision->setToolTip(tr2i18n("Number of digits after the decimal point", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        chkLabelsAutoPrecision->setToolTip(tr2i18n("Automatically determine the optimal number of digits after the decimal point", nullptr));
#endif // QT_CONFIG(tooltip)
        chkLabelsAutoPrecision->setText(tr2i18n("Auto", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabControlLimitLabels), tr2i18n("Center/Limit Values", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ProcessBehaviorChartDock: public Ui_ProcessBehaviorChartDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROCESSBEHAVIORCHARTDOCK_H

