/********************************************************************************
** Form generated from reading UI file 'samplevalueswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SAMPLEVALUESWIDGET_H
#define UI_SAMPLEVALUESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SampleValuesWidget
{
public:
    QGridLayout *gridLayout;
    QSpinBox *sbValue;
    QLabel *lValue;
    QComboBox *cbMethod;
    QLabel *lMethod;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SampleValuesWidget)
    {
        if (SampleValuesWidget->objectName().isEmpty())
            SampleValuesWidget->setObjectName("SampleValuesWidget");
        SampleValuesWidget->resize(330, 107);
        gridLayout = new QGridLayout(SampleValuesWidget);
        gridLayout->setObjectName("gridLayout");
        sbValue = new QSpinBox(SampleValuesWidget);
        sbValue->setObjectName("sbValue");
        sbValue->setMinimum(1);
        sbValue->setMaximum(9999);

        gridLayout->addWidget(sbValue, 1, 1, 1, 1);

        lValue = new QLabel(SampleValuesWidget);
        lValue->setObjectName("lValue");

        gridLayout->addWidget(lValue, 1, 0, 1, 1);

        cbMethod = new QComboBox(SampleValuesWidget);
        cbMethod->setObjectName("cbMethod");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbMethod->sizePolicy().hasHeightForWidth());
        cbMethod->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbMethod, 0, 1, 1, 1);

        lMethod = new QLabel(SampleValuesWidget);
        lMethod->setObjectName("lMethod");

        gridLayout->addWidget(lMethod, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);


        retranslateUi(SampleValuesWidget);

        QMetaObject::connectSlotsByName(SampleValuesWidget);
    } // setupUi

    void retranslateUi(QWidget *SampleValuesWidget)
    {
        SampleValuesWidget->setWindowTitle(tr2i18n("Form", nullptr));
        lValue->setText(tr2i18n("Period:", nullptr));
        lMethod->setText(tr2i18n("Method:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SampleValuesWidget: public Ui_SampleValuesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SAMPLEVALUESWIDGET_H

