/****************************************************************************
** Meta object code from reading C++ file 'MQTTClient.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/datasources/MQTTClient.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MQTTClient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MQTTClientE_t {};
} // unnamed namespace

template <> constexpr inline auto MQTTClient::qt_create_metaobjectdata<qt_meta_tag_ZN10MQTTClientE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MQTTClient",
        "MQTTSubscribed",
        "",
        "MQTTTopicsChanged",
        "readFromTopics",
        "clientAboutToBeDeleted",
        "messagedReceived",
        "read",
        "onMQTTConnect",
        "MQTTSubscriptionMessageReceived",
        "QMqttMessage",
        "MQTTErrorChanged",
        "QMqttClient::ClientError",
        "disconnected",
        "subscriptionLoaded"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'MQTTSubscribed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MQTTTopicsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readFromTopics'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clientAboutToBeDeleted'
        QtMocHelpers::SignalData<void(const QString &, quint16)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::UShort, 2 },
        }}),
        // Signal 'messagedReceived'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'read'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onMQTTConnect'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'MQTTSubscriptionMessageReceived'
        QtMocHelpers::SlotData<void(const QMqttMessage &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'MQTTErrorChanged'
        QtMocHelpers::SlotData<void(QMqttClient::ClientError)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Slot 'disconnected'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'subscriptionLoaded'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MQTTClient, qt_meta_tag_ZN10MQTTClientE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MQTTClient::staticMetaObject = { {
    QMetaObject::SuperData::link<Folder::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MQTTClientE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MQTTClientE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MQTTClientE_t>.metaTypes,
    nullptr
} };

void MQTTClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MQTTClient *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->MQTTSubscribed(); break;
        case 1: _t->MQTTTopicsChanged(); break;
        case 2: _t->readFromTopics(); break;
        case 3: _t->clientAboutToBeDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint16>>(_a[2]))); break;
        case 4: _t->messagedReceived(); break;
        case 5: _t->read(); break;
        case 6: _t->onMQTTConnect(); break;
        case 7: _t->MQTTSubscriptionMessageReceived((*reinterpret_cast<std::add_pointer_t<QMqttMessage>>(_a[1]))); break;
        case 8: _t->MQTTErrorChanged((*reinterpret_cast<std::add_pointer_t<QMqttClient::ClientError>>(_a[1]))); break;
        case 9: _t->disconnected(); break;
        case 10: _t->subscriptionLoaded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMqttMessage >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMqttClient::ClientError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MQTTClient::*)()>(_a, &MQTTClient::MQTTSubscribed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MQTTClient::*)()>(_a, &MQTTClient::MQTTTopicsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MQTTClient::*)()>(_a, &MQTTClient::readFromTopics, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MQTTClient::*)(const QString & , quint16 )>(_a, &MQTTClient::clientAboutToBeDeleted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MQTTClient::*)()>(_a, &MQTTClient::messagedReceived, 4))
            return;
    }
}

const QMetaObject *MQTTClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MQTTClient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MQTTClientE_t>.strings))
        return static_cast<void*>(this);
    return Folder::qt_metacast(_clname);
}

int MQTTClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Folder::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void MQTTClient::MQTTSubscribed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MQTTClient::MQTTTopicsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MQTTClient::readFromTopics()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MQTTClient::clientAboutToBeDeleted(const QString & _t1, quint16 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void MQTTClient::messagedReceived()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
