/****************************************************************************
** Meta object code from reading C++ file 'TextLabel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/TextLabel.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TextLabel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9TextLabelE_t {};
} // unnamed namespace

template <> constexpr inline auto TextLabel::qt_create_metaobjectdata<qt_meta_tag_ZN9TextLabelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TextLabel",
        "textWrapperChanged",
        "",
        "TextLabel::TextWrapper",
        "teXFontSizeChanged",
        "teXFontChanged",
        "QFont",
        "fontColorChanged",
        "QColor",
        "backgroundColorChanged",
        "borderShapeChanged",
        "TextLabel::BorderShape",
        "teXImageUpdated",
        "TeXRenderer::Result",
        "updateTeXImage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textWrapperChanged'
        QtMocHelpers::SignalData<void(const TextLabel::TextWrapper &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'teXFontSizeChanged'
        QtMocHelpers::SignalData<void(const int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'teXFontChanged'
        QtMocHelpers::SignalData<void(const QFont)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'fontColorChanged'
        QtMocHelpers::SignalData<void(const QColor)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'backgroundColorChanged'
        QtMocHelpers::SignalData<void(const QColor)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'borderShapeChanged'
        QtMocHelpers::SignalData<void(TextLabel::BorderShape)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Signal 'teXImageUpdated'
        QtMocHelpers::SignalData<void(const TeXRenderer::Result &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'updateTeXImage'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TextLabel, qt_meta_tag_ZN9TextLabelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TextLabel::staticMetaObject = { {
    QMetaObject::SuperData::link<WorksheetElement::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TextLabelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TextLabelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9TextLabelE_t>.metaTypes,
    nullptr
} };

void TextLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TextLabel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textWrapperChanged((*reinterpret_cast<std::add_pointer_t<TextLabel::TextWrapper>>(_a[1]))); break;
        case 1: _t->teXFontSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->teXFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 3: _t->fontColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 4: _t->backgroundColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 5: _t->borderShapeChanged((*reinterpret_cast<std::add_pointer_t<TextLabel::BorderShape>>(_a[1]))); break;
        case 6: _t->teXImageUpdated((*reinterpret_cast<std::add_pointer_t<TeXRenderer::Result>>(_a[1]))); break;
        case 7: _t->updateTeXImage(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TextLabel::*)(const TextLabel::TextWrapper & )>(_a, &TextLabel::textWrapperChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextLabel::*)(const int )>(_a, &TextLabel::teXFontSizeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextLabel::*)(const QFont )>(_a, &TextLabel::teXFontChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextLabel::*)(const QColor )>(_a, &TextLabel::fontColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextLabel::*)(const QColor )>(_a, &TextLabel::backgroundColorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextLabel::*)(TextLabel::BorderShape )>(_a, &TextLabel::borderShapeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextLabel::*)(const TeXRenderer::Result & )>(_a, &TextLabel::teXImageUpdated, 6))
            return;
    }
}

const QMetaObject *TextLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TextLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TextLabelE_t>.strings))
        return static_cast<void*>(this);
    return WorksheetElement::qt_metacast(_clname);
}

int TextLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WorksheetElement::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void TextLabel::textWrapperChanged(const TextLabel::TextWrapper & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TextLabel::teXFontSizeChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TextLabel::teXFontChanged(const QFont _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TextLabel::fontColorChanged(const QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void TextLabel::backgroundColorChanged(const QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void TextLabel::borderShapeChanged(TextLabel::BorderShape _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void TextLabel::teXImageUpdated(const TeXRenderer::Result & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
