/****************************************************************************
** Meta object code from reading C++ file 'AbstractFileFilter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/datasources/filters/AbstractFileFilter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AbstractFileFilter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18AbstractFileFilterE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractFileFilter::qt_create_metaobjectdata<qt_meta_tag_ZN18AbstractFileFilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractFileFilter",
        "completed",
        "",
        "FileType",
        "Ascii",
        "Binary",
        "XLSX",
        "Ods",
        "Image",
        "HDF5",
        "NETCDF",
        "FITS",
        "JSON",
        "ROOT",
        "Spice",
        "READSTAT",
        "MATIO",
        "VECTOR_BLF",
        "MCAP",
        "ImportMode",
        "Append",
        "Prepend",
        "Replace"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'completed'
        QtMocHelpers::SignalData<void(int) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FileType'
        QtMocHelpers::EnumData<enum FileType>(3, 3, QMC::EnumIsScoped).add({
            {    4, FileType::Ascii },
            {    5, FileType::Binary },
            {    6, FileType::XLSX },
            {    7, FileType::Ods },
            {    8, FileType::Image },
            {    9, FileType::HDF5 },
            {   10, FileType::NETCDF },
            {   11, FileType::FITS },
            {   12, FileType::JSON },
            {   13, FileType::ROOT },
            {   14, FileType::Spice },
            {   15, FileType::READSTAT },
            {   16, FileType::MATIO },
            {   17, FileType::VECTOR_BLF },
            {   18, FileType::MCAP },
        }),
        // enum 'ImportMode'
        QtMocHelpers::EnumData<enum ImportMode>(19, 19, QMC::EnumIsScoped).add({
            {   20, ImportMode::Append },
            {   21, ImportMode::Prepend },
            {   22, ImportMode::Replace },
        }),
    };
    return QtMocHelpers::metaObjectData<AbstractFileFilter, qt_meta_tag_ZN18AbstractFileFilterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractFileFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AbstractFileFilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AbstractFileFilterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18AbstractFileFilterE_t>.metaTypes,
    nullptr
} };

void AbstractFileFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractFileFilter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->completed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractFileFilter::*)(int ) const>(_a, &AbstractFileFilter::completed, 0))
            return;
    }
}

const QMetaObject *AbstractFileFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractFileFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AbstractFileFilterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractFileFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void AbstractFileFilter::completed(int _t1)const
{
    QMetaObject::activate<void>(const_cast< AbstractFileFilter *>(this), &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
