/********************************************************************************
** Form generated from reading UI file 'settingsgeneralpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSGENERALPAGE_H
#define UI_SETTINGSGENERALPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_SettingsGeneralPage
{
public:
    QGridLayout *gridLayout;
    QLabel *lAutoSave;
    QSpacerItem *horizontalSpacer_3;
    QComboBox *cbUnits;
    QComboBox *cbNumberFormat;
    QLabel *lDockWindowPositionReopen;
    QCheckBox *chkSaveCalculations;
    QLabel *lNumberFormat;
    QLabel *lStartup;
    QCheckBox *chkSaveDockStates;
    QComboBox *cbTitleBar;
    QCheckBox *chkGUMTerms;
    QComboBox *cbNewProjectNotebook;
    QCheckBox *chkCompatible;
    QLabel *lNumberOptions;
    QLabel *lUnits;
    QLabel *lNewProject;
    QCheckBox *chkIncludeTrailingZeroesAfterDot;
    QLabel *lNewProjectNotebook;
    QSpacerItem *verticalSpacer;
    QLabel *lSaveCalculations;
    QSpacerItem *verticalSpacer_4;
    QSpacerItem *verticalSpacer_3;
    QComboBox *cbNewProject;
    QCheckBox *chkOmitGroupSeparator;
    KComboBox *cbLoadOnStart;
    QLabel *lTracing;
    QFrame *frameTracing;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *chkInfoTrace;
    QSpacerItem *horizontalSpacer_6;
    QSpacerItem *horizontalSpacer_4;
    QCheckBox *chkPerfTrace;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *chkDebugTrace;
    QCheckBox *chkOmitLeadingZeroInExponent;
    QLabel *lTitleBar;
    QComboBox *cbDockWindowPositionReopen;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QCheckBox *chkAutoSave;
    QSpacerItem *horizontalSpacer;
    QLabel *lAutoSaveInterval;
    QSpinBox *sbAutoSaveInterval;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label;
    QLabel *lGUMTerms;
    QSpacerItem *verticalSpacer_2;
    QLabel *lSaveDockStates;
    QCheckBox *chkUseHyphen;

    void setupUi(QWidget *SettingsGeneralPage)
    {
        if (SettingsGeneralPage->objectName().isEmpty())
            SettingsGeneralPage->setObjectName("SettingsGeneralPage");
        SettingsGeneralPage->resize(577, 670);
        gridLayout = new QGridLayout(SettingsGeneralPage);
        gridLayout->setObjectName("gridLayout");
        lAutoSave = new QLabel(SettingsGeneralPage);
        lAutoSave->setObjectName("lAutoSave");

        gridLayout->addWidget(lAutoSave, 16, 0, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 0, 1, 1, 1);

        cbUnits = new QComboBox(SettingsGeneralPage);
        cbUnits->setObjectName("cbUnits");

        gridLayout->addWidget(cbUnits, 7, 2, 1, 1);

        cbNumberFormat = new QComboBox(SettingsGeneralPage);
        cbNumberFormat->setObjectName("cbNumberFormat");

        gridLayout->addWidget(cbNumberFormat, 10, 2, 1, 1);

        lDockWindowPositionReopen = new QLabel(SettingsGeneralPage);
        lDockWindowPositionReopen->setObjectName("lDockWindowPositionReopen");

        gridLayout->addWidget(lDockWindowPositionReopen, 4, 0, 1, 1);

        chkSaveCalculations = new QCheckBox(SettingsGeneralPage);
        chkSaveCalculations->setObjectName("chkSaveCalculations");

        gridLayout->addWidget(chkSaveCalculations, 18, 2, 1, 1);

        lNumberFormat = new QLabel(SettingsGeneralPage);
        lNumberFormat->setObjectName("lNumberFormat");

        gridLayout->addWidget(lNumberFormat, 10, 0, 1, 1);

        lStartup = new QLabel(SettingsGeneralPage);
        lStartup->setObjectName("lStartup");

        gridLayout->addWidget(lStartup, 0, 0, 1, 1);

        chkSaveDockStates = new QCheckBox(SettingsGeneralPage);
        chkSaveDockStates->setObjectName("chkSaveDockStates");

        gridLayout->addWidget(chkSaveDockStates, 17, 2, 1, 1);

        cbTitleBar = new QComboBox(SettingsGeneralPage);
        cbTitleBar->setObjectName("cbTitleBar");

        gridLayout->addWidget(cbTitleBar, 5, 2, 1, 1);

        chkGUMTerms = new QCheckBox(SettingsGeneralPage);
        chkGUMTerms->setObjectName("chkGUMTerms");

        gridLayout->addWidget(chkGUMTerms, 9, 2, 1, 1);

        cbNewProjectNotebook = new QComboBox(SettingsGeneralPage);
        cbNewProjectNotebook->setObjectName("cbNewProjectNotebook");

        gridLayout->addWidget(cbNewProjectNotebook, 2, 2, 1, 1);

        chkCompatible = new QCheckBox(SettingsGeneralPage);
        chkCompatible->setObjectName("chkCompatible");

        gridLayout->addWidget(chkCompatible, 19, 2, 1, 1);

        lNumberOptions = new QLabel(SettingsGeneralPage);
        lNumberOptions->setObjectName("lNumberOptions");

        gridLayout->addWidget(lNumberOptions, 11, 0, 1, 1);

        lUnits = new QLabel(SettingsGeneralPage);
        lUnits->setObjectName("lUnits");

        gridLayout->addWidget(lUnits, 7, 0, 1, 1);

        lNewProject = new QLabel(SettingsGeneralPage);
        lNewProject->setObjectName("lNewProject");

        gridLayout->addWidget(lNewProject, 1, 0, 1, 1);

        chkIncludeTrailingZeroesAfterDot = new QCheckBox(SettingsGeneralPage);
        chkIncludeTrailingZeroesAfterDot->setObjectName("chkIncludeTrailingZeroesAfterDot");

        gridLayout->addWidget(chkIncludeTrailingZeroesAfterDot, 13, 2, 1, 1);

        lNewProjectNotebook = new QLabel(SettingsGeneralPage);
        lNewProjectNotebook->setObjectName("lNewProjectNotebook");

        gridLayout->addWidget(lNewProjectNotebook, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 156, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 21, 0, 1, 2);

        lSaveCalculations = new QLabel(SettingsGeneralPage);
        lSaveCalculations->setObjectName("lSaveCalculations");

        gridLayout->addWidget(lSaveCalculations, 19, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 6, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 3, 0, 1, 1);

        cbNewProject = new QComboBox(SettingsGeneralPage);
        cbNewProject->setObjectName("cbNewProject");

        gridLayout->addWidget(cbNewProject, 1, 2, 1, 1);

        chkOmitGroupSeparator = new QCheckBox(SettingsGeneralPage);
        chkOmitGroupSeparator->setObjectName("chkOmitGroupSeparator");

        gridLayout->addWidget(chkOmitGroupSeparator, 11, 2, 1, 1);

        cbLoadOnStart = new KComboBox(SettingsGeneralPage);
        cbLoadOnStart->setObjectName("cbLoadOnStart");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbLoadOnStart->sizePolicy().hasHeightForWidth());
        cbLoadOnStart->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbLoadOnStart, 0, 2, 1, 1);

        lTracing = new QLabel(SettingsGeneralPage);
        lTracing->setObjectName("lTracing");

        gridLayout->addWidget(lTracing, 20, 0, 1, 1);

        frameTracing = new QFrame(SettingsGeneralPage);
        frameTracing->setObjectName("frameTracing");
        frameTracing->setFrameShape(QFrame::Shape::NoFrame);
        frameTracing->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout_2 = new QHBoxLayout(frameTracing);
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        chkInfoTrace = new QCheckBox(frameTracing);
        chkInfoTrace->setObjectName("chkInfoTrace");

        horizontalLayout_2->addWidget(chkInfoTrace);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_6);

        horizontalSpacer_4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);

        chkPerfTrace = new QCheckBox(frameTracing);
        chkPerfTrace->setObjectName("chkPerfTrace");

        horizontalLayout_2->addWidget(chkPerfTrace);

        horizontalSpacer_5 = new QSpacerItem(156, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_5);

        chkDebugTrace = new QCheckBox(frameTracing);
        chkDebugTrace->setObjectName("chkDebugTrace");

        horizontalLayout_2->addWidget(chkDebugTrace);


        gridLayout->addWidget(frameTracing, 20, 2, 1, 1);

        chkOmitLeadingZeroInExponent = new QCheckBox(SettingsGeneralPage);
        chkOmitLeadingZeroInExponent->setObjectName("chkOmitLeadingZeroInExponent");

        gridLayout->addWidget(chkOmitLeadingZeroInExponent, 12, 2, 1, 1);

        lTitleBar = new QLabel(SettingsGeneralPage);
        lTitleBar->setObjectName("lTitleBar");

        gridLayout->addWidget(lTitleBar, 5, 0, 1, 1);

        cbDockWindowPositionReopen = new QComboBox(SettingsGeneralPage);
        cbDockWindowPositionReopen->setObjectName("cbDockWindowPositionReopen");

        gridLayout->addWidget(cbDockWindowPositionReopen, 4, 2, 1, 1);

        frame = new QFrame(SettingsGeneralPage);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::Shape::NoFrame);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        chkAutoSave = new QCheckBox(frame);
        chkAutoSave->setObjectName("chkAutoSave");

        horizontalLayout->addWidget(chkAutoSave);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        lAutoSaveInterval = new QLabel(frame);
        lAutoSaveInterval->setObjectName("lAutoSaveInterval");

        horizontalLayout->addWidget(lAutoSaveInterval);

        sbAutoSaveInterval = new QSpinBox(frame);
        sbAutoSaveInterval->setObjectName("sbAutoSaveInterval");
        sbAutoSaveInterval->setMinimum(1);
        sbAutoSaveInterval->setValue(5);

        horizontalLayout->addWidget(sbAutoSaveInterval);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        gridLayout->addWidget(frame, 16, 2, 1, 1);

        label = new QLabel(SettingsGeneralPage);
        label->setObjectName("label");

        gridLayout->addWidget(label, 18, 0, 1, 1);

        lGUMTerms = new QLabel(SettingsGeneralPage);
        lGUMTerms->setObjectName("lGUMTerms");

        gridLayout->addWidget(lGUMTerms, 9, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 15, 0, 1, 1);

        lSaveDockStates = new QLabel(SettingsGeneralPage);
        lSaveDockStates->setObjectName("lSaveDockStates");

        gridLayout->addWidget(lSaveDockStates, 17, 0, 1, 1);

        chkUseHyphen = new QCheckBox(SettingsGeneralPage);
        chkUseHyphen->setObjectName("chkUseHyphen");

        gridLayout->addWidget(chkUseHyphen, 14, 2, 1, 1);


        retranslateUi(SettingsGeneralPage);

        QMetaObject::connectSlotsByName(SettingsGeneralPage);
    } // setupUi

    void retranslateUi(QWidget *SettingsGeneralPage)
    {
        lAutoSave->setText(tr2i18n("Auto-save:", nullptr));
        lDockWindowPositionReopen->setText(tr2i18n("Dock Widget Placement:", nullptr));
        chkSaveCalculations->setText(tr2i18n("Enabled", nullptr));
        lNumberFormat->setText(tr2i18n("Number Format:", nullptr));
        lStartup->setText(tr2i18n("Startup:", nullptr));
        chkSaveDockStates->setText(tr2i18n("Enabled", nullptr));
#if QT_CONFIG(tooltip)
        chkGUMTerms->setToolTip(tr2i18n("<html><head/><body><p>Use terms compliant with the <a href=\"http://www.bipm.org/utils/common/documents/jcgm/JCGM_100_2008_E.pdf\"><span style=\" text-decoration: underline; color:#2980b9;\">Guide to the Expression of Uncertainty in Measurement (GUM)</span></a></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        chkGUMTerms->setText(tr2i18n("GUM compliant", nullptr));
#if QT_CONFIG(tooltip)
        chkCompatible->setToolTip(tr2i18n("<html><head/><body><p>Save projects in a compatible format that can be opened in LabPlot versions older than 2.9.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        chkCompatible->setText(tr2i18n("Save in compatible format", nullptr));
        lNumberOptions->setText(tr2i18n("Number Options:", nullptr));
        lUnits->setText(tr2i18n("Units:", nullptr));
        lNewProject->setText(tr2i18n("New Project:", nullptr));
        chkIncludeTrailingZeroesAfterDot->setText(tr2i18n("Include trailing zeroes after dot", nullptr));
        lNewProjectNotebook->setText(tr2i18n("Notebook:", nullptr));
        lSaveCalculations->setText(tr2i18n("Compatibility:", nullptr));
        chkOmitGroupSeparator->setText(tr2i18n("Omit group separator", nullptr));
        lTracing->setText(tr2i18n("Tracing:", nullptr));
        chkInfoTrace->setText(tr2i18n("Info", nullptr));
        chkPerfTrace->setText(tr2i18n("Performance", nullptr));
        chkDebugTrace->setText(tr2i18n("Debug", nullptr));
        chkOmitLeadingZeroInExponent->setText(tr2i18n("Omit leading zero in exponent", nullptr));
        lTitleBar->setText(tr2i18n("Title Bar:", nullptr));
        chkAutoSave->setText(tr2i18n("Enabled", nullptr));
        lAutoSaveInterval->setText(tr2i18n("Interval:", nullptr));
        label->setText(tr2i18n("Save  Calculations:", nullptr));
        lGUMTerms->setText(tr2i18n("Terms:", nullptr));
        lSaveDockStates->setText(tr2i18n("Save Dock States:", nullptr));
        chkUseHyphen->setText(tr2i18n("Use Hyphen '-' instead of Minus '\342\200\223'", nullptr));
        (void)SettingsGeneralPage;
    } // retranslateUi

};

namespace Ui {
    class SettingsGeneralPage: public Ui_SettingsGeneralPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGSGENERALPAGE_H

