/****************************************************************************
** Meta object code from reading C++ file 'SpreadsheetDock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/dockwidgets/SpreadsheetDock.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SpreadsheetDock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SpreadsheetDockE_t {};
} // unnamed namespace

template <> constexpr inline auto SpreadsheetDock::qt_create_metaobjectdata<qt_meta_tag_ZN15SpreadsheetDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SpreadsheetDock",
        "info",
        "",
        "rowCountChanged",
        "columnCountChanged",
        "commentsShownChanged",
        "sparklinesShownChanged",
        "linkingChanged",
        "linkedSpreadsheetChanged",
        "QModelIndex",
        "spreadsheetRowCountChanged",
        "spreadsheetColumnCountChanged",
        "spreadsheetShowCommentsChanged",
        "spreadsheetShowSparklinesChanged",
        "spreadsheetLinkingChanged",
        "spreadsheetLinkedSpreadsheetChanged",
        "const Spreadsheet*",
        "loadConfigFromTemplate",
        "KConfig&",
        "saveConfigAsTemplate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'info'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'rowCountChanged'
        QtMocHelpers::SlotData<void(int)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'columnCountChanged'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'commentsShownChanged'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'sparklinesShownChanged'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'linkingChanged'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'linkedSpreadsheetChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Slot 'spreadsheetRowCountChanged'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'spreadsheetColumnCountChanged'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'spreadsheetShowCommentsChanged'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'spreadsheetShowSparklinesChanged'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'spreadsheetLinkingChanged'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'spreadsheetLinkedSpreadsheetChanged'
        QtMocHelpers::SlotData<void(const Spreadsheet *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'loadConfigFromTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Slot 'saveConfigAsTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SpreadsheetDock, qt_meta_tag_ZN15SpreadsheetDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SpreadsheetDock::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseDock::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SpreadsheetDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SpreadsheetDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SpreadsheetDockE_t>.metaTypes,
    nullptr
} };

void SpreadsheetDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SpreadsheetDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->rowCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->columnCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->commentsShownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->sparklinesShownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->linkingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->linkedSpreadsheetChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 7: _t->spreadsheetRowCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->spreadsheetColumnCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->spreadsheetShowCommentsChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->spreadsheetShowSparklinesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->spreadsheetLinkingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->spreadsheetLinkedSpreadsheetChanged((*reinterpret_cast<std::add_pointer_t<const Spreadsheet*>>(_a[1]))); break;
        case 13: _t->loadConfigFromTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        case 14: _t->saveConfigAsTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SpreadsheetDock::*)(const QString & )>(_a, &SpreadsheetDock::info, 0))
            return;
    }
}

const QMetaObject *SpreadsheetDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SpreadsheetDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SpreadsheetDockE_t>.strings))
        return static_cast<void*>(this);
    return BaseDock::qt_metacast(_clname);
}

int SpreadsheetDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseDock::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void SpreadsheetDock::info(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
