/********************************************************************************
** Form generated from reading UI file 'PlotTemplateDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLOTTEMPLATEDIALOG_H
#define UI_PLOTTEMPLATEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PlotTemplateDialog
{
public:
    QGridLayout *gridLayout_2;
    QSplitter *splitter;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout;
    QLabel *lInstalledTemplates;
    QListView *lvInstalledTemplates;
    QWidget *layoutWidget1;
    QVBoxLayout *lPreview;
    QLabel *label_2;
    QTextEdit *teMessage;
    QDialogButtonBox *buttonBox;
    QFrame *frame;
    QGridLayout *gridLayout;
    QLabel *lLocation;
    QLabel *lCustomFolder;
    QLineEdit *leCustomFolder;
    QPushButton *pbCustomFolder;
    QComboBox *cbLocation;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *PlotTemplateDialog)
    {
        if (PlotTemplateDialog->objectName().isEmpty())
            PlotTemplateDialog->setObjectName("PlotTemplateDialog");
        PlotTemplateDialog->resize(499, 397);
        gridLayout_2 = new QGridLayout(PlotTemplateDialog);
        gridLayout_2->setObjectName("gridLayout_2");
        splitter = new QSplitter(PlotTemplateDialog);
        splitter->setObjectName("splitter");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(splitter->sizePolicy().hasHeightForWidth());
        splitter->setSizePolicy(sizePolicy);
        splitter->setOrientation(Qt::Horizontal);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName("layoutWidget");
        verticalLayout = new QVBoxLayout(layoutWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        lInstalledTemplates = new QLabel(layoutWidget);
        lInstalledTemplates->setObjectName("lInstalledTemplates");

        verticalLayout->addWidget(lInstalledTemplates);

        lvInstalledTemplates = new QListView(layoutWidget);
        lvInstalledTemplates->setObjectName("lvInstalledTemplates");

        verticalLayout->addWidget(lvInstalledTemplates);

        splitter->addWidget(layoutWidget);
        layoutWidget1 = new QWidget(splitter);
        layoutWidget1->setObjectName("layoutWidget1");
        lPreview = new QVBoxLayout(layoutWidget1);
        lPreview->setObjectName("lPreview");
        lPreview->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(layoutWidget1);
        label_2->setObjectName("label_2");

        lPreview->addWidget(label_2);

        teMessage = new QTextEdit(layoutWidget1);
        teMessage->setObjectName("teMessage");
        teMessage->setReadOnly(true);

        lPreview->addWidget(teMessage);

        splitter->addWidget(layoutWidget1);

        gridLayout_2->addWidget(splitter, 2, 0, 1, 1);

        buttonBox = new QDialogButtonBox(PlotTemplateDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout_2->addWidget(buttonBox, 3, 0, 1, 1);

        frame = new QFrame(PlotTemplateDialog);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Raised);
        gridLayout = new QGridLayout(frame);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        lLocation = new QLabel(frame);
        lLocation->setObjectName("lLocation");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lLocation->sizePolicy().hasHeightForWidth());
        lLocation->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(lLocation, 0, 0, 1, 1);

        lCustomFolder = new QLabel(frame);
        lCustomFolder->setObjectName("lCustomFolder");
        sizePolicy1.setHeightForWidth(lCustomFolder->sizePolicy().hasHeightForWidth());
        lCustomFolder->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(lCustomFolder, 1, 0, 1, 1);

        leCustomFolder = new QLineEdit(frame);
        leCustomFolder->setObjectName("leCustomFolder");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(leCustomFolder->sizePolicy().hasHeightForWidth());
        leCustomFolder->setSizePolicy(sizePolicy2);
        leCustomFolder->setClearButtonEnabled(true);

        gridLayout->addWidget(leCustomFolder, 1, 1, 1, 1);

        pbCustomFolder = new QPushButton(frame);
        pbCustomFolder->setObjectName("pbCustomFolder");

        gridLayout->addWidget(pbCustomFolder, 1, 2, 1, 1);

        cbLocation = new QComboBox(frame);
        cbLocation->setObjectName("cbLocation");
        sizePolicy2.setHeightForWidth(cbLocation->sizePolicy().hasHeightForWidth());
        cbLocation->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(cbLocation, 0, 1, 1, 1);


        gridLayout_2->addWidget(frame, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer, 1, 0, 1, 1);


        retranslateUi(PlotTemplateDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, PlotTemplateDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, PlotTemplateDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(PlotTemplateDialog);
    } // setupUi

    void retranslateUi(QDialog *PlotTemplateDialog)
    {
        PlotTemplateDialog->setWindowTitle(tr2i18n("Dialog", nullptr));
        lInstalledTemplates->setText(tr2i18n("Installed Templates:", nullptr));
        label_2->setText(tr2i18n("Preview:", nullptr));
        lLocation->setText(tr2i18n("Location:", nullptr));
        lCustomFolder->setText(tr2i18n("Folder:", nullptr));
        pbCustomFolder->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class PlotTemplateDialog: public Ui_PlotTemplateDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PLOTTEMPLATEDIALOG_H

