/********************************************************************************
** Form generated from reading UI file 'searchwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHWIDGET_H
#define UI_SEARCHWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ksqueezedtextlabel.h"

QT_BEGIN_NAMESPACE

class Ui_SearchWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QLabel *lFind;
    QComboBox *cbFind;
    QToolButton *tbFindNext;
    QToolButton *tbFindPrev;
    QToolButton *tbMatchCase;
    KSqueezedTextLabel *lStatus;
    QToolButton *tbSwitchFindReplace;
    QPushButton *bCancel;

    void setupUi(QWidget *SearchWidget)
    {
        if (SearchWidget->objectName().isEmpty())
            SearchWidget->setObjectName("SearchWidget");
        SearchWidget->resize(446, 34);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SearchWidget->sizePolicy().hasHeightForWidth());
        SearchWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(SearchWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        lFind = new QLabel(SearchWidget);
        lFind->setObjectName("lFind");
        lFind->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        hboxLayout->addWidget(lFind);

        cbFind = new QComboBox(SearchWidget);
        cbFind->setObjectName("cbFind");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbFind->sizePolicy().hasHeightForWidth());
        cbFind->setSizePolicy(sizePolicy1);
        cbFind->setMouseTracking(false);
        cbFind->setFocusPolicy(Qt::StrongFocus);
        cbFind->setAcceptDrops(true);
        cbFind->setEditable(true);
        cbFind->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        hboxLayout->addWidget(cbFind);

        tbFindNext = new QToolButton(SearchWidget);
        tbFindNext->setObjectName("tbFindNext");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("go-down-search");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        tbFindNext->setIcon(icon);
        tbFindNext->setAutoRaise(true);

        hboxLayout->addWidget(tbFindNext);

        tbFindPrev = new QToolButton(SearchWidget);
        tbFindPrev->setObjectName("tbFindPrev");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("go-up-search");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        tbFindPrev->setIcon(icon1);
        tbFindPrev->setAutoRaise(true);

        hboxLayout->addWidget(tbFindPrev);

        tbMatchCase = new QToolButton(SearchWidget);
        tbMatchCase->setObjectName("tbMatchCase");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("format-text-superscript");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        tbMatchCase->setIcon(icon2);
        tbMatchCase->setCheckable(true);
        tbMatchCase->setAutoRaise(true);

        hboxLayout->addWidget(tbMatchCase);

        lStatus = new KSqueezedTextLabel(SearchWidget);
        lStatus->setObjectName("lStatus");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(lStatus->sizePolicy().hasHeightForWidth());
        lStatus->setSizePolicy(sizePolicy2);
        lStatus->setMinimumSize(QSize(0, 0));
        lStatus->setAlignment(Qt::AlignCenter);
        lStatus->setWordWrap(false);

        hboxLayout->addWidget(lStatus);

        tbSwitchFindReplace = new QToolButton(SearchWidget);
        tbSwitchFindReplace->setObjectName("tbSwitchFindReplace");
        QIcon icon3;
        iconThemeName = QString::fromUtf8("games-config-options");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        tbSwitchFindReplace->setIcon(icon3);
        tbSwitchFindReplace->setCheckable(true);
        tbSwitchFindReplace->setAutoRaise(true);

        hboxLayout->addWidget(tbSwitchFindReplace);

        bCancel = new QPushButton(SearchWidget);
        bCancel->setObjectName("bCancel");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("dialog-close")));
        bCancel->setIcon(icon4);

        hboxLayout->addWidget(bCancel);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        lFind->setBuddy(cbFind);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SearchWidget);

        QMetaObject::connectSlotsByName(SearchWidget);
    } // setupUi

    void retranslateUi(QWidget *SearchWidget)
    {
        lFind->setText(tr2i18n("F&ind:", nullptr));
#if QT_CONFIG(tooltip)
        cbFind->setToolTip(tr2i18n("Text to search for", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tbFindNext->setToolTip(tr2i18n("Jump to next match", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tbFindPrev->setToolTip(tr2i18n("Jump to previous match", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tbMatchCase->setToolTip(tr2i18n("Match case sensitive", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tbSwitchFindReplace->setToolTip(tr2i18n("Switch to power search and replace bar", nullptr));
#endif // QT_CONFIG(tooltip)
        tbSwitchFindReplace->setText(QString());
        bCancel->setText(QString());
        (void)SearchWidget;
    } // retranslateUi

};

namespace Ui {
    class SearchWidget: public Ui_SearchWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEARCHWIDGET_H

