/********************************************************************************
** Form generated from reading UI file 'imagedock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMAGEDOCK_H
#define UI_IMAGEDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_ImageDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    ResizableTextEdit *teComment;
    QLabel *lHorizontalAlignment;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *horizontalSpacer_5;
    QLabel *lWidth;
    QCheckBox *chbEmbedded;
    QLabel *lRotation;
    QComboBox *cbVerticalAlignment;
    QLabel *lPosition;
    QLabel *lPositionXLogicalDateTime;
    QCheckBox *chbVisible;
    TimedLineEdit *leName;
    QLabel *lOpacity;
    QLabel *lPositionY;
    QLabel *lFileName;
    QHBoxLayout *horizontalLayout_6;
    QComboBox *cbPositionX;
    NumberSpinBox *sbPositionX;
    QLabel *lPositionYLogical;
    NumberSpinBox *sbPositionYLogical;
    QLabel *lPositionXLogical;
    QCheckBox *chbBindLogicalPos;
    QLabel *lPositionX;
    NumberSpinBox *sbHeight;
    QSpacerItem *verticalSpacer_2;
    NumberSpinBox *sbWidth;
    QHBoxLayout *horizontalLayout_5;
    QComboBox *cbPositionY;
    NumberSpinBox *sbPositionY;
    QLabel *lEmbedded;
    QLabel *lName;
    QLabel *lVerticalAlignment;
    QLabel *lComment;
    QComboBox *cbHorizontalAlignment;
    QSpinBox *sbRotation;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QLineEdit *leFileName;
    QPushButton *bOpen;
    QLabel *lRatio;
    QSpinBox *sbOpacity;
    UTCDateTimeEdit *dtePositionXLogical;
    QLabel *lSize;
    QSpacerItem *verticalSpacer_4;
    QCheckBox *chbKeepRatio;
    QLabel *lHeight;
    NumberSpinBox *sbPositionXLogical;
    QCheckBox *chbLock;
    QWidget *tabBorder;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer_5;

    void setupUi(QWidget *ImageDock)
    {
        if (ImageDock->objectName().isEmpty())
            ImageDock->setObjectName("ImageDock");
        ImageDock->resize(434, 874);
        verticalLayout = new QVBoxLayout(ImageDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(ImageDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setObjectName("gridLayout");
        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        lHorizontalAlignment = new QLabel(tabGeneral);
        lHorizontalAlignment->setObjectName("lHorizontalAlignment");

        gridLayout->addWidget(lHorizontalAlignment, 18, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(58, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 2, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        lWidth = new QLabel(tabGeneral);
        lWidth->setObjectName("lWidth");

        gridLayout->addWidget(lWidth, 8, 0, 1, 1);

        chbEmbedded = new QCheckBox(tabGeneral);
        chbEmbedded->setObjectName("chbEmbedded");

        gridLayout->addWidget(chbEmbedded, 4, 2, 1, 1);

        lRotation = new QLabel(tabGeneral);
        lRotation->setObjectName("lRotation");

        gridLayout->addWidget(lRotation, 20, 0, 1, 1);

        cbVerticalAlignment = new QComboBox(tabGeneral);
        cbVerticalAlignment->setObjectName("cbVerticalAlignment");

        gridLayout->addWidget(cbVerticalAlignment, 19, 2, 1, 1);

        lPosition = new QLabel(tabGeneral);
        lPosition->setObjectName("lPosition");
        QFont font;
        font.setBold(true);
        lPosition->setFont(font);

        gridLayout->addWidget(lPosition, 12, 0, 1, 1);

        lPositionXLogicalDateTime = new QLabel(tabGeneral);
        lPositionXLogicalDateTime->setObjectName("lPositionXLogicalDateTime");

        gridLayout->addWidget(lPositionXLogicalDateTime, 16, 0, 1, 1);

        chbVisible = new QCheckBox(tabGeneral);
        chbVisible->setObjectName("chbVisible");

        gridLayout->addWidget(chbVisible, 23, 0, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        lOpacity = new QLabel(tabGeneral);
        lOpacity->setObjectName("lOpacity");

        gridLayout->addWidget(lOpacity, 5, 0, 1, 1);

        lPositionY = new QLabel(tabGeneral);
        lPositionY->setObjectName("lPositionY");

        gridLayout->addWidget(lPositionY, 14, 0, 1, 1);

        lFileName = new QLabel(tabGeneral);
        lFileName->setObjectName("lFileName");

        gridLayout->addWidget(lFileName, 3, 0, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        cbPositionX = new QComboBox(tabGeneral);
        cbPositionX->setObjectName("cbPositionX");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbPositionX->sizePolicy().hasHeightForWidth());
        cbPositionX->setSizePolicy(sizePolicy);

        horizontalLayout_6->addWidget(cbPositionX);

        sbPositionX = new NumberSpinBox(tabGeneral);
        sbPositionX->setObjectName("sbPositionX");
        sizePolicy.setHeightForWidth(sbPositionX->sizePolicy().hasHeightForWidth());
        sbPositionX->setSizePolicy(sizePolicy);
        sbPositionX->setProperty("feedback", QVariant(true));

        horizontalLayout_6->addWidget(sbPositionX);


        gridLayout->addLayout(horizontalLayout_6, 13, 2, 1, 1);

        lPositionYLogical = new QLabel(tabGeneral);
        lPositionYLogical->setObjectName("lPositionYLogical");

        gridLayout->addWidget(lPositionYLogical, 17, 0, 1, 1);

        sbPositionYLogical = new NumberSpinBox(tabGeneral);
        sbPositionYLogical->setObjectName("sbPositionYLogical");
        sizePolicy.setHeightForWidth(sbPositionYLogical->sizePolicy().hasHeightForWidth());
        sbPositionYLogical->setSizePolicy(sizePolicy);
        sbPositionYLogical->setProperty("feedback", QVariant(false));

        gridLayout->addWidget(sbPositionYLogical, 17, 2, 1, 1);

        lPositionXLogical = new QLabel(tabGeneral);
        lPositionXLogical->setObjectName("lPositionXLogical");

        gridLayout->addWidget(lPositionXLogical, 15, 0, 1, 1);

        chbBindLogicalPos = new QCheckBox(tabGeneral);
        chbBindLogicalPos->setObjectName("chbBindLogicalPos");

        gridLayout->addWidget(chbBindLogicalPos, 12, 2, 1, 1);

        lPositionX = new QLabel(tabGeneral);
        lPositionX->setObjectName("lPositionX");

        gridLayout->addWidget(lPositionX, 13, 0, 1, 1);

        sbHeight = new NumberSpinBox(tabGeneral);
        sbHeight->setObjectName("sbHeight");
        sizePolicy.setHeightForWidth(sbHeight->sizePolicy().hasHeightForWidth());
        sbHeight->setSizePolicy(sizePolicy);
        sbHeight->setMinimum(0.000000000000000);
        sbHeight->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbHeight, 9, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 11, 0, 1, 1);

        sbWidth = new NumberSpinBox(tabGeneral);
        sbWidth->setObjectName("sbWidth");
        sizePolicy.setHeightForWidth(sbWidth->sizePolicy().hasHeightForWidth());
        sbWidth->setSizePolicy(sizePolicy);
        sbWidth->setMinimum(0.000000000000000);
        sbWidth->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbWidth, 8, 2, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        cbPositionY = new QComboBox(tabGeneral);
        cbPositionY->setObjectName("cbPositionY");
        sizePolicy.setHeightForWidth(cbPositionY->sizePolicy().hasHeightForWidth());
        cbPositionY->setSizePolicy(sizePolicy);

        horizontalLayout_5->addWidget(cbPositionY);

        sbPositionY = new NumberSpinBox(tabGeneral);
        sbPositionY->setObjectName("sbPositionY");
        sizePolicy.setHeightForWidth(sbPositionY->sizePolicy().hasHeightForWidth());
        sbPositionY->setSizePolicy(sizePolicy);
        sbPositionY->setProperty("feedback", QVariant(true));

        horizontalLayout_5->addWidget(sbPositionY);


        gridLayout->addLayout(horizontalLayout_5, 14, 2, 1, 1);

        lEmbedded = new QLabel(tabGeneral);
        lEmbedded->setObjectName("lEmbedded");

        gridLayout->addWidget(lEmbedded, 4, 0, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lName->sizePolicy().hasHeightForWidth());
        lName->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        lVerticalAlignment = new QLabel(tabGeneral);
        lVerticalAlignment->setObjectName("lVerticalAlignment");

        gridLayout->addWidget(lVerticalAlignment, 19, 0, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        sizePolicy1.setHeightForWidth(lComment->sizePolicy().hasHeightForWidth());
        lComment->setSizePolicy(sizePolicy1);
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        cbHorizontalAlignment = new QComboBox(tabGeneral);
        cbHorizontalAlignment->setObjectName("cbHorizontalAlignment");

        gridLayout->addWidget(cbHorizontalAlignment, 18, 2, 1, 1);

        sbRotation = new QSpinBox(tabGeneral);
        sbRotation->setObjectName("sbRotation");
        sbRotation->setMinimum(-360);
        sbRotation->setMaximum(360);
        sbRotation->setSingleStep(5);

        gridLayout->addWidget(sbRotation, 20, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 128, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 21, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        leFileName = new QLineEdit(tabGeneral);
        leFileName->setObjectName("leFileName");
        leFileName->setClearButtonEnabled(true);

        horizontalLayout->addWidget(leFileName);

        bOpen = new QPushButton(tabGeneral);
        bOpen->setObjectName("bOpen");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(bOpen->sizePolicy().hasHeightForWidth());
        bOpen->setSizePolicy(sizePolicy2);

        horizontalLayout->addWidget(bOpen);


        gridLayout->addLayout(horizontalLayout, 3, 2, 1, 1);

        lRatio = new QLabel(tabGeneral);
        lRatio->setObjectName("lRatio");

        gridLayout->addWidget(lRatio, 10, 0, 1, 1);

        sbOpacity = new QSpinBox(tabGeneral);
        sbOpacity->setObjectName("sbOpacity");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(sbOpacity->sizePolicy().hasHeightForWidth());
        sbOpacity->setSizePolicy(sizePolicy3);
        sbOpacity->setMinimum(0);
        sbOpacity->setMaximum(100);
        sbOpacity->setSingleStep(10);
        sbOpacity->setValue(100);

        gridLayout->addWidget(sbOpacity, 5, 2, 1, 1);

        dtePositionXLogical = new UTCDateTimeEdit(tabGeneral);
        dtePositionXLogical->setObjectName("dtePositionXLogical");

        gridLayout->addWidget(dtePositionXLogical, 16, 2, 1, 1);

        lSize = new QLabel(tabGeneral);
        lSize->setObjectName("lSize");
        lSize->setFont(font);

        gridLayout->addWidget(lSize, 7, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(58, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 6, 0, 1, 1);

        chbKeepRatio = new QCheckBox(tabGeneral);
        chbKeepRatio->setObjectName("chbKeepRatio");
        chbKeepRatio->setChecked(true);

        gridLayout->addWidget(chbKeepRatio, 10, 2, 1, 1);

        lHeight = new QLabel(tabGeneral);
        lHeight->setObjectName("lHeight");

        gridLayout->addWidget(lHeight, 9, 0, 1, 1);

        sbPositionXLogical = new NumberSpinBox(tabGeneral);
        sbPositionXLogical->setObjectName("sbPositionXLogical");
        sizePolicy.setHeightForWidth(sbPositionXLogical->sizePolicy().hasHeightForWidth());
        sbPositionXLogical->setSizePolicy(sizePolicy);
        sbPositionXLogical->setProperty("feedback", QVariant(false));

        gridLayout->addWidget(sbPositionXLogical, 15, 2, 1, 1);

        chbLock = new QCheckBox(tabGeneral);
        chbLock->setObjectName("chbLock");

        gridLayout->addWidget(chbLock, 22, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabBorder = new QWidget();
        tabBorder->setObjectName("tabBorder");
        verticalLayout_2 = new QVBoxLayout(tabBorder);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalSpacer_5 = new QSpacerItem(20, 695, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_5);

        tabWidget->addTab(tabBorder, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, leFileName);
        QWidget::setTabOrder(leFileName, bOpen);
        QWidget::setTabOrder(bOpen, chbEmbedded);
        QWidget::setTabOrder(chbEmbedded, sbOpacity);
        QWidget::setTabOrder(sbOpacity, sbWidth);
        QWidget::setTabOrder(sbWidth, sbHeight);
        QWidget::setTabOrder(sbHeight, chbKeepRatio);
        QWidget::setTabOrder(chbKeepRatio, chbBindLogicalPos);
        QWidget::setTabOrder(chbBindLogicalPos, cbPositionX);
        QWidget::setTabOrder(cbPositionX, sbPositionX);
        QWidget::setTabOrder(sbPositionX, cbPositionY);
        QWidget::setTabOrder(cbPositionY, sbPositionY);
        QWidget::setTabOrder(sbPositionY, sbPositionXLogical);
        QWidget::setTabOrder(sbPositionXLogical, dtePositionXLogical);
        QWidget::setTabOrder(dtePositionXLogical, sbPositionYLogical);
        QWidget::setTabOrder(sbPositionYLogical, cbHorizontalAlignment);
        QWidget::setTabOrder(cbHorizontalAlignment, cbVerticalAlignment);
        QWidget::setTabOrder(cbVerticalAlignment, sbRotation);
        QWidget::setTabOrder(sbRotation, chbLock);
        QWidget::setTabOrder(chbLock, chbVisible);

        retranslateUi(ImageDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ImageDock);
    } // setupUi

    void retranslateUi(QWidget *ImageDock)
    {
        lHorizontalAlignment->setText(tr2i18n("Hor. align.:", nullptr));
        lWidth->setText(tr2i18n("Width:", nullptr));
        chbEmbedded->setText(QString());
        lRotation->setText(tr2i18n("Rotation:", nullptr));
        lPosition->setText(tr2i18n("Position", nullptr));
        lPositionXLogicalDateTime->setText(tr2i18n("x:", nullptr));
        chbVisible->setText(tr2i18n("Visible", nullptr));
        lOpacity->setText(tr2i18n("Opacity:", nullptr));
#if QT_CONFIG(tooltip)
        lPositionY->setToolTip(tr2i18n("Vertical position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
        lPositionY->setText(tr2i18n("Position Y:", nullptr));
        lFileName->setText(tr2i18n("File name:", nullptr));
#if QT_CONFIG(tooltip)
        cbPositionX->setToolTip(tr2i18n("Horizontal position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        sbPositionX->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionX->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbPositionX->setSuffix(tr2i18n(" cm", nullptr));
        lPositionYLogical->setText(tr2i18n("Y:", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionYLogical->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionYLogical->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lPositionXLogical->setText(tr2i18n("X:", nullptr));
        chbBindLogicalPos->setText(tr2i18n("Logical Coordinates", nullptr));
#if QT_CONFIG(tooltip)
        lPositionX->setToolTip(tr2i18n("Horizontal position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
        lPositionX->setText(tr2i18n("Position X:", nullptr));
#if QT_CONFIG(tooltip)
        sbHeight->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbHeight->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbHeight->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        sbWidth->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbWidth->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbWidth->setSuffix(tr2i18n(" cm", nullptr));
#if QT_CONFIG(tooltip)
        cbPositionY->setToolTip(tr2i18n("Vertical position relative to label's parent", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        sbPositionY->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionY->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbPositionY->setSuffix(tr2i18n(" cm", nullptr));
        lEmbedded->setText(tr2i18n("Embedded:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lVerticalAlignment->setText(tr2i18n("Vert. align.:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        sbRotation->setSuffix(tr2i18n("\302\260", nullptr));
#if QT_CONFIG(tooltip)
        leFileName->setToolTip(tr2i18n("Specify the name of the image file", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        bOpen->setToolTip(tr2i18n(" Select the image file", nullptr));
#endif // QT_CONFIG(tooltip)
        bOpen->setText(QString());
        lRatio->setText(tr2i18n("Keep Ratio:", nullptr));
#if QT_CONFIG(tooltip)
        sbOpacity->setToolTip(tr2i18n("The opacity ranges from 0 to 100, where 0 is fully transparent and 100 is fully opaque.", nullptr));
#endif // QT_CONFIG(tooltip)
        sbOpacity->setSuffix(tr2i18n(" %", nullptr));
        lSize->setText(tr2i18n("Size", nullptr));
        chbKeepRatio->setText(QString());
        lHeight->setText(tr2i18n("Height:", nullptr));
#if QT_CONFIG(tooltip)
        sbPositionXLogical->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPositionXLogical->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chbLock->setText(tr2i18n("Locked", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabBorder), tr2i18n("Border", nullptr));
        (void)ImageDock;
    } // retranslateUi

};

namespace Ui {
    class ImageDock: public Ui_ImageDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMAGEDOCK_H

