/********************************************************************************
** Form generated from reading UI file 'notedock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NOTEDOCK_H
#define UI_NOTEDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcolorbutton.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_NoteDock
{
public:
    QGridLayout *gridLayout;
    QLabel *lName;
    QSpacerItem *horizontalSpacer_5;
    TimedLineEdit *leName;
    QLabel *lComment;
    ResizableTextEdit *teComment;
    QSpacerItem *verticalSpacer_8;
    QLabel *bgcolor;
    KColorButton *kcbBgColor;
    QLabel *textcolor;
    KColorButton *kcbTextColor;
    QLabel *lLabelsFont;
    KFontRequester *kfrTextFont;
    QSpacerItem *verticalSpacerGeneral;

    void setupUi(QWidget *NoteDock)
    {
        if (NoteDock->objectName().isEmpty())
            NoteDock->setObjectName("NoteDock");
        NoteDock->resize(326, 386);
        gridLayout = new QGridLayout(NoteDock);
        gridLayout->setObjectName("gridLayout");
        lName = new QLabel(NoteDock);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 2);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 2, 1, 1);

        leName = new TimedLineEdit(NoteDock);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 3, 1, 1);

        lComment = new QLabel(NoteDock);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 2);

        teComment = new ResizableTextEdit(NoteDock);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 3, 1, 1);

        verticalSpacer_8 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_8, 2, 1, 1, 1);

        bgcolor = new QLabel(NoteDock);
        bgcolor->setObjectName("bgcolor");

        gridLayout->addWidget(bgcolor, 3, 0, 1, 2);

        kcbBgColor = new KColorButton(NoteDock);
        kcbBgColor->setObjectName("kcbBgColor");

        gridLayout->addWidget(kcbBgColor, 3, 3, 1, 1);

        textcolor = new QLabel(NoteDock);
        textcolor->setObjectName("textcolor");

        gridLayout->addWidget(textcolor, 4, 0, 1, 2);

        kcbTextColor = new KColorButton(NoteDock);
        kcbTextColor->setObjectName("kcbTextColor");

        gridLayout->addWidget(kcbTextColor, 4, 3, 1, 1);

        lLabelsFont = new QLabel(NoteDock);
        lLabelsFont->setObjectName("lLabelsFont");

        gridLayout->addWidget(lLabelsFont, 5, 0, 1, 2);

        kfrTextFont = new KFontRequester(NoteDock);
        kfrTextFont->setObjectName("kfrTextFont");

        gridLayout->addWidget(kfrTextFont, 5, 3, 1, 1);

        verticalSpacerGeneral = new QSpacerItem(24, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout->addItem(verticalSpacerGeneral, 6, 0, 1, 1);


        retranslateUi(NoteDock);

        QMetaObject::connectSlotsByName(NoteDock);
    } // setupUi

    void retranslateUi(QWidget *NoteDock)
    {
        lName->setText(tr2i18n("Name:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        bgcolor->setText(tr2i18n("Background color:", nullptr));
        textcolor->setText(tr2i18n("Text color:", nullptr));
        lLabelsFont->setText(tr2i18n("Font:", nullptr));
        (void)NoteDock;
    } // retranslateUi

};

namespace Ui {
    class NoteDock: public Ui_NoteDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NOTEDOCK_H

