/****************************************************************************
** Meta object code from reading C++ file 'qxtspanslider.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/widgets/qxtspanslider.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qxtspanslider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10SpanSliderE_t {};
} // unnamed namespace

template <> constexpr inline auto SpanSlider::qt_create_metaobjectdata<qt_meta_tag_ZN10SpanSliderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SpanSlider",
        "spanChanged",
        "",
        "lower",
        "upper",
        "sliderSpanChanged",
        "spinBoxMinChanged",
        "spinBoxMaxChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'spanChanged'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'sliderSpanChanged'
        QtMocHelpers::SlotData<void(int, int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'spinBoxMinChanged'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'spinBoxMaxChanged'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SpanSlider, qt_meta_tag_ZN10SpanSliderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SpanSlider::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10SpanSliderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10SpanSliderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10SpanSliderE_t>.metaTypes,
    nullptr
} };

void SpanSlider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SpanSlider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->spanChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->sliderSpanChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->spinBoxMinChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->spinBoxMaxChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SpanSlider::*)(int , int )>(_a, &SpanSlider::spanChanged, 0))
            return;
    }
}

const QMetaObject *SpanSlider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SpanSlider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10SpanSliderE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int SpanSlider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void SpanSlider::spanChanged(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN13QxtSpanSliderE_t {};
} // unnamed namespace

template <> constexpr inline auto QxtSpanSlider::qt_create_metaobjectdata<qt_meta_tag_ZN13QxtSpanSliderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QxtSpanSlider",
        "spanChanged",
        "",
        "lower",
        "upper",
        "lowerValueChanged",
        "upperValueChanged",
        "lowerPositionChanged",
        "upperPositionChanged",
        "sliderPressed",
        "QxtSpanSlider::SpanHandle",
        "setLowerValue",
        "setUpperValue",
        "setSpan",
        "setLowerPosition",
        "setUpperPosition",
        "lowerValue",
        "upperValue",
        "lowerPosition",
        "upperPosition",
        "handleMovementMode",
        "HandleMovementMode",
        "FreeMovement",
        "NoCrossing",
        "NoOverlapping",
        "SpanHandle",
        "NoHandle",
        "LowerHandle",
        "UpperHandle"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'spanChanged'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'lowerValueChanged'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'upperValueChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'lowerPositionChanged'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'upperPositionChanged'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'sliderPressed'
        QtMocHelpers::SignalData<void(QxtSpanSlider::SpanHandle)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'setLowerValue'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setUpperValue'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'setSpan'
        QtMocHelpers::SlotData<void(int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'setLowerPosition'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setUpperPosition'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lowerValue'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'upperValue'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'lowerPosition'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'upperPosition'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'handleMovementMode'
        QtMocHelpers::PropertyData<enum HandleMovementMode>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'HandleMovementMode'
        QtMocHelpers::EnumData<enum HandleMovementMode>(21, 21, QMC::EnumFlags{}).add({
            {   22, HandleMovementMode::FreeMovement },
            {   23, HandleMovementMode::NoCrossing },
            {   24, HandleMovementMode::NoOverlapping },
        }),
        // enum 'SpanHandle'
        QtMocHelpers::EnumData<enum SpanHandle>(25, 25, QMC::EnumFlags{}).add({
            {   26, SpanHandle::NoHandle },
            {   27, SpanHandle::LowerHandle },
            {   28, SpanHandle::UpperHandle },
        }),
    };
    return QtMocHelpers::metaObjectData<QxtSpanSlider, qt_meta_tag_ZN13QxtSpanSliderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QxtSpanSlider::staticMetaObject = { {
    QMetaObject::SuperData::link<QSlider::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QxtSpanSliderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QxtSpanSliderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QxtSpanSliderE_t>.metaTypes,
    nullptr
} };

void QxtSpanSlider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QxtSpanSlider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->spanChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->lowerValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->upperValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->lowerPositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->upperPositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->sliderPressed((*reinterpret_cast<std::add_pointer_t<QxtSpanSlider::SpanHandle>>(_a[1]))); break;
        case 6: _t->setLowerValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->setUpperValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setSpan((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->setLowerPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->setUpperPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QxtSpanSlider::*)(int , int )>(_a, &QxtSpanSlider::spanChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QxtSpanSlider::*)(int )>(_a, &QxtSpanSlider::lowerValueChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QxtSpanSlider::*)(int )>(_a, &QxtSpanSlider::upperValueChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QxtSpanSlider::*)(int )>(_a, &QxtSpanSlider::lowerPositionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QxtSpanSlider::*)(int )>(_a, &QxtSpanSlider::upperPositionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QxtSpanSlider::*)(QxtSpanSlider::SpanHandle )>(_a, &QxtSpanSlider::sliderPressed, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->lowerValue(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->upperValue(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->lowerPosition(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->upperPosition(); break;
        case 4: *reinterpret_cast<enum HandleMovementMode*>(_v) = _t->handleMovementMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLowerValue(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setUpperValue(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setLowerPosition(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setUpperPosition(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setHandleMovementMode(*reinterpret_cast<enum HandleMovementMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QxtSpanSlider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QxtSpanSlider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QxtSpanSliderE_t>.strings))
        return static_cast<void*>(this);
    return QSlider::qt_metacast(_clname);
}

int QxtSpanSlider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSlider::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void QxtSpanSlider::spanChanged(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void QxtSpanSlider::lowerValueChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QxtSpanSlider::upperValueChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QxtSpanSlider::lowerPositionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QxtSpanSlider::upperPositionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QxtSpanSlider::sliderPressed(QxtSpanSlider::SpanHandle _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
