/********************************************************************************
** Form generated from reading UI file 'mqttsubscriptionwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MQTTSUBSCRIPTIONWIDGET_H
#define UI_MQTTSUBSCRIPTIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MQTTSubscriptionWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *gbManageSubscriptions;
    QGridLayout *gridLayout_6;
    QLabel *lTopicSearch;
    QLineEdit *leSubscriptions;
    QTreeWidget *twSubscriptions;
    QVBoxLayout *verticalLayout_5;
    QSpacerItem *verticalSpacer_5;
    QPushButton *bSubscribe;
    QPushButton *bUnsubscribe;
    QSpacerItem *verticalSpacer_3;
    QComboBox *cbQos;
    QLineEdit *leTopics;
    QLabel *lSubscriptionSearch;
    QTreeWidget *twTopics;

    void setupUi(QWidget *MQTTSubscriptionWidget)
    {
        if (MQTTSubscriptionWidget->objectName().isEmpty())
            MQTTSubscriptionWidget->setObjectName("MQTTSubscriptionWidget");
        MQTTSubscriptionWidget->resize(762, 362);
        gridLayout = new QGridLayout(MQTTSubscriptionWidget);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gbManageSubscriptions = new QGroupBox(MQTTSubscriptionWidget);
        gbManageSubscriptions->setObjectName("gbManageSubscriptions");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(gbManageSubscriptions->sizePolicy().hasHeightForWidth());
        gbManageSubscriptions->setSizePolicy(sizePolicy);
        gbManageSubscriptions->setFlat(true);
        gridLayout_6 = new QGridLayout(gbManageSubscriptions);
        gridLayout_6->setSpacing(0);
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setContentsMargins(0, 0, 0, 0);
        lTopicSearch = new QLabel(gbManageSubscriptions);
        lTopicSearch->setObjectName("lTopicSearch");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lTopicSearch->sizePolicy().hasHeightForWidth());
        lTopicSearch->setSizePolicy(sizePolicy1);
        lTopicSearch->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_6->addWidget(lTopicSearch, 1, 0, 1, 1);

        leSubscriptions = new QLineEdit(gbManageSubscriptions);
        leSubscriptions->setObjectName("leSubscriptions");
        leSubscriptions->setClearButtonEnabled(true);

        gridLayout_6->addWidget(leSubscriptions, 1, 4, 1, 1);

        twSubscriptions = new QTreeWidget(gbManageSubscriptions);
        twSubscriptions->setObjectName("twSubscriptions");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(twSubscriptions->sizePolicy().hasHeightForWidth());
        twSubscriptions->setSizePolicy(sizePolicy2);

        gridLayout_6->addWidget(twSubscriptions, 0, 3, 1, 2);

        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setSpacing(12);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(6, 6, 6, -1);
        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_5);

        bSubscribe = new QPushButton(gbManageSubscriptions);
        bSubscribe->setObjectName("bSubscribe");

        verticalLayout_5->addWidget(bSubscribe);

        bUnsubscribe = new QPushButton(gbManageSubscriptions);
        bUnsubscribe->setObjectName("bUnsubscribe");

        verticalLayout_5->addWidget(bUnsubscribe);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_3);

        cbQos = new QComboBox(gbManageSubscriptions);
        cbQos->addItem(QString());
        cbQos->addItem(QString());
        cbQos->addItem(QString());
        cbQos->setObjectName("cbQos");

        verticalLayout_5->addWidget(cbQos);

        verticalLayout_5->setStretch(1, 1);
        verticalLayout_5->setStretch(2, 1);

        gridLayout_6->addLayout(verticalLayout_5, 0, 2, 1, 1);

        leTopics = new QLineEdit(gbManageSubscriptions);
        leTopics->setObjectName("leTopics");
        leTopics->setClearButtonEnabled(true);

        gridLayout_6->addWidget(leTopics, 1, 1, 1, 1);

        lSubscriptionSearch = new QLabel(gbManageSubscriptions);
        lSubscriptionSearch->setObjectName("lSubscriptionSearch");
        sizePolicy1.setHeightForWidth(lSubscriptionSearch->sizePolicy().hasHeightForWidth());
        lSubscriptionSearch->setSizePolicy(sizePolicy1);

        gridLayout_6->addWidget(lSubscriptionSearch, 1, 3, 1, 1);

        twTopics = new QTreeWidget(gbManageSubscriptions);
        twTopics->setObjectName("twTopics");
        sizePolicy2.setHeightForWidth(twTopics->sizePolicy().hasHeightForWidth());
        twTopics->setSizePolicy(sizePolicy2);

        gridLayout_6->addWidget(twTopics, 0, 0, 1, 2);


        gridLayout->addWidget(gbManageSubscriptions, 0, 0, 1, 1);


        retranslateUi(MQTTSubscriptionWidget);

        QMetaObject::connectSlotsByName(MQTTSubscriptionWidget);
    } // setupUi

    void retranslateUi(QWidget *MQTTSubscriptionWidget)
    {
        gbManageSubscriptions->setTitle(QString());
        lTopicSearch->setText(QString());
        QTreeWidgetItem *___qtreewidgetitem = twSubscriptions->headerItem();
        ___qtreewidgetitem->setText(0, tr2i18n("Subscribed", nullptr));
        bSubscribe->setText(QString());
        bUnsubscribe->setText(QString());
        cbQos->setItemText(0, tr2i18n("QoS 0", nullptr));
        cbQos->setItemText(1, tr2i18n("QoS 1", nullptr));
        cbQos->setItemText(2, tr2i18n("QoS 2", nullptr));

        lSubscriptionSearch->setText(QString());
        QTreeWidgetItem *___qtreewidgetitem1 = twTopics->headerItem();
        ___qtreewidgetitem1->setText(0, tr2i18n("Available", nullptr));
        (void)MQTTSubscriptionWidget;
    } // retranslateUi

};

namespace Ui {
    class MQTTSubscriptionWidget: public Ui_MQTTSubscriptionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MQTTSUBSCRIPTIONWIDGET_H

