/********************************************************************************
** Form generated from reading UI file 'linewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LINEWIDGET_H
#define UI_LINEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "kcolorbutton.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_LineWidget
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    KColorButton *kcbColor;
    KComboBox *cbStyle;
    QLabel *lWidth;
    QLabel *lStyle;
    QLabel *lType;
    QLabel *lColor;
    QSpinBox *sbOpacity;
    QLabel *lOpacity;
    NumberSpinBox *sbWidth;
    KComboBox *cbType;

    void setupUi(QWidget *LineWidget)
    {
        if (LineWidget->objectName().isEmpty())
            LineWidget->setObjectName("LineWidget");
        LineWidget->resize(238, 167);
        gridLayout = new QGridLayout(LineWidget);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 1, 1, 1);

        kcbColor = new KColorButton(LineWidget);
        kcbColor->setObjectName("kcbColor");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcbColor->sizePolicy().hasHeightForWidth());
        kcbColor->setSizePolicy(sizePolicy);

        gridLayout->addWidget(kcbColor, 2, 2, 1, 1);

        cbStyle = new KComboBox(LineWidget);
        cbStyle->setObjectName("cbStyle");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbStyle->sizePolicy().hasHeightForWidth());
        cbStyle->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbStyle, 1, 2, 1, 1);

        lWidth = new QLabel(LineWidget);
        lWidth->setObjectName("lWidth");

        gridLayout->addWidget(lWidth, 3, 0, 1, 1);

        lStyle = new QLabel(LineWidget);
        lStyle->setObjectName("lStyle");

        gridLayout->addWidget(lStyle, 1, 0, 1, 1);

        lType = new QLabel(LineWidget);
        lType->setObjectName("lType");

        gridLayout->addWidget(lType, 0, 0, 1, 1);

        lColor = new QLabel(LineWidget);
        lColor->setObjectName("lColor");

        gridLayout->addWidget(lColor, 2, 0, 1, 1);

        sbOpacity = new QSpinBox(LineWidget);
        sbOpacity->setObjectName("sbOpacity");
        sizePolicy.setHeightForWidth(sbOpacity->sizePolicy().hasHeightForWidth());
        sbOpacity->setSizePolicy(sizePolicy);
        sbOpacity->setMinimum(0);
        sbOpacity->setMaximum(100);
        sbOpacity->setSingleStep(10);
        sbOpacity->setValue(100);

        gridLayout->addWidget(sbOpacity, 4, 2, 1, 1);

        lOpacity = new QLabel(LineWidget);
        lOpacity->setObjectName("lOpacity");

        gridLayout->addWidget(lOpacity, 4, 0, 1, 1);

        sbWidth = new NumberSpinBox(LineWidget);
        sbWidth->setObjectName("sbWidth");
        sizePolicy1.setHeightForWidth(sbWidth->sizePolicy().hasHeightForWidth());
        sbWidth->setSizePolicy(sizePolicy1);
        sbWidth->setMinimum(0.000000000000000);
        sbWidth->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbWidth, 3, 2, 1, 1);

        cbType = new KComboBox(LineWidget);
        cbType->setObjectName("cbType");
        sizePolicy1.setHeightForWidth(cbType->sizePolicy().hasHeightForWidth());
        cbType->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbType, 0, 2, 1, 1);

        QWidget::setTabOrder(cbType, cbStyle);
        QWidget::setTabOrder(cbStyle, kcbColor);
        QWidget::setTabOrder(kcbColor, sbWidth);
        QWidget::setTabOrder(sbWidth, sbOpacity);

        retranslateUi(LineWidget);

        QMetaObject::connectSlotsByName(LineWidget);
    } // setupUi

    void retranslateUi(QWidget *LineWidget)
    {
        LineWidget->setWindowTitle(tr2i18n("Form", nullptr));
        lWidth->setText(tr2i18n("Width:", nullptr));
        lStyle->setText(tr2i18n("Style:", nullptr));
        lType->setText(tr2i18n("Type:", nullptr));
        lColor->setText(tr2i18n("Color:", nullptr));
#if QT_CONFIG(tooltip)
        sbOpacity->setToolTip(tr2i18n("The opacity ranges from 0 to 100, where 0 is fully transparent and 100 is fully opaque.", nullptr));
#endif // QT_CONFIG(tooltip)
        sbOpacity->setSuffix(tr2i18n(" %", nullptr));
        lOpacity->setText(tr2i18n("Opacity:", nullptr));
#if QT_CONFIG(tooltip)
        sbWidth->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbWidth->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbWidth->setSuffix(tr2i18n(" pt", nullptr));
    } // retranslateUi

};

namespace Ui {
    class LineWidget: public Ui_LineWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LINEWIDGET_H

