/****************************************************************************
** Meta object code from reading C++ file 'ProcessBehaviorChart.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/plots/cartesian/ProcessBehaviorChart.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ProcessBehaviorChart.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20ProcessBehaviorChartE_t {};
} // unnamed namespace

template <> constexpr inline auto ProcessBehaviorChart::qt_create_metaobjectdata<qt_meta_tag_ZN20ProcessBehaviorChartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProcessBehaviorChart",
        "recalculated",
        "",
        "typeChanged",
        "ProcessBehaviorChart::Type",
        "limitsMetricChanged",
        "ProcessBehaviorChart::LimitsMetric",
        "dataDataChanged",
        "data2DataChanged",
        "dataColumnChanged",
        "const AbstractColumn*",
        "data2ColumnChanged",
        "sampleSizeChanged",
        "exactLimitsEnabledChanged",
        "limitConstraintsChanged",
        "maxUpperLimitChanged",
        "minLowerLimitChanged",
        "labelsEnabledChanged",
        "labelsAutoPrecisionChanged",
        "labelsPrecisionChanged",
        "labelsFontChanged",
        "QFont",
        "labelsFontColorChanged",
        "QColor",
        "labelsBackgroundColorChanged",
        "labelsBorderShapeChanged",
        "TextLabel::BorderShape",
        "dataColumnAboutToBeRemoved",
        "const AbstractAspect*",
        "data2ColumnAboutToBeRemoved",
        "renameInternalCurves",
        "labelsBorderStyleChanged",
        "Qt::PenStyle",
        "labelsBorderWidthChanged",
        "labelsBorderColorChanged",
        "labelsBorderOpacityChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'recalculated'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(ProcessBehaviorChart::Type)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'limitsMetricChanged'
        QtMocHelpers::SignalData<void(ProcessBehaviorChart::LimitsMetric)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'dataDataChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'data2DataChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'data2ColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'sampleSizeChanged'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'exactLimitsEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'limitConstraintsChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxUpperLimitChanged'
        QtMocHelpers::SignalData<void(double)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'minLowerLimitChanged'
        QtMocHelpers::SignalData<void(double)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'labelsEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'labelsAutoPrecisionChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'labelsPrecisionChanged'
        QtMocHelpers::SignalData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'labelsFontChanged'
        QtMocHelpers::SignalData<void(const QFont)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Signal 'labelsFontColorChanged'
        QtMocHelpers::SignalData<void(const QColor)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 2 },
        }}),
        // Signal 'labelsBackgroundColorChanged'
        QtMocHelpers::SignalData<void(const QColor)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 2 },
        }}),
        // Signal 'labelsBorderShapeChanged'
        QtMocHelpers::SignalData<void(TextLabel::BorderShape)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
        // Slot 'dataColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 2 },
        }}),
        // Slot 'data2ColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 2 },
        }}),
        // Slot 'renameInternalCurves'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'labelsBorderStyleChanged'
        QtMocHelpers::SlotData<void(Qt::PenStyle)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 2 },
        }}),
        // Slot 'labelsBorderWidthChanged'
        QtMocHelpers::SlotData<void(double)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'labelsBorderColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 2 },
        }}),
        // Slot 'labelsBorderOpacityChanged'
        QtMocHelpers::SlotData<void(float)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProcessBehaviorChart, qt_meta_tag_ZN20ProcessBehaviorChartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProcessBehaviorChart::staticMetaObject = { {
    QMetaObject::SuperData::link<Plot::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ProcessBehaviorChartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ProcessBehaviorChartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20ProcessBehaviorChartE_t>.metaTypes,
    nullptr
} };

void ProcessBehaviorChart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProcessBehaviorChart *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->recalculated(); break;
        case 1: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<ProcessBehaviorChart::Type>>(_a[1]))); break;
        case 2: _t->limitsMetricChanged((*reinterpret_cast<std::add_pointer_t<ProcessBehaviorChart::LimitsMetric>>(_a[1]))); break;
        case 3: _t->dataDataChanged(); break;
        case 4: _t->data2DataChanged(); break;
        case 5: _t->dataColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 6: _t->data2ColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 7: _t->sampleSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->exactLimitsEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->limitConstraintsChanged(); break;
        case 10: _t->maxUpperLimitChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 11: _t->minLowerLimitChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 12: _t->labelsEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->labelsAutoPrecisionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->labelsPrecisionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->labelsFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 16: _t->labelsFontColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 17: _t->labelsBackgroundColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 18: _t->labelsBorderShapeChanged((*reinterpret_cast<std::add_pointer_t<TextLabel::BorderShape>>(_a[1]))); break;
        case 19: _t->dataColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 20: _t->data2ColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 21: _t->renameInternalCurves(); break;
        case 22: _t->labelsBorderStyleChanged((*reinterpret_cast<std::add_pointer_t<Qt::PenStyle>>(_a[1]))); break;
        case 23: _t->labelsBorderWidthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 24: _t->labelsBorderColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 25: _t->labelsBorderOpacityChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)()>(_a, &ProcessBehaviorChart::recalculated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(ProcessBehaviorChart::Type )>(_a, &ProcessBehaviorChart::typeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(ProcessBehaviorChart::LimitsMetric )>(_a, &ProcessBehaviorChart::limitsMetricChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)()>(_a, &ProcessBehaviorChart::dataDataChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)()>(_a, &ProcessBehaviorChart::data2DataChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(const AbstractColumn * )>(_a, &ProcessBehaviorChart::dataColumnChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(const AbstractColumn * )>(_a, &ProcessBehaviorChart::data2ColumnChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(int )>(_a, &ProcessBehaviorChart::sampleSizeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(bool )>(_a, &ProcessBehaviorChart::exactLimitsEnabledChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)()>(_a, &ProcessBehaviorChart::limitConstraintsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(double )>(_a, &ProcessBehaviorChart::maxUpperLimitChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(double )>(_a, &ProcessBehaviorChart::minLowerLimitChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(bool )>(_a, &ProcessBehaviorChart::labelsEnabledChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(bool )>(_a, &ProcessBehaviorChart::labelsAutoPrecisionChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(int )>(_a, &ProcessBehaviorChart::labelsPrecisionChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(const QFont )>(_a, &ProcessBehaviorChart::labelsFontChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(const QColor )>(_a, &ProcessBehaviorChart::labelsFontColorChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(const QColor )>(_a, &ProcessBehaviorChart::labelsBackgroundColorChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProcessBehaviorChart::*)(TextLabel::BorderShape )>(_a, &ProcessBehaviorChart::labelsBorderShapeChanged, 18))
            return;
    }
}

const QMetaObject *ProcessBehaviorChart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProcessBehaviorChart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ProcessBehaviorChartE_t>.strings))
        return static_cast<void*>(this);
    return Plot::qt_metacast(_clname);
}

int ProcessBehaviorChart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Plot::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void ProcessBehaviorChart::recalculated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ProcessBehaviorChart::typeChanged(ProcessBehaviorChart::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ProcessBehaviorChart::limitsMetricChanged(ProcessBehaviorChart::LimitsMetric _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ProcessBehaviorChart::dataDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ProcessBehaviorChart::data2DataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ProcessBehaviorChart::dataColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ProcessBehaviorChart::data2ColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ProcessBehaviorChart::sampleSizeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ProcessBehaviorChart::exactLimitsEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ProcessBehaviorChart::limitConstraintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ProcessBehaviorChart::maxUpperLimitChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void ProcessBehaviorChart::minLowerLimitChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ProcessBehaviorChart::labelsEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void ProcessBehaviorChart::labelsAutoPrecisionChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void ProcessBehaviorChart::labelsPrecisionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void ProcessBehaviorChart::labelsFontChanged(const QFont _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void ProcessBehaviorChart::labelsFontColorChanged(const QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void ProcessBehaviorChart::labelsBackgroundColorChanged(const QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void ProcessBehaviorChart::labelsBorderShapeChanged(TextLabel::BorderShape _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}
QT_WARNING_POP
