/********************************************************************************
** Form generated from reading UI file 'dropvalueswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DROPVALUESWIDGET_H
#define UI_DROPVALUESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "UTCDateTimeEdit.h"

QT_BEGIN_NAMESPACE

class Ui_DropValuesWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFrame *frameNumeric;
    QGridLayout *gridLayout;
    QLineEdit *leValue2;
    QLabel *lNumeric;
    QLabel *lMin;
    QComboBox *cbOperator;
    QLineEdit *leValue1;
    QLabel *lMode;
    QLabel *lAnd;
    QLabel *lMax;
    QSpacerItem *verticalSpacer_2;
    QFrame *frameText;
    QGridLayout *gridLayout_2;
    QLabel *lConditionText;
    QLineEdit *leValueText;
    QLabel *lText;
    QComboBox *cbOperatorText;
    QSpacerItem *verticalSpacer_3;
    QFrame *frameDateTime;
    QGridLayout *gridLayout_3;
    QComboBox *cbOperatorDateTime;
    QLabel *label;
    UTCDateTimeEdit *dteValue1;
    QLabel *lAndDateTime;
    QLabel *lMaxDateTime;
    QLabel *lConditionDateTime;
    QLabel *lMinDateTime;
    UTCDateTimeEdit *dteValue2;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *DropValuesWidget)
    {
        if (DropValuesWidget->objectName().isEmpty())
            DropValuesWidget->setObjectName("DropValuesWidget");
        DropValuesWidget->resize(529, 240);
        verticalLayout = new QVBoxLayout(DropValuesWidget);
        verticalLayout->setObjectName("verticalLayout");
        frameNumeric = new QFrame(DropValuesWidget);
        frameNumeric->setObjectName("frameNumeric");
        frameNumeric->setFrameShape(QFrame::NoFrame);
        frameNumeric->setFrameShadow(QFrame::Raised);
        gridLayout = new QGridLayout(frameNumeric);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        leValue2 = new QLineEdit(frameNumeric);
        leValue2->setObjectName("leValue2");

        gridLayout->addWidget(leValue2, 1, 6, 1, 1);

        lNumeric = new QLabel(frameNumeric);
        lNumeric->setObjectName("lNumeric");
        QFont font;
        font.setBold(true);
        lNumeric->setFont(font);

        gridLayout->addWidget(lNumeric, 0, 0, 1, 7);

        lMin = new QLabel(frameNumeric);
        lMin->setObjectName("lMin");

        gridLayout->addWidget(lMin, 1, 2, 1, 1);

        cbOperator = new QComboBox(frameNumeric);
        cbOperator->setObjectName("cbOperator");

        gridLayout->addWidget(cbOperator, 1, 1, 1, 1);

        leValue1 = new QLineEdit(frameNumeric);
        leValue1->setObjectName("leValue1");

        gridLayout->addWidget(leValue1, 1, 3, 1, 1);

        lMode = new QLabel(frameNumeric);
        lMode->setObjectName("lMode");

        gridLayout->addWidget(lMode, 1, 0, 1, 1);

        lAnd = new QLabel(frameNumeric);
        lAnd->setObjectName("lAnd");

        gridLayout->addWidget(lAnd, 1, 4, 1, 1);

        lMax = new QLabel(frameNumeric);
        lMax->setObjectName("lMax");

        gridLayout->addWidget(lMax, 1, 5, 1, 1);


        verticalLayout->addWidget(frameNumeric);

        verticalSpacer_2 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);

        frameText = new QFrame(DropValuesWidget);
        frameText->setObjectName("frameText");
        frameText->setFrameShape(QFrame::NoFrame);
        frameText->setFrameShadow(QFrame::Raised);
        gridLayout_2 = new QGridLayout(frameText);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        lConditionText = new QLabel(frameText);
        lConditionText->setObjectName("lConditionText");

        gridLayout_2->addWidget(lConditionText, 1, 0, 1, 1);

        leValueText = new QLineEdit(frameText);
        leValueText->setObjectName("leValueText");

        gridLayout_2->addWidget(leValueText, 1, 2, 1, 1);

        lText = new QLabel(frameText);
        lText->setObjectName("lText");
        lText->setFont(font);

        gridLayout_2->addWidget(lText, 0, 0, 1, 4);

        cbOperatorText = new QComboBox(frameText);
        cbOperatorText->setObjectName("cbOperatorText");

        gridLayout_2->addWidget(cbOperatorText, 1, 1, 1, 1);


        verticalLayout->addWidget(frameText);

        verticalSpacer_3 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_3);

        frameDateTime = new QFrame(DropValuesWidget);
        frameDateTime->setObjectName("frameDateTime");
        frameDateTime->setFrameShape(QFrame::NoFrame);
        frameDateTime->setFrameShadow(QFrame::Raised);
        gridLayout_3 = new QGridLayout(frameDateTime);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        cbOperatorDateTime = new QComboBox(frameDateTime);
        cbOperatorDateTime->setObjectName("cbOperatorDateTime");

        gridLayout_3->addWidget(cbOperatorDateTime, 1, 1, 1, 1);

        label = new QLabel(frameDateTime);
        label->setObjectName("label");
        label->setFont(font);

        gridLayout_3->addWidget(label, 0, 0, 1, 2);

        dteValue1 = new UTCDateTimeEdit(frameDateTime);
        dteValue1->setObjectName("dteValue1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(dteValue1->sizePolicy().hasHeightForWidth());
        dteValue1->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(dteValue1, 1, 3, 1, 1);

        lAndDateTime = new QLabel(frameDateTime);
        lAndDateTime->setObjectName("lAndDateTime");

        gridLayout_3->addWidget(lAndDateTime, 1, 4, 1, 1);

        lMaxDateTime = new QLabel(frameDateTime);
        lMaxDateTime->setObjectName("lMaxDateTime");

        gridLayout_3->addWidget(lMaxDateTime, 1, 5, 1, 1);

        lConditionDateTime = new QLabel(frameDateTime);
        lConditionDateTime->setObjectName("lConditionDateTime");

        gridLayout_3->addWidget(lConditionDateTime, 1, 0, 1, 1);

        lMinDateTime = new QLabel(frameDateTime);
        lMinDateTime->setObjectName("lMinDateTime");

        gridLayout_3->addWidget(lMinDateTime, 1, 2, 1, 1);

        dteValue2 = new UTCDateTimeEdit(frameDateTime);
        dteValue2->setObjectName("dteValue2");
        sizePolicy.setHeightForWidth(dteValue2->sizePolicy().hasHeightForWidth());
        dteValue2->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(dteValue2, 1, 6, 1, 1);


        verticalLayout->addWidget(frameDateTime);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(DropValuesWidget);

        QMetaObject::connectSlotsByName(DropValuesWidget);
    } // setupUi

    void retranslateUi(QWidget *DropValuesWidget)
    {
        lNumeric->setText(tr2i18n("Numeric Values", nullptr));
        lMin->setText(tr2i18n("min.", nullptr));
        lMode->setText(tr2i18n("Condition:", nullptr));
        lAnd->setText(tr2i18n("and", nullptr));
        lMax->setText(tr2i18n("max.", nullptr));
        lConditionText->setText(tr2i18n("Condition:", nullptr));
        lText->setText(tr2i18n("Text Values", nullptr));
        label->setText(tr2i18n("DateTime Values", nullptr));
        lAndDateTime->setText(tr2i18n("and", nullptr));
        lMaxDateTime->setText(tr2i18n("max.", nullptr));
        lConditionDateTime->setText(tr2i18n("Condition:", nullptr));
        lMinDateTime->setText(tr2i18n("min.", nullptr));
        (void)DropValuesWidget;
    } // retranslateUi

};

namespace Ui {
    class DropValuesWidget: public Ui_DropValuesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DROPVALUESWIDGET_H

