/********************************************************************************
** Form generated from reading UI file 'xydatareductioncurvedockgeneraltab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XYDATAREDUCTIONCURVEDOCKGENERALTAB_H
#define UI_XYDATAREDUCTIONCURVEDOCKGENERALTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_XYDataReductionCurveDockGeneralTab
{
public:
    QGridLayout *gridLayout_2;
    QPushButton *pbRecalculate;
    QLabel *lSimplification;
    QLabel *lName;
    QLabel *lDataSourceType;
    QLabel *lResults;
    KComboBox *cbMethod;
    QCheckBox *chkVisible;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *chkAuto2;
    NumberSpinBox *sbTolerance2;
    QCheckBox *cbAutoRange;
    QLabel *lXColumn;
    QLabel *lOption2;
    QLabel *lMethod;
    QFrame *frameRange;
    QGridLayout *gridLayout;
    QLabel *lMax;
    QLabel *lMaxDateTime;
    QLabel *lMinDateTime;
    QLabel *lMin;
    UTCDateTimeEdit *dateTimeEditMin;
    UTCDateTimeEdit *dateTimeEditMax;
    QLineEdit *leMin;
    QLineEdit *leMax;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_4;
    QLabel *lOption;
    QSpacerItem *horizontalSpacer;
    QLabel *lData;
    QTextEdit *teResult;
    QLabel *lXRange;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QCheckBox *chkAuto;
    NumberSpinBox *sbTolerance;
    ResizableTextEdit *teComment;
    QLabel *lComment;
    QLabel *lDataSourceCurve;
    QComboBox *cbPlotRanges;
    QFrame *line_2;
    QLabel *lPlotRange;
    TimedLineEdit *leName;
    QComboBox *cbDataSourceType;
    QSpacerItem *verticalSpacerGeneral;
    QLabel *lYColumn;
    QCheckBox *chkLegendVisible;

    void setupUi(QWidget *XYDataReductionCurveDockGeneralTab)
    {
        if (XYDataReductionCurveDockGeneralTab->objectName().isEmpty())
            XYDataReductionCurveDockGeneralTab->setObjectName("XYDataReductionCurveDockGeneralTab");
        XYDataReductionCurveDockGeneralTab->resize(332, 913);
        gridLayout_2 = new QGridLayout(XYDataReductionCurveDockGeneralTab);
        gridLayout_2->setObjectName("gridLayout_2");
        pbRecalculate = new QPushButton(XYDataReductionCurveDockGeneralTab);
        pbRecalculate->setObjectName("pbRecalculate");

        gridLayout_2->addWidget(pbRecalculate, 18, 3, 1, 1);

        lSimplification = new QLabel(XYDataReductionCurveDockGeneralTab);
        lSimplification->setObjectName("lSimplification");
        QFont font;
        font.setBold(true);
        lSimplification->setFont(font);

        gridLayout_2->addWidget(lSimplification, 11, 0, 1, 1);

        lName = new QLabel(XYDataReductionCurveDockGeneralTab);
        lName->setObjectName("lName");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lName->sizePolicy().hasHeightForWidth());
        lName->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(lName, 0, 0, 1, 1);

        lDataSourceType = new QLabel(XYDataReductionCurveDockGeneralTab);
        lDataSourceType->setObjectName("lDataSourceType");

        gridLayout_2->addWidget(lDataSourceType, 4, 0, 1, 1);

        lResults = new QLabel(XYDataReductionCurveDockGeneralTab);
        lResults->setObjectName("lResults");
        lResults->setFont(font);
        lResults->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout_2->addWidget(lResults, 16, 0, 1, 1);

        cbMethod = new KComboBox(XYDataReductionCurveDockGeneralTab);
        cbMethod->setObjectName("cbMethod");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbMethod->sizePolicy().hasHeightForWidth());
        cbMethod->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(cbMethod, 12, 2, 1, 2);

        chkVisible = new QCheckBox(XYDataReductionCurveDockGeneralTab);
        chkVisible->setObjectName("chkVisible");

        gridLayout_2->addWidget(chkVisible, 23, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_3, 2, 2, 1, 2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        chkAuto2 = new QCheckBox(XYDataReductionCurveDockGeneralTab);
        chkAuto2->setObjectName("chkAuto2");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(chkAuto2->sizePolicy().hasHeightForWidth());
        chkAuto2->setSizePolicy(sizePolicy2);
        chkAuto2->setMinimumSize(QSize(100, 0));
        chkAuto2->setChecked(true);

        horizontalLayout_3->addWidget(chkAuto2);

        sbTolerance2 = new NumberSpinBox(XYDataReductionCurveDockGeneralTab);
        sbTolerance2->setObjectName("sbTolerance2");
        sbTolerance2->setEnabled(false);
        sbTolerance2->setDecimals(6);
        sbTolerance2->setProperty("feedback", QVariant(false));

        horizontalLayout_3->addWidget(sbTolerance2);


        gridLayout_2->addLayout(horizontalLayout_3, 14, 2, 1, 2);

        cbAutoRange = new QCheckBox(XYDataReductionCurveDockGeneralTab);
        cbAutoRange->setObjectName("cbAutoRange");
        cbAutoRange->setChecked(true);

        gridLayout_2->addWidget(cbAutoRange, 8, 2, 1, 2);

        lXColumn = new QLabel(XYDataReductionCurveDockGeneralTab);
        lXColumn->setObjectName("lXColumn");

        gridLayout_2->addWidget(lXColumn, 6, 0, 1, 1);

        lOption2 = new QLabel(XYDataReductionCurveDockGeneralTab);
        lOption2->setObjectName("lOption2");

        gridLayout_2->addWidget(lOption2, 14, 0, 1, 1);

        lMethod = new QLabel(XYDataReductionCurveDockGeneralTab);
        lMethod->setObjectName("lMethod");

        gridLayout_2->addWidget(lMethod, 12, 0, 1, 1);

        frameRange = new QFrame(XYDataReductionCurveDockGeneralTab);
        frameRange->setObjectName("frameRange");
        frameRange->setFrameShape(QFrame::Shape::NoFrame);
        frameRange->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout = new QGridLayout(frameRange);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, -1);
        lMax = new QLabel(frameRange);
        lMax->setObjectName("lMax");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(lMax->sizePolicy().hasHeightForWidth());
        lMax->setSizePolicy(sizePolicy3);
        lMax->setMinimumSize(QSize(50, 0));

        gridLayout->addWidget(lMax, 1, 0, 1, 1);

        lMaxDateTime = new QLabel(frameRange);
        lMaxDateTime->setObjectName("lMaxDateTime");
        sizePolicy3.setHeightForWidth(lMaxDateTime->sizePolicy().hasHeightForWidth());
        lMaxDateTime->setSizePolicy(sizePolicy3);
        lMaxDateTime->setMinimumSize(QSize(50, 0));

        gridLayout->addWidget(lMaxDateTime, 3, 0, 1, 1);

        lMinDateTime = new QLabel(frameRange);
        lMinDateTime->setObjectName("lMinDateTime");
        sizePolicy3.setHeightForWidth(lMinDateTime->sizePolicy().hasHeightForWidth());
        lMinDateTime->setSizePolicy(sizePolicy3);
        lMinDateTime->setMinimumSize(QSize(50, 0));

        gridLayout->addWidget(lMinDateTime, 2, 0, 1, 1);

        lMin = new QLabel(frameRange);
        lMin->setObjectName("lMin");
        sizePolicy3.setHeightForWidth(lMin->sizePolicy().hasHeightForWidth());
        lMin->setSizePolicy(sizePolicy3);
        lMin->setMinimumSize(QSize(50, 0));

        gridLayout->addWidget(lMin, 0, 0, 1, 1);

        dateTimeEditMin = new UTCDateTimeEdit(frameRange);
        dateTimeEditMin->setObjectName("dateTimeEditMin");
        dateTimeEditMin->setCalendarPopup(true);

        gridLayout->addWidget(dateTimeEditMin, 2, 1, 1, 1);

        dateTimeEditMax = new UTCDateTimeEdit(frameRange);
        dateTimeEditMax->setObjectName("dateTimeEditMax");
        dateTimeEditMax->setCalendarPopup(true);

        gridLayout->addWidget(dateTimeEditMax, 3, 1, 1, 1);

        leMin = new QLineEdit(frameRange);
        leMin->setObjectName("leMin");

        gridLayout->addWidget(leMin, 0, 1, 1, 1);

        leMax = new QLineEdit(frameRange);
        leMax->setObjectName("leMax");

        gridLayout->addWidget(leMax, 1, 1, 1, 1);


        gridLayout_2->addWidget(frameRange, 9, 2, 1, 2);

        horizontalSpacer_2 = new QSpacerItem(266, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 18, 2, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_4, 10, 2, 1, 2);

        lOption = new QLabel(XYDataReductionCurveDockGeneralTab);
        lOption->setObjectName("lOption");

        gridLayout_2->addWidget(lOption, 13, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 1, 1, 1);

        lData = new QLabel(XYDataReductionCurveDockGeneralTab);
        lData->setObjectName("lData");
        lData->setFont(font);

        gridLayout_2->addWidget(lData, 3, 0, 1, 1);

        teResult = new QTextEdit(XYDataReductionCurveDockGeneralTab);
        teResult->setObjectName("teResult");
        teResult->setReadOnly(true);

        gridLayout_2->addWidget(teResult, 16, 2, 1, 2);

        lXRange = new QLabel(XYDataReductionCurveDockGeneralTab);
        lXRange->setObjectName("lXRange");

        gridLayout_2->addWidget(lXRange, 8, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer, 15, 2, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        chkAuto = new QCheckBox(XYDataReductionCurveDockGeneralTab);
        chkAuto->setObjectName("chkAuto");
        sizePolicy2.setHeightForWidth(chkAuto->sizePolicy().hasHeightForWidth());
        chkAuto->setSizePolicy(sizePolicy2);
        chkAuto->setMinimumSize(QSize(100, 0));
        chkAuto->setChecked(true);

        horizontalLayout->addWidget(chkAuto);

        sbTolerance = new NumberSpinBox(XYDataReductionCurveDockGeneralTab);
        sbTolerance->setObjectName("sbTolerance");
        sbTolerance->setEnabled(false);
        sbTolerance->setDecimals(6);
        sbTolerance->setProperty("feedback", QVariant(false));

        horizontalLayout->addWidget(sbTolerance);


        gridLayout_2->addLayout(horizontalLayout, 13, 2, 1, 2);

        teComment = new ResizableTextEdit(XYDataReductionCurveDockGeneralTab);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout_2->addWidget(teComment, 1, 2, 1, 2);

        lComment = new QLabel(XYDataReductionCurveDockGeneralTab);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(lComment, 1, 0, 1, 1);

        lDataSourceCurve = new QLabel(XYDataReductionCurveDockGeneralTab);
        lDataSourceCurve->setObjectName("lDataSourceCurve");

        gridLayout_2->addWidget(lDataSourceCurve, 5, 0, 1, 1);

        cbPlotRanges = new QComboBox(XYDataReductionCurveDockGeneralTab);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout_2->addWidget(cbPlotRanges, 20, 2, 1, 2);

        line_2 = new QFrame(XYDataReductionCurveDockGeneralTab);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(line_2, 17, 0, 1, 4);

        lPlotRange = new QLabel(XYDataReductionCurveDockGeneralTab);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout_2->addWidget(lPlotRange, 20, 0, 1, 2);

        leName = new TimedLineEdit(XYDataReductionCurveDockGeneralTab);
        leName->setObjectName("leName");

        gridLayout_2->addWidget(leName, 0, 2, 1, 2);

        cbDataSourceType = new QComboBox(XYDataReductionCurveDockGeneralTab);
        cbDataSourceType->setObjectName("cbDataSourceType");
        sizePolicy1.setHeightForWidth(cbDataSourceType->sizePolicy().hasHeightForWidth());
        cbDataSourceType->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(cbDataSourceType, 4, 2, 1, 2);

        verticalSpacerGeneral = new QSpacerItem(24, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacerGeneral, 21, 0, 1, 1);

        lYColumn = new QLabel(XYDataReductionCurveDockGeneralTab);
        lYColumn->setObjectName("lYColumn");

        gridLayout_2->addWidget(lYColumn, 7, 0, 1, 1);

        chkLegendVisible = new QCheckBox(XYDataReductionCurveDockGeneralTab);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout_2->addWidget(chkLegendVisible, 22, 0, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbDataSourceType);
        QWidget::setTabOrder(cbDataSourceType, cbAutoRange);
        QWidget::setTabOrder(cbAutoRange, leMin);
        QWidget::setTabOrder(leMin, leMax);
        QWidget::setTabOrder(leMax, dateTimeEditMin);
        QWidget::setTabOrder(dateTimeEditMin, dateTimeEditMax);
        QWidget::setTabOrder(dateTimeEditMax, cbMethod);
        QWidget::setTabOrder(cbMethod, chkAuto);
        QWidget::setTabOrder(chkAuto, sbTolerance);
        QWidget::setTabOrder(sbTolerance, chkAuto2);
        QWidget::setTabOrder(chkAuto2, sbTolerance2);
        QWidget::setTabOrder(sbTolerance2, teResult);
        QWidget::setTabOrder(teResult, pbRecalculate);
        QWidget::setTabOrder(pbRecalculate, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);

        retranslateUi(XYDataReductionCurveDockGeneralTab);

        QMetaObject::connectSlotsByName(XYDataReductionCurveDockGeneralTab);
    } // setupUi

    void retranslateUi(QWidget *XYDataReductionCurveDockGeneralTab)
    {
        pbRecalculate->setText(tr2i18n("Recalculate", nullptr));
        lSimplification->setText(tr2i18n("Simplification", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lDataSourceType->setText(tr2i18n("Source:", nullptr));
        lResults->setText(tr2i18n("Results:", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        chkAuto2->setText(tr2i18n("Auto", nullptr));
#if QT_CONFIG(tooltip)
        sbTolerance2->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbTolerance2->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cbAutoRange->setText(tr2i18n("Auto", nullptr));
        lXColumn->setText(tr2i18n("X-Data:", nullptr));
        lOption2->setText(tr2i18n("Option:", nullptr));
        lMethod->setText(tr2i18n("Method:", nullptr));
        lMax->setText(tr2i18n("Maximum:", nullptr));
        lMaxDateTime->setText(tr2i18n("Maximum:", nullptr));
        lMinDateTime->setText(tr2i18n("Minimum:", nullptr));
        lMin->setText(tr2i18n("Minimum:", nullptr));
        lOption->setText(tr2i18n("Option:", nullptr));
        lData->setText(tr2i18n("Data", nullptr));
        lXRange->setText(tr2i18n("X-Range:", nullptr));
        chkAuto->setText(tr2i18n("Auto", nullptr));
#if QT_CONFIG(tooltip)
        sbTolerance->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbTolerance->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lComment->setText(tr2i18n("Comment:", nullptr));
        lDataSourceCurve->setText(tr2i18n("Curve:", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        lYColumn->setText(tr2i18n("Y-Data:", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        (void)XYDataReductionCurveDockGeneralTab;
    } // retranslateUi

};

namespace Ui {
    class XYDataReductionCurveDockGeneralTab: public Ui_XYDataReductionCurveDockGeneralTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // XYDATAREDUCTIONCURVEDOCKGENERALTAB_H

