/********************************************************************************
** Form generated from reading UI file 'spreadsheetdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPREADSHEETDOCK_H
#define UI_SPREADSHEETDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "TreeViewComboBox.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_SpreadsheetDock
{
public:
    QGridLayout *gridLayout;
    QLabel *lLinkingEnabled;
    ResizableTextEdit *teComment;
    QCheckBox *cbShowSparklines;
    QSpacerItem *verticalSpacer;
    QSpinBox *sbColumnCount;
    QCheckBox *cbLinkingEnabled;
    QSpacerItem *verticalSpacer_2;
    QLabel *lName;
    QSpacerItem *verticalSpacer_4;
    TreeViewComboBox *cbLinkedSpreadsheet;
    TimedLineEdit *leName;
    QLabel *lLinkedSpreadsheet;
    QSpacerItem *verticalSpacer_3;
    QLabel *lColumnCount;
    QLabel *lDimensions;
    QSpinBox *sbRowCount;
    QLabel *lShowSparklines;
    QLabel *lComment;
    QLabel *lFormat;
    QCheckBox *cbShowComments;
    QLabel *lRowCount;
    QLabel *lShowComments;
    QLabel *lLinking;
    QSpacerItem *horizontalSpacer_4;

    void setupUi(QWidget *SpreadsheetDock)
    {
        if (SpreadsheetDock->objectName().isEmpty())
            SpreadsheetDock->setObjectName("SpreadsheetDock");
        SpreadsheetDock->resize(414, 694);
        gridLayout = new QGridLayout(SpreadsheetDock);
        gridLayout->setObjectName("gridLayout");
        lLinkingEnabled = new QLabel(SpreadsheetDock);
        lLinkingEnabled->setObjectName("lLinkingEnabled");

        gridLayout->addWidget(lLinkingEnabled, 14, 0, 1, 2);

        teComment = new ResizableTextEdit(SpreadsheetDock);
        teComment->setObjectName("teComment");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(teComment->sizePolicy().hasHeightForWidth());
        teComment->setSizePolicy(sizePolicy);
        teComment->setMaximumSize(QSize(16777215, 16777215));
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 3, 1, 1);

        cbShowSparklines = new QCheckBox(SpreadsheetDock);
        cbShowSparklines->setObjectName("cbShowSparklines");

        gridLayout->addWidget(cbShowSparklines, 11, 3, 1, 1);

        verticalSpacer = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 16, 0, 1, 2);

        sbColumnCount = new QSpinBox(SpreadsheetDock);
        sbColumnCount->setObjectName("sbColumnCount");
        sbColumnCount->setMinimum(0);
        sbColumnCount->setMaximum(16777215);

        gridLayout->addWidget(sbColumnCount, 7, 3, 1, 1);

        cbLinkingEnabled = new QCheckBox(SpreadsheetDock);
        cbLinkingEnabled->setObjectName("cbLinkingEnabled");

        gridLayout->addWidget(cbLinkingEnabled, 14, 3, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 12, 0, 1, 2);

        lName = new QLabel(SpreadsheetDock);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(58, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 8, 0, 1, 2);

        cbLinkedSpreadsheet = new TreeViewComboBox(SpreadsheetDock);
        cbLinkedSpreadsheet->setObjectName("cbLinkedSpreadsheet");

        gridLayout->addWidget(cbLinkedSpreadsheet, 15, 3, 1, 1);

        leName = new TimedLineEdit(SpreadsheetDock);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 3, 1, 1);

        lLinkedSpreadsheet = new QLabel(SpreadsheetDock);
        lLinkedSpreadsheet->setObjectName("lLinkedSpreadsheet");

        gridLayout->addWidget(lLinkedSpreadsheet, 15, 0, 1, 2);

        verticalSpacer_3 = new QSpacerItem(58, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 2, 0, 1, 2);

        lColumnCount = new QLabel(SpreadsheetDock);
        lColumnCount->setObjectName("lColumnCount");

        gridLayout->addWidget(lColumnCount, 7, 0, 1, 2);

        lDimensions = new QLabel(SpreadsheetDock);
        lDimensions->setObjectName("lDimensions");
        QFont font;
        font.setBold(true);
        lDimensions->setFont(font);

        gridLayout->addWidget(lDimensions, 5, 0, 1, 2);

        sbRowCount = new QSpinBox(SpreadsheetDock);
        sbRowCount->setObjectName("sbRowCount");
        sbRowCount->setMinimum(0);
        sbRowCount->setMaximum(999999999);

        gridLayout->addWidget(sbRowCount, 6, 3, 1, 1);

        lShowSparklines = new QLabel(SpreadsheetDock);
        lShowSparklines->setObjectName("lShowSparklines");

        gridLayout->addWidget(lShowSparklines, 11, 0, 1, 1);

        lComment = new QLabel(SpreadsheetDock);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        lFormat = new QLabel(SpreadsheetDock);
        lFormat->setObjectName("lFormat");
        lFormat->setFont(font);

        gridLayout->addWidget(lFormat, 9, 0, 1, 2);

        cbShowComments = new QCheckBox(SpreadsheetDock);
        cbShowComments->setObjectName("cbShowComments");
        cbShowComments->setChecked(false);

        gridLayout->addWidget(cbShowComments, 10, 3, 1, 1);

        lRowCount = new QLabel(SpreadsheetDock);
        lRowCount->setObjectName("lRowCount");

        gridLayout->addWidget(lRowCount, 6, 0, 1, 2);

        lShowComments = new QLabel(SpreadsheetDock);
        lShowComments->setObjectName("lShowComments");

        gridLayout->addWidget(lShowComments, 10, 0, 1, 2);

        lLinking = new QLabel(SpreadsheetDock);
        lLinking->setObjectName("lLinking");
        lLinking->setFont(font);

        gridLayout->addWidget(lLinking, 13, 0, 1, 2);

        horizontalSpacer_4 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 0, 2, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, sbRowCount);
        QWidget::setTabOrder(sbRowCount, sbColumnCount);
        QWidget::setTabOrder(sbColumnCount, cbShowComments);
        QWidget::setTabOrder(cbShowComments, cbShowSparklines);
        QWidget::setTabOrder(cbShowSparklines, cbLinkingEnabled);
        QWidget::setTabOrder(cbLinkingEnabled, cbLinkedSpreadsheet);

        retranslateUi(SpreadsheetDock);

        QMetaObject::connectSlotsByName(SpreadsheetDock);
    } // setupUi

    void retranslateUi(QWidget *SpreadsheetDock)
    {
        lLinkingEnabled->setText(tr2i18n("Enabled", nullptr));
        cbShowSparklines->setText(QString());
        cbLinkingEnabled->setText(QString());
        lName->setText(tr2i18n("Name:", nullptr));
        lLinkedSpreadsheet->setText(tr2i18n("Spreadsheet", nullptr));
        lColumnCount->setText(tr2i18n("Columns:", nullptr));
        lDimensions->setText(tr2i18n("Dimensions", nullptr));
        lShowSparklines->setText(tr2i18n("Sparklines:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lFormat->setText(tr2i18n("Column Header", nullptr));
        cbShowComments->setText(QString());
        lRowCount->setText(tr2i18n("Rows:", nullptr));
        lShowComments->setText(tr2i18n("Comments:", nullptr));
        lLinking->setText(tr2i18n("Linking", nullptr));
        (void)SpreadsheetDock;
    } // retranslateUi

};

namespace Ui {
    class SpreadsheetDock: public Ui_SpreadsheetDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SPREADSHEETDOCK_H

