/********************************************************************************
** Form generated from reading UI file 'valuewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VALUEWIDGET_H
#define UI_VALUEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "kcolorbutton.h"
#include "kcombobox.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ValueWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *lGeneral;
    QLabel *lType;
    QSpacerItem *horizontalSpacer;
    KComboBox *cbType;
    QLabel *lColumn;
    QLabel *lPosition;
    KComboBox *cbPosition;
    QLabel *lDistance;
    QLabel *lRotation;
    QSpinBox *sbRotation;
    QLabel *lOpacity;
    QSpinBox *sbOpacity;
    QSpacerItem *verticalSpacer_6;
    QLabel *lFormat;
    QLabel *lNumericFormat;
    KComboBox *cbNumericFormat;
    QLabel *lPrecision;
    QSpinBox *sbPrecision;
    QLabel *lDateTimeFormat;
    QComboBox *cbDateTimeFormat;
    QSpacerItem *verticalSpacer_7;
    QLabel *lText;
    QLabel *lPrefix;
    QLineEdit *lePrefix;
    QLabel *lSuffix;
    QLineEdit *leSuffix;
    QLabel *lFont;
    KFontRequester *kfrFont;
    QLabel *lColor;
    KColorButton *kcbColor;
    QSpacerItem *verticalSpacer_8;
    NumberSpinBox *sbDistance;

    void setupUi(QWidget *ValueWidget)
    {
        if (ValueWidget->objectName().isEmpty())
            ValueWidget->setObjectName("ValueWidget");
        ValueWidget->resize(287, 533);
        gridLayout = new QGridLayout(ValueWidget);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        lGeneral = new QLabel(ValueWidget);
        lGeneral->setObjectName("lGeneral");
        QFont font;
        font.setBold(true);
        lGeneral->setFont(font);

        gridLayout->addWidget(lGeneral, 0, 0, 1, 1);

        lType = new QLabel(ValueWidget);
        lType->setObjectName("lType");

        gridLayout->addWidget(lType, 1, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 1, 1, 1);

        cbType = new KComboBox(ValueWidget);
        cbType->setObjectName("cbType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbType->sizePolicy().hasHeightForWidth());
        cbType->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbType, 1, 2, 1, 1);

        lColumn = new QLabel(ValueWidget);
        lColumn->setObjectName("lColumn");

        gridLayout->addWidget(lColumn, 2, 0, 1, 1);

        lPosition = new QLabel(ValueWidget);
        lPosition->setObjectName("lPosition");

        gridLayout->addWidget(lPosition, 3, 0, 1, 1);

        cbPosition = new KComboBox(ValueWidget);
        cbPosition->setObjectName("cbPosition");

        gridLayout->addWidget(cbPosition, 3, 2, 1, 1);

        lDistance = new QLabel(ValueWidget);
        lDistance->setObjectName("lDistance");
        lDistance->setWordWrap(true);

        gridLayout->addWidget(lDistance, 4, 0, 1, 1);

        lRotation = new QLabel(ValueWidget);
        lRotation->setObjectName("lRotation");

        gridLayout->addWidget(lRotation, 5, 0, 1, 1);

        sbRotation = new QSpinBox(ValueWidget);
        sbRotation->setObjectName("sbRotation");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sbRotation->sizePolicy().hasHeightForWidth());
        sbRotation->setSizePolicy(sizePolicy1);
        sbRotation->setMinimum(-360);
        sbRotation->setMaximum(360);
        sbRotation->setSingleStep(10);

        gridLayout->addWidget(sbRotation, 5, 2, 1, 1);

        lOpacity = new QLabel(ValueWidget);
        lOpacity->setObjectName("lOpacity");

        gridLayout->addWidget(lOpacity, 6, 0, 1, 1);

        sbOpacity = new QSpinBox(ValueWidget);
        sbOpacity->setObjectName("sbOpacity");
        sizePolicy1.setHeightForWidth(sbOpacity->sizePolicy().hasHeightForWidth());
        sbOpacity->setSizePolicy(sizePolicy1);
        sbOpacity->setMinimum(0);
        sbOpacity->setMaximum(100);
        sbOpacity->setSingleStep(10);
        sbOpacity->setValue(100);

        gridLayout->addWidget(sbOpacity, 6, 2, 1, 1);

        verticalSpacer_6 = new QSpacerItem(86, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_6, 7, 0, 1, 2);

        lFormat = new QLabel(ValueWidget);
        lFormat->setObjectName("lFormat");
        lFormat->setFont(font);

        gridLayout->addWidget(lFormat, 8, 0, 1, 1);

        lNumericFormat = new QLabel(ValueWidget);
        lNumericFormat->setObjectName("lNumericFormat");

        gridLayout->addWidget(lNumericFormat, 9, 0, 1, 1);

        cbNumericFormat = new KComboBox(ValueWidget);
        cbNumericFormat->setObjectName("cbNumericFormat");

        gridLayout->addWidget(cbNumericFormat, 9, 2, 1, 1);

        lPrecision = new QLabel(ValueWidget);
        lPrecision->setObjectName("lPrecision");

        gridLayout->addWidget(lPrecision, 10, 0, 1, 1);

        sbPrecision = new QSpinBox(ValueWidget);
        sbPrecision->setObjectName("sbPrecision");
        sizePolicy1.setHeightForWidth(sbPrecision->sizePolicy().hasHeightForWidth());
        sbPrecision->setSizePolicy(sizePolicy1);
        sbPrecision->setMinimum(0);
        sbPrecision->setMaximum(16);
        sbPrecision->setValue(0);

        gridLayout->addWidget(sbPrecision, 10, 2, 1, 1);

        lDateTimeFormat = new QLabel(ValueWidget);
        lDateTimeFormat->setObjectName("lDateTimeFormat");

        gridLayout->addWidget(lDateTimeFormat, 11, 0, 1, 1);

        cbDateTimeFormat = new QComboBox(ValueWidget);
        cbDateTimeFormat->setObjectName("cbDateTimeFormat");

        gridLayout->addWidget(cbDateTimeFormat, 11, 2, 1, 1);

        verticalSpacer_7 = new QSpacerItem(86, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_7, 12, 0, 1, 2);

        lText = new QLabel(ValueWidget);
        lText->setObjectName("lText");
        lText->setFont(font);

        gridLayout->addWidget(lText, 13, 0, 1, 1);

        lPrefix = new QLabel(ValueWidget);
        lPrefix->setObjectName("lPrefix");

        gridLayout->addWidget(lPrefix, 14, 0, 1, 1);

        lePrefix = new QLineEdit(ValueWidget);
        lePrefix->setObjectName("lePrefix");
        sizePolicy1.setHeightForWidth(lePrefix->sizePolicy().hasHeightForWidth());
        lePrefix->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(lePrefix, 14, 2, 1, 1);

        lSuffix = new QLabel(ValueWidget);
        lSuffix->setObjectName("lSuffix");

        gridLayout->addWidget(lSuffix, 15, 0, 1, 1);

        leSuffix = new QLineEdit(ValueWidget);
        leSuffix->setObjectName("leSuffix");
        sizePolicy1.setHeightForWidth(leSuffix->sizePolicy().hasHeightForWidth());
        leSuffix->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(leSuffix, 15, 2, 1, 1);

        lFont = new QLabel(ValueWidget);
        lFont->setObjectName("lFont");

        gridLayout->addWidget(lFont, 16, 0, 1, 1);

        kfrFont = new KFontRequester(ValueWidget);
        kfrFont->setObjectName("kfrFont");

        gridLayout->addWidget(kfrFont, 16, 2, 1, 1);

        lColor = new QLabel(ValueWidget);
        lColor->setObjectName("lColor");

        gridLayout->addWidget(lColor, 17, 0, 1, 1);

        kcbColor = new KColorButton(ValueWidget);
        kcbColor->setObjectName("kcbColor");
        sizePolicy1.setHeightForWidth(kcbColor->sizePolicy().hasHeightForWidth());
        kcbColor->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(kcbColor, 17, 2, 1, 1);

        verticalSpacer_8 = new QSpacerItem(28, 85, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_8, 18, 0, 1, 1);

        sbDistance = new NumberSpinBox(ValueWidget);
        sbDistance->setObjectName("sbDistance");
        sbDistance->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbDistance, 4, 2, 1, 1);

        QWidget::setTabOrder(cbType, cbPosition);
        QWidget::setTabOrder(cbPosition, sbDistance);
        QWidget::setTabOrder(sbDistance, sbRotation);
        QWidget::setTabOrder(sbRotation, sbOpacity);
        QWidget::setTabOrder(sbOpacity, cbNumericFormat);
        QWidget::setTabOrder(cbNumericFormat, sbPrecision);
        QWidget::setTabOrder(sbPrecision, cbDateTimeFormat);
        QWidget::setTabOrder(cbDateTimeFormat, lePrefix);
        QWidget::setTabOrder(lePrefix, leSuffix);
        QWidget::setTabOrder(leSuffix, kfrFont);
        QWidget::setTabOrder(kfrFont, kcbColor);

        retranslateUi(ValueWidget);

        QMetaObject::connectSlotsByName(ValueWidget);
    } // setupUi

    void retranslateUi(QWidget *ValueWidget)
    {
        ValueWidget->setWindowTitle(tr2i18n("Form", nullptr));
        lGeneral->setText(tr2i18n("General", nullptr));
        lType->setText(tr2i18n("Type:", nullptr));
        lColumn->setText(tr2i18n("Column:", nullptr));
        lPosition->setText(tr2i18n("Position:", nullptr));
        lDistance->setText(tr2i18n("Distance:", nullptr));
        lRotation->setText(tr2i18n("Rotation:", nullptr));
        sbRotation->setSuffix(tr2i18n("\302\260", nullptr));
        lOpacity->setText(tr2i18n("Opacity:", nullptr));
#if QT_CONFIG(tooltip)
        sbOpacity->setToolTip(tr2i18n("The opacity ranges from 0 to 100, where 0 is fully transparent and 100 is fully opaque.", nullptr));
#endif // QT_CONFIG(tooltip)
        sbOpacity->setSuffix(tr2i18n(" %", nullptr));
        lFormat->setText(tr2i18n("Format", nullptr));
        lNumericFormat->setText(tr2i18n("Numeric:", nullptr));
        lPrecision->setText(tr2i18n("Precision:", nullptr));
        lDateTimeFormat->setText(tr2i18n("DateTime:", nullptr));
        lText->setText(tr2i18n("Text", nullptr));
        lPrefix->setText(tr2i18n("Prefix:", nullptr));
        lSuffix->setText(tr2i18n("Suffix:", nullptr));
        lFont->setText(tr2i18n("Font:", nullptr));
        lColor->setText(tr2i18n("Color:", nullptr));
#if QT_CONFIG(tooltip)
        sbDistance->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbDistance->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbDistance->setSuffix(tr2i18n(" pt", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ValueWidget: public Ui_ValueWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VALUEWIDGET_H

