/********************************************************************************
** Form generated from reading UI file 'qqplotdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QQPLOTDOCK_H
#define UI_QQPLOTDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_QQPlotDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    ResizableTextEdit *teComment;
    TimedLineEdit *leName;
    QComboBox *cbPlotRanges;
    QSpacerItem *verticalSpacerGeneral;
    QLabel *lName;
    QCheckBox *chkVisible;
    QSpacerItem *verticalSpacer_4;
    QLabel *lDataColumn;
    QLabel *lFuncPic;
    QLabel *lComment;
    QLabel *lDistribution;
    QLabel *lPlotRange;
    QLabel *lFunc;
    QSpacerItem *verticalSpacer;
    QComboBox *cbDistribution;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *chkLegendVisible;
    QWidget *tabReferenceLine;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer_2;
    QWidget *tabPercentiles;
    QVBoxLayout *verticalLayout_3;
    QSpacerItem *verticalSpacer_3;

    void setupUi(QWidget *QQPlotDock)
    {
        if (QQPlotDock->objectName().isEmpty())
            QQPlotDock->setObjectName("QQPlotDock");
        QQPlotDock->resize(381, 718);
        verticalLayout = new QVBoxLayout(QQPlotDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(QQPlotDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setObjectName("gridLayout");
        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout->addWidget(cbPlotRanges, 7, 2, 1, 1);

        verticalSpacerGeneral = new QSpacerItem(24, 214, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout->addItem(verticalSpacerGeneral, 8, 0, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout->addWidget(chkVisible, 10, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 6, 0, 1, 1);

        lDataColumn = new QLabel(tabGeneral);
        lDataColumn->setObjectName("lDataColumn");

        gridLayout->addWidget(lDataColumn, 3, 0, 1, 1);

        lFuncPic = new QLabel(tabGeneral);
        lFuncPic->setObjectName("lFuncPic");

        gridLayout->addWidget(lFuncPic, 5, 2, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        lDistribution = new QLabel(tabGeneral);
        lDistribution->setObjectName("lDistribution");

        gridLayout->addWidget(lDistribution, 4, 0, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout->addWidget(lPlotRange, 7, 0, 1, 1);

        lFunc = new QLabel(tabGeneral);
        lFunc->setObjectName("lFunc");
        lFunc->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lFunc, 5, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        cbDistribution = new QComboBox(tabGeneral);
        cbDistribution->setObjectName("cbDistribution");

        gridLayout->addWidget(cbDistribution, 4, 2, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        chkLegendVisible = new QCheckBox(tabGeneral);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout->addWidget(chkLegendVisible, 9, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabReferenceLine = new QWidget();
        tabReferenceLine->setObjectName("tabReferenceLine");
        verticalLayout_2 = new QVBoxLayout(tabReferenceLine);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalSpacer_2 = new QSpacerItem(20, 654, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        tabWidget->addTab(tabReferenceLine, QString());
        tabPercentiles = new QWidget();
        tabPercentiles->setObjectName("tabPercentiles");
        verticalLayout_3 = new QVBoxLayout(tabPercentiles);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalSpacer_3 = new QSpacerItem(20, 654, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);

        tabWidget->addTab(tabPercentiles, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbDistribution);
        QWidget::setTabOrder(cbDistribution, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);

        retranslateUi(QQPlotDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(QQPlotDock);
    } // setupUi

    void retranslateUi(QWidget *QQPlotDock)
    {
        QQPlotDock->setWindowTitle(tr2i18n("Form", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lDataColumn->setText(tr2i18n("Data:", nullptr));
        lFuncPic->setText(QString());
        lComment->setText(tr2i18n("Comment:", nullptr));
        lDistribution->setText(tr2i18n("Distribution:", nullptr));
        lPlotRange->setText(tr2i18n("Plot range:", nullptr));
        lFunc->setText(tr2i18n("p(x) =", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabReferenceLine), tr2i18n("Reference Line", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabPercentiles), tr2i18n("Percentiles", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QQPlotDock: public Ui_QQPlotDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QQPLOTDOCK_H

