/****************************************************************************
** Meta object code from reading C++ file 'WorksheetElement.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/WorksheetElement.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'WorksheetElement.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16WorksheetElementE_t {};
} // unnamed namespace

template <> constexpr inline auto WorksheetElement::qt_create_metaobjectdata<qt_meta_tag_ZN16WorksheetElementE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WorksheetElement",
        "positionChanged",
        "",
        "WorksheetElement::PositionWrapper",
        "horizontalAlignmentChanged",
        "WorksheetElement::HorizontalAlignment",
        "verticalAlignmentChanged",
        "WorksheetElement::VerticalAlignment",
        "coordinateBindingEnabledChanged",
        "positionLogicalChanged",
        "QPointF",
        "rotationAngleChanged",
        "rotationChanged",
        "visibleChanged",
        "lockChanged",
        "coordinateSystemIndexChanged",
        "changed",
        "hoveredChanged",
        "objectPositionChanged",
        "hovered",
        "unhovered",
        "plotRangeListChanged",
        "retransform",
        "changeVisibility",
        "changeLocking",
        "prepareDrawingOrderMenu",
        "execMoveBehind",
        "QAction*",
        "execMoveInFrontOf",
        "Orientation",
        "Horizontal",
        "Vertical",
        "Both",
        "HorizontalPosition",
        "Left",
        "Center",
        "Right",
        "Relative",
        "VerticalPosition",
        "Top",
        "Bottom",
        "HorizontalAlignment",
        "VerticalAlignment",
        "PositionLimit",
        "None",
        "X",
        "Y"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(const WorksheetElement::PositionWrapper &) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'horizontalAlignmentChanged'
        QtMocHelpers::SignalData<void(const WorksheetElement::HorizontalAlignment) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'verticalAlignmentChanged'
        QtMocHelpers::SignalData<void(const WorksheetElement::VerticalAlignment) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'coordinateBindingEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'positionLogicalChanged'
        QtMocHelpers::SignalData<void(QPointF) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'rotationAngleChanged'
        QtMocHelpers::SignalData<void(qreal) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'rotationChanged'
        QtMocHelpers::SignalData<void(qreal) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void(bool) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'lockChanged'
        QtMocHelpers::SignalData<void(bool) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'coordinateSystemIndexChanged'
        QtMocHelpers::SignalData<void(int) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoveredChanged'
        QtMocHelpers::SignalData<void(bool) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'objectPositionChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hovered'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unhovered'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'plotRangeListChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'retransform'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeVisibility'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'changeLocking'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'prepareDrawingOrderMenu'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'execMoveBehind'
        QtMocHelpers::SlotData<void(QAction *)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 2 },
        }}),
        // Slot 'execMoveInFrontOf'
        QtMocHelpers::SlotData<void(QAction *)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Orientation'
        QtMocHelpers::EnumData<enum Orientation>(29, 29, QMC::EnumIsScoped).add({
            {   30, Orientation::Horizontal },
            {   31, Orientation::Vertical },
            {   32, Orientation::Both },
        }),
        // enum 'HorizontalPosition'
        QtMocHelpers::EnumData<enum HorizontalPosition>(33, 33, QMC::EnumIsScoped).add({
            {   34, HorizontalPosition::Left },
            {   35, HorizontalPosition::Center },
            {   36, HorizontalPosition::Right },
            {   37, HorizontalPosition::Relative },
        }),
        // enum 'VerticalPosition'
        QtMocHelpers::EnumData<enum VerticalPosition>(38, 38, QMC::EnumIsScoped).add({
            {   39, VerticalPosition::Top },
            {   35, VerticalPosition::Center },
            {   40, VerticalPosition::Bottom },
            {   37, VerticalPosition::Relative },
        }),
        // enum 'HorizontalAlignment'
        QtMocHelpers::EnumData<enum HorizontalAlignment>(41, 41, QMC::EnumIsScoped).add({
            {   34, HorizontalAlignment::Left },
            {   35, HorizontalAlignment::Center },
            {   36, HorizontalAlignment::Right },
        }),
        // enum 'VerticalAlignment'
        QtMocHelpers::EnumData<enum VerticalAlignment>(42, 42, QMC::EnumIsScoped).add({
            {   39, VerticalAlignment::Top },
            {   35, VerticalAlignment::Center },
            {   40, VerticalAlignment::Bottom },
        }),
        // enum 'PositionLimit'
        QtMocHelpers::EnumData<enum PositionLimit>(43, 43, QMC::EnumIsScoped).add({
            {   44, PositionLimit::None },
            {   45, PositionLimit::X },
            {   46, PositionLimit::Y },
        }),
    };
    return QtMocHelpers::metaObjectData<WorksheetElement, qt_meta_tag_ZN16WorksheetElementE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WorksheetElement::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractAspect::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16WorksheetElementE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16WorksheetElementE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16WorksheetElementE_t>.metaTypes,
    nullptr
} };

void WorksheetElement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WorksheetElement *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<WorksheetElement::PositionWrapper>>(_a[1]))); break;
        case 1: _t->horizontalAlignmentChanged((*reinterpret_cast<std::add_pointer_t<WorksheetElement::HorizontalAlignment>>(_a[1]))); break;
        case 2: _t->verticalAlignmentChanged((*reinterpret_cast<std::add_pointer_t<WorksheetElement::VerticalAlignment>>(_a[1]))); break;
        case 3: _t->coordinateBindingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->positionLogicalChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 5: _t->rotationAngleChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 6: _t->rotationChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 7: _t->visibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->lockChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->coordinateSystemIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->changed(); break;
        case 11: _t->hoveredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->objectPositionChanged(); break;
        case 13: _t->hovered(); break;
        case 14: _t->unhovered(); break;
        case 15: _t->plotRangeListChanged(); break;
        case 16: _t->retransform(); break;
        case 17: _t->changeVisibility(); break;
        case 18: _t->changeLocking(); break;
        case 19: _t->prepareDrawingOrderMenu(); break;
        case 20: _t->execMoveBehind((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 21: _t->execMoveInFrontOf((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)(const WorksheetElement::PositionWrapper & ) const>(_a, &WorksheetElement::positionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)(const WorksheetElement::HorizontalAlignment ) const>(_a, &WorksheetElement::horizontalAlignmentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)(const WorksheetElement::VerticalAlignment ) const>(_a, &WorksheetElement::verticalAlignmentChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)(bool ) const>(_a, &WorksheetElement::coordinateBindingEnabledChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)(QPointF ) const>(_a, &WorksheetElement::positionLogicalChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)(qreal ) const>(_a, &WorksheetElement::rotationAngleChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)(qreal ) const>(_a, &WorksheetElement::rotationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)(bool ) const>(_a, &WorksheetElement::visibleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)(bool ) const>(_a, &WorksheetElement::lockChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)(int ) const>(_a, &WorksheetElement::coordinateSystemIndexChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)()>(_a, &WorksheetElement::changed, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)(bool ) const>(_a, &WorksheetElement::hoveredChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)()>(_a, &WorksheetElement::objectPositionChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)()>(_a, &WorksheetElement::hovered, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)()>(_a, &WorksheetElement::unhovered, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetElement::*)()>(_a, &WorksheetElement::plotRangeListChanged, 15))
            return;
    }
}

const QMetaObject *WorksheetElement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorksheetElement::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16WorksheetElementE_t>.strings))
        return static_cast<void*>(this);
    return AbstractAspect::qt_metacast(_clname);
}

int WorksheetElement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractAspect::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void WorksheetElement::positionChanged(const WorksheetElement::PositionWrapper & _t1)const
{
    QMetaObject::activate<void>(const_cast< WorksheetElement *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void WorksheetElement::horizontalAlignmentChanged(const WorksheetElement::HorizontalAlignment _t1)const
{
    QMetaObject::activate<void>(const_cast< WorksheetElement *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void WorksheetElement::verticalAlignmentChanged(const WorksheetElement::VerticalAlignment _t1)const
{
    QMetaObject::activate<void>(const_cast< WorksheetElement *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void WorksheetElement::coordinateBindingEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< WorksheetElement *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void WorksheetElement::positionLogicalChanged(QPointF _t1)const
{
    QMetaObject::activate<void>(const_cast< WorksheetElement *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void WorksheetElement::rotationAngleChanged(qreal _t1)const
{
    QMetaObject::activate<void>(const_cast< WorksheetElement *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void WorksheetElement::rotationChanged(qreal _t1)const
{
    QMetaObject::activate<void>(const_cast< WorksheetElement *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void WorksheetElement::visibleChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< WorksheetElement *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void WorksheetElement::lockChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< WorksheetElement *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void WorksheetElement::coordinateSystemIndexChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< WorksheetElement *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void WorksheetElement::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void WorksheetElement::hoveredChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< WorksheetElement *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void WorksheetElement::objectPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void WorksheetElement::hovered()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void WorksheetElement::unhovered()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void WorksheetElement::plotRangeListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
