/********************************************************************************
** Form generated from reading UI file 'fitparameterswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FITPARAMETERSWIDGET_H
#define UI_FITPARAMETERSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FitParametersWidget
{
public:
    QGridLayout *gridLayout;
    QTableWidget *tableWidget;

    void setupUi(QWidget *FitParametersWidget)
    {
        if (FitParametersWidget->objectName().isEmpty())
            FitParametersWidget->setObjectName("FitParametersWidget");
        FitParametersWidget->resize(584, 270);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(FitParametersWidget->sizePolicy().hasHeightForWidth());
        FitParametersWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(FitParametersWidget);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        tableWidget = new QTableWidget(FitParametersWidget);
        tableWidget->setObjectName("tableWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(tableWidget->sizePolicy().hasHeightForWidth());
        tableWidget->setSizePolicy(sizePolicy1);
        tableWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        gridLayout->addWidget(tableWidget, 0, 0, 1, 2);


        retranslateUi(FitParametersWidget);

        QMetaObject::connectSlotsByName(FitParametersWidget);
    } // setupUi

    void retranslateUi(QWidget *FitParametersWidget)
    {
        (void)FitParametersWidget;
    } // retranslateUi

};

namespace Ui {
    class FitParametersWidget: public Ui_FitParametersWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FITPARAMETERSWIDGET_H

