/****************************************************************************
** Meta object code from reading C++ file 'LiveDataSource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/datasources/LiveDataSource.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'LiveDataSource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14LiveDataSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto LiveDataSource::qt_create_metaobjectdata<qt_meta_tag_ZN14LiveDataSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LiveDataSource",
        "readOnUpdateCalled",
        "",
        "read",
        "readOnUpdate",
        "plotData",
        "readyRead",
        "localSocketError",
        "QLocalSocket::LocalSocketError",
        "tcpSocketError",
        "QAbstractSocket::SocketError",
        "serialPortError",
        "QSerialPort::SerialPortError",
        "SourceType",
        "FileOrPipe",
        "NetworkTCPSocket",
        "NetworkUDPSocket",
        "LocalSocket",
        "SerialPort",
        "MQTT",
        "UpdateType",
        "TimeInterval",
        "NewData",
        "ReadingType",
        "ContinuousFixed",
        "FromEnd",
        "TillEnd",
        "WholeFile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'readOnUpdateCalled'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'read'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readOnUpdate'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'plotData'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'readyRead'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'localSocketError'
        QtMocHelpers::SlotData<void(QLocalSocket::LocalSocketError)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'tcpSocketError'
        QtMocHelpers::SlotData<void(QAbstractSocket::SocketError)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'serialPortError'
        QtMocHelpers::SlotData<void(QSerialPort::SerialPortError)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SourceType'
        QtMocHelpers::EnumData<enum SourceType>(13, 13, QMC::EnumIsScoped).add({
            {   14, SourceType::FileOrPipe },
            {   15, SourceType::NetworkTCPSocket },
            {   16, SourceType::NetworkUDPSocket },
            {   17, SourceType::LocalSocket },
            {   18, SourceType::SerialPort },
            {   19, SourceType::MQTT },
        }),
        // enum 'UpdateType'
        QtMocHelpers::EnumData<enum UpdateType>(20, 20, QMC::EnumIsScoped).add({
            {   21, UpdateType::TimeInterval },
            {   22, UpdateType::NewData },
        }),
        // enum 'ReadingType'
        QtMocHelpers::EnumData<enum ReadingType>(23, 23, QMC::EnumIsScoped).add({
            {   24, ReadingType::ContinuousFixed },
            {   25, ReadingType::FromEnd },
            {   26, ReadingType::TillEnd },
            {   27, ReadingType::WholeFile },
        }),
    };
    return QtMocHelpers::metaObjectData<LiveDataSource, qt_meta_tag_ZN14LiveDataSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LiveDataSource::staticMetaObject = { {
    QMetaObject::SuperData::link<Spreadsheet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LiveDataSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LiveDataSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14LiveDataSourceE_t>.metaTypes,
    nullptr
} };

void LiveDataSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LiveDataSource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->readOnUpdateCalled(); break;
        case 1: _t->read(); break;
        case 2: _t->readOnUpdate(); break;
        case 3: _t->plotData(); break;
        case 4: _t->readyRead(); break;
        case 5: _t->localSocketError((*reinterpret_cast<std::add_pointer_t<QLocalSocket::LocalSocketError>>(_a[1]))); break;
        case 6: _t->tcpSocketError((*reinterpret_cast<std::add_pointer_t<QAbstractSocket::SocketError>>(_a[1]))); break;
        case 7: _t->serialPortError((*reinterpret_cast<std::add_pointer_t<QSerialPort::SerialPortError>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSocket::SocketError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LiveDataSource::*)()>(_a, &LiveDataSource::readOnUpdateCalled, 0))
            return;
    }
}

const QMetaObject *LiveDataSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LiveDataSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LiveDataSourceE_t>.strings))
        return static_cast<void*>(this);
    return Spreadsheet::qt_metacast(_clname);
}

int LiveDataSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Spreadsheet::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void LiveDataSource::readOnUpdateCalled()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
