/****************************************************************************
** Meta object code from reading C++ file 'CartesianPlotLegendDock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/dockwidgets/CartesianPlotLegendDock.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CartesianPlotLegendDock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23CartesianPlotLegendDockE_t {};
} // unnamed namespace

template <> constexpr inline auto CartesianPlotLegendDock::qt_create_metaobjectdata<qt_meta_tag_ZN23CartesianPlotLegendDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CartesianPlotLegendDock",
        "info",
        "",
        "lockChanged",
        "labelFontChanged",
        "QFont",
        "usePlotColorChanged",
        "labelColorChanged",
        "QColor",
        "labelOrderChanged",
        "lineSymbolWidthChanged",
        "positionXChanged",
        "positionYChanged",
        "customPositionXChanged",
        "customPositionYChanged",
        "horizontalAlignmentChanged",
        "index",
        "verticalAlignmentChanged",
        "rotationChanged",
        "value",
        "bindingChanged",
        "checked",
        "borderCornerRadiusChanged",
        "layoutTopMarginChanged",
        "layoutBottomMarginChanged",
        "layoutRightMarginChanged",
        "layoutLeftMarginChanged",
        "layoutHorizontalSpacingChanged",
        "layoutVerticalSpacingChanged",
        "layoutColumnCountChanged",
        "legendLabelFontChanged",
        "QFont&",
        "legendUsePlotColorChanged",
        "legendLabelColorChanged",
        "QColor&",
        "legendLabelOrderChanged",
        "legendLineSymbolWidthChanged",
        "legendPositionChanged",
        "CartesianPlotLegend::PositionWrapper",
        "legendPositionLogicalChanged",
        "QPointF",
        "legendRotationAngleChanged",
        "legendLockChanged",
        "legendHorizontalAlignmentChanged",
        "WorksheetElement::HorizontalAlignment",
        "legendVerticalAlignmentChanged",
        "WorksheetElement::VerticalAlignment",
        "legendBorderCornerRadiusChanged",
        "legendLayoutTopMarginChanged",
        "legendLayoutBottomMarginChanged",
        "legendLayoutLeftMarginChanged",
        "legendLayoutRightMarginChanged",
        "legendLayoutVerticalSpacingChanged",
        "legendLayoutHorizontalSpacingChanged",
        "legendLayoutColumnCountChanged",
        "loadConfigFromTemplate",
        "KConfig&",
        "saveConfigAsTemplate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'info'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'lockChanged'
        QtMocHelpers::SlotData<void(bool)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'labelFontChanged'
        QtMocHelpers::SlotData<void(const QFont &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'usePlotColorChanged'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'labelColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'labelOrderChanged'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'lineSymbolWidthChanged'
        QtMocHelpers::SlotData<void(double)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'positionXChanged'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'positionYChanged'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'customPositionXChanged'
        QtMocHelpers::SlotData<void(double)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'customPositionYChanged'
        QtMocHelpers::SlotData<void(double)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'horizontalAlignmentChanged'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'verticalAlignmentChanged'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'rotationChanged'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'bindingChanged'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'borderCornerRadiusChanged'
        QtMocHelpers::SlotData<void(double)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'layoutTopMarginChanged'
        QtMocHelpers::SlotData<void(double)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'layoutBottomMarginChanged'
        QtMocHelpers::SlotData<void(double)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'layoutRightMarginChanged'
        QtMocHelpers::SlotData<void(double)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'layoutLeftMarginChanged'
        QtMocHelpers::SlotData<void(double)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'layoutHorizontalSpacingChanged'
        QtMocHelpers::SlotData<void(double)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'layoutVerticalSpacingChanged'
        QtMocHelpers::SlotData<void(double)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'layoutColumnCountChanged'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'legendLabelFontChanged'
        QtMocHelpers::SlotData<void(QFont &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 2 },
        }}),
        // Slot 'legendUsePlotColorChanged'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'legendLabelColorChanged'
        QtMocHelpers::SlotData<void(QColor &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 2 },
        }}),
        // Slot 'legendLabelOrderChanged'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'legendLineSymbolWidthChanged'
        QtMocHelpers::SlotData<void(float)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Slot 'legendPositionChanged'
        QtMocHelpers::SlotData<void(const CartesianPlotLegend::PositionWrapper &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 2 },
        }}),
        // Slot 'legendPositionLogicalChanged'
        QtMocHelpers::SlotData<void(QPointF)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 2 },
        }}),
        // Slot 'legendRotationAngleChanged'
        QtMocHelpers::SlotData<void(qreal)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'legendLockChanged'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'legendHorizontalAlignmentChanged'
        QtMocHelpers::SlotData<void(const WorksheetElement::HorizontalAlignment)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 2 },
        }}),
        // Slot 'legendVerticalAlignmentChanged'
        QtMocHelpers::SlotData<void(const WorksheetElement::VerticalAlignment)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 2 },
        }}),
        // Slot 'legendBorderCornerRadiusChanged'
        QtMocHelpers::SlotData<void(float)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Slot 'legendLayoutTopMarginChanged'
        QtMocHelpers::SlotData<void(float)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Slot 'legendLayoutBottomMarginChanged'
        QtMocHelpers::SlotData<void(float)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Slot 'legendLayoutLeftMarginChanged'
        QtMocHelpers::SlotData<void(float)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Slot 'legendLayoutRightMarginChanged'
        QtMocHelpers::SlotData<void(float)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Slot 'legendLayoutVerticalSpacingChanged'
        QtMocHelpers::SlotData<void(float)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Slot 'legendLayoutHorizontalSpacingChanged'
        QtMocHelpers::SlotData<void(float)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Slot 'legendLayoutColumnCountChanged'
        QtMocHelpers::SlotData<void(int)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'loadConfigFromTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 56, 2 },
        }}),
        // Slot 'saveConfigAsTemplate'
        QtMocHelpers::SlotData<void(KConfig &)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 56, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CartesianPlotLegendDock, qt_meta_tag_ZN23CartesianPlotLegendDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CartesianPlotLegendDock::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseDock::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23CartesianPlotLegendDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23CartesianPlotLegendDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23CartesianPlotLegendDockE_t>.metaTypes,
    nullptr
} };

void CartesianPlotLegendDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CartesianPlotLegendDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->lockChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->labelFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 3: _t->usePlotColorChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->labelColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 5: _t->labelOrderChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->lineSymbolWidthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 7: _t->positionXChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->positionYChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->customPositionXChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->customPositionYChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 11: _t->horizontalAlignmentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->verticalAlignmentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->rotationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->bindingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->borderCornerRadiusChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 16: _t->layoutTopMarginChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: _t->layoutBottomMarginChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 18: _t->layoutRightMarginChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 19: _t->layoutLeftMarginChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 20: _t->layoutHorizontalSpacingChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 21: _t->layoutVerticalSpacingChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 22: _t->layoutColumnCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->legendLabelFontChanged((*reinterpret_cast<std::add_pointer_t<QFont&>>(_a[1]))); break;
        case 24: _t->legendUsePlotColorChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->legendLabelColorChanged((*reinterpret_cast<std::add_pointer_t<QColor&>>(_a[1]))); break;
        case 26: _t->legendLabelOrderChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->legendLineSymbolWidthChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 28: _t->legendPositionChanged((*reinterpret_cast<std::add_pointer_t<CartesianPlotLegend::PositionWrapper>>(_a[1]))); break;
        case 29: _t->legendPositionLogicalChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 30: _t->legendRotationAngleChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 31: _t->legendLockChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->legendHorizontalAlignmentChanged((*reinterpret_cast<std::add_pointer_t<WorksheetElement::HorizontalAlignment>>(_a[1]))); break;
        case 33: _t->legendVerticalAlignmentChanged((*reinterpret_cast<std::add_pointer_t<WorksheetElement::VerticalAlignment>>(_a[1]))); break;
        case 34: _t->legendBorderCornerRadiusChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 35: _t->legendLayoutTopMarginChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 36: _t->legendLayoutBottomMarginChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 37: _t->legendLayoutLeftMarginChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 38: _t->legendLayoutRightMarginChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 39: _t->legendLayoutVerticalSpacingChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 40: _t->legendLayoutHorizontalSpacingChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 41: _t->legendLayoutColumnCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 42: _t->loadConfigFromTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        case 43: _t->saveConfigAsTemplate((*reinterpret_cast<std::add_pointer_t<KConfig&>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CartesianPlotLegendDock::*)(const QString & )>(_a, &CartesianPlotLegendDock::info, 0))
            return;
    }
}

const QMetaObject *CartesianPlotLegendDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CartesianPlotLegendDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23CartesianPlotLegendDockE_t>.strings))
        return static_cast<void*>(this);
    return BaseDock::qt_metacast(_clname);
}

int CartesianPlotLegendDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseDock::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void CartesianPlotLegendDock::info(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
