/********************************************************************************
** Form generated from reading UI file 'barplotdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BARPLOTDOCK_H
#define UI_BARPLOTDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_BarPlotDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout_3;
    QFrame *frameXColumn;
    QHBoxLayout *horizontalLayout;
    QPushButton *bRemoveXColumn;
    QCheckBox *chkVisible;
    QComboBox *cbType;
    QLabel *lXData;
    QLabel *lXColumn;
    QSpacerItem *verticalSpacerST;
    QLabel *lName;
    TimedLineEdit *leName;
    QLabel *lType;
    QLabel *lDataColumn;
    QFrame *frameDataColumns;
    QSpacerItem *verticalSpacer_2;
    QComboBox *cbOrientation;
    QLabel *lComment;
    QSpacerItem *verticalSpacerGeneral;
    QComboBox *cbPlotRanges;
    QLabel *lPlotRange;
    QSpacerItem *hsName;
    QLabel *lOrientation;
    ResizableTextEdit *teComment;
    QSpacerItem *verticalSpacerST_2;
    QCheckBox *chkLegendVisible;
    QWidget *tabBars;
    QGridLayout *gridLayout;
    QComboBox *cbNumber;
    QLabel *lBorder;
    QLabel *lFilling;
    QSpacerItem *verticalSpacer_4;
    QLabel *lNumber;
    QLabel *lWidthFactor;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *horizontalSpacer;
    QSpinBox *sbWidthFactor;
    QSpacerItem *verticalSpacer_7;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacer_5;
    QSpacerItem *verticalSpacer_8;
    QWidget *tabValues;
    QWidget *tabErrorBars;
    QGridLayout *gridLayout_2;
    QSpacerItem *verticalSpacer_6;
    QLabel *lErrorBarsNumber;
    QComboBox *cbErrorBarsNumber;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *BarPlotDock)
    {
        if (BarPlotDock->objectName().isEmpty())
            BarPlotDock->setObjectName("BarPlotDock");
        BarPlotDock->resize(391, 704);
        verticalLayout = new QVBoxLayout(BarPlotDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(BarPlotDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout_3 = new QGridLayout(tabGeneral);
        gridLayout_3->setObjectName("gridLayout_3");
        frameXColumn = new QFrame(tabGeneral);
        frameXColumn->setObjectName("frameXColumn");
        frameXColumn->setFrameShape(QFrame::Shape::NoFrame);
        frameXColumn->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout = new QHBoxLayout(frameXColumn);
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        bRemoveXColumn = new QPushButton(frameXColumn);
        bRemoveXColumn->setObjectName("bRemoveXColumn");

        horizontalLayout->addWidget(bRemoveXColumn);


        gridLayout_3->addWidget(frameXColumn, 4, 2, 1, 1);

        chkVisible = new QCheckBox(tabGeneral);
        chkVisible->setObjectName("chkVisible");

        gridLayout_3->addWidget(chkVisible, 17, 0, 1, 1);

        cbType = new QComboBox(tabGeneral);
        cbType->setObjectName("cbType");

        gridLayout_3->addWidget(cbType, 7, 2, 1, 1);

        lXData = new QLabel(tabGeneral);
        lXData->setObjectName("lXData");

        gridLayout_3->addWidget(lXData, 4, 0, 1, 1);

        lXColumn = new QLabel(tabGeneral);
        lXColumn->setObjectName("lXColumn");

        gridLayout_3->addWidget(lXColumn, 3, 0, 1, 1);

        verticalSpacerST = new QSpacerItem(32, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacerST, 2, 0, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout_3->addWidget(lName, 0, 0, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");

        gridLayout_3->addWidget(leName, 0, 2, 1, 1);

        lType = new QLabel(tabGeneral);
        lType->setObjectName("lType");

        gridLayout_3->addWidget(lType, 7, 0, 1, 1);

        lDataColumn = new QLabel(tabGeneral);
        lDataColumn->setObjectName("lDataColumn");
        lDataColumn->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout_3->addWidget(lDataColumn, 5, 0, 1, 1);

        frameDataColumns = new QFrame(tabGeneral);
        frameDataColumns->setObjectName("frameDataColumns");
        frameDataColumns->setFrameShape(QFrame::Shape::NoFrame);
        frameDataColumns->setFrameShadow(QFrame::Shadow::Raised);

        gridLayout_3->addWidget(frameDataColumns, 5, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_2, 13, 0, 1, 1);

        cbOrientation = new QComboBox(tabGeneral);
        cbOrientation->setObjectName("cbOrientation");

        gridLayout_3->addWidget(cbOrientation, 8, 2, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(lComment, 1, 0, 1, 1);

        verticalSpacerGeneral = new QSpacerItem(24, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout_3->addItem(verticalSpacerGeneral, 15, 0, 1, 1);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout_3->addWidget(cbPlotRanges, 14, 2, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout_3->addWidget(lPlotRange, 14, 0, 1, 1);

        hsName = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(hsName, 0, 1, 1, 1);

        lOrientation = new QLabel(tabGeneral);
        lOrientation->setObjectName("lOrientation");

        gridLayout_3->addWidget(lOrientation, 8, 0, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout_3->addWidget(teComment, 1, 2, 1, 1);

        verticalSpacerST_2 = new QSpacerItem(32, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacerST_2, 6, 0, 1, 1);

        chkLegendVisible = new QCheckBox(tabGeneral);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout_3->addWidget(chkLegendVisible, 16, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabBars = new QWidget();
        tabBars->setObjectName("tabBars");
        gridLayout = new QGridLayout(tabBars);
        gridLayout->setObjectName("gridLayout");
        cbNumber = new QComboBox(tabBars);
        cbNumber->setObjectName("cbNumber");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbNumber->sizePolicy().hasHeightForWidth());
        cbNumber->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbNumber, 0, 2, 1, 1);

        lBorder = new QLabel(tabBars);
        lBorder->setObjectName("lBorder");
        QFont font;
        font.setBold(true);
        lBorder->setFont(font);

        gridLayout->addWidget(lBorder, 7, 0, 1, 1);

        lFilling = new QLabel(tabBars);
        lFilling->setObjectName("lFilling");
        lFilling->setFont(font);

        gridLayout->addWidget(lFilling, 4, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_4, 9, 0, 1, 1);

        lNumber = new QLabel(tabBars);
        lNumber->setObjectName("lNumber");

        gridLayout->addWidget(lNumber, 0, 0, 1, 1);

        lWidthFactor = new QLabel(tabBars);
        lWidthFactor->setObjectName("lWidthFactor");

        gridLayout->addWidget(lWidthFactor, 2, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 3, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 2, 1, 1, 1);

        sbWidthFactor = new QSpinBox(tabBars);
        sbWidthFactor->setObjectName("sbWidthFactor");
        sizePolicy.setHeightForWidth(sbWidthFactor->sizePolicy().hasHeightForWidth());
        sbWidthFactor->setSizePolicy(sizePolicy);
        sbWidthFactor->setMaximum(100);
        sbWidthFactor->setSingleStep(10);
        sbWidthFactor->setValue(100);

        gridLayout->addWidget(sbWidthFactor, 2, 2, 1, 2);

        verticalSpacer_7 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_7, 6, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_5, 5, 0, 1, 1);

        verticalSpacer_8 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_8, 8, 0, 1, 1);

        tabWidget->addTab(tabBars, QString());
        tabValues = new QWidget();
        tabValues->setObjectName("tabValues");
        tabWidget->addTab(tabValues, QString());
        tabErrorBars = new QWidget();
        tabErrorBars->setObjectName("tabErrorBars");
        gridLayout_2 = new QGridLayout(tabErrorBars);
        gridLayout_2->setObjectName("gridLayout_2");
        verticalSpacer_6 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_6, 1, 0, 1, 1);

        lErrorBarsNumber = new QLabel(tabErrorBars);
        lErrorBarsNumber->setObjectName("lErrorBarsNumber");

        gridLayout_2->addWidget(lErrorBarsNumber, 0, 0, 1, 1);

        cbErrorBarsNumber = new QComboBox(tabErrorBars);
        cbErrorBarsNumber->setObjectName("cbErrorBarsNumber");
        sizePolicy.setHeightForWidth(cbErrorBarsNumber->sizePolicy().hasHeightForWidth());
        cbErrorBarsNumber->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(cbErrorBarsNumber, 0, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(13, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 0, 1, 1, 1);

        tabWidget->addTab(tabErrorBars, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, bRemoveXColumn);
        QWidget::setTabOrder(bRemoveXColumn, cbType);
        QWidget::setTabOrder(cbType, cbOrientation);
        QWidget::setTabOrder(cbOrientation, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);
        QWidget::setTabOrder(chkVisible, cbNumber);
        QWidget::setTabOrder(cbNumber, sbWidthFactor);
        QWidget::setTabOrder(sbWidthFactor, cbErrorBarsNumber);

        retranslateUi(BarPlotDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(BarPlotDock);
    } // setupUi

    void retranslateUi(QWidget *BarPlotDock)
    {
        bRemoveXColumn->setText(QString());
        chkVisible->setText(tr2i18n("visible", nullptr));
        lXData->setText(tr2i18n("x:", nullptr));
        lXColumn->setText(tr2i18n("Data:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lType->setText(tr2i18n("Type:", nullptr));
        lDataColumn->setText(tr2i18n("y:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        lOrientation->setText(tr2i18n("Orientation:", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        lBorder->setText(tr2i18n("Border", nullptr));
        lFilling->setText(tr2i18n("Filling", nullptr));
        lNumber->setText(tr2i18n("Column", nullptr));
        lWidthFactor->setText(tr2i18n("Width", nullptr));
        sbWidthFactor->setSuffix(tr2i18n("%", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabBars), tr2i18n("Bars", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabValues), tr2i18n("Values", nullptr));
        lErrorBarsNumber->setText(tr2i18n("Column", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabErrorBars), tr2i18n("Error Bars", nullptr));
        (void)BarPlotDock;
    } // retranslateUi

};

namespace Ui {
    class BarPlotDock: public Ui_BarPlotDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BARPLOTDOCK_H

