/****************************************************************************
** Meta object code from reading C++ file 'ProjectExplorer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/ProjectExplorer.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ProjectExplorer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ProjectExplorerE_t {};
} // unnamed namespace

template <> constexpr inline auto ProjectExplorer::qt_create_metaobjectdata<qt_meta_tag_ZN15ProjectExplorerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProjectExplorer",
        "currentAspectChanged",
        "",
        "AbstractAspect*",
        "activateView",
        "selectedAspectsChanged",
        "QList<AbstractAspect*>&",
        "hiddenAspectSelected",
        "const AbstractAspect*",
        "aspectAdded",
        "toggleColumn",
        "showAllColumns",
        "filterTextChanged",
        "toggleFilterOptionsMenu",
        "resizeHeader",
        "expandSelected",
        "collapseSelected",
        "deleteSelected",
        "changeSelectedVisible",
        "navigateTo",
        "path",
        "selectIndex",
        "QModelIndex",
        "deselectIndex",
        "selectionChanged",
        "QItemSelection",
        "selected",
        "deselected",
        "save",
        "QXmlStreamWriter*",
        "load",
        "XmlStreamReader*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentAspectChanged'
        QtMocHelpers::SignalData<void(AbstractAspect *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'activateView'
        QtMocHelpers::SignalData<void(AbstractAspect *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'selectedAspectsChanged'
        QtMocHelpers::SignalData<void(QList<AbstractAspect*> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'hiddenAspectSelected'
        QtMocHelpers::SignalData<void(const AbstractAspect *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'aspectAdded'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'toggleColumn'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'showAllColumns'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'filterTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'toggleFilterOptionsMenu'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'resizeHeader'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'expandSelected'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'collapseSelected'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteSelected'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeSelectedVisible'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'navigateTo'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'selectIndex'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Slot 'deselectIndex'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { 0x80000000 | 25, 27 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void(QXmlStreamWriter *) const>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<bool(XmlStreamReader *)>(30, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 31, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProjectExplorer, qt_meta_tag_ZN15ProjectExplorerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProjectExplorer::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ProjectExplorerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ProjectExplorerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ProjectExplorerE_t>.metaTypes,
    nullptr
} };

void ProjectExplorer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProjectExplorer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentAspectChanged((*reinterpret_cast<std::add_pointer_t<AbstractAspect*>>(_a[1]))); break;
        case 1: _t->activateView((*reinterpret_cast<std::add_pointer_t<AbstractAspect*>>(_a[1]))); break;
        case 2: _t->selectedAspectsChanged((*reinterpret_cast<std::add_pointer_t<QList<AbstractAspect*>&>>(_a[1]))); break;
        case 3: _t->hiddenAspectSelected((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 4: _t->aspectAdded((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 5: _t->toggleColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->showAllColumns(); break;
        case 7: _t->filterTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->toggleFilterOptionsMenu((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->resizeHeader(); break;
        case 10: _t->expandSelected(); break;
        case 11: _t->collapseSelected(); break;
        case 12: _t->deleteSelected(); break;
        case 13: _t->changeSelectedVisible(); break;
        case 14: _t->navigateTo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->selectIndex((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 16: _t->deselectIndex((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 17: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 18: _t->save((*reinterpret_cast<std::add_pointer_t<QXmlStreamWriter*>>(_a[1]))); break;
        case 19: { bool _r = _t->load((*reinterpret_cast<std::add_pointer_t<XmlStreamReader*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProjectExplorer::*)(AbstractAspect * )>(_a, &ProjectExplorer::currentAspectChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectExplorer::*)(AbstractAspect * )>(_a, &ProjectExplorer::activateView, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectExplorer::*)(QList<AbstractAspect*> & )>(_a, &ProjectExplorer::selectedAspectsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectExplorer::*)(const AbstractAspect * )>(_a, &ProjectExplorer::hiddenAspectSelected, 3))
            return;
    }
}

const QMetaObject *ProjectExplorer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProjectExplorer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ProjectExplorerE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ProjectExplorer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void ProjectExplorer::currentAspectChanged(AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ProjectExplorer::activateView(AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ProjectExplorer::selectedAspectsChanged(QList<AbstractAspect*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ProjectExplorer::hiddenAspectSelected(const AbstractAspect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
