/********************************************************************************
** Form generated from reading UI file 'addsubtractvaluewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDSUBTRACTVALUEWIDGET_H
#define UI_ADDSUBTRACTVALUEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AddSubtractValueWidget
{
public:
    QGridLayout *gridLayout;
    QLineEdit *leValueStart;
    QLabel *lValue;
    QLineEdit *leBaselineParameter2;
    QLabel *lType;
    QLabel *lTimeValue;
    QSpinBox *sbBaselineParameter1;
    QLineEdit *leValue;
    QLabel *lTimeValueStart;
    QLabel *lValueEnd;
    QDateTimeEdit *dteTimeValueEnd;
    QSpinBox *sbBaselineParameter3;
    QLabel *lBaselineParameter1;
    QLabel *lPreview;
    QLabel *lBaselineParameter2;
    QLabel *lValueStart;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QLineEdit *leTimeValue;
    QComboBox *cbTimeUnits;
    QComboBox *cbType;
    QCheckBox *chbPreview;
    QLabel *lBaselineParameter3;
    QFrame *framePreview;
    QDateTimeEdit *dteTimeValueStart;
    QLineEdit *leValueEnd;
    QLabel *lTimeValueEnd;

    void setupUi(QWidget *AddSubtractValueWidget)
    {
        if (AddSubtractValueWidget->objectName().isEmpty())
            AddSubtractValueWidget->setObjectName("AddSubtractValueWidget");
        AddSubtractValueWidget->resize(381, 618);
        gridLayout = new QGridLayout(AddSubtractValueWidget);
        gridLayout->setObjectName("gridLayout");
        leValueStart = new QLineEdit(AddSubtractValueWidget);
        leValueStart->setObjectName("leValueStart");

        gridLayout->addWidget(leValueStart, 2, 1, 1, 1);

        lValue = new QLabel(AddSubtractValueWidget);
        lValue->setObjectName("lValue");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lValue->sizePolicy().hasHeightForWidth());
        lValue->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lValue, 1, 0, 1, 1);

        leBaselineParameter2 = new QLineEdit(AddSubtractValueWidget);
        leBaselineParameter2->setObjectName("leBaselineParameter2");

        gridLayout->addWidget(leBaselineParameter2, 8, 1, 1, 1);

        lType = new QLabel(AddSubtractValueWidget);
        lType->setObjectName("lType");
        sizePolicy.setHeightForWidth(lType->sizePolicy().hasHeightForWidth());
        lType->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lType, 0, 0, 1, 1);

        lTimeValue = new QLabel(AddSubtractValueWidget);
        lTimeValue->setObjectName("lTimeValue");
        sizePolicy.setHeightForWidth(lTimeValue->sizePolicy().hasHeightForWidth());
        lTimeValue->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lTimeValue, 4, 0, 1, 1);

        sbBaselineParameter1 = new QSpinBox(AddSubtractValueWidget);
        sbBaselineParameter1->setObjectName("sbBaselineParameter1");
        sbBaselineParameter1->setValue(6);

        gridLayout->addWidget(sbBaselineParameter1, 7, 1, 1, 1);

        leValue = new QLineEdit(AddSubtractValueWidget);
        leValue->setObjectName("leValue");

        gridLayout->addWidget(leValue, 1, 1, 1, 1);

        lTimeValueStart = new QLabel(AddSubtractValueWidget);
        lTimeValueStart->setObjectName("lTimeValueStart");
        sizePolicy.setHeightForWidth(lTimeValueStart->sizePolicy().hasHeightForWidth());
        lTimeValueStart->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lTimeValueStart, 5, 0, 1, 1);

        lValueEnd = new QLabel(AddSubtractValueWidget);
        lValueEnd->setObjectName("lValueEnd");
        sizePolicy.setHeightForWidth(lValueEnd->sizePolicy().hasHeightForWidth());
        lValueEnd->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lValueEnd, 3, 0, 1, 1);

        dteTimeValueEnd = new QDateTimeEdit(AddSubtractValueWidget);
        dteTimeValueEnd->setObjectName("dteTimeValueEnd");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(dteTimeValueEnd->sizePolicy().hasHeightForWidth());
        dteTimeValueEnd->setSizePolicy(sizePolicy1);
        dteTimeValueEnd->setTimeSpec(Qt::UTC);

        gridLayout->addWidget(dteTimeValueEnd, 6, 1, 1, 1);

        sbBaselineParameter3 = new QSpinBox(AddSubtractValueWidget);
        sbBaselineParameter3->setObjectName("sbBaselineParameter3");
        sizePolicy1.setHeightForWidth(sbBaselineParameter3->sizePolicy().hasHeightForWidth());
        sbBaselineParameter3->setSizePolicy(sizePolicy1);
        sbBaselineParameter3->setMinimum(1);
        sbBaselineParameter3->setMaximum(1000);
        sbBaselineParameter3->setValue(10);

        gridLayout->addWidget(sbBaselineParameter3, 9, 1, 1, 1);

        lBaselineParameter1 = new QLabel(AddSubtractValueWidget);
        lBaselineParameter1->setObjectName("lBaselineParameter1");
        sizePolicy.setHeightForWidth(lBaselineParameter1->sizePolicy().hasHeightForWidth());
        lBaselineParameter1->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lBaselineParameter1, 7, 0, 1, 1);

        lPreview = new QLabel(AddSubtractValueWidget);
        lPreview->setObjectName("lPreview");
        sizePolicy.setHeightForWidth(lPreview->sizePolicy().hasHeightForWidth());
        lPreview->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lPreview, 10, 0, 1, 1);

        lBaselineParameter2 = new QLabel(AddSubtractValueWidget);
        lBaselineParameter2->setObjectName("lBaselineParameter2");
        sizePolicy.setHeightForWidth(lBaselineParameter2->sizePolicy().hasHeightForWidth());
        lBaselineParameter2->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lBaselineParameter2, 8, 0, 1, 1);

        lValueStart = new QLabel(AddSubtractValueWidget);
        lValueStart->setObjectName("lValueStart");
        sizePolicy.setHeightForWidth(lValueStart->sizePolicy().hasHeightForWidth());
        lValueStart->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lValueStart, 2, 0, 1, 1);

        frame = new QFrame(AddSubtractValueWidget);
        frame->setObjectName("frame");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy2);
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        leTimeValue = new QLineEdit(frame);
        leTimeValue->setObjectName("leTimeValue");

        horizontalLayout->addWidget(leTimeValue);

        cbTimeUnits = new QComboBox(frame);
        cbTimeUnits->setObjectName("cbTimeUnits");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(cbTimeUnits->sizePolicy().hasHeightForWidth());
        cbTimeUnits->setSizePolicy(sizePolicy3);

        horizontalLayout->addWidget(cbTimeUnits);


        gridLayout->addWidget(frame, 4, 1, 1, 1);

        cbType = new QComboBox(AddSubtractValueWidget);
        cbType->setObjectName("cbType");
        sizePolicy1.setHeightForWidth(cbType->sizePolicy().hasHeightForWidth());
        cbType->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbType, 0, 1, 1, 1);

        chbPreview = new QCheckBox(AddSubtractValueWidget);
        chbPreview->setObjectName("chbPreview");
        sizePolicy1.setHeightForWidth(chbPreview->sizePolicy().hasHeightForWidth());
        chbPreview->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(chbPreview, 10, 1, 1, 1);

        lBaselineParameter3 = new QLabel(AddSubtractValueWidget);
        lBaselineParameter3->setObjectName("lBaselineParameter3");
        sizePolicy.setHeightForWidth(lBaselineParameter3->sizePolicy().hasHeightForWidth());
        lBaselineParameter3->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lBaselineParameter3, 9, 0, 1, 1);

        framePreview = new QFrame(AddSubtractValueWidget);
        framePreview->setObjectName("framePreview");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(framePreview->sizePolicy().hasHeightForWidth());
        framePreview->setSizePolicy(sizePolicy4);
        framePreview->setMinimumSize(QSize(200, 200));
        framePreview->setFrameShape(QFrame::StyledPanel);
        framePreview->setFrameShadow(QFrame::Raised);

        gridLayout->addWidget(framePreview, 11, 1, 1, 1);

        dteTimeValueStart = new QDateTimeEdit(AddSubtractValueWidget);
        dteTimeValueStart->setObjectName("dteTimeValueStart");
        sizePolicy1.setHeightForWidth(dteTimeValueStart->sizePolicy().hasHeightForWidth());
        dteTimeValueStart->setSizePolicy(sizePolicy1);
        dteTimeValueStart->setTimeSpec(Qt::UTC);

        gridLayout->addWidget(dteTimeValueStart, 5, 1, 1, 1);

        leValueEnd = new QLineEdit(AddSubtractValueWidget);
        leValueEnd->setObjectName("leValueEnd");

        gridLayout->addWidget(leValueEnd, 3, 1, 1, 1);

        lTimeValueEnd = new QLabel(AddSubtractValueWidget);
        lTimeValueEnd->setObjectName("lTimeValueEnd");
        sizePolicy.setHeightForWidth(lTimeValueEnd->sizePolicy().hasHeightForWidth());
        lTimeValueEnd->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lTimeValueEnd, 6, 0, 1, 1);


        retranslateUi(AddSubtractValueWidget);

        QMetaObject::connectSlotsByName(AddSubtractValueWidget);
    } // setupUi

    void retranslateUi(QWidget *AddSubtractValueWidget)
    {
        lValue->setText(tr2i18n("Value:", nullptr));
        lType->setText(tr2i18n("Add:", nullptr));
        lTimeValue->setText(tr2i18n("Value:", nullptr));
        lTimeValueStart->setText(tr2i18n("Start Time:", nullptr));
        lValueEnd->setText(tr2i18n("End Value:", nullptr));
        lBaselineParameter1->setText(tr2i18n("Smoothness (Power of 10):", nullptr));
        lPreview->setText(tr2i18n("Preview:", nullptr));
        lBaselineParameter2->setText(tr2i18n("Termination Ratio:", nullptr));
        lValueStart->setText(tr2i18n("Start Value:", nullptr));
        chbPreview->setText(QString());
        lBaselineParameter3->setText(tr2i18n("Iterations:", nullptr));
        lTimeValueEnd->setText(tr2i18n("End Time:", nullptr));
        (void)AddSubtractValueWidget;
    } // retranslateUi

};

namespace Ui {
    class AddSubtractValueWidget: public Ui_AddSubtractValueWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADDSUBTRACTVALUEWIDGET_H

