/********************************************************************************
** Form generated from reading UI file 'notebookdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NOTEBOOKDOCK_H
#define UI_NOTEBOOKDOCK_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_NotebookDock
{
public:
    QGridLayout *gridLayout_2;
    QTabWidget *tabWidget;
    QWidget *general;
    QGridLayout *gridLayout;
    QLabel *lName;
    QSpacerItem *horizontalSpacer_8;
    TimedLineEdit *leName;
    QLabel *lComment;
    ResizableTextEdit *teComment;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_4;
    QPushButton *bEvaluate;
    QPushButton *bRestart;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *NotebookDock)
    {
        if (NotebookDock->objectName().isEmpty())
            NotebookDock->setObjectName("NotebookDock");
        NotebookDock->resize(345, 265);
        gridLayout_2 = new QGridLayout(NotebookDock);
        gridLayout_2->setObjectName("gridLayout_2");
        tabWidget = new QTabWidget(NotebookDock);
        tabWidget->setObjectName("tabWidget");
        general = new QWidget();
        general->setObjectName("general");
        gridLayout = new QGridLayout(general);
        gridLayout->setObjectName("gridLayout");
        lName = new QLabel(general);
        lName->setObjectName("lName");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lName->sizePolicy().hasHeightForWidth());
        lName->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        horizontalSpacer_8 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_8, 0, 1, 1, 1);

        leName = new TimedLineEdit(general);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 1);

        lComment = new QLabel(general);
        lComment->setObjectName("lComment");
        sizePolicy.setHeightForWidth(lComment->sizePolicy().hasHeightForWidth());
        lComment->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        teComment = new ResizableTextEdit(general);
        teComment->setObjectName("teComment");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(teComment->sizePolicy().hasHeightForWidth());
        teComment->setSizePolicy(sizePolicy1);
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 1);

        verticalSpacer_3 = new QSpacerItem(58, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 2, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        bEvaluate = new QPushButton(general);
        bEvaluate->setObjectName("bEvaluate");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("system-run")));
        bEvaluate->setIcon(icon);

        horizontalLayout_4->addWidget(bEvaluate);

        bRestart = new QPushButton(general);
        bRestart->setObjectName("bRestart");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("system-reboot")));
        bRestart->setIcon(icon1);

        horizontalLayout_4->addWidget(bRestart);


        gridLayout->addLayout(horizontalLayout_4, 3, 0, 1, 3);

        verticalSpacer = new QSpacerItem(24, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 4, 0, 1, 3);

        tabWidget->addTab(general, QString());

        gridLayout_2->addWidget(tabWidget, 0, 0, 1, 1);


        retranslateUi(NotebookDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(NotebookDock);
    } // setupUi

    void retranslateUi(QWidget *NotebookDock)
    {
        lName->setText(tr2i18n("Name:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        bEvaluate->setText(tr2i18n("Evaluate", nullptr));
        bRestart->setText(tr2i18n("Restart", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(general), tr2i18n("General", nullptr));
        (void)NotebookDock;
    } // retranslateUi

};

namespace Ui {
    class NotebookDock: public Ui_NotebookDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NOTEBOOKDOCK_H

