/********************************************************************************
** Form generated from reading UI file 'xyequationcurvedockgeneraltab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XYEQUATIONCURVEDOCKGENERALTAB_H
#define UI_XYEQUATIONCURVEDOCKGENERALTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "frontend/widgets/ExpressionTextEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_XYEquationCurveDockGeneralTab
{
public:
    QGridLayout *gridLayout_3;
    QLabel *lNumber;
    QSpacerItem *horizontalSpacer_2;
    QComboBox *cbPlotRanges;
    ExpressionTextEdit *teMax;
    QSpinBox *sbCount;
    QSpacerItem *horizontalSpacer_5;
    QLabel *lMax;
    QLabel *lName;
    QLabel *lEquation1;
    QLabel *lEquation;
    QFrame *line_2;
    QLabel *lType;
    QSpacerItem *verticalSpacer_3;
    QPushButton *pbRecalculate;
    QLabel *lPlotRange;
    QCheckBox *chkVisible;
    QLabel *lMin;
    ResizableTextEdit *teComment;
    QFrame *frame;
    QGridLayout *gridLayout;
    ExpressionTextEdit *teEquation1;
    QToolButton *tbFunctions1;
    QToolButton *tbConstants1;
    ExpressionTextEdit *teMin;
    QSpacerItem *verticalSpacerGeneral;
    QLabel *lEquation2;
    TimedLineEdit *leName;
    QLabel *lComment;
    KComboBox *cbType;
    QFrame *frame_2;
    QGridLayout *gridLayout_2;
    ExpressionTextEdit *teEquation2;
    QToolButton *tbFunctions2;
    QToolButton *tbConstants2;
    QCheckBox *chkLegendVisible;

    void setupUi(QWidget *XYEquationCurveDockGeneralTab)
    {
        if (XYEquationCurveDockGeneralTab->objectName().isEmpty())
            XYEquationCurveDockGeneralTab->setObjectName("XYEquationCurveDockGeneralTab");
        XYEquationCurveDockGeneralTab->resize(419, 1202);
        gridLayout_3 = new QGridLayout(XYEquationCurveDockGeneralTab);
        gridLayout_3->setObjectName("gridLayout_3");
        lNumber = new QLabel(XYEquationCurveDockGeneralTab);
        lNumber->setObjectName("lNumber");

        gridLayout_3->addWidget(lNumber, 9, 0, 1, 3);

        horizontalSpacer_2 = new QSpacerItem(97, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 12, 4, 1, 1);

        cbPlotRanges = new QComboBox(XYEquationCurveDockGeneralTab);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout_3->addWidget(cbPlotRanges, 13, 4, 1, 2);

        teMax = new ExpressionTextEdit(XYEquationCurveDockGeneralTab);
        teMax->setObjectName("teMax");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(teMax->sizePolicy().hasHeightForWidth());
        teMax->setSizePolicy(sizePolicy);
        teMax->setMaximumSize(QSize(16777215, 16777215));
        teMax->setVerticalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        teMax->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        teMax->setTabChangesFocus(true);

        gridLayout_3->addWidget(teMax, 8, 4, 1, 2);

        sbCount = new QSpinBox(XYEquationCurveDockGeneralTab);
        sbCount->setObjectName("sbCount");
        sizePolicy.setHeightForWidth(sbCount->sizePolicy().hasHeightForWidth());
        sbCount->setSizePolicy(sizePolicy);
        sbCount->setMaximum(999999999);
        sbCount->setValue(100);

        gridLayout_3->addWidget(sbCount, 9, 4, 1, 2);

        horizontalSpacer_5 = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_5, 0, 3, 1, 1);

        lMax = new QLabel(XYEquationCurveDockGeneralTab);
        lMax->setObjectName("lMax");

        gridLayout_3->addWidget(lMax, 8, 0, 1, 3);

        lName = new QLabel(XYEquationCurveDockGeneralTab);
        lName->setObjectName("lName");

        gridLayout_3->addWidget(lName, 0, 0, 1, 3);

        lEquation1 = new QLabel(XYEquationCurveDockGeneralTab);
        lEquation1->setObjectName("lEquation1");

        gridLayout_3->addWidget(lEquation1, 5, 0, 1, 3);

        lEquation = new QLabel(XYEquationCurveDockGeneralTab);
        lEquation->setObjectName("lEquation");
        QFont font;
        font.setBold(true);
        lEquation->setFont(font);

        gridLayout_3->addWidget(lEquation, 3, 0, 1, 1);

        line_2 = new QFrame(XYEquationCurveDockGeneralTab);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_3->addWidget(line_2, 11, 0, 1, 6);

        lType = new QLabel(XYEquationCurveDockGeneralTab);
        lType->setObjectName("lType");

        gridLayout_3->addWidget(lType, 4, 0, 1, 3);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_3, 2, 0, 1, 1);

        pbRecalculate = new QPushButton(XYEquationCurveDockGeneralTab);
        pbRecalculate->setObjectName("pbRecalculate");

        gridLayout_3->addWidget(pbRecalculate, 12, 5, 1, 1);

        lPlotRange = new QLabel(XYEquationCurveDockGeneralTab);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout_3->addWidget(lPlotRange, 13, 0, 1, 1);

        chkVisible = new QCheckBox(XYEquationCurveDockGeneralTab);
        chkVisible->setObjectName("chkVisible");

        gridLayout_3->addWidget(chkVisible, 16, 0, 1, 2);

        lMin = new QLabel(XYEquationCurveDockGeneralTab);
        lMin->setObjectName("lMin");

        gridLayout_3->addWidget(lMin, 7, 0, 1, 3);

        teComment = new ResizableTextEdit(XYEquationCurveDockGeneralTab);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout_3->addWidget(teComment, 1, 4, 1, 2);

        frame = new QFrame(XYEquationCurveDockGeneralTab);
        frame->setObjectName("frame");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy1);
        frame->setMaximumSize(QSize(16777215, 16777215));
        frame->setFrameShape(QFrame::Shape::NoFrame);
        frame->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout = new QGridLayout(frame);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        teEquation1 = new ExpressionTextEdit(frame);
        teEquation1->setObjectName("teEquation1");
        sizePolicy1.setHeightForWidth(teEquation1->sizePolicy().hasHeightForWidth());
        teEquation1->setSizePolicy(sizePolicy1);
        teEquation1->setMaximumSize(QSize(16777215, 16777215));
        teEquation1->setTabChangesFocus(true);

        gridLayout->addWidget(teEquation1, 0, 0, 3, 1);

        tbFunctions1 = new QToolButton(frame);
        tbFunctions1->setObjectName("tbFunctions1");

        gridLayout->addWidget(tbFunctions1, 0, 1, 1, 1);

        tbConstants1 = new QToolButton(frame);
        tbConstants1->setObjectName("tbConstants1");

        gridLayout->addWidget(tbConstants1, 1, 1, 1, 1);


        gridLayout_3->addWidget(frame, 5, 4, 1, 2);

        teMin = new ExpressionTextEdit(XYEquationCurveDockGeneralTab);
        teMin->setObjectName("teMin");
        sizePolicy.setHeightForWidth(teMin->sizePolicy().hasHeightForWidth());
        teMin->setSizePolicy(sizePolicy);
        teMin->setMaximumSize(QSize(16777215, 16777215));
        teMin->setVerticalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        teMin->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        teMin->setTabChangesFocus(true);

        gridLayout_3->addWidget(teMin, 7, 4, 1, 2);

        verticalSpacerGeneral = new QSpacerItem(24, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacerGeneral, 14, 0, 1, 2);

        lEquation2 = new QLabel(XYEquationCurveDockGeneralTab);
        lEquation2->setObjectName("lEquation2");

        gridLayout_3->addWidget(lEquation2, 6, 0, 1, 3);

        leName = new TimedLineEdit(XYEquationCurveDockGeneralTab);
        leName->setObjectName("leName");

        gridLayout_3->addWidget(leName, 0, 4, 1, 2);

        lComment = new QLabel(XYEquationCurveDockGeneralTab);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(lComment, 1, 0, 1, 3);

        cbType = new KComboBox(XYEquationCurveDockGeneralTab);
        cbType->setObjectName("cbType");
        sizePolicy.setHeightForWidth(cbType->sizePolicy().hasHeightForWidth());
        cbType->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(cbType, 4, 4, 1, 2);

        frame_2 = new QFrame(XYEquationCurveDockGeneralTab);
        frame_2->setObjectName("frame_2");
        sizePolicy1.setHeightForWidth(frame_2->sizePolicy().hasHeightForWidth());
        frame_2->setSizePolicy(sizePolicy1);
        frame_2->setMaximumSize(QSize(16777215, 16777215));
        frame_2->setFrameShape(QFrame::Shape::NoFrame);
        frame_2->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout_2 = new QGridLayout(frame_2);
        gridLayout_2->setSpacing(0);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        teEquation2 = new ExpressionTextEdit(frame_2);
        teEquation2->setObjectName("teEquation2");
        sizePolicy1.setHeightForWidth(teEquation2->sizePolicy().hasHeightForWidth());
        teEquation2->setSizePolicy(sizePolicy1);
        teEquation2->setMaximumSize(QSize(16777215, 16777215));
        teEquation2->setTabChangesFocus(true);

        gridLayout_2->addWidget(teEquation2, 0, 0, 3, 1);

        tbFunctions2 = new QToolButton(frame_2);
        tbFunctions2->setObjectName("tbFunctions2");

        gridLayout_2->addWidget(tbFunctions2, 0, 1, 1, 1);

        tbConstants2 = new QToolButton(frame_2);
        tbConstants2->setObjectName("tbConstants2");

        gridLayout_2->addWidget(tbConstants2, 1, 1, 1, 1);


        gridLayout_3->addWidget(frame_2, 6, 4, 1, 2);

        chkLegendVisible = new QCheckBox(XYEquationCurveDockGeneralTab);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout_3->addWidget(chkLegendVisible, 15, 0, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbType);
        QWidget::setTabOrder(cbType, teEquation1);
        QWidget::setTabOrder(teEquation1, tbFunctions1);
        QWidget::setTabOrder(tbFunctions1, tbConstants1);
        QWidget::setTabOrder(tbConstants1, teEquation2);
        QWidget::setTabOrder(teEquation2, tbFunctions2);
        QWidget::setTabOrder(tbFunctions2, tbConstants2);
        QWidget::setTabOrder(tbConstants2, teMin);
        QWidget::setTabOrder(teMin, teMax);
        QWidget::setTabOrder(teMax, sbCount);
        QWidget::setTabOrder(sbCount, pbRecalculate);
        QWidget::setTabOrder(pbRecalculate, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);

        retranslateUi(XYEquationCurveDockGeneralTab);

        QMetaObject::connectSlotsByName(XYEquationCurveDockGeneralTab);
    } // setupUi

    void retranslateUi(QWidget *XYEquationCurveDockGeneralTab)
    {
        lNumber->setText(tr2i18n("Points:", nullptr));
        lMax->setText(tr2i18n("t, max", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lEquation1->setText(tr2i18n("x=f(t)", nullptr));
        lEquation->setText(tr2i18n("Equation", nullptr));
        lType->setText(tr2i18n("Type:", nullptr));
        pbRecalculate->setText(tr2i18n("Recalculate", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lMin->setText(tr2i18n("t, min", nullptr));
#if QT_CONFIG(tooltip)
        tbFunctions1->setToolTip(tr2i18n("Functions", nullptr));
#endif // QT_CONFIG(tooltip)
        tbFunctions1->setText(QString());
#if QT_CONFIG(tooltip)
        tbConstants1->setToolTip(tr2i18n("Constants", nullptr));
#endif // QT_CONFIG(tooltip)
        tbConstants1->setText(QString());
        lEquation2->setText(tr2i18n("y=g(t)", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
#if QT_CONFIG(tooltip)
        tbFunctions2->setToolTip(tr2i18n("Functions", nullptr));
#endif // QT_CONFIG(tooltip)
        tbFunctions2->setText(QString());
#if QT_CONFIG(tooltip)
        tbConstants2->setToolTip(tr2i18n("Constants", nullptr));
#endif // QT_CONFIG(tooltip)
        tbConstants2->setText(QString());
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        (void)XYEquationCurveDockGeneralTab;
    } // retranslateUi

};

namespace Ui {
    class XYEquationCurveDockGeneralTab: public Ui_XYEquationCurveDockGeneralTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // XYEQUATIONCURVEDOCKGENERALTAB_H

