/********************************************************************************
** Form generated from reading UI file 'infoelementdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INFOELEMENTDOCK_H
#define UI_INFOELEMENTDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "UTCDateTimeEdit.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_InfoElementDock
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    QLabel *lCurves;
    QLabel *lPosition;
    QListWidget *lwCurves;
    QLabel *lConnectToCurve;
    QLabel *lConnectToAnchor;
    QCheckBox *chbVisible;
    QLabel *lComment;
    QComboBox *cbConnectToCurve;
    TimedLineEdit *leName;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacer_6;
    QComboBox *cbConnectToAnchor;
    QSpacerItem *verticalSpacer_5;
    QLabel *lName;
    QSpacerItem *horizontalSpacer_3;
    ResizableTextEdit *teComment;
    QLabel *lPositionDateTime;
    UTCDateTimeEdit *dateTimeEditPosition;
    QLabel *lPlotRange;
    QComboBox *cbPlotRanges;
    NumberSpinBox *sbPosition;
    QWidget *tabTitle;
    QWidget *tabLines;
    QGridLayout *gridLayout_2;
    QLabel *lVerticalLine;
    QLabel *lConnectionLines;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer_7;
    QSpacerItem *verticalSpacer_4;

    void setupUi(QWidget *InfoElementDock)
    {
        if (InfoElementDock->objectName().isEmpty())
            InfoElementDock->setObjectName("InfoElementDock");
        InfoElementDock->resize(371, 619);
        verticalLayout = new QVBoxLayout(InfoElementDock);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(InfoElementDock);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setObjectName("gridLayout");
        lCurves = new QLabel(tabGeneral);
        lCurves->setObjectName("lCurves");
        QFont font;
        font.setBold(false);
        lCurves->setFont(font);
        lCurves->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout->addWidget(lCurves, 5, 0, 1, 1);

        lPosition = new QLabel(tabGeneral);
        lPosition->setObjectName("lPosition");

        gridLayout->addWidget(lPosition, 3, 0, 1, 1);

        lwCurves = new QListWidget(tabGeneral);
        lwCurves->setObjectName("lwCurves");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lwCurves->sizePolicy().hasHeightForWidth());
        lwCurves->setSizePolicy(sizePolicy);
        lwCurves->setSelectionMode(QAbstractItemView::SelectionMode::MultiSelection);

        gridLayout->addWidget(lwCurves, 5, 3, 1, 1);

        lConnectToCurve = new QLabel(tabGeneral);
        lConnectToCurve->setObjectName("lConnectToCurve");

        gridLayout->addWidget(lConnectToCurve, 7, 0, 1, 2);

        lConnectToAnchor = new QLabel(tabGeneral);
        lConnectToAnchor->setObjectName("lConnectToAnchor");

        gridLayout->addWidget(lConnectToAnchor, 8, 0, 1, 2);

        chbVisible = new QCheckBox(tabGeneral);
        chbVisible->setObjectName("chbVisible");

        gridLayout->addWidget(chbVisible, 11, 0, 1, 1);

        lComment = new QLabel(tabGeneral);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 2);

        cbConnectToCurve = new QComboBox(tabGeneral);
        cbConnectToCurve->setObjectName("cbConnectToCurve");

        gridLayout->addWidget(cbConnectToCurve, 7, 3, 1, 1);

        leName = new TimedLineEdit(tabGeneral);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 3, 1, 1);

        verticalSpacer = new QSpacerItem(20, 67, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 10, 0, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_6, 2, 1, 1, 1);

        cbConnectToAnchor = new QComboBox(tabGeneral);
        cbConnectToAnchor->setObjectName("cbConnectToAnchor");

        gridLayout->addWidget(cbConnectToAnchor, 8, 3, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_5, 6, 0, 1, 1);

        lName = new QLabel(tabGeneral);
        lName->setObjectName("lName");

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(10, 24, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 0, 2, 1, 1);

        teComment = new ResizableTextEdit(tabGeneral);
        teComment->setObjectName("teComment");
        sizePolicy.setHeightForWidth(teComment->sizePolicy().hasHeightForWidth());
        teComment->setSizePolicy(sizePolicy);
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 3, 1, 1);

        lPositionDateTime = new QLabel(tabGeneral);
        lPositionDateTime->setObjectName("lPositionDateTime");

        gridLayout->addWidget(lPositionDateTime, 4, 0, 1, 1);

        dateTimeEditPosition = new UTCDateTimeEdit(tabGeneral);
        dateTimeEditPosition->setObjectName("dateTimeEditPosition");
        dateTimeEditPosition->setCalendarPopup(true);

        gridLayout->addWidget(dateTimeEditPosition, 4, 3, 1, 1);

        lPlotRange = new QLabel(tabGeneral);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout->addWidget(lPlotRange, 9, 0, 1, 2);

        cbPlotRanges = new QComboBox(tabGeneral);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout->addWidget(cbPlotRanges, 9, 3, 1, 1);

        sbPosition = new NumberSpinBox(tabGeneral);
        sbPosition->setObjectName("sbPosition");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sbPosition->sizePolicy().hasHeightForWidth());
        sbPosition->setSizePolicy(sizePolicy1);
        sbPosition->setProperty("feedback", QVariant(true));

        gridLayout->addWidget(sbPosition, 3, 3, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabTitle = new QWidget();
        tabTitle->setObjectName("tabTitle");
        tabWidget->addTab(tabTitle, QString());
        tabLines = new QWidget();
        tabLines->setObjectName("tabLines");
        gridLayout_2 = new QGridLayout(tabLines);
        gridLayout_2->setObjectName("gridLayout_2");
        lVerticalLine = new QLabel(tabLines);
        lVerticalLine->setObjectName("lVerticalLine");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(lVerticalLine->sizePolicy().hasHeightForWidth());
        lVerticalLine->setSizePolicy(sizePolicy2);
        QFont font1;
        font1.setBold(true);
        lVerticalLine->setFont(font1);

        gridLayout_2->addWidget(lVerticalLine, 0, 0, 1, 1);

        lConnectionLines = new QLabel(tabLines);
        lConnectionLines->setObjectName("lConnectionLines");
        sizePolicy2.setHeightForWidth(lConnectionLines->sizePolicy().hasHeightForWidth());
        lConnectionLines->setSizePolicy(sizePolicy2);
        lConnectionLines->setFont(font1);

        gridLayout_2->addWidget(lConnectionLines, 3, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 0, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_2, 1, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_3, 2, 0, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_7, 4, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(17, 152, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_4, 5, 0, 1, 2);

        tabWidget->addTab(tabLines, QString());

        verticalLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, leName);
        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, sbPosition);
        QWidget::setTabOrder(sbPosition, dateTimeEditPosition);
        QWidget::setTabOrder(dateTimeEditPosition, lwCurves);
        QWidget::setTabOrder(lwCurves, cbConnectToCurve);
        QWidget::setTabOrder(cbConnectToCurve, cbConnectToAnchor);
        QWidget::setTabOrder(cbConnectToAnchor, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chbVisible);

        retranslateUi(InfoElementDock);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(InfoElementDock);
    } // setupUi

    void retranslateUi(QWidget *InfoElementDock)
    {
        lCurves->setText(tr2i18n("Curves:", nullptr));
        lPosition->setText(tr2i18n("Position:", nullptr));
        lConnectToCurve->setText(tr2i18n("Connect To:", nullptr));
        lConnectToAnchor->setText(tr2i18n("Anchor:", nullptr));
        chbVisible->setText(tr2i18n("Visible", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lPositionDateTime->setText(tr2i18n("Position:", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
#if QT_CONFIG(tooltip)
        sbPosition->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbPosition->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabTitle), tr2i18n("Title", nullptr));
        lVerticalLine->setText(tr2i18n("Vertical Line", nullptr));
        lConnectionLines->setText(tr2i18n("Connection Line", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabLines), tr2i18n("Lines", nullptr));
        (void)InfoElementDock;
    } // retranslateUi

};

namespace Ui {
    class InfoElementDock: public Ui_InfoElementDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // INFOELEMENTDOCK_H

