/********************************************************************************
** Form generated from reading UI file 'importwarningsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTWARNINGSDIALOG_H
#define UI_IMPORTWARNINGSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ImportWarningsDialog
{
public:
    QVBoxLayout *verticalLayout;
    QListWidget *lwWarnings;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *pbOk;

    void setupUi(QDialog *ImportWarningsDialog)
    {
        if (ImportWarningsDialog->objectName().isEmpty())
            ImportWarningsDialog->setObjectName("ImportWarningsDialog");
        ImportWarningsDialog->resize(663, 434);
        verticalLayout = new QVBoxLayout(ImportWarningsDialog);
        verticalLayout->setObjectName("verticalLayout");
        lwWarnings = new QListWidget(ImportWarningsDialog);
        lwWarnings->setObjectName("lwWarnings");

        verticalLayout->addWidget(lwWarnings);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pbOk = new QPushButton(ImportWarningsDialog);
        pbOk->setObjectName("pbOk");

        horizontalLayout->addWidget(pbOk);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(ImportWarningsDialog);

        QMetaObject::connectSlotsByName(ImportWarningsDialog);
    } // setupUi

    void retranslateUi(QDialog *ImportWarningsDialog)
    {
        ImportWarningsDialog->setWindowTitle(tr2i18n("Import Warnings", nullptr));
        pbOk->setText(tr2i18n("OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ImportWarningsDialog: public Ui_ImportWarningsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTWARNINGSDIALOG_H

