/********************************************************************************
** Form generated from reading UI file 'sortdialogwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SORTDIALOGWIDGET_H
#define UI_SORTDIALOGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SortDialogWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *lColumns;
    QLabel *lOrdering;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;
    QComboBox *cbOrdering;
    QComboBox *cbColumns;

    void setupUi(QWidget *SortDialogWidget)
    {
        if (SortDialogWidget->objectName().isEmpty())
            SortDialogWidget->setObjectName("SortDialogWidget");
        SortDialogWidget->resize(326, 128);
        gridLayout = new QGridLayout(SortDialogWidget);
        gridLayout->setObjectName("gridLayout");
        lColumns = new QLabel(SortDialogWidget);
        lColumns->setObjectName("lColumns");

        gridLayout->addWidget(lColumns, 1, 0, 1, 2);

        lOrdering = new QLabel(SortDialogWidget);
        lOrdering->setObjectName("lOrdering");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lOrdering->sizePolicy().hasHeightForWidth());
        lOrdering->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lOrdering, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 2, 1, 1);

        buttonBox = new QDialogButtonBox(SortDialogWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 3, 0, 1, 3);

        cbOrdering = new QComboBox(SortDialogWidget);
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("view-sort-ascending");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        cbOrdering->addItem(icon, QString());
        QIcon icon1;
        iconThemeName = QString::fromUtf8("view-sort-descending");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        cbOrdering->addItem(icon1, QString());
        cbOrdering->setObjectName("cbOrdering");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbOrdering->sizePolicy().hasHeightForWidth());
        cbOrdering->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbOrdering, 0, 2, 1, 1);

        cbColumns = new QComboBox(SortDialogWidget);
        cbColumns->setObjectName("cbColumns");

        gridLayout->addWidget(cbColumns, 1, 2, 1, 1);


        retranslateUi(SortDialogWidget);

        QMetaObject::connectSlotsByName(SortDialogWidget);
    } // setupUi

    void retranslateUi(QWidget *SortDialogWidget)
    {
        lColumns->setText(tr2i18n("Sort by", nullptr));
        lOrdering->setText(tr2i18n("Order:", nullptr));
        cbOrdering->setItemText(0, tr2i18n("Ascending", nullptr));
        cbOrdering->setItemText(1, tr2i18n("Descending", nullptr));

        (void)SortDialogWidget;
    } // retranslateUi

};

namespace Ui {
    class SortDialogWidget: public Ui_SortDialogWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SORTDIALOGWIDGET_H

