/****************************************************************************
** Meta object code from reading C++ file 'BarPlot.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/worksheet/plots/cartesian/BarPlot.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'BarPlot.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BarPlotE_t {};
} // unnamed namespace

template <> constexpr inline auto BarPlot::qt_create_metaobjectdata<qt_meta_tag_ZN7BarPlotE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BarPlot",
        "xColumnChanged",
        "",
        "const AbstractColumn*",
        "xDataChanged",
        "dataColumnsChanged",
        "QList<const AbstractColumn*>",
        "dataDataChanged",
        "typeChanged",
        "BarPlot::Type",
        "orientationChanged",
        "BarPlot::Orientation",
        "widthFactorChanged",
        "borderPenChanged",
        "QPen&",
        "borderOpacityChanged",
        "orientationChangedSlot",
        "QAction*",
        "xColumnAboutToBeRemoved",
        "const AbstractAspect*",
        "dataColumnAboutToBeRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'xColumnChanged'
        QtMocHelpers::SignalData<void(const AbstractColumn *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'xDataChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataColumnsChanged'
        QtMocHelpers::SignalData<void(const QVector<const AbstractColumn*> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'dataDataChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(BarPlot::Type)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'orientationChanged'
        QtMocHelpers::SignalData<void(BarPlot::Orientation)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Signal 'widthFactorChanged'
        QtMocHelpers::SignalData<void(double)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'borderPenChanged'
        QtMocHelpers::SignalData<void(QPen &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Signal 'borderOpacityChanged'
        QtMocHelpers::SignalData<void(float)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Slot 'orientationChangedSlot'
        QtMocHelpers::SlotData<void(QAction *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Slot 'xColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Slot 'dataColumnAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BarPlot, qt_meta_tag_ZN7BarPlotE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BarPlot::staticMetaObject = { {
    QMetaObject::SuperData::link<Plot::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BarPlotE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BarPlotE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BarPlotE_t>.metaTypes,
    nullptr
} };

void BarPlot::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BarPlot *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->xColumnChanged((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 1: _t->xDataChanged(); break;
        case 2: _t->dataColumnsChanged((*reinterpret_cast<std::add_pointer_t<QList<const AbstractColumn*>>>(_a[1]))); break;
        case 3: _t->dataDataChanged(); break;
        case 4: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<BarPlot::Type>>(_a[1]))); break;
        case 5: _t->orientationChanged((*reinterpret_cast<std::add_pointer_t<BarPlot::Orientation>>(_a[1]))); break;
        case 6: _t->widthFactorChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 7: _t->borderPenChanged((*reinterpret_cast<std::add_pointer_t<QPen&>>(_a[1]))); break;
        case 8: _t->borderOpacityChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 9: _t->orientationChangedSlot((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 10: _t->xColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 11: _t->dataColumnAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BarPlot::*)(const AbstractColumn * )>(_a, &BarPlot::xColumnChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BarPlot::*)()>(_a, &BarPlot::xDataChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BarPlot::*)(const QVector<const AbstractColumn*> & )>(_a, &BarPlot::dataColumnsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BarPlot::*)()>(_a, &BarPlot::dataDataChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BarPlot::*)(BarPlot::Type )>(_a, &BarPlot::typeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BarPlot::*)(BarPlot::Orientation )>(_a, &BarPlot::orientationChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BarPlot::*)(double )>(_a, &BarPlot::widthFactorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BarPlot::*)(QPen & )>(_a, &BarPlot::borderPenChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BarPlot::*)(float )>(_a, &BarPlot::borderOpacityChanged, 8))
            return;
    }
}

const QMetaObject *BarPlot::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BarPlot::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BarPlotE_t>.strings))
        return static_cast<void*>(this);
    return Plot::qt_metacast(_clname);
}

int BarPlot::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Plot::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void BarPlot::xColumnChanged(const AbstractColumn * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BarPlot::xDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void BarPlot::dataColumnsChanged(const QVector<const AbstractColumn*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BarPlot::dataDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void BarPlot::typeChanged(BarPlot::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BarPlot::orientationChanged(BarPlot::Orientation _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BarPlot::widthFactorChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void BarPlot::borderPenChanged(QPen & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void BarPlot::borderOpacityChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
