/****************************************************************************
** Meta object code from reading C++ file 'SpreadsheetModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/backend/spreadsheet/SpreadsheetModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SpreadsheetModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16SpreadsheetModelE_t {};
} // unnamed namespace

template <> constexpr inline auto SpreadsheetModel::qt_create_metaobjectdata<qt_meta_tag_ZN16SpreadsheetModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SpreadsheetModel",
        "handleAspectsAboutToBeInserted",
        "",
        "first",
        "last",
        "handleAspectsInserted",
        "handleAspectsAboutToBeRemoved",
        "handleAspectsRemoved",
        "handleAspectCountChanged",
        "handleAspectAboutToBeAdded",
        "const AbstractAspect*",
        "index",
        "handleAspectAdded",
        "aspect",
        "handleAspectAboutToBeRemoved",
        "handleAspectRemoved",
        "parent",
        "before",
        "child",
        "handleDescriptionChange",
        "handleModeChange",
        "const AbstractColumn*",
        "handleDigitsChange",
        "handlePlotDesignationChange",
        "handleDataChange",
        "handleRowsInserted",
        "newRowCount",
        "handleRowsRemoved",
        "handleRowsAboutToBeInserted",
        "handleRowsAboutToBeRemoved",
        "handleRowCountChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleAspectsAboutToBeInserted'
        QtMocHelpers::SlotData<void(int, int)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'handleAspectsInserted'
        QtMocHelpers::SlotData<void(int, int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'handleAspectsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(int, int)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'handleAspectsRemoved'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleAspectCountChanged'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleAspectAboutToBeAdded'
        QtMocHelpers::SlotData<void(const AbstractAspect *, int, const AbstractAspect *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 }, { QMetaType::Int, 11 }, { 0x80000000 | 10, 2 },
        }}),
        // Slot 'handleAspectAdded'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 13 },
        }}),
        // Slot 'handleAspectAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 13 },
        }}),
        // Slot 'handleAspectRemoved'
        QtMocHelpers::SlotData<void(const AbstractAspect *, const AbstractAspect *, const AbstractAspect *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 16 }, { 0x80000000 | 10, 17 }, { 0x80000000 | 10, 18 },
        }}),
        // Slot 'handleDescriptionChange'
        QtMocHelpers::SlotData<void(const AbstractAspect *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'handleModeChange'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'handleDigitsChange'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handlePlotDesignationChange'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'handleDataChange'
        QtMocHelpers::SlotData<void(const AbstractColumn *)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'handleRowsInserted'
        QtMocHelpers::SlotData<void(int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'handleRowsRemoved'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'handleRowsAboutToBeInserted'
        QtMocHelpers::SlotData<void(int, int)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'handleRowsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(int, int)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'handleRowCountChanged'
        QtMocHelpers::SlotData<void(int)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SpreadsheetModel, qt_meta_tag_ZN16SpreadsheetModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SpreadsheetModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SpreadsheetModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SpreadsheetModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16SpreadsheetModelE_t>.metaTypes,
    nullptr
} };

void SpreadsheetModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SpreadsheetModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleAspectsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->handleAspectsInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->handleAspectsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->handleAspectsRemoved(); break;
        case 4: _t->handleAspectCountChanged(); break;
        case 5: _t->handleAspectAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[3]))); break;
        case 6: _t->handleAspectAdded((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 7: _t->handleAspectAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 8: _t->handleAspectRemoved((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[3]))); break;
        case 9: _t->handleDescriptionChange((*reinterpret_cast<std::add_pointer_t<const AbstractAspect*>>(_a[1]))); break;
        case 10: _t->handleModeChange((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 11: _t->handleDigitsChange(); break;
        case 12: _t->handlePlotDesignationChange((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 13: _t->handleDataChange((*reinterpret_cast<std::add_pointer_t<const AbstractColumn*>>(_a[1]))); break;
        case 14: _t->handleRowsInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->handleRowsRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->handleRowsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 17: _t->handleRowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 18: _t->handleRowCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *SpreadsheetModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SpreadsheetModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SpreadsheetModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int SpreadsheetModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}
QT_WARNING_POP
