/****************************************************************************
** Meta object code from reading C++ file 'SearchReplaceWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../labplot-2.12.1/src/frontend/spreadsheet/SearchReplaceWidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SearchReplaceWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19SearchReplaceWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto SearchReplaceWidget::qt_create_metaobjectdata<qt_meta_tag_ZN19SearchReplaceWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SearchReplaceWidget",
        "dataTypeChanged",
        "",
        "index",
        "operatorChanged",
        "operatorDateTimeChanged",
        "findNextSimple",
        "proceed",
        "findPreviousSimple",
        "findNext",
        "findAndReplace",
        "findPrevious",
        "findAll",
        "replaceNext",
        "replaceAll",
        "cancel",
        "findContextMenuRequest",
        "QPoint",
        "replaceContextMenuRequest",
        "switchFindReplace"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'dataTypeChanged'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'operatorChanged'
        QtMocHelpers::SlotData<void(int) const>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'operatorDateTimeChanged'
        QtMocHelpers::SlotData<void(int) const>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'findNextSimple'
        QtMocHelpers::SlotData<bool(bool)>(6, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'findPreviousSimple'
        QtMocHelpers::SlotData<bool(bool)>(8, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'findNext'
        QtMocHelpers::SlotData<bool(bool, bool)>(9, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Bool, 7 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'findNext'
        QtMocHelpers::SlotData<bool(bool)>(9, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'findPrevious'
        QtMocHelpers::SlotData<bool(bool)>(11, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'findAll'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'replaceNext'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'replaceAll'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'findContextMenuRequest'
        QtMocHelpers::SlotData<void(const QPoint &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Slot 'replaceContextMenuRequest'
        QtMocHelpers::SlotData<void(const QPoint &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Slot 'switchFindReplace'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SearchReplaceWidget, qt_meta_tag_ZN19SearchReplaceWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SearchReplaceWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SearchReplaceWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SearchReplaceWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19SearchReplaceWidgetE_t>.metaTypes,
    nullptr
} };

void SearchReplaceWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SearchReplaceWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->operatorChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->operatorDateTimeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: { bool _r = _t->findNextSimple((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->findPreviousSimple((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->findNext((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->findNext((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->findPrevious((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->findAll(); break;
        case 9: _t->replaceNext(); break;
        case 10: _t->replaceAll(); break;
        case 11: _t->cancel(); break;
        case 12: _t->findContextMenuRequest((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 13: _t->replaceContextMenuRequest((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 14: _t->switchFindReplace(); break;
        default: ;
        }
    }
}

const QMetaObject *SearchReplaceWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SearchReplaceWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SearchReplaceWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int SearchReplaceWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
