/********************************************************************************
** Form generated from reading UI file 'xycorrelationcurvedockgeneraltab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XYCORRELATIONCURVEDOCKGENERALTAB_H
#define UI_XYCORRELATIONCURVEDOCKGENERALTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "NumberSpinBox.h"
#include "frontend/widgets/ResizableTextEdit.h"
#include "frontend/widgets/TimedLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_XYCorrelationCurveDockGeneralTab
{
public:
    QGridLayout *gridLayout;
    QLabel *lType;
    QLabel *l2SamplingInterval;
    QHBoxLayout *horizontalLayout;
    QLabel *lMin;
    QLineEdit *leMin;
    TimedLineEdit *leName;
    QLabel *lData;
    QLabel *lResults;
    QLabel *lConvolution;
    QComboBox *cbDataSourceType;
    QFrame *line_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *lMax;
    QLineEdit *leMax;
    QLabel *lY2Column;
    NumberSpinBox *sbSamplingInterval;
    ResizableTextEdit *teComment;
    QSpacerItem *verticalSpacer_4;
    QLabel *lYColumn;
    QLabel *lNormalize;
    QLabel *lDataSourceType;
    QCheckBox *cbAutoRange;
    QLabel *lPlotRange;
    QComboBox *cbPlotRanges;
    QSpacerItem *verticalSpacerGeneral;
    QSpacerItem *verticalSpacer;
    QLabel *lComment;
    QLabel *lName;
    QLabel *lXRange;
    QTextEdit *teResult;
    QLabel *lSamplingInterval;
    QPushButton *pbRecalculate;
    QComboBox *cbType;
    QSpacerItem *horizontalSpacer_2;
    QComboBox *cbNorm;
    QLabel *lXColumn;
    QCheckBox *chkVisible;
    QLabel *lDataSourceCurve;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_3;
    QCheckBox *chkLegendVisible;

    void setupUi(QWidget *XYCorrelationCurveDockGeneralTab)
    {
        if (XYCorrelationCurveDockGeneralTab->objectName().isEmpty())
            XYCorrelationCurveDockGeneralTab->setObjectName("XYCorrelationCurveDockGeneralTab");
        XYCorrelationCurveDockGeneralTab->resize(355, 855);
        gridLayout = new QGridLayout(XYCorrelationCurveDockGeneralTab);
        gridLayout->setObjectName("gridLayout");
        lType = new QLabel(XYCorrelationCurveDockGeneralTab);
        lType->setObjectName("lType");

        gridLayout->addWidget(lType, 15, 0, 1, 1);

        l2SamplingInterval = new QLabel(XYCorrelationCurveDockGeneralTab);
        l2SamplingInterval->setObjectName("l2SamplingInterval");
        l2SamplingInterval->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(l2SamplingInterval, 7, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        lMin = new QLabel(XYCorrelationCurveDockGeneralTab);
        lMin->setObjectName("lMin");
        lMin->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lMin->sizePolicy().hasHeightForWidth());
        lMin->setSizePolicy(sizePolicy);
        lMin->setMinimumSize(QSize(50, 0));

        horizontalLayout->addWidget(lMin);

        leMin = new QLineEdit(XYCorrelationCurveDockGeneralTab);
        leMin->setObjectName("leMin");

        horizontalLayout->addWidget(leMin);


        gridLayout->addLayout(horizontalLayout, 11, 2, 1, 4);

        leName = new TimedLineEdit(XYCorrelationCurveDockGeneralTab);
        leName->setObjectName("leName");

        gridLayout->addWidget(leName, 0, 2, 1, 4);

        lData = new QLabel(XYCorrelationCurveDockGeneralTab);
        lData->setObjectName("lData");
        QFont font;
        font.setBold(true);
        lData->setFont(font);

        gridLayout->addWidget(lData, 3, 0, 1, 1);

        lResults = new QLabel(XYCorrelationCurveDockGeneralTab);
        lResults->setObjectName("lResults");
        lResults->setFont(font);
        lResults->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout->addWidget(lResults, 19, 0, 1, 1);

        lConvolution = new QLabel(XYCorrelationCurveDockGeneralTab);
        lConvolution->setObjectName("lConvolution");
        lConvolution->setFont(font);

        gridLayout->addWidget(lConvolution, 14, 0, 1, 3);

        cbDataSourceType = new QComboBox(XYCorrelationCurveDockGeneralTab);
        cbDataSourceType->setObjectName("cbDataSourceType");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbDataSourceType->sizePolicy().hasHeightForWidth());
        cbDataSourceType->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(cbDataSourceType, 4, 2, 1, 4);

        line_2 = new QFrame(XYCorrelationCurveDockGeneralTab);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 21, 0, 1, 6);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        lMax = new QLabel(XYCorrelationCurveDockGeneralTab);
        lMax->setObjectName("lMax");
        lMax->setEnabled(false);
        sizePolicy.setHeightForWidth(lMax->sizePolicy().hasHeightForWidth());
        lMax->setSizePolicy(sizePolicy);
        lMax->setMinimumSize(QSize(50, 0));

        horizontalLayout_2->addWidget(lMax);

        leMax = new QLineEdit(XYCorrelationCurveDockGeneralTab);
        leMax->setObjectName("leMax");

        horizontalLayout_2->addWidget(leMax);


        gridLayout->addLayout(horizontalLayout_2, 12, 2, 1, 4);

        lY2Column = new QLabel(XYCorrelationCurveDockGeneralTab);
        lY2Column->setObjectName("lY2Column");

        gridLayout->addWidget(lY2Column, 9, 0, 1, 1);

        sbSamplingInterval = new NumberSpinBox(XYCorrelationCurveDockGeneralTab);
        sbSamplingInterval->setObjectName("sbSamplingInterval");
        sizePolicy1.setHeightForWidth(sbSamplingInterval->sizePolicy().hasHeightForWidth());
        sbSamplingInterval->setSizePolicy(sizePolicy1);
        sbSamplingInterval->setValue(1.000000000000000);
        sbSamplingInterval->setProperty("feedback", QVariant(false));

        gridLayout->addWidget(sbSamplingInterval, 7, 5, 1, 1);

        teComment = new ResizableTextEdit(XYCorrelationCurveDockGeneralTab);
        teComment->setObjectName("teComment");
        teComment->setTabChangesFocus(true);

        gridLayout->addWidget(teComment, 1, 2, 1, 4);

        verticalSpacer_4 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 13, 2, 1, 4);

        lYColumn = new QLabel(XYCorrelationCurveDockGeneralTab);
        lYColumn->setObjectName("lYColumn");

        gridLayout->addWidget(lYColumn, 8, 0, 1, 1);

        lNormalize = new QLabel(XYCorrelationCurveDockGeneralTab);
        lNormalize->setObjectName("lNormalize");

        gridLayout->addWidget(lNormalize, 16, 0, 1, 1);

        lDataSourceType = new QLabel(XYCorrelationCurveDockGeneralTab);
        lDataSourceType->setObjectName("lDataSourceType");

        gridLayout->addWidget(lDataSourceType, 4, 0, 1, 1);

        cbAutoRange = new QCheckBox(XYCorrelationCurveDockGeneralTab);
        cbAutoRange->setObjectName("cbAutoRange");
        cbAutoRange->setChecked(true);

        gridLayout->addWidget(cbAutoRange, 10, 2, 1, 4);

        lPlotRange = new QLabel(XYCorrelationCurveDockGeneralTab);
        lPlotRange->setObjectName("lPlotRange");

        gridLayout->addWidget(lPlotRange, 23, 0, 1, 1);

        cbPlotRanges = new QComboBox(XYCorrelationCurveDockGeneralTab);
        cbPlotRanges->setObjectName("cbPlotRanges");

        gridLayout->addWidget(cbPlotRanges, 23, 2, 1, 4);

        verticalSpacerGeneral = new QSpacerItem(24, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacerGeneral, 24, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 18, 2, 1, 4);

        lComment = new QLabel(XYCorrelationCurveDockGeneralTab);
        lComment->setObjectName("lComment");
        lComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(lComment, 1, 0, 1, 1);

        lName = new QLabel(XYCorrelationCurveDockGeneralTab);
        lName->setObjectName("lName");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(lName->sizePolicy().hasHeightForWidth());
        lName->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(lName, 0, 0, 1, 1);

        lXRange = new QLabel(XYCorrelationCurveDockGeneralTab);
        lXRange->setObjectName("lXRange");

        gridLayout->addWidget(lXRange, 10, 0, 1, 1);

        teResult = new QTextEdit(XYCorrelationCurveDockGeneralTab);
        teResult->setObjectName("teResult");
        teResult->setReadOnly(true);

        gridLayout->addWidget(teResult, 19, 2, 1, 4);

        lSamplingInterval = new QLabel(XYCorrelationCurveDockGeneralTab);
        lSamplingInterval->setObjectName("lSamplingInterval");

        gridLayout->addWidget(lSamplingInterval, 7, 2, 1, 1);

        pbRecalculate = new QPushButton(XYCorrelationCurveDockGeneralTab);
        pbRecalculate->setObjectName("pbRecalculate");

        gridLayout->addWidget(pbRecalculate, 22, 5, 1, 1);

        cbType = new QComboBox(XYCorrelationCurveDockGeneralTab);
        cbType->setObjectName("cbType");

        gridLayout->addWidget(cbType, 15, 2, 1, 4);

        horizontalSpacer_2 = new QSpacerItem(266, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 22, 2, 1, 3);

        cbNorm = new QComboBox(XYCorrelationCurveDockGeneralTab);
        cbNorm->setObjectName("cbNorm");

        gridLayout->addWidget(cbNorm, 16, 2, 1, 4);

        lXColumn = new QLabel(XYCorrelationCurveDockGeneralTab);
        lXColumn->setObjectName("lXColumn");

        gridLayout->addWidget(lXColumn, 6, 0, 1, 1);

        chkVisible = new QCheckBox(XYCorrelationCurveDockGeneralTab);
        chkVisible->setObjectName("chkVisible");

        gridLayout->addWidget(chkVisible, 26, 0, 1, 1);

        lDataSourceCurve = new QLabel(XYCorrelationCurveDockGeneralTab);
        lDataSourceCurve->setObjectName("lDataSourceCurve");

        gridLayout->addWidget(lDataSourceCurve, 5, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 23, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 2, 2, 1, 4);

        chkLegendVisible = new QCheckBox(XYCorrelationCurveDockGeneralTab);
        chkLegendVisible->setObjectName("chkLegendVisible");

        gridLayout->addWidget(chkLegendVisible, 25, 0, 1, 1);

        QWidget::setTabOrder(leName, teComment);
        QWidget::setTabOrder(teComment, cbDataSourceType);
        QWidget::setTabOrder(cbDataSourceType, sbSamplingInterval);
        QWidget::setTabOrder(sbSamplingInterval, cbAutoRange);
        QWidget::setTabOrder(cbAutoRange, leMin);
        QWidget::setTabOrder(leMin, leMax);
        QWidget::setTabOrder(leMax, cbType);
        QWidget::setTabOrder(cbType, cbNorm);
        QWidget::setTabOrder(cbNorm, teResult);
        QWidget::setTabOrder(teResult, pbRecalculate);
        QWidget::setTabOrder(pbRecalculate, cbPlotRanges);
        QWidget::setTabOrder(cbPlotRanges, chkLegendVisible);
        QWidget::setTabOrder(chkLegendVisible, chkVisible);

        retranslateUi(XYCorrelationCurveDockGeneralTab);

        QMetaObject::connectSlotsByName(XYCorrelationCurveDockGeneralTab);
    } // setupUi

    void retranslateUi(QWidget *XYCorrelationCurveDockGeneralTab)
    {
        lType->setText(tr2i18n("Type:", nullptr));
        l2SamplingInterval->setText(tr2i18n("or", nullptr));
        lMin->setText(tr2i18n("Minimum:", nullptr));
        lData->setText(tr2i18n("Data", nullptr));
        lResults->setText(tr2i18n("Results:", nullptr));
        lConvolution->setText(tr2i18n("Correlation", nullptr));
        lMax->setText(tr2i18n("Maximum:", nullptr));
        lY2Column->setText(tr2i18n("Y-Data Signal 2:", nullptr));
#if QT_CONFIG(tooltip)
        sbSamplingInterval->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbSamplingInterval->setWhatsThis(tr2i18n("Spinbox for numbers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lYColumn->setText(tr2i18n("Y-Data Signal 1:", nullptr));
        lNormalize->setText(tr2i18n("Normalize:", nullptr));
        lDataSourceType->setText(tr2i18n("Source:", nullptr));
        cbAutoRange->setText(tr2i18n("Auto", nullptr));
        lPlotRange->setText(tr2i18n("Plot Range:", nullptr));
        lComment->setText(tr2i18n("Comment:", nullptr));
        lName->setText(tr2i18n("Name:", nullptr));
        lXRange->setText(tr2i18n("X-Range:", nullptr));
        lSamplingInterval->setText(tr2i18n("Sampling Interval:", nullptr));
        pbRecalculate->setText(tr2i18n("Recalculate", nullptr));
        lXColumn->setText(tr2i18n("X-Data:", nullptr));
        chkVisible->setText(tr2i18n("Visible", nullptr));
        lDataSourceCurve->setText(tr2i18n("Curve:", nullptr));
        chkLegendVisible->setText(tr2i18n("Legend", nullptr));
        (void)XYCorrelationCurveDockGeneralTab;
    } // retranslateUi

};

namespace Ui {
    class XYCorrelationCurveDockGeneralTab: public Ui_XYCorrelationCurveDockGeneralTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // XYCORRELATIONCURVEDOCKGENERALTAB_H

