/********************************************************************************
** Form generated from reading UI file 'searchreplacewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHREPLACEWIDGET_H
#define UI_SEARCHREPLACEWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SearchReplaceWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *lOrder;
    QFrame *frame_2;
    QHBoxLayout *horizontalLayout;
    QComboBox *cbDataType;
    QSpacerItem *horizontalSpacer;
    QLabel *lReplaceDateTime;
    QLabel *lReplace;
    QLabel *lFind;
    QFrame *frame_3;
    QHBoxLayout *horizontalLayout_2;
    QComboBox *cbOrder;
    QToolButton *tbMatchCase;
    QToolButton *tbSelectionOnly;
    QSpacerItem *horizontalSpacer_2;
    QToolButton *tbFindNext;
    QToolButton *tbFindPrev;
    QPushButton *bReplaceNext;
    QPushButton *bReplaceAll;
    QPushButton *bFindAll;
    QToolButton *tbSwitchFindReplace;
    QFrame *frame;
    QGridLayout *gridLayout_5;
    QFrame *frameNumeric;
    QGridLayout *gridLayout_2;
    QLabel *lMin;
    QComboBox *cbOperator;
    QLabel *lMax;
    QComboBox *cbValue1;
    QLabel *lAnd;
    QComboBox *cbValue2;
    QFrame *frameDateTime;
    QGridLayout *gridLayout_4;
    QLabel *lMaxDateTime;
    QLabel *lMinDateTime;
    QLabel *lAndDateTime;
    QComboBox *cbOperatorDateTime;
    QDateTimeEdit *dteValue1;
    QDateTimeEdit *dteValue2;
    QFrame *frameText;
    QGridLayout *gridLayout_3;
    QComboBox *cbOperatorText;
    QComboBox *cbValueText;
    QPushButton *bCancel;
    QComboBox *cbReplace;
    QLabel *lDataType;
    QDateTimeEdit *dteReplace;
    QLabel *lReplaceText;
    QComboBox *cbReplaceText;

    void setupUi(QWidget *SearchReplaceWidget)
    {
        if (SearchReplaceWidget->objectName().isEmpty())
            SearchReplaceWidget->setObjectName("SearchReplaceWidget");
        SearchReplaceWidget->resize(793, 312);
        gridLayout = new QGridLayout(SearchReplaceWidget);
        gridLayout->setObjectName("gridLayout");
        lOrder = new QLabel(SearchReplaceWidget);
        lOrder->setObjectName("lOrder");
        lOrder->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lOrder, 5, 0, 1, 1);

        frame_2 = new QFrame(SearchReplaceWidget);
        frame_2->setObjectName("frame_2");
        frame_2->setFrameShape(QFrame::NoFrame);
        frame_2->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(frame_2);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        cbDataType = new QComboBox(frame_2);
        cbDataType->setObjectName("cbDataType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbDataType->sizePolicy().hasHeightForWidth());
        cbDataType->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(cbDataType);

        horizontalSpacer = new QSpacerItem(400, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addWidget(frame_2, 0, 2, 1, 1);

        lReplaceDateTime = new QLabel(SearchReplaceWidget);
        lReplaceDateTime->setObjectName("lReplaceDateTime");

        gridLayout->addWidget(lReplaceDateTime, 4, 0, 1, 1);

        lReplace = new QLabel(SearchReplaceWidget);
        lReplace->setObjectName("lReplace");
        lReplace->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lReplace, 2, 0, 1, 1);

        lFind = new QLabel(SearchReplaceWidget);
        lFind->setObjectName("lFind");
        lFind->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lFind, 1, 0, 1, 1);

        frame_3 = new QFrame(SearchReplaceWidget);
        frame_3->setObjectName("frame_3");
        frame_3->setFrameShape(QFrame::NoFrame);
        frame_3->setFrameShadow(QFrame::Raised);
        horizontalLayout_2 = new QHBoxLayout(frame_3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        cbOrder = new QComboBox(frame_3);
        cbOrder->setObjectName("cbOrder");
        sizePolicy.setHeightForWidth(cbOrder->sizePolicy().hasHeightForWidth());
        cbOrder->setSizePolicy(sizePolicy);
        cbOrder->setMaxVisibleItems(4);
        cbOrder->setFrame(true);

        horizontalLayout_2->addWidget(cbOrder);

        tbMatchCase = new QToolButton(frame_3);
        tbMatchCase->setObjectName("tbMatchCase");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("format-text-superscript");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        tbMatchCase->setIcon(icon);
        tbMatchCase->setCheckable(true);
        tbMatchCase->setAutoRaise(true);

        horizontalLayout_2->addWidget(tbMatchCase);

        tbSelectionOnly = new QToolButton(frame_3);
        tbSelectionOnly->setObjectName("tbSelectionOnly");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("edit-select-all");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        tbSelectionOnly->setIcon(icon1);
        tbSelectionOnly->setCheckable(true);
        tbSelectionOnly->setAutoRaise(true);

        horizontalLayout_2->addWidget(tbSelectionOnly);

        horizontalSpacer_2 = new QSpacerItem(213, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        tbFindNext = new QToolButton(frame_3);
        tbFindNext->setObjectName("tbFindNext");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("go-down-search");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        tbFindNext->setIcon(icon2);
        tbFindNext->setAutoRaise(true);

        horizontalLayout_2->addWidget(tbFindNext);

        tbFindPrev = new QToolButton(frame_3);
        tbFindPrev->setObjectName("tbFindPrev");
        QIcon icon3;
        iconThemeName = QString::fromUtf8("go-up-search");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        tbFindPrev->setIcon(icon3);
        tbFindPrev->setAutoRaise(true);

        horizontalLayout_2->addWidget(tbFindPrev);

        bReplaceNext = new QPushButton(frame_3);
        bReplaceNext->setObjectName("bReplaceNext");

        horizontalLayout_2->addWidget(bReplaceNext);

        bReplaceAll = new QPushButton(frame_3);
        bReplaceAll->setObjectName("bReplaceAll");

        horizontalLayout_2->addWidget(bReplaceAll);

        bFindAll = new QPushButton(frame_3);
        bFindAll->setObjectName("bFindAll");

        horizontalLayout_2->addWidget(bFindAll);

        tbSwitchFindReplace = new QToolButton(frame_3);
        tbSwitchFindReplace->setObjectName("tbSwitchFindReplace");
        QIcon icon4;
        iconThemeName = QString::fromUtf8("games-config-options");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        tbSwitchFindReplace->setIcon(icon4);
        tbSwitchFindReplace->setCheckable(true);
        tbSwitchFindReplace->setAutoRaise(true);

        horizontalLayout_2->addWidget(tbSwitchFindReplace);


        gridLayout->addWidget(frame_3, 5, 2, 1, 1);

        frame = new QFrame(SearchReplaceWidget);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Raised);
        gridLayout_5 = new QGridLayout(frame);
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setHorizontalSpacing(0);
        gridLayout_5->setContentsMargins(0, 0, 0, 0);
        frameNumeric = new QFrame(frame);
        frameNumeric->setObjectName("frameNumeric");
        frameNumeric->setFrameShape(QFrame::NoFrame);
        frameNumeric->setFrameShadow(QFrame::Raised);
        gridLayout_2 = new QGridLayout(frameNumeric);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        lMin = new QLabel(frameNumeric);
        lMin->setObjectName("lMin");

        gridLayout_2->addWidget(lMin, 0, 2, 1, 1);

        cbOperator = new QComboBox(frameNumeric);
        cbOperator->setObjectName("cbOperator");
        sizePolicy.setHeightForWidth(cbOperator->sizePolicy().hasHeightForWidth());
        cbOperator->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(cbOperator, 0, 0, 1, 1);

        lMax = new QLabel(frameNumeric);
        lMax->setObjectName("lMax");

        gridLayout_2->addWidget(lMax, 0, 4, 1, 1);

        cbValue1 = new QComboBox(frameNumeric);
        cbValue1->setObjectName("cbValue1");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbValue1->sizePolicy().hasHeightForWidth());
        cbValue1->setSizePolicy(sizePolicy1);
        cbValue1->setEditable(true);

        gridLayout_2->addWidget(cbValue1, 0, 1, 1, 1);

        lAnd = new QLabel(frameNumeric);
        lAnd->setObjectName("lAnd");

        gridLayout_2->addWidget(lAnd, 0, 3, 1, 1);

        cbValue2 = new QComboBox(frameNumeric);
        cbValue2->setObjectName("cbValue2");
        sizePolicy1.setHeightForWidth(cbValue2->sizePolicy().hasHeightForWidth());
        cbValue2->setSizePolicy(sizePolicy1);
        cbValue2->setEditable(true);

        gridLayout_2->addWidget(cbValue2, 0, 5, 1, 1);


        gridLayout_5->addWidget(frameNumeric, 0, 0, 1, 1);

        frameDateTime = new QFrame(frame);
        frameDateTime->setObjectName("frameDateTime");
        frameDateTime->setFrameShape(QFrame::NoFrame);
        frameDateTime->setFrameShadow(QFrame::Raised);
        gridLayout_4 = new QGridLayout(frameDateTime);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(0, 0, 0, 0);
        lMaxDateTime = new QLabel(frameDateTime);
        lMaxDateTime->setObjectName("lMaxDateTime");

        gridLayout_4->addWidget(lMaxDateTime, 0, 4, 1, 1);

        lMinDateTime = new QLabel(frameDateTime);
        lMinDateTime->setObjectName("lMinDateTime");

        gridLayout_4->addWidget(lMinDateTime, 0, 1, 1, 1);

        lAndDateTime = new QLabel(frameDateTime);
        lAndDateTime->setObjectName("lAndDateTime");

        gridLayout_4->addWidget(lAndDateTime, 0, 3, 1, 1);

        cbOperatorDateTime = new QComboBox(frameDateTime);
        cbOperatorDateTime->setObjectName("cbOperatorDateTime");
        sizePolicy.setHeightForWidth(cbOperatorDateTime->sizePolicy().hasHeightForWidth());
        cbOperatorDateTime->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(cbOperatorDateTime, 0, 0, 1, 1);

        dteValue1 = new QDateTimeEdit(frameDateTime);
        dteValue1->setObjectName("dteValue1");
        sizePolicy1.setHeightForWidth(dteValue1->sizePolicy().hasHeightForWidth());
        dteValue1->setSizePolicy(sizePolicy1);
        dteValue1->setTimeSpec(Qt::UTC);

        gridLayout_4->addWidget(dteValue1, 0, 2, 1, 1);

        dteValue2 = new QDateTimeEdit(frameDateTime);
        dteValue2->setObjectName("dteValue2");
        sizePolicy1.setHeightForWidth(dteValue2->sizePolicy().hasHeightForWidth());
        dteValue2->setSizePolicy(sizePolicy1);
        dteValue2->setTimeSpec(Qt::UTC);

        gridLayout_4->addWidget(dteValue2, 0, 5, 1, 1);


        gridLayout_5->addWidget(frameDateTime, 2, 0, 1, 1);

        frameText = new QFrame(frame);
        frameText->setObjectName("frameText");
        frameText->setFrameShape(QFrame::NoFrame);
        frameText->setFrameShadow(QFrame::Raised);
        gridLayout_3 = new QGridLayout(frameText);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        cbOperatorText = new QComboBox(frameText);
        cbOperatorText->setObjectName("cbOperatorText");
        sizePolicy.setHeightForWidth(cbOperatorText->sizePolicy().hasHeightForWidth());
        cbOperatorText->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(cbOperatorText, 0, 0, 1, 1);

        cbValueText = new QComboBox(frameText);
        cbValueText->setObjectName("cbValueText");
        sizePolicy1.setHeightForWidth(cbValueText->sizePolicy().hasHeightForWidth());
        cbValueText->setSizePolicy(sizePolicy1);
        cbValueText->setEditable(true);

        gridLayout_3->addWidget(cbValueText, 0, 1, 1, 1);


        gridLayout_5->addWidget(frameText, 1, 0, 1, 1);


        gridLayout->addWidget(frame, 1, 2, 1, 1);

        bCancel = new QPushButton(SearchReplaceWidget);
        bCancel->setObjectName("bCancel");
        QIcon icon5;
        iconThemeName = QString::fromUtf8("dialog-close");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon5 = QIcon::fromTheme(iconThemeName);
        } else {
            icon5.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        bCancel->setIcon(icon5);

        gridLayout->addWidget(bCancel, 0, 3, 1, 1);

        cbReplace = new QComboBox(SearchReplaceWidget);
        cbReplace->setObjectName("cbReplace");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(9);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cbReplace->sizePolicy().hasHeightForWidth());
        cbReplace->setSizePolicy(sizePolicy2);
        cbReplace->setEditable(true);
        cbReplace->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        gridLayout->addWidget(cbReplace, 2, 2, 1, 1);

        lDataType = new QLabel(SearchReplaceWidget);
        lDataType->setObjectName("lDataType");
        lDataType->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lDataType, 0, 0, 1, 1);

        dteReplace = new QDateTimeEdit(SearchReplaceWidget);
        dteReplace->setObjectName("dteReplace");
        sizePolicy1.setHeightForWidth(dteReplace->sizePolicy().hasHeightForWidth());
        dteReplace->setSizePolicy(sizePolicy1);
        dteReplace->setTimeSpec(Qt::UTC);

        gridLayout->addWidget(dteReplace, 4, 2, 1, 1);

        lReplaceText = new QLabel(SearchReplaceWidget);
        lReplaceText->setObjectName("lReplaceText");

        gridLayout->addWidget(lReplaceText, 3, 0, 1, 1);

        cbReplaceText = new QComboBox(SearchReplaceWidget);
        cbReplaceText->setObjectName("cbReplaceText");
        sizePolicy2.setHeightForWidth(cbReplaceText->sizePolicy().hasHeightForWidth());
        cbReplaceText->setSizePolicy(sizePolicy2);
        cbReplaceText->setEditable(true);
        cbReplaceText->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        gridLayout->addWidget(cbReplaceText, 3, 2, 1, 1);

#if QT_CONFIG(shortcut)
        lOrder->setBuddy(cbOrder);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SearchReplaceWidget);

        QMetaObject::connectSlotsByName(SearchReplaceWidget);
    } // setupUi

    void retranslateUi(QWidget *SearchReplaceWidget)
    {
        SearchReplaceWidget->setWindowTitle(tr2i18n("Form", nullptr));
        lOrder->setText(tr2i18n("Order:", nullptr));
        lReplaceDateTime->setText(tr2i18n("Replace:", nullptr));
        lReplace->setText(tr2i18n("Replace:", nullptr));
        lFind->setText(tr2i18n("Find:", nullptr));
#if QT_CONFIG(tooltip)
        cbOrder->setToolTip(tr2i18n("Search order", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tbMatchCase->setToolTip(tr2i18n("Match case sensitive", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tbSelectionOnly->setToolTip(tr2i18n("Search in the selection only", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tbFindNext->setToolTip(tr2i18n("Jump to next match", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tbFindPrev->setToolTip(tr2i18n("Jump to previous match", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        bReplaceNext->setToolTip(tr2i18n("Replace next match", nullptr));
#endif // QT_CONFIG(tooltip)
        bReplaceNext->setText(tr2i18n("&Replace", nullptr));
#if QT_CONFIG(tooltip)
        bReplaceAll->setToolTip(tr2i18n("Replace all matches", nullptr));
#endif // QT_CONFIG(tooltip)
        bReplaceAll->setText(tr2i18n("Replace &All", nullptr));
        bFindAll->setText(tr2i18n("&Find All", nullptr));
#if QT_CONFIG(tooltip)
        tbSwitchFindReplace->setToolTip(tr2i18n("Switch to incremental search bar", nullptr));
#endif // QT_CONFIG(tooltip)
        tbSwitchFindReplace->setText(QString());
        lMin->setText(tr2i18n("min.", nullptr));
        lMax->setText(tr2i18n("max.", nullptr));
        lAnd->setText(tr2i18n("and", nullptr));
        lMaxDateTime->setText(tr2i18n("max.", nullptr));
        lMinDateTime->setText(tr2i18n("min.", nullptr));
        lAndDateTime->setText(tr2i18n("and", nullptr));
        bCancel->setText(QString());
#if QT_CONFIG(tooltip)
        cbReplace->setToolTip(tr2i18n("Text to replace with", nullptr));
#endif // QT_CONFIG(tooltip)
        lDataType->setText(tr2i18n("Type:", nullptr));
        lReplaceText->setText(tr2i18n("Replace:", nullptr));
#if QT_CONFIG(tooltip)
        cbReplaceText->setToolTip(tr2i18n("Text to replace with", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class SearchReplaceWidget: public Ui_SearchReplaceWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEARCHREPLACEWIDGET_H

